from typing import List as List_, Optional as Optional_, Literal as Literal_, Annotated as Annotated_, NewType as NewType_

from pydantic import BaseModel as BaseModel
from pydantic import Field, Extra


class Element(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Base definition for all elements in a resource."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class BackboneElement(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Base definition for all elements that are defined inside a resource - but not those in a data type."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


base64Binary = NewType_('base64Binary', str)


'A stream of bytes'


boolean = NewType_('boolean', bool)


'Value of "true" or "false"'


canonical = NewType_('canonical', str)


'A URI that is a reference to a canonical URL on a FHIR resource'


code = NewType_('code', str)


'A string which has at least one character and no leading or trailing whitespace and where there is no whitespace other than single spaces in the contents'


date = NewType_('date', str)


'A date or partial date (e.g. just year or year + month). There is no time zone. The format is a union of the schema types gYear, gYearMonth and date.  Dates SHALL be valid dates.'


dateTime = NewType_('dateTime', str)


'A date, date-time or partial date (e.g. just year or year + month).  If hours and minutes are specified, a time zone SHALL be populated. The format is a union of the schema types gYear, gYearMonth, date and dateTime. Seconds must be provided due to schema type constraints but may be zero-filled and may be ignored.                 Dates SHALL be valid dates.'


decimal = NewType_('decimal', int)


'A rational number with implicit precision'


id = NewType_('id', str)


'Any combination of letters, numerals, "-" and ".", with a length limit of 64 characters.  (This might be an integer, an unprefixed OID, UUID or any other identifier pattern that meets these constraints.)  Ids are case-insensitive.'


instant = NewType_('instant', str)


'An instant in time - known at least to the second'


integer = NewType_('integer', int)


'A whole number'


markdown = NewType_('markdown', str)


'A string that may contain Github Flavored Markdown syntax for optional processing by a mark down presentation engine'


oid = NewType_('oid', str)


'An OID represented as a URI'


positiveInt = NewType_('positiveInt', str)


'An integer with a value that is positive (e.g. >0)'


string = NewType_('string', str)


'A sequence of Unicode characters'


time = NewType_('time', str)


'A time during the day, with no date specified'


unsignedInt = NewType_('unsignedInt', str)


'An integer with a value that is not negative (e.g. >= 0)'


uri = NewType_('uri', str)


'String of characters used to identify a name or a resource'


url = NewType_('url', str)


'A URI that is a literal reference'


uuid = NewType_('uuid', str)


'A UUID, represented as a URI'


xhtml = NewType_('xhtml', str)


'XHTML'


class Address(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An address expressed using postal conventions (as opposed to GPS or other location definition formats).  This data type may be used to convey addresses for use in delivering mail as well as for visiting locations which might not be valid for mail delivery.  There are a variety of postal address formats defined around the world."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: Optional_['code'] = Field(default=None)
    'The purpose of this address.'
    type: Optional_['code'] = Field(default=None)
    'Distinguishes between physical addresses (those you can visit) and mailing addresses (e.g. PO Boxes and care-of addresses). Most addresses are both.'
    text: Optional_['string'] = Field(default=None)
    'Specifies the entire address as it should be displayed e.g. on a postal label. This may be provided instead of or as well as the specific parts.'
    line: List_['string'] = Field(default_factory=list)
    'This component contains the house number, apartment number, street name, street direction,  P.O. Box number, delivery hints, and similar address information.'
    city: Optional_['string'] = Field(default=None)
    'The name of the city, town, suburb, village or other community or delivery center.'
    state: Optional_['string'] = Field(default=None)
    'Sub-unit of a country with limited sovereignty in a federally organized country. A code may be used if codes are in common use (e.g. US 2 letter state codes).'
    period: Optional_['Period'] = Field(default=None)
    'Time period when address was/is in use.'
    country: Optional_['string'] = Field(default=None)
    'Country - a nation as commonly understood or generally accepted.'
    district: Optional_['string'] = Field(default=None)
    'The name of the administrative area (county).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    postalCode: Optional_['string'] = Field(default=None)
    'A postal code designating a region defined by the postal service.'


class Age(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A duration of time during which an organism (or a process) has existed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    unit: Optional_['string'] = Field(default=None)
    'A human-readable form of the unit.'
    value: Optional_['decimal'] = Field(default=None)
    'The value of the measured amount. The value includes an implicit precision in the presentation of the value.'
    system: Optional_['uri'] = Field(default=None)
    'The identification of the system that provides the coded form of the unit.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    comparator: Optional_['code'] = Field(default=None)
    'How the value should be understood and represented - whether the actual value is greater or less than the stated value due to measurement issues; e.g. if the comparator is "<" , then the real value is < stated value.'
    code: Optional_['code'] = Field(default=None)
    'A computer processable form of the unit in some unit representation system.'


class Annotation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A  text note which also  contains information about who made the statement and when."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    time: Optional_['dateTime'] = Field(default=None)
    'Indicates when this particular annotation was made.'
    text: 'markdown' = Field(default=...)
    'The text of the annotation in markdown format.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    authorReference: Optional_['Reference'] = Field(default=None)
    'The individual responsible for making the annotation.'
    authorString: Optional_['string'] = Field(default=None)
    'The individual responsible for making the annotation.'


class Attachment(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """For referring to data content defined in other formats."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    data: Optional_['base64Binary'] = Field(default=None)
    'The actual data of the attachment - a sequence of bytes, base64 encoded.'
    size: Optional_['unsignedInt'] = Field(default=None)
    'The number of bytes of data that make up this attachment (before base64 encoding, if that is done).'
    hash: Optional_['base64Binary'] = Field(default=None)
    'The calculated hash of the data using SHA-1. Represented using base64.'
    title: Optional_['string'] = Field(default=None)
    'A label or set of text to display in place of the data.'
    language: Optional_['code'] = Field(default=None)
    'The human language of the content. The value can be any valid value according to BCP 47.'
    creation: Optional_['dateTime'] = Field(default=None)
    'The date that the attachment was first created.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    contentType: Optional_['code'] = Field(default=None)
    'Identifies the type of the data in the attachment and allows a method to be chosen to interpret or render the data. Includes mime type parameters such as charset where appropriate.'
    url: Optional_['url'] = Field(default=None)
    'A location where the data can be accessed.'


class CodeableConcept(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A concept that may be defined by a formal reference to a terminology or ontology or may be provided by text."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    text: Optional_['string'] = Field(default=None)
    'A human language representation of the concept as seen/selected/uttered by the user who entered the data and/or which represents the intended meaning of the user.'
    coding: List_['Coding'] = Field(default_factory=list)
    'A reference to a code defined by a terminology system.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class CodeableReference(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A reference to a resource (by instance), or instead, a reference to a concept defined in a terminology or ontology (by class)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    concept: Optional_['CodeableConcept'] = Field(default=None)
    'A reference to a concept - e.g. the information is identified by its general class to the degree of precision found in the terminology.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: Optional_['Reference'] = Field(default=None)
    'A reference to a resource the provides exact details about the information being referenced.'


class Coding(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A reference to a code defined by a terminology system."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    system: Optional_['uri'] = Field(default=None)
    'The identification of the code system that defines the meaning of the symbol in the code.'
    version: Optional_['string'] = Field(default=None)
    'The version of the code system which was used when choosing this code. Note that a well-maintained code system does not need the version reported, because the meaning of codes is consistent across versions. However this cannot consistently be assured, and when the meaning is not guaranteed to be consistent, the version SHOULD be exchanged.'
    display: Optional_['string'] = Field(default=None)
    'A representation of the meaning of the code in the system, following the rules of the system.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    userSelected: Optional_['boolean'] = Field(default=None)
    'Indicates that this coding was chosen by a user directly - e.g. off a pick list of available items (codes or displays).'
    code: Optional_['code'] = Field(default=None)
    'A symbol in syntax defined by the system. The symbol may be a predefined code or an expression in a syntax defined by the coding system (e.g. post-coordination).'


class ContactDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies contact information for a person or organization."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'The name of an individual to contact.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'The contact details for the individual (if a name was provided) or the organization.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class ContactPoint(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details for all kinds of technology mediated contact points for a person or organization, including telephone, email, etc."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: Optional_['code'] = Field(default=None)
    'Identifies the purpose for the contact point.'
    rank: Optional_['positiveInt'] = Field(default=None)
    'Specifies a preferred order in which to use a set of contacts. ContactPoints with lower rank values are more preferred than those with higher rank values.'
    value: Optional_['string'] = Field(default=None)
    'The actual contact point details, in a form that is meaningful to the designated communication system (i.e. phone number or email address).'
    system: Optional_['code'] = Field(default=None)
    'Telecommunications form for contact point - what communications system is required to make use of the contact.'
    period: Optional_['Period'] = Field(default=None)
    'Time period when the contact point was/is in use.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class Contributor(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A contributor to the content of a knowledge asset, including authors, editors, reviewers, and endorsers."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of contributor.'
    name: 'string' = Field(default=...)
    'The name of the individual or organization responsible for the contribution.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the contributor.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class Count(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    unit: Optional_['string'] = Field(default=None)
    'A human-readable form of the unit.'
    value: Optional_['decimal'] = Field(default=None)
    'The value of the measured amount. The value includes an implicit precision in the presentation of the value.'
    system: Optional_['uri'] = Field(default=None)
    'The identification of the system that provides the coded form of the unit.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    comparator: Optional_['code'] = Field(default=None)
    'How the value should be understood and represented - whether the actual value is greater or less than the stated value due to measurement issues; e.g. if the comparator is "<" , then the real value is < stated value.'
    code: Optional_['code'] = Field(default=None)
    'A computer processable form of the unit in some unit representation system.'


class DataRequirementDateFilter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Date filters specify additional constraints on the data in terms of the applicable date range for specific elements. Each date filter specifies an additional constraint on the data, i.e. date filters are AND'ed, not OR'ed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    path: Optional_['string'] = Field(default=None)
    'The date-valued attribute of the filter. The specified path SHALL be a FHIRPath resolveable on the specified type of the DataRequirement, and SHALL consist only of identifiers, constant indexers, and .resolve(). The path is allowed to contain qualifiers (.) to traverse sub-elements, as well as indexers ([x]) to traverse multiple-cardinality sub-elements (see the [Simple FHIRPath Profile](fhirpath.html#simple) for full details). Note that the index must be an integer constant. The path must resolve to an element of type date, dateTime, Period, Schedule, or Timing.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The value of the filter. If period is specified, the filter will return only those data items that fall within the bounds determined by the Period, inclusive of the period boundaries. If dateTime is specified, the filter will return only those data items that are equal to the specified dateTime. If a Duration is specified, the filter will return only those data items that fall within Duration before now.'
    valuePeriod: Optional_['Period'] = Field(default=None)
    'The value of the filter. If period is specified, the filter will return only those data items that fall within the bounds determined by the Period, inclusive of the period boundaries. If dateTime is specified, the filter will return only those data items that are equal to the specified dateTime. If a Duration is specified, the filter will return only those data items that fall within Duration before now.'
    valueDuration: Optional_['Duration'] = Field(default=None)
    'The value of the filter. If period is specified, the filter will return only those data items that fall within the bounds determined by the Period, inclusive of the period boundaries. If dateTime is specified, the filter will return only those data items that are equal to the specified dateTime. If a Duration is specified, the filter will return only those data items that fall within Duration before now.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    searchParam: Optional_['string'] = Field(default=None)
    'A date parameter that refers to a search parameter defined on the specified type of the DataRequirement, and which searches on elements of type date, dateTime, Period, Schedule, or Timing.'


class DataRequirementCodeFilter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Code filters specify additional constraints on the data, specifying the value set of interest for a particular element of the data. Each code filter defines an additional constraint on the data, i.e. code filters are AND'ed, not OR'ed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    path: Optional_['string'] = Field(default=None)
    'The code-valued attribute of the filter. The specified path SHALL be a FHIRPath resolveable on the specified type of the DataRequirement, and SHALL consist only of identifiers, constant indexers, and .resolve(). The path is allowed to contain qualifiers (.) to traverse sub-elements, as well as indexers ([x]) to traverse multiple-cardinality sub-elements (see the [Simple FHIRPath Profile](fhirpath.html#simple) for full details). Note that the index must be an integer constant. The path must resolve to an element of type code, Coding, or CodeableConcept.'
    code: List_['Coding'] = Field(default_factory=list)
    'The codes for the code filter. If values are given, the filter will return only those data items for which the code-valued attribute specified by the path has a value that is one of the specified codes. If codes are specified in addition to a value set, the filter returns items matching a code in the value set or one of the specified codes.'
    valueSet: Optional_['canonical'] = Field(default=None)
    'The valueset for the code filter. The valueSet and code elements are additive. If valueSet is specified, the filter will return only those data items for which the value of the code-valued element specified in the path is a member of the specified valueset.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    searchParam: Optional_['string'] = Field(default=None)
    'A token parameter that refers to a search parameter defined on the specified type of the DataRequirement, and which searches on elements of type code, Coding, or CodeableConcept.'


class DataRequirementSort(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies the order of the results to be returned."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    path: 'string' = Field(default=...)
    'The attribute of the sort. The specified path must be resolvable from the type of the required data. The path is allowed to contain qualifiers (.) to traverse sub-elements, as well as indexers ([x]) to traverse multiple-cardinality sub-elements. Note that the index must be an integer constant.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    direction: 'code' = Field(default=...)
    'The direction of the sort, ascending or descending.'


class DataRequirement(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes a required data item for evaluation in terms of the type of data, and optional code or date-based filters of the data."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of the required data, specified as the type name of a resource. For profiles, this value is set to the type of the base resource of the profile.'
    sort: List_['DataRequirementSort'] = Field(default_factory=list)
    'Specifies the order of the results to be returned.'
    limit: Optional_['positiveInt'] = Field(default=None)
    'Specifies a maximum number of results that are required (uses the _count search parameter).'
    profile: List_['canonical'] = Field(default_factory=list)
    'The profile of the required data, specified as the uri of the profile definition.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    subjectCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The intended subjects of the data requirement. If this element is not provided, a Patient subject is assumed.'
    subjectReference: Optional_['Reference'] = Field(default=None)
    'The intended subjects of the data requirement. If this element is not provided, a Patient subject is assumed.'
    codeFilter: List_['DataRequirementCodeFilter'] = Field(default_factory=list)
    "Code filters specify additional constraints on the data, specifying the value set of interest for a particular element of the data. Each code filter defines an additional constraint on the data, i.e. code filters are AND'ed, not OR'ed."
    dateFilter: List_['DataRequirementDateFilter'] = Field(default_factory=list)
    "Date filters specify additional constraints on the data in terms of the applicable date range for specific elements. Each date filter specifies an additional constraint on the data, i.e. date filters are AND'ed, not OR'ed."
    mustSupport: List_['string'] = Field(default_factory=list)
    'Indicates that specific elements of the type are referenced by the knowledge module and must be supported by the consumer in order to obtain an effective evaluation. This does not mean that a value is required for this element, only that the consuming system must understand the element and be able to provide values for it if they are available. \n\nThe value of mustSupport SHALL be a FHIRPath resolveable on the type of the DataRequirement. The path SHALL consist only of identifiers, constant indexers, and .resolve() (see the [Simple FHIRPath Profile](fhirpath.html#simple) for full details).'


class Distance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A length - a value with a unit that is a physical distance."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    unit: Optional_['string'] = Field(default=None)
    'A human-readable form of the unit.'
    value: Optional_['decimal'] = Field(default=None)
    'The value of the measured amount. The value includes an implicit precision in the presentation of the value.'
    system: Optional_['uri'] = Field(default=None)
    'The identification of the system that provides the coded form of the unit.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    comparator: Optional_['code'] = Field(default=None)
    'How the value should be understood and represented - whether the actual value is greater or less than the stated value due to measurement issues; e.g. if the comparator is "<" , then the real value is < stated value.'
    code: Optional_['code'] = Field(default=None)
    'A computer processable form of the unit in some unit representation system.'


class DosageDoseAndRate(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The amount of medication administered."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of dose or rate specified, for example, ordered or calculated.'
    doseRange: Optional_['Range'] = Field(default=None)
    'Amount of medication per dose.'
    doseQuantity: Optional_['Quantity'] = Field(default=None)
    'Amount of medication per dose.'
    rateRatio: Optional_['Ratio'] = Field(default=None)
    'Amount of medication per unit of time.'
    rateRange: Optional_['Range'] = Field(default=None)
    'Amount of medication per unit of time.'
    rateQuantity: Optional_['Quantity'] = Field(default=None)
    'Amount of medication per unit of time.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class Dosage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates how the medication is/was taken or should be taken by the patient."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    text: Optional_['string'] = Field(default=None)
    'Free text dosage instructions e.g. SIG.'
    site: Optional_['CodeableConcept'] = Field(default=None)
    'Body site to administer to.'
    route: Optional_['CodeableConcept'] = Field(default=None)
    'How drug should enter body.'
    timing: Optional_['Timing'] = Field(default=None)
    'When medication should be administered.'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'Technique for administering medication.'
    sequence: Optional_['integer'] = Field(default=None)
    'Indicates the order in which the dosage instructions should be applied or interpreted.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    asNeededBoolean: Optional_['boolean'] = Field(default=None)
    'Indicates whether the Medication is only taken when needed within a specific dosing schedule (Boolean option), or it indicates the precondition for taking the Medication (CodeableConcept).'
    asNeededCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates whether the Medication is only taken when needed within a specific dosing schedule (Boolean option), or it indicates the precondition for taking the Medication (CodeableConcept).'
    doseAndRate: List_['DosageDoseAndRate'] = Field(default_factory=list)
    'The amount of medication administered.'
    maxDosePerPeriod: Optional_['Ratio'] = Field(default=None)
    'Upper limit on medication per unit of time.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    patientInstruction: Optional_['string'] = Field(default=None)
    'Instructions in terms that are understood by the patient or consumer.'
    maxDosePerLifetime: Optional_['Quantity'] = Field(default=None)
    'Upper limit on medication per lifetime of the patient.'
    additionalInstruction: List_['CodeableConcept'] = Field(default_factory=list)
    'Supplemental instructions to the patient on how to take the medication  (e.g. "with meals" or"take half to one hour before food") or warnings for the patient about the medication (e.g. "may cause drowsiness" or "avoid exposure of skin to direct sunlight or sunlamps").'
    maxDosePerAdministration: Optional_['Quantity'] = Field(default=None)
    'Upper limit on medication per administration.'


class Duration(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A length of time."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    unit: Optional_['string'] = Field(default=None)
    'A human-readable form of the unit.'
    value: Optional_['decimal'] = Field(default=None)
    'The value of the measured amount. The value includes an implicit precision in the presentation of the value.'
    system: Optional_['uri'] = Field(default=None)
    'The identification of the system that provides the coded form of the unit.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    comparator: Optional_['code'] = Field(default=None)
    'How the value should be understood and represented - whether the actual value is greater or less than the stated value due to measurement issues; e.g. if the comparator is "<" , then the real value is < stated value.'
    code: Optional_['code'] = Field(default=None)
    'A computer processable form of the unit in some unit representation system.'


class ElementDefinitionConstraint(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Formal constraints such as co-occurrence and other constraints that can be computationally evaluated within the context of the instance."""
    key: 'id' = Field(default=...)
    'Allows identification of which elements have their cardinalities impacted by the constraint.  Will not be referenced for constraints that do not affect cardinality.'
    human: 'string' = Field(default=...)
    'Text that can be used to describe the constraint in messages identifying that the constraint has been violated.'
    xpath: Optional_['string'] = Field(default=None)
    'An XPath expression of constraint that can be executed to see if this constraint is met.'
    source: Optional_['canonical'] = Field(default=None)
    'A reference to the original source of the constraint, for traceability purposes.'
    severity: 'code' = Field(default=...)
    'Identifies the impact constraint violation has on the conformance of the instance.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: Optional_['string'] = Field(default=None)
    'A [FHIRPath](fhirpath.html) expression of constraint that can be executed to see if this constraint is met.'
    requirements: Optional_['string'] = Field(default=None)
    'Description of why this constraint is necessary or appropriate.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class ElementDefinitionMapping(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies a concept from an external specification that roughly corresponds to this element."""
    map: 'string' = Field(default=...)
    'Expresses what part of the target specification corresponds to this element.'
    comment: Optional_['string'] = Field(default=None)
    'Comments that provide information about the mapping or its use.'
    identity: 'id' = Field(default=...)
    'An internal reference to the definition of a mapping.'
    language: Optional_['code'] = Field(default=None)
    'Identifies the computable language in which mapping.map is expressed.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class ElementDefinitionBinding(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Binds to a value set if this element is coded (code, Coding, CodeableConcept, Quantity), or the data types (string, uri)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    strength: 'code' = Field(default=...)
    'Indicates the degree of conformance expectations associated with this binding - that is, the degree to which the provided value set must be adhered to in the instances.'
    valueSet: Optional_['canonical'] = Field(default=None)
    'Refers to the value set that identifies the set of codes the binding refers to.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'Describes the intended use of this particular set of codes.'


class ElementDefinitionExample(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A sample value for this element demonstrating the type of information that would typically be found in the element."""
    label: 'string' = Field(default=...)
    'Describes the purpose of this example amoung the set of examples.'
    valueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueCanonical: Optional_['canonical'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueCode: Optional_['code'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueDate: Optional_['date'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueId: Optional_['id'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueInstant: Optional_['instant'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueMarkdown: Optional_['markdown'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueOid: Optional_['oid'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valuePositiveInt: Optional_['positiveInt'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueString: Optional_['string'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueTime: Optional_['time'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueUri: Optional_['uri'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueUrl: Optional_['url'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueUuid: Optional_['uuid'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueAddress: Optional_['Address'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueAge: Optional_['Age'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueAnnotation: Optional_['Annotation'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueCodeableReference: Optional_['CodeableReference'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueCoding: Optional_['Coding'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueContactPoint: Optional_['ContactPoint'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueCount: Optional_['Count'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueDistance: Optional_['Distance'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueDuration: Optional_['Duration'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueHumanName: Optional_['HumanName'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueIdentifier: Optional_['Identifier'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueMoney: Optional_['Money'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valuePeriod: Optional_['Period'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueRange: Optional_['Range'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueRatio: Optional_['Ratio'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueRatioRange: Optional_['RatioRange'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueSampledData: Optional_['SampledData'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueSignature: Optional_['Signature'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueTiming: Optional_['Timing'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueContactDetail: Optional_['ContactDetail'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueContributor: Optional_['Contributor'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueExpression: Optional_['Expression'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueParameterDefinition: Optional_['ParameterDefinition'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueRelatedArtifact: Optional_['RelatedArtifact'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueTriggerDefinition: Optional_['TriggerDefinition'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueUsageContext: Optional_['UsageContext'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    valueDosage: Optional_['Dosage'] = Field(default=None)
    'The actual value for the element, which must be one of the types allowed for this element.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class ElementDefinitionSlicing(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates that the element is sliced into a set of alternative definitions (i.e. in a structure definition, there are multiple different constraints on a single element in the base resource). Slicing can be used in any resource that has cardinality ..* on the base resource, or any resource with a choice of types. The set of slices is any elements that come after this in the element sequence that have the same path, until a shorter path occurs (the shorter path terminates the set)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    rules: 'code' = Field(default=...)
    'Whether additional slices are allowed or not. When the slices are ordered, profile authors can also say that additional slices are only allowed at the end.'
    ordered: Optional_['boolean'] = Field(default=None)
    'If the matching elements have to occur in the same order as defined in the profile.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'A human-readable text description of how the slicing works. If there is no discriminator, this is required to be present to provide whatever information is possible about how the slices can be differentiated.'
    discriminator: List_['ElementDefinitionSlicingDiscriminator'] = Field(default_factory=list)
    'Designates which child elements are used to discriminate between the slices when processing an instance. If one or more discriminators are provided, the value of the child elements in the instance data SHALL completely distinguish which slice the element in the resource matches based on the allowed values for those elements in each of the slices.'


class ElementDefinitionSlicingDiscriminator(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Designates which child elements are used to discriminate between the slices when processing an instance. If one or more discriminators are provided, the value of the child elements in the instance data SHALL completely distinguish which slice the element in the resource matches based on the allowed values for those elements in each of the slices."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'How the element value is interpreted when discrimination is evaluated.'
    path: 'string' = Field(default=...)
    'A FHIRPath expression, using [the simple subset of FHIRPath](fhirpath.html#simple), that is used to identify the element on which discrimination is based.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class ElementDefinitionType(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The data type or resource that the value of this element is permitted to be."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    profile: List_['canonical'] = Field(default_factory=list)
    'Identifies a profile structure or implementation Guide that applies to the datatype this element refers to. If any profiles are specified, then the content must conform to at least one of them. The URL can be a local reference - to a contained StructureDefinition, or a reference to another StructureDefinition or Implementation Guide by a canonical URL. When an implementation guide is specified, the type SHALL conform to at least one profile defined in the implementation guide.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    versioning: Optional_['code'] = Field(default=None)
    'Whether this reference needs to be version specific or version independent, or whether either can be used.'
    aggregation: List_['code'] = Field(default_factory=list)
    'If the type is a reference to another resource, how the resource is or can be aggregated - is it a contained resource, or a reference, and if the context is a bundle, is it included in the bundle.'
    targetProfile: List_['canonical'] = Field(default_factory=list)
    'Used when the type is "Reference" or "canonical", and identifies a profile structure or implementation Guide that applies to the target of the reference this element refers to. If any profiles are specified, then the content must conform to at least one of them. The URL can be a local reference - to a contained StructureDefinition, or a reference to another StructureDefinition or Implementation Guide by a canonical URL. When an implementation guide is specified, the target resource SHALL conform to at least one profile defined in the implementation guide.'
    code: 'uri' = Field(default=...)
    'URL of Data type or Resource that is a(or the) type used for this element. References are URLs that are relative to http://hl7.org/fhir/StructureDefinition e.g. "string" is a reference to http://hl7.org/fhir/StructureDefinition/string. Absolute URLs are only allowed in logical models.'


class ElementDefinitionBase(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the base definition of the element, provided to make it unnecessary for tools to trace the deviation of the element through the derived and related profiles. When the element definition is not the original definition of an element - i.g. either in a constraint on another type, or for elements from a super type in a snap shot - then the information in provided in the element definition may be different to the base definition. On the original definition of the element, it will be same."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    min: 'unsignedInt' = Field(default=...)
    'Minimum cardinality of the base element identified by the path.'
    max: 'string' = Field(default=...)
    'Maximum cardinality of the base element identified by the path.'
    path: 'string' = Field(default=...)
    'The Path that identifies the base element - this matches the ElementDefinition.path for that element. Across FHIR, there is only one base definition of any element - that is, an element definition on a [StructureDefinition](structuredefinition.html#) without a StructureDefinition.base.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class ElementDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Captures constraints on each element within the resource, profile, or extension."""
    min: Optional_['unsignedInt'] = Field(default=None)
    'The minimum number of times this element SHALL appear in the instance.'
    max: Optional_['string'] = Field(default=None)
    'The maximum number of times this element is permitted to appear in the instance.'
    path: 'string' = Field(default=...)
    'The path identifies the element and is expressed as a "."-separated list of ancestor elements, beginning with the name of the resource or extension.'
    base: Optional_['ElementDefinitionBase'] = Field(default=None)
    'Information about the base definition of the element, provided to make it unnecessary for tools to trace the deviation of the element through the derived and related profiles. When the element definition is not the original definition of an element - i.g. either in a constraint on another type, or for elements from a super type in a snap shot - then the information in provided in the element definition may be different to the base definition. On the original definition of the element, it will be same.'
    type: List_['ElementDefinitionType'] = Field(default_factory=list)
    'The data type or resource that the value of this element is permitted to be.'
    label: Optional_['string'] = Field(default=None)
    'A single preferred label which is the text to display beside the element indicating its meaning or to use to prompt for the element in a user display or form.'
    short: Optional_['string'] = Field(default=None)
    'A concise description of what this element means (e.g. for use in autogenerated summaries).'
    alias: List_['string'] = Field(default_factory=list)
    'Identifies additional names by which this element might also be known.'
    slicing: Optional_['ElementDefinitionSlicing'] = Field(default=None)
    'Indicates that the element is sliced into a set of alternative definitions (i.e. in a structure definition, there are multiple different constraints on a single element in the base resource). Slicing can be used in any resource that has cardinality ..* on the base resource, or any resource with a choice of types. The set of slices is any elements that come after this in the element sequence that have the same path, until a shorter path occurs (the shorter path terminates the set).'
    comment: Optional_['markdown'] = Field(default=None)
    'Explanatory notes and implementation guidance about the data element, including notes about how to use the data properly, exceptions to proper use, etc. (Note: The text you are reading is specified in ElementDefinition.comment).'
    example: List_['ElementDefinitionExample'] = Field(default_factory=list)
    'A sample value for this element demonstrating the type of information that would typically be found in the element.'
    binding: Optional_['ElementDefinitionBinding'] = Field(default=None)
    'Binds to a value set if this element is coded (code, Coding, CodeableConcept, Quantity), or the data types (string, uri).'
    mapping: List_['ElementDefinitionMapping'] = Field(default_factory=list)
    'Identifies a concept from an external specification that roughly corresponds to this element.'
    fixedBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedBoolean: Optional_['boolean'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedCanonical: Optional_['canonical'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedCode: Optional_['code'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedDate: Optional_['date'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedDateTime: Optional_['dateTime'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedDecimal: Optional_['decimal'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedId: Optional_['id'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedInstant: Optional_['instant'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedInteger: Optional_['integer'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedMarkdown: Optional_['markdown'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedOid: Optional_['oid'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedPositiveInt: Optional_['positiveInt'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedString: Optional_['string'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedTime: Optional_['time'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedUri: Optional_['uri'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedUrl: Optional_['url'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedUuid: Optional_['uuid'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedAddress: Optional_['Address'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedAge: Optional_['Age'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedAnnotation: Optional_['Annotation'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedAttachment: Optional_['Attachment'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedCodeableReference: Optional_['CodeableReference'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedCoding: Optional_['Coding'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedContactPoint: Optional_['ContactPoint'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedCount: Optional_['Count'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedDistance: Optional_['Distance'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedDuration: Optional_['Duration'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedHumanName: Optional_['HumanName'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedIdentifier: Optional_['Identifier'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedMoney: Optional_['Money'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedPeriod: Optional_['Period'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedQuantity: Optional_['Quantity'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedRange: Optional_['Range'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedRatio: Optional_['Ratio'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedRatioRange: Optional_['RatioRange'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedReference: Optional_['Reference'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedSampledData: Optional_['SampledData'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedSignature: Optional_['Signature'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedTiming: Optional_['Timing'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedContactDetail: Optional_['ContactDetail'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedContributor: Optional_['Contributor'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedExpression: Optional_['Expression'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedParameterDefinition: Optional_['ParameterDefinition'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedRelatedArtifact: Optional_['RelatedArtifact'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedTriggerDefinition: Optional_['TriggerDefinition'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedUsageContext: Optional_['UsageContext'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    fixedDosage: Optional_['Dosage'] = Field(default=None)
    'Specifies a value that SHALL be exactly the value  for this element in the instance. For purposes of comparison, non-significant whitespace is ignored, and all values must be an exact match (case and accent sensitive). Missing elements/attributes must also be missing.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    sliceName: Optional_['string'] = Field(default=None)
    'The name of this element definition slice, when slicing is working. The name must be a token with no dots or spaces. This is a unique name referring to a specific set of constraints applied to this element, used to provide a name to different slices of the same element.'
    maxLength: Optional_['integer'] = Field(default=None)
    'Indicates the maximum length in characters that is permitted to be present in conformant instances and which is expected to be supported by conformant consumers that support the element.'
    condition: List_['id'] = Field(default_factory=list)
    'A reference to an invariant that may make additional statements about the cardinality or value in the instance.'
    isSummary: Optional_['boolean'] = Field(default=None)
    'Whether the element should be included if a client requests a search with the parameter _summary=true.'
    definition: Optional_['markdown'] = Field(default=None)
    'Provides a complete explanation of the meaning of the data element for human readability.  For the case of elements derived from existing elements (e.g. constraints), the definition SHALL be consistent with the base definition, but convey the meaning of the element in the particular context of use of the resource. (Note: The text you are reading is specified in ElementDefinition.definition).'
    patternBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternBoolean: Optional_['boolean'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternCanonical: Optional_['canonical'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternCode: Optional_['code'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternDate: Optional_['date'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternDateTime: Optional_['dateTime'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternDecimal: Optional_['decimal'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternId: Optional_['id'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternInstant: Optional_['instant'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternInteger: Optional_['integer'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternMarkdown: Optional_['markdown'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternOid: Optional_['oid'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternPositiveInt: Optional_['positiveInt'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternString: Optional_['string'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternTime: Optional_['time'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternUri: Optional_['uri'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternUrl: Optional_['url'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternUuid: Optional_['uuid'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternAddress: Optional_['Address'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternAge: Optional_['Age'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternAnnotation: Optional_['Annotation'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternAttachment: Optional_['Attachment'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternCodeableReference: Optional_['CodeableReference'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternCoding: Optional_['Coding'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternContactPoint: Optional_['ContactPoint'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternCount: Optional_['Count'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternDistance: Optional_['Distance'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternDuration: Optional_['Duration'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternHumanName: Optional_['HumanName'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternIdentifier: Optional_['Identifier'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternMoney: Optional_['Money'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternPeriod: Optional_['Period'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternQuantity: Optional_['Quantity'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternRange: Optional_['Range'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternRatio: Optional_['Ratio'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternRatioRange: Optional_['RatioRange'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternReference: Optional_['Reference'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternSampledData: Optional_['SampledData'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternSignature: Optional_['Signature'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternTiming: Optional_['Timing'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternContactDetail: Optional_['ContactDetail'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternContributor: Optional_['Contributor'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternExpression: Optional_['Expression'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternParameterDefinition: Optional_['ParameterDefinition'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternRelatedArtifact: Optional_['RelatedArtifact'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternTriggerDefinition: Optional_['TriggerDefinition'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternUsageContext: Optional_['UsageContext'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    patternDosage: Optional_['Dosage'] = Field(default=None)
    'Specifies a value that the value in the instance SHALL follow - that is, any value in the pattern must be found in the instance. Other additional values may be found too. This is effectively constraint by example.  \n\nWhen pattern[x] is used to constrain a primitive, it means that the value provided in the pattern[x] must match the instance value exactly.\n\nWhen pattern[x] is used to constrain an array, it means that each element provided in the pattern[x] array must (recursively) match at least one element from the instance array.\n\nWhen pattern[x] is used to constrain a complex object, it means that each property in the pattern must be present in the complex object, and its value must recursively match -- i.e.,\n\n1. If primitive: it must match exactly the pattern value\n2. If a complex object: it must match (recursively) the pattern value\n3. If an array: it must match (recursively) the pattern value.'
    constraint: List_['ElementDefinitionConstraint'] = Field(default_factory=list)
    'Formal constraints such as co-occurrence and other constraints that can be computationally evaluated within the context of the instance.'
    isModifier: Optional_['boolean'] = Field(default=None)
    'If true, the value of this element affects the interpretation of the element or resource that contains it, and the value of the element cannot be ignored. Typically, this is used for status, negation and qualification codes. The effect of this is that the element cannot be ignored by systems: they SHALL either recognize the element and process it, and/or a pre-determination has been made that it is not relevant to their particular system.'
    minValueDate: Optional_['date'] = Field(default=None)
    'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    minValueDateTime: Optional_['dateTime'] = Field(default=None)
    'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    minValueInstant: Optional_['instant'] = Field(default=None)
    'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    minValueTime: Optional_['time'] = Field(default=None)
    'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    minValueDecimal: Optional_['decimal'] = Field(default=None)
    'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    minValueInteger: Optional_['integer'] = Field(default=None)
    'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    minValuePositiveInt: Optional_['positiveInt'] = Field(default=None)
    'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    minValueUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    minValueQuantity: Optional_['Quantity'] = Field(default=None)
    'The minimum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    maxValueDate: Optional_['date'] = Field(default=None)
    'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    maxValueDateTime: Optional_['dateTime'] = Field(default=None)
    'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    maxValueInstant: Optional_['instant'] = Field(default=None)
    'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    maxValueTime: Optional_['time'] = Field(default=None)
    'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    maxValueDecimal: Optional_['decimal'] = Field(default=None)
    'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    maxValueInteger: Optional_['integer'] = Field(default=None)
    'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    maxValuePositiveInt: Optional_['positiveInt'] = Field(default=None)
    'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    maxValueUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    maxValueQuantity: Optional_['Quantity'] = Field(default=None)
    'The maximum allowed value for the element. The value is inclusive. This is allowed for the types date, dateTime, instant, time, decimal, integer, and Quantity.'
    mustSupport: Optional_['boolean'] = Field(default=None)
    'If true, implementations that produce or consume resources SHALL provide "support" for the element in some meaningful way.  If false, the element may be ignored and not supported. If false, whether to populate or use the data element in any way is at the discretion of the implementation.'
    requirements: Optional_['markdown'] = Field(default=None)
    'This element is for traceability of why the element was created and why the constraints exist as they do. This may be used to point to source materials or specifications that drove the structure of this element.'
    orderMeaning: Optional_['string'] = Field(default=None)
    'If present, indicates that the order of the repeating element has meaning and describes what that meaning is.  If absent, it means that the order of the element has no meaning.'
    representation: List_['code'] = Field(default_factory=list)
    'Codes that define how this element is represented in instances, when the deviation varies from the normal case.'
    defaultValueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueBoolean: Optional_['boolean'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueCanonical: Optional_['canonical'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueCode: Optional_['code'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueDate: Optional_['date'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueDateTime: Optional_['dateTime'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueDecimal: Optional_['decimal'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueId: Optional_['id'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueInstant: Optional_['instant'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueInteger: Optional_['integer'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueMarkdown: Optional_['markdown'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueOid: Optional_['oid'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValuePositiveInt: Optional_['positiveInt'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueString: Optional_['string'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueTime: Optional_['time'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueUri: Optional_['uri'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueUrl: Optional_['url'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueUuid: Optional_['uuid'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueAddress: Optional_['Address'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueAge: Optional_['Age'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueAnnotation: Optional_['Annotation'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueAttachment: Optional_['Attachment'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueCodeableReference: Optional_['CodeableReference'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueCoding: Optional_['Coding'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueContactPoint: Optional_['ContactPoint'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueCount: Optional_['Count'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueDistance: Optional_['Distance'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueDuration: Optional_['Duration'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueHumanName: Optional_['HumanName'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueIdentifier: Optional_['Identifier'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueMoney: Optional_['Money'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValuePeriod: Optional_['Period'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueQuantity: Optional_['Quantity'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueRange: Optional_['Range'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueRatio: Optional_['Ratio'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueRatioRange: Optional_['RatioRange'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueReference: Optional_['Reference'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueSampledData: Optional_['SampledData'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueSignature: Optional_['Signature'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueTiming: Optional_['Timing'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueContactDetail: Optional_['ContactDetail'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueContributor: Optional_['Contributor'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueExpression: Optional_['Expression'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueParameterDefinition: Optional_['ParameterDefinition'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueRelatedArtifact: Optional_['RelatedArtifact'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueTriggerDefinition: Optional_['TriggerDefinition'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueUsageContext: Optional_['UsageContext'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    defaultValueDosage: Optional_['Dosage'] = Field(default=None)
    "The value that should be used if there is no value stated in the instance (e.g. 'if not otherwise specified, the abstract is false')."
    contentReference: Optional_['uri'] = Field(default=None)
    'Identifies an element defined elsewhere in the definition whose content rules should be applied to the current element. ContentReferences bring across all the rules that are in the ElementDefinition for the element, including definitions, cardinality constraints, bindings, invariants etc.'
    isModifierReason: Optional_['string'] = Field(default=None)
    'Explains how that element affects the interpretation of the resource or element that contains it.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    meaningWhenMissing: Optional_['markdown'] = Field(default=None)
    "The Implicit meaning that is to be understood when this element is missing (e.g. 'when this element is missing, the period is ongoing')."
    sliceIsConstraining: Optional_['boolean'] = Field(default=None)
    'If true, indicates that this slice definition is constraining a slice definition with the same name in an inherited profile. If false, the slice is not overriding any slice in an inherited profile. If missing, the slice might or might not be overriding a slice in an inherited profile, depending on the sliceName.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: List_['Coding'] = Field(default_factory=list)
    'A code that has the same meaning as the element in a particular terminology.'


class Expression(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A expression that is evaluated in a specified context and returns a value. The context of use of the expression must specify the context in which the expression is evaluated, and how the result of the expression is used."""
    name: Optional_['id'] = Field(default=None)
    'A short name assigned to the expression to allow for multiple reuse of the expression in the context where it is defined.'
    language: 'code' = Field(default=...)
    'The media type of the language for the expression.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: Optional_['uri'] = Field(default=None)
    'A URI that defines where the expression is found.'
    expression: Optional_['string'] = Field(default=None)
    'An expression in the specified language that returns a value.'
    description: Optional_['string'] = Field(default=None)
    'A brief, natural language description of the condition that effectively communicates the intended semantics.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class Extension(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Optional Extension Element - found in all resources."""
    valueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueCanonical: Optional_['canonical'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueCode: Optional_['code'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueDate: Optional_['date'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueId: Optional_['id'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueInstant: Optional_['instant'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueInteger: Optional_['integer'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueMarkdown: Optional_['markdown'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueOid: Optional_['oid'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valuePositiveInt: Optional_['positiveInt'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueString: Optional_['string'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueTime: Optional_['time'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueUri: Optional_['uri'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueUrl: Optional_['url'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueUuid: Optional_['uuid'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueAddress: Optional_['Address'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueAge: Optional_['Age'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueAnnotation: Optional_['Annotation'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueCodeableReference: Optional_['CodeableReference'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueCoding: Optional_['Coding'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueContactPoint: Optional_['ContactPoint'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueCount: Optional_['Count'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueDistance: Optional_['Distance'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueDuration: Optional_['Duration'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueHumanName: Optional_['HumanName'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueIdentifier: Optional_['Identifier'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueMoney: Optional_['Money'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valuePeriod: Optional_['Period'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueRange: Optional_['Range'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueRatio: Optional_['Ratio'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueRatioRange: Optional_['RatioRange'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueReference: Optional_['Reference'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueSampledData: Optional_['SampledData'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueSignature: Optional_['Signature'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueTiming: Optional_['Timing'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueContactDetail: Optional_['ContactDetail'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueContributor: Optional_['Contributor'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueExpression: Optional_['Expression'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueParameterDefinition: Optional_['ParameterDefinition'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueRelatedArtifact: Optional_['RelatedArtifact'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueTriggerDefinition: Optional_['TriggerDefinition'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueUsageContext: Optional_['UsageContext'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    valueDosage: Optional_['Dosage'] = Field(default=None)
    'Value of extension - must be one of a constrained set of the data types (see [Extensibility](extensibility.html) for a list).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    url: 'str' = Field(default=...)
    'Source of the definition for the extension code - a logical name or a URL.'


class HumanName(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A human's name with the ability to identify parts and usage."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: Optional_['code'] = Field(default=None)
    'Identifies the purpose for this name.'
    text: Optional_['string'] = Field(default=None)
    'Specifies the entire name as it should be displayed e.g. on an application UI. This may be provided instead of or as well as the specific parts.'
    given: List_['string'] = Field(default_factory=list)
    'Given name.'
    family: Optional_['string'] = Field(default=None)
    'The part of a name that links to the genealogy. In some cultures (e.g. Eritrea) the family name of a son is the first name of his father.'
    prefix: List_['string'] = Field(default_factory=list)
    'Part of the name that is acquired as a title due to academic, legal, employment or nobility status, etc. and that appears at the start of the name.'
    suffix: List_['string'] = Field(default_factory=list)
    'Part of the name that is acquired as a title due to academic, legal, employment or nobility status, etc. and that appears at the end of the name.'
    period: Optional_['Period'] = Field(default=None)
    'Indicates the period of time when this name was valid for the named person.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class Identifier(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An identifier - identifies some entity uniquely and unambiguously. Typically this is used for business identifiers."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: Optional_['code'] = Field(default=None)
    'The purpose of this identifier.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'A coded type for the identifier that can be used to determine which identifier to use for a specific purpose.'
    value: Optional_['string'] = Field(default=None)
    'The portion of the identifier typically relevant to the user and which is unique within the context of the system.'
    system: Optional_['uri'] = Field(default=None)
    'Establishes the namespace for the value - that is, a URL that describes a set values that are unique.'
    period: Optional_['Period'] = Field(default=None)
    'Time period during which identifier is/was valid for use.'
    assigner: Optional_['Reference'] = Field(default=None)
    'Organization that issued/manages the identifier.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class MarketingStatus(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    status: 'CodeableConcept' = Field(default=...)
    'This attribute provides information on the status of the marketing of the medicinal product See ISO/TS 20443 for more information and examples.'
    country: Optional_['CodeableConcept'] = Field(default=None)
    'The country in which the marketing authorisation has been granted shall be specified It should be specified using the ISO 3166 ‑ 1 alpha-2 code elements.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    dateRange: Optional_['Period'] = Field(default=None)
    'The date when the Medicinal Product is placed on the market by the Marketing Authorisation Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain.'
    restoreDate: Optional_['dateTime'] = Field(default=None)
    'The date when the Medicinal Product is placed on the market by the Marketing Authorisation Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain.'
    jurisdiction: Optional_['CodeableConcept'] = Field(default=None)
    'Where a Medicines Regulatory Agency has granted a marketing authorisation for which specific provisions within a jurisdiction apply, the jurisdiction can be specified using an appropriate controlled terminology The controlled term and the controlled term identifier shall be specified.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Meta(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The metadata about a resource. This is content in the resource that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource."""
    tag: List_['Coding'] = Field(default_factory=list)
    'Tags applied to this resource. Tags are intended to be used to identify and relate resources to process and workflow, and applications are not required to consider the tags when interpreting the meaning of a resource.'
    source: Optional_['uri'] = Field(default=None)
    'A uri that identifies the source system of the resource. This provides a minimal amount of [Provenance](provenance.html#) information that can be used to track or differentiate the source of information in the resource. The source may identify another FHIR server, document, message, database, etc.'
    profile: List_['canonical'] = Field(default_factory=list)
    'A list of profiles (references to [StructureDefinition](structuredefinition.html#) resources) that this resource claims to conform to. The URL is a reference to [StructureDefinition.url](structuredefinition-definitions.html#StructureDefinition.url).'
    security: List_['Coding'] = Field(default_factory=list)
    'Security labels applied to this resource. These tags connect specific resources to the overall security policy and infrastructure.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    versionId: Optional_['id'] = Field(default=None)
    'The version specific identifier, as it appears in the version portion of the URL. This value changes when the resource is created, updated, or deleted.'
    lastUpdated: Optional_['instant'] = Field(default=None)
    'When the resource last changed - e.g. when the version changed.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class Money(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An amount of economic utility in some recognized currency."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: Optional_['decimal'] = Field(default=None)
    'Numerical value (with implicit precision).'
    currency: Optional_['code'] = Field(default=None)
    'ISO 4217 Currency Code.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class Narrative(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A human-readable summary of the resource conveying the essential clinical and business information for the resource."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    div: 'xhtml' = Field(default=...)
    'The actual narrative content, a stripped down version of XHTML.'
    status: 'code' = Field(default=...)
    "The status of the narrative - whether it's entirely generated (from just the defined data or the extensions too), or whether a human authored it and it may contain additional data."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class ParameterDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The parameters to the module. This collection specifies both the input and output parameters. Input parameters are provided by the caller as part of the $evaluate operation. Output parameters are included in the GuidanceResponse."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: 'code' = Field(default=...)
    'Whether the parameter is input or output for the module.'
    min: Optional_['integer'] = Field(default=None)
    'The minimum number of times this parameter SHALL appear in the request or response.'
    max: Optional_['string'] = Field(default=None)
    'The maximum number of times this element is permitted to appear in the request or response.'
    name: Optional_['code'] = Field(default=None)
    'The name of the parameter used to allow access to the value of the parameter in evaluation contexts.'
    type: 'code' = Field(default=...)
    'The type of the parameter.'
    profile: Optional_['canonical'] = Field(default=None)
    'If specified, this indicates a profile that the input data must conform to, or that the output data will conform to.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    documentation: Optional_['string'] = Field(default=None)
    'A brief discussion of what the parameter is for and how it is used by the module.'


class Period(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A time period defined by a start and end date and optionally time."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    end: Optional_['dateTime'] = Field(default=None)
    'The end of the period. If the end of the period is missing, it means no end was known or planned at the time the instance was created. The start may be in the past, and the end date in the future, which means that period is expected/planned to end at that time.'
    start: Optional_['dateTime'] = Field(default=None)
    'The start of the period. The boundary is inclusive.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class Population(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A populatioof people with some set of grouping criteria."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    race: Optional_['CodeableConcept'] = Field(default=None)
    'Race of the specific population.'
    ageRange: Optional_['Range'] = Field(default=None)
    'The age of the specific population.'
    ageCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The age of the specific population.'
    gender: Optional_['CodeableConcept'] = Field(default=None)
    'The gender of the specific population.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    physiologicalCondition: Optional_['CodeableConcept'] = Field(default=None)
    'The existing physiological conditions of the specific population to which this applies.'


class ProdCharacteristic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    width: Optional_['Quantity'] = Field(default=None)
    'Where applicable, the width can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.'
    depth: Optional_['Quantity'] = Field(default=None)
    'Where applicable, the depth can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.'
    shape: Optional_['string'] = Field(default=None)
    'Where applicable, the shape can be specified An appropriate controlled vocabulary shall be used The term and the term identifier shall be used.'
    color: List_['string'] = Field(default_factory=list)
    'Where applicable, the color can be specified An appropriate controlled vocabulary shall be used The term and the term identifier shall be used.'
    image: List_['Attachment'] = Field(default_factory=list)
    'Where applicable, the image can be provided The format of the image attachment shall be specified by regional implementations.'
    height: Optional_['Quantity'] = Field(default=None)
    'Where applicable, the height can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.'
    weight: Optional_['Quantity'] = Field(default=None)
    'Where applicable, the weight can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.'
    imprint: List_['string'] = Field(default_factory=list)
    'Where applicable, the imprint can be specified as text.'
    scoring: Optional_['CodeableConcept'] = Field(default=None)
    'Where applicable, the scoring can be specified An appropriate controlled vocabulary shall be used The term and the term identifier shall be used.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    nominalVolume: Optional_['Quantity'] = Field(default=None)
    'Where applicable, the nominal volume can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.'
    externalDiameter: Optional_['Quantity'] = Field(default=None)
    'Where applicable, the external diameter can be specified using a numerical value and its unit of measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ProductShelfLife(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The shelf-life and storage information for a medicinal product item or container can be described using this class."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'This describes the shelf life, taking into account various scenarios such as shelf life of the packaged Medicinal Product itself, shelf life after transformation where necessary and shelf life after the first opening of a bottle, etc. The shelf life type shall be specified using an appropriate controlled vocabulary The controlled term and the controlled term identifier shall be specified.'
    period: 'Quantity' = Field(default=...)
    'The shelf life time period can be specified using a numerical value for the period of time and its unit of time measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Unique identifier for the packaged Medicinal Product.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    specialPrecautionsForStorage: List_['CodeableConcept'] = Field(default_factory=list)
    'Special precautions for storage, if any, can be specified using an appropriate controlled vocabulary The controlled term and the controlled term identifier shall be specified.'


class Quantity(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    unit: Optional_['string'] = Field(default=None)
    'A human-readable form of the unit.'
    value: Optional_['decimal'] = Field(default=None)
    'The value of the measured amount. The value includes an implicit precision in the presentation of the value.'
    system: Optional_['uri'] = Field(default=None)
    'The identification of the system that provides the coded form of the unit.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    comparator: Optional_['code'] = Field(default=None)
    'How the value should be understood and represented - whether the actual value is greater or less than the stated value due to measurement issues; e.g. if the comparator is "<" , then the real value is < stated value.'
    code: Optional_['code'] = Field(default=None)
    'A computer processable form of the unit in some unit representation system.'


class Range(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A set of ordered Quantities defined by a low and high limit."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    low: Optional_['Quantity'] = Field(default=None)
    'The low limit. The boundary is inclusive.'
    high: Optional_['Quantity'] = Field(default=None)
    'The high limit. The boundary is inclusive.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class Ratio(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A relationship of two Quantity values - expressed as a numerator and a denominator."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    numerator: Optional_['Quantity'] = Field(default=None)
    'The value of the numerator.'
    denominator: Optional_['Quantity'] = Field(default=None)
    'The value of the denominator.'


class RatioRange(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A range of ratios expressed as a low and high numerator and a denominator."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    denominator: Optional_['Quantity'] = Field(default=None)
    'The value of the denominator.'
    lowNumerator: Optional_['Quantity'] = Field(default=None)
    'The value of the low limit numerator.'
    highNumerator: Optional_['Quantity'] = Field(default=None)
    'The value of the high limit numerator.'


class Reference(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A reference from one resource to another."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['uri'] = Field(default=None)
    'The expected type of the target of the reference. If both Reference.type and Reference.reference are populated and Reference.reference is a FHIR URL, both SHALL be consistent.\n\nThe type is the Canonical URL of Resource Definition that is the type this reference refers to. References are URLs that are relative to http://hl7.org/fhir/StructureDefinition/ e.g. "Patient" is a reference to http://hl7.org/fhir/StructureDefinition/Patient. Absolute URLs are only allowed for logical models (and can only be used in references in logical models, not resources).'
    display: Optional_['string'] = Field(default=None)
    'Plain text narrative that identifies the resource in addition to the resource reference.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: Optional_['string'] = Field(default=None)
    "A reference to a location at which the other resource is found. The reference may be a relative reference, in which case it is relative to the service base URL, or an absolute URL that resolves to the location where the resource is found. The reference may be version specific or not. If the reference is not to a FHIR RESTful server, then it should be assumed to be version specific. Internal fragment references (start with '#') refer to contained resources."
    identifier: Optional_['Identifier'] = Field(default=None)
    'An identifier for the target resource. This is used when there is no way to reference the other resource directly, either because the entity it represents is not available through a FHIR server, or because there is no way for the author of the resource to convert a known identifier to an actual location. There is no requirement that a Reference.identifier point to something that is actually exposed as a FHIR instance, but it SHALL point to a business concept that would be expected to be exposed as a FHIR instance, and that instance would need to be of a FHIR resource type allowed by the reference.'


class RelatedArtifact(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Related artifacts such as additional documentation, justification, or bibliographic references."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of relationship to the related artifact.'
    label: Optional_['string'] = Field(default=None)
    'A short label that can be used to reference the citation from elsewhere in the containing artifact, such as a footnote index.'
    display: Optional_['string'] = Field(default=None)
    'A brief description of the document or knowledge resource being referenced, suitable for display to a consumer.'
    citation: Optional_['markdown'] = Field(default=None)
    'A bibliographic citation for the related artifact. This text SHOULD be formatted according to an accepted citation format.'
    document: Optional_['Attachment'] = Field(default=None)
    'The document being referenced, represented as an attachment. This is exclusive with the resource element.'
    resource: Optional_['canonical'] = Field(default=None)
    'The related resource, such as a library, value set, profile, or other knowledge resource.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    url: Optional_['url'] = Field(default=None)
    'A url for the artifact that can be followed to access the actual content.'


class SampledData(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A series of measurements taken by a device, with upper and lower limits. There may be more than one dimension in the data."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    data: Optional_['string'] = Field(default=None)
    'A series of data points which are decimal values separated by a single space (character u20). The special values "E" (error), "L" (below detection limit) and "U" (above detection limit) can also be used in place of a decimal value.'
    origin: 'Quantity' = Field(default=...)
    'The base quantity that a measured value of zero represents. In addition, this provides the units of the entire measurement series.'
    period: 'decimal' = Field(default=...)
    'The length of time between sampling times, measured in milliseconds.'
    factor: Optional_['decimal'] = Field(default=None)
    'A correction factor that is applied to the sampled data points before they are added to the origin.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    lowerLimit: Optional_['decimal'] = Field(default=None)
    'The lower limit of detection of the measured points. This is needed if any of the data points have the value "L" (lower than detection limit).'
    upperLimit: Optional_['decimal'] = Field(default=None)
    'The upper limit of detection of the measured points. This is needed if any of the data points have the value "U" (higher than detection limit).'
    dimensions: 'positiveInt' = Field(default=...)
    'The number of sample points at each time point. If this value is greater than one, then the dimensions will be interlaced - all the sample points for a point in time will be recorded at once.'


class Signature(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A signature along with supporting context. The signature may be a digital signature that is cryptographic in nature, or some other signature acceptable to the domain. This other signature may be as simple as a graphical image representing a hand-written signature, or a signature ceremony Different signature approaches have different utilities."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    who: 'Reference' = Field(default=...)
    'A reference to an application-usable description of the identity that signed  (e.g. the signature used their private key).'
    type: List_['Coding'] = Field(default=...)
    'An indication of the reason that the entity signed this document. This may be explicitly included as part of the signature information and can be used when determining accountability for various actions concerning the document.'
    when: 'instant' = Field(default=...)
    'When the digital signature was signed.'
    data: Optional_['base64Binary'] = Field(default=None)
    'The base64 encoding of the Signature content. When signature is not recorded electronically this element would be empty.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    sigFormat: Optional_['code'] = Field(default=None)
    'A mime type that indicates the technical format of the signature. Important mime types are application/signature+xml for X ML DigSig, application/jose for JWS, and image/* for a graphical image of a signature, etc.'
    onBehalfOf: Optional_['Reference'] = Field(default=None)
    'A reference to an application-usable description of the identity that is represented by the signature.'
    targetFormat: Optional_['code'] = Field(default=None)
    'A mime type that indicates the technical format of the target resources signed by the signature.'


class TimingRepeat(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A set of rules that describe when the event is scheduled."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    when: List_['code'] = Field(default_factory=list)
    'An approximate time period during the day, potentially linked to an event of daily living that indicates when the action should occur.'
    count: Optional_['positiveInt'] = Field(default=None)
    'A total count of the desired number of repetitions across the duration of the entire timing specification. If countMax is present, this element indicates the lower bound of the allowed range of count values.'
    period: Optional_['decimal'] = Field(default=None)
    'Indicates the duration of time over which repetitions are to occur; e.g. to express "3 times per day", 3 would be the frequency and "1 day" would be the period. If periodMax is present, this element indicates the lower bound of the allowed range of the period length.'
    offset: Optional_['unsignedInt'] = Field(default=None)
    'The number of minutes from the event. If the event code does not indicate whether the minutes is before or after the event, then the offset is assumed to be after the event.'
    countMax: Optional_['positiveInt'] = Field(default=None)
    'If present, indicates that the count is a range - so to perform the action between [count] and [countMax] times.'
    duration: Optional_['decimal'] = Field(default=None)
    'How long this thing happens for when it happens. If durationMax is present, this element indicates the lower bound of the allowed range of the duration.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    boundsDuration: Optional_['Duration'] = Field(default=None)
    'Either a duration for the length of the timing schedule, a range of possible length, or outer bounds for start and/or end limits of the timing schedule.'
    boundsRange: Optional_['Range'] = Field(default=None)
    'Either a duration for the length of the timing schedule, a range of possible length, or outer bounds for start and/or end limits of the timing schedule.'
    boundsPeriod: Optional_['Period'] = Field(default=None)
    'Either a duration for the length of the timing schedule, a range of possible length, or outer bounds for start and/or end limits of the timing schedule.'
    frequency: Optional_['positiveInt'] = Field(default=None)
    'The number of times to repeat the action within the specified period. If frequencyMax is present, this element indicates the lower bound of the allowed range of the frequency.'
    periodMax: Optional_['decimal'] = Field(default=None)
    'If present, indicates that the period is a range from [period] to [periodMax], allowing expressing concepts such as "do this once every 3-5 days.'
    dayOfWeek: List_['code'] = Field(default_factory=list)
    'If one or more days of week is provided, then the action happens only on the specified day(s).'
    timeOfDay: List_['time'] = Field(default_factory=list)
    'Specified time of day for action to take place.'
    periodUnit: Optional_['code'] = Field(default=None)
    'The units of time for the period in UCUM units.'
    durationMax: Optional_['decimal'] = Field(default=None)
    'If present, indicates that the duration is a range - so to perform the action between [duration] and [durationMax] time length.'
    durationUnit: Optional_['code'] = Field(default=None)
    'The units of time for the duration, in UCUM units.'
    frequencyMax: Optional_['positiveInt'] = Field(default=None)
    'If present, indicates that the frequency is a range - so to repeat between [frequency] and [frequencyMax] times within the period or period range.'


class Timing(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies an event that may occur multiple times. Timing schedules are used to record when things are planned, expected or requested to occur. The most common usage is in dosage instructions for medications. They are also used when planning care of various kinds, and may be used for reporting the schedule to which past regular activities were carried out."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code for the timing schedule (or just text in code.text). Some codes such as BID are ubiquitous, but many institutions define their own additional codes. If a code is provided, the code is understood to be a complete statement of whatever is specified in the structured timing data, and either the code or the data may be used to interpret the Timing, with the exception that .repeat.bounds still applies over the code (and is not contained in the code).'
    event: List_['dateTime'] = Field(default_factory=list)
    'Identifies specific times when the event occurs.'
    repeat: Optional_['TimingRepeat'] = Field(default=None)
    'A set of rules that describe when the event is scheduled.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TriggerDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A description of a triggering event. Triggering events can be named events, data events, or periodic, as determined by the type element."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of triggering event.'
    name: Optional_['string'] = Field(default=None)
    'A formal name for the event. This may be an absolute URI that identifies the event formally (e.g. from a trigger registry), or a simple relative URI that identifies the event in a local context.'
    data: List_['DataRequirement'] = Field(default_factory=list)
    'The triggering data of the event (if this is a data trigger). If more than one data is requirement is specified, then all the data requirements must be true.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    timingTiming: Optional_['Timing'] = Field(default=None)
    'The timing of the event (if this is a periodic trigger).'
    timingReference: Optional_['Reference'] = Field(default=None)
    'The timing of the event (if this is a periodic trigger).'
    timingDate: Optional_['date'] = Field(default=None)
    'The timing of the event (if this is a periodic trigger).'
    timingDateTime: Optional_['dateTime'] = Field(default=None)
    'The timing of the event (if this is a periodic trigger).'
    condition: Optional_['Expression'] = Field(default=None)
    'A boolean-valued expression that is evaluated in the context of the container of the trigger definition and returns whether or not the trigger fires.'


class UsageContext(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies clinical/business/etc. metadata that can be used to retrieve, index and/or categorize an artifact. This metadata can either be specific to the applicable population (e.g., age category, DRG) or the specific context of care (e.g., venue, care setting, provider of care)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'Coding' = Field(default=...)
    'A code that identifies the type of context being specified by this usage context.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A value that defines the context specified in this context of use. The interpretation of the value is defined by the code.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'A value that defines the context specified in this context of use. The interpretation of the value is defined by the code.'
    valueRange: Optional_['Range'] = Field(default=None)
    'A value that defines the context specified in this context of use. The interpretation of the value is defined by the code.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'A value that defines the context specified in this context of use. The interpretation of the value is defined by the code.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'


class MoneyQuantity(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """There SHALL be a code if there is a value and it SHALL be an expression of currency.  If system is present, it SHALL be ISO 4217 (system = "urn:iso:std:iso:4217" - currency)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    unit: Optional_['string'] = Field(default=None)
    'A human-readable form of the unit.'
    value: Optional_['decimal'] = Field(default=None)
    'The value of the measured amount. The value includes an implicit precision in the presentation of the value.'
    system: Optional_['uri'] = Field(default=None)
    'The identification of the system that provides the coded form of the unit.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    comparator: Optional_['code'] = Field(default=None)
    'How the value should be understood and represented - whether the actual value is greater or less than the stated value due to measurement issues; e.g. if the comparator is "<" , then the real value is < stated value.'
    code: Optional_['code'] = Field(default=None)
    'A computer processable form of the unit in some unit representation system.'


class SimpleQuantity(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The comparator is not used on a SimpleQuantity"""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    unit: Optional_['string'] = Field(default=None)
    'A human-readable form of the unit.'
    value: Optional_['decimal'] = Field(default=None)
    'The value of the measured amount. The value includes an implicit precision in the presentation of the value.'
    system: Optional_['uri'] = Field(default=None)
    'The identification of the system that provides the coded form of the unit.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    comparator: List_['code'] = Field(default_factory=list)
    'Not allowed to be used in this context'
    code: Optional_['code'] = Field(default=None)
    'A computer processable form of the unit in some unit representation system.'


class Resource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This is the base resource type for everything."""
    resourceType: Literal_['Resource'] = Field(default=...)
    'Base Resource'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'


class AccountGuarantor(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The parties responsible for balancing the account if other payment options fall short."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    party: 'Reference' = Field(default=...)
    'The entity who is responsible.'
    onHold: Optional_['boolean'] = Field(default=None)
    'A guarantor may be placed on credit hold or otherwise have their role temporarily suspended.'
    period: Optional_['Period'] = Field(default=None)
    'The timeframe during which the guarantor accepts responsibility for the account.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AccountCoverage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The party(s) that are responsible for covering the payment of this account, and what order should they be applied to the account."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    coverage: 'Reference' = Field(default=...)
    'The party(s) that contribute to payment (or part of) of the charges applied to this account (including self-pay).\n\nA coverage may only be responsible for specific types of charges, and the sequence of the coverages in the account could be important when processing billing.'
    priority: Optional_['positiveInt'] = Field(default=None)
    'The priority of the coverage in the context of this account.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Account(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A financial tool for tracking value accrued for a particular purpose.  In the healthcare field, used to track charges for a patient, cost centers, etc."""
    resourceType: Literal_['Account'] = Field(default=...)
    'Tracks balance, charges, for patient or cost center'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Categorizes the account for reporting and searching purposes.'
    name: Optional_['string'] = Field(default=None)
    'Name used for the account when displaying it to humans in reports, etc.'
    owner: Optional_['Reference'] = Field(default=None)
    'Indicates the service area, hospital, department, etc. with responsibility for managing the Account.'
    status: 'code' = Field(default=...)
    'Indicates whether the account is presently used/usable or not.'
    partOf: Optional_['Reference'] = Field(default=None)
    'Reference to a parent Account.'
    subject: List_['Reference'] = Field(default_factory=list)
    'Identifies the entity which incurs the expenses. While the immediate recipients of services or goods might be entities related to the subject, the expenses were ultimately incurred by the subject of the Account.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    coverage: List_['AccountCoverage'] = Field(default_factory=list)
    'The party(s) that are responsible for covering the payment of this account, and what order should they be applied to the account.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    guarantor: List_['AccountGuarantor'] = Field(default_factory=list)
    'The parties responsible for balancing the account if other payment options fall short.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique identifier used to reference the account.  Might or might not be intended for human use (e.g. credit card number).'
    description: Optional_['string'] = Field(default=None)
    'Provides additional information about what the account tracks and how it is used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    servicePeriod: Optional_['Period'] = Field(default=None)
    'The date range of services associated with this account.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ActivityDefinitionDynamicValue(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Dynamic values that will be evaluated to produce values for elements of the resulting resource. For example, if the dosage of a medication must be computed based on the patient's weight, a dynamic value would be used to specify an expression that calculated the weight, and the path on the request resource that would contain the result."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    path: 'string' = Field(default=...)
    'The path to the element to be customized. This is the path on the resource that will hold the result of the calculation defined by the expression. The specified path SHALL be a FHIRPath resolveable on the specified target type of the ActivityDefinition, and SHALL consist only of identifiers, constant indexers, and a restricted subset of functions. The path is allowed to contain qualifiers (.) to traverse sub-elements, as well as indexers ([x]) to traverse multiple-cardinality sub-elements (see the [Simple FHIRPath Profile](fhirpath.html#simple) for full details).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: 'Expression' = Field(default=...)
    'An expression specifying the value of the customized element.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ActivityDefinitionParticipant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates who should participate in performing the action described."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of participant in the action.'
    role: Optional_['CodeableConcept'] = Field(default=None)
    'The role the participant should play in performing the described action.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ActivityDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource allows for the definition of some activity to be performed, independent of a particular patient, practitioner, or other performance context."""
    resourceType: Literal_['ActivityDefinition'] = Field(default=...)
    'The definition of a specific activity to be taken, independent of any particular patient or context'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this activity definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this activity definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the activity definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the activity definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    kind: Optional_['code'] = Field(default=None)
    'A description of the kind of resource the activity definition is representing. For example, a MedicationRequest, a ServiceRequest, or a CommunicationRequest. Typically, but not always, this is a Request resource.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the activity definition.'
    usage: Optional_['string'] = Field(default=None)
    'A detailed description of how the activity definition is used from a clinical perspective.'
    topic: List_['CodeableConcept'] = Field(default_factory=list)
    'Descriptive topics related to the content of the activity. Topics provide a high-level categorization of the activity that can be useful for filtering and searching.'
    status: 'code' = Field(default=...)
    'The status of this activity definition. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual or organization primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for internal coherence of the content.'
    intent: Optional_['code'] = Field(default=None)
    'Indicates the level of authority/intentionality associated with the activity and where the request should fit into the workflow chain.'
    dosage: List_['Dosage'] = Field(default_factory=list)
    'Provides detailed dosage instructions in the same way that they are described for MedicationRequest resources.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the activity definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the activity definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active assets.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this activity definition is needed and why it has been designed as it has.'
    library: List_['canonical'] = Field(default_factory=list)
    'A reference to a Library resource containing any formal logic used by the activity definition.'
    profile: Optional_['canonical'] = Field(default=None)
    'A profile to which the target of the activity definition is expected to conform.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    subtitle: Optional_['string'] = Field(default=None)
    'An explanatory or alternate title for the activity definition giving additional information about its content.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization responsible for officially endorsing the content for use in some setting.'
    priority: Optional_['code'] = Field(default=None)
    'Indicates how quickly the activity  should be addressed with respect to other requests.'
    location: Optional_['Reference'] = Field(default=None)
    'Identifies the facility where the activity will occur; e.g. home, hospital, specific clinic, etc.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'Identifies the quantity expected to be consumed at once (per dose, per meal, etc.).'
    bodySite: List_['CodeableConcept'] = Field(default_factory=list)
    "Indicates the sites on the subject's body where the procedure should be performed (I.e. the target sites)."
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the activity definition.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the activity definition and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the activity definition.'
    timingTiming: Optional_['Timing'] = Field(default=None)
    'The period, timing or frequency upon which the described activity is to occur.'
    timingDateTime: Optional_['dateTime'] = Field(default=None)
    'The period, timing or frequency upon which the described activity is to occur.'
    timingAge: Optional_['Age'] = Field(default=None)
    'The period, timing or frequency upon which the described activity is to occur.'
    timingPeriod: Optional_['Period'] = Field(default=None)
    'The period, timing or frequency upon which the described activity is to occur.'
    timingRange: Optional_['Range'] = Field(default=None)
    'The period, timing or frequency upon which the described activity is to occur.'
    timingDuration: Optional_['Duration'] = Field(default=None)
    'The period, timing or frequency upon which the described activity is to occur.'
    transform: Optional_['canonical'] = Field(default=None)
    'A reference to a StructureMap resource that defines a transform that can be executed to produce the intent resource using the ActivityDefinition instance as the input.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this activity definition when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    subjectCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A code, group definition, or canonical reference that describes  or identifies the intended subject of the activity being defined.  Canonical references are allowed to support the definition of protocols for drug and substance quality specifications, and is allowed to reference a MedicinalProductDefinition, SubstanceDefinition, AdministrableProductDefinition, ManufacturedItemDefinition, or PackagedProductDefinition resource.'
    subjectReference: Optional_['Reference'] = Field(default=None)
    'A code, group definition, or canonical reference that describes  or identifies the intended subject of the activity being defined.  Canonical references are allowed to support the definition of protocols for drug and substance quality specifications, and is allowed to reference a MedicinalProductDefinition, SubstanceDefinition, AdministrableProductDefinition, ManufacturedItemDefinition, or PackagedProductDefinition resource.'
    subjectCanonical: Optional_['canonical'] = Field(default=None)
    'A code, group definition, or canonical reference that describes  or identifies the intended subject of the activity being defined.  Canonical references are allowed to support the definition of protocols for drug and substance quality specifications, and is allowed to reference a MedicinalProductDefinition, SubstanceDefinition, AdministrableProductDefinition, ManufacturedItemDefinition, or PackagedProductDefinition resource.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate activity definition instances.'
    productReference: Optional_['Reference'] = Field(default=None)
    'Identifies the food, drug or other product being consumed or supplied in the activity.'
    productCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the food, drug or other product being consumed or supplied in the activity.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the activity definition from a consumer's perspective."
    participant: List_['ActivityDefinitionParticipant'] = Field(default_factory=list)
    'Indicates who should participate in performing the action described.'
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this activity definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the activity definition is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    doNotPerform: Optional_['boolean'] = Field(default=None)
    'Set this to true if the definition is to indicate that a particular activity should NOT be performed. If true, this element should be interpreted to reinforce a negative coding. For example NPO as a code with a doNotPerform of true would still indicate to NOT perform the action.'
    dynamicValue: List_['ActivityDefinitionDynamicValue'] = Field(default_factory=list)
    "Dynamic values that will be evaluated to produce values for elements of the resulting resource. For example, if the dosage of a medication must be computed based on the patient's weight, a dynamic value would be used to specify an expression that calculated the weight, and the path on the request resource that would contain the result."
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the activity definition content was or is planned to be in active use.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Related artifacts such as additional documentation, justification, or bibliographic references.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    specimenRequirement: List_['Reference'] = Field(default_factory=list)
    'Defines specimen requirements for the action to be performed, such as required specimens for a lab test.'
    observationRequirement: List_['Reference'] = Field(default_factory=list)
    'Defines observation requirements for the action to be performed, such as body weight or surface area.'
    observationResultRequirement: List_['Reference'] = Field(default_factory=list)
    'Defines the observations that are expected to be produced by the action.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the activity definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the activity definition changes.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Detailed description of the type of activity; e.g. What lab test, what procedure, what kind of encounter.'


class AdministrableProductDefinitionRouteOfAdministration(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The path by which the product is taken into or makes contact with the body. In some regions this is referred to as the licenced or approved route. RouteOfAdministration cannot be used when the 'formOf' product already uses MedicinalProductDefinition.route (and vice versa)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'Coded expression for the route.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    firstDose: Optional_['Quantity'] = Field(default=None)
    'The first dose (dose quantity) administered can be specified for the product, using a numerical value and its unit of measurement.'
    maxSingleDose: Optional_['Quantity'] = Field(default=None)
    'The maximum single dose that can be administered, specified using a numerical value and its unit of measurement.'
    maxDosePerDay: Optional_['Quantity'] = Field(default=None)
    'The maximum dose per day (maximum dose quantity to be administered in any one 24-h period) that can be administered.'
    targetSpecies: List_['AdministrableProductDefinitionRouteOfAdministrationTargetSpecies'] = Field(default_factory=list)
    'A species for which this route applies.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    maxTreatmentPeriod: Optional_['Duration'] = Field(default=None)
    'The maximum treatment period during which the product can be administered.'
    maxDosePerTreatmentPeriod: Optional_['Ratio'] = Field(default=None)
    'The maximum dose per treatment period that can be administered.'


class AdministrableProductDefinitionRouteOfAdministrationTargetSpecies(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A species for which this route applies."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'Coded expression for the species.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    withdrawalPeriod: List_['AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriod'] = Field(default_factory=list)
    'A species specific time during which consumption of animal product is not appropriate.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriod(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A species specific time during which consumption of animal product is not appropriate."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: 'Quantity' = Field(default=...)
    'A value for the time.'
    tissue: 'CodeableConcept' = Field(default=...)
    'Coded expression for the type of tissue for which the withdrawal period applies, e.g. meat, milk.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    supportingInformation: Optional_['string'] = Field(default=None)
    'Extra information about the withdrawal period.'


class AdministrableProductDefinitionProperty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Characteristics e.g. a product's onset of action."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'A code expressing the type of characteristic.'
    status: Optional_['CodeableConcept'] = Field(default=None)
    'The status of characteristic e.g. assigned or pending.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A value for the characteristic.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'A value for the characteristic.'
    valueDate: Optional_['date'] = Field(default=None)
    'A value for the characteristic.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'A value for the characteristic.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'A value for the characteristic.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AdministrableProductDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A medicinal product in the final form which is suitable for administering to a patient (after any mixing of multiple components, dissolution etc. has been performed)."""
    resourceType: Literal_['AdministrableProductDefinition'] = Field(default=...)
    'A medicinal product in the final form, suitable for administration - after any mixing of multiple components'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: 'code' = Field(default=...)
    'The status of this administrable product. Enables tracking the life-cycle of the content.'
    formOf: List_['Reference'] = Field(default_factory=list)
    "References a product from which one or more of the constituent parts of that product can be prepared and used as described by this administrable product.  If this administrable product describes the administration of a crushed tablet, the 'formOf' would be the product representing a distribution containing tablets and possibly also a cream.  This is distinct from the 'producedFrom' which refers to the specific components of the product that are used in this preparation, rather than the product as a whole."
    device: Optional_['Reference'] = Field(default=None)
    'A device that is integral to the medicinal product, in effect being considered as an "ingredient" of the medicinal product. This is not intended for devices that are just co-packaged.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    property: List_['AdministrableProductDefinitionProperty'] = Field(default_factory=list)
    "Characteristics e.g. a product's onset of action."
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'An identifier for the administrable product.'
    ingredient: List_['CodeableConcept'] = Field(default_factory=list)
    'The ingredients of this administrable medicinal product. This is only needed if the ingredients are not specified either using ManufacturedItemDefiniton (via AdministrableProductDefinition.producedFrom) to state which component items are used to make this, or using by incoming references from the Ingredient resource, to state in detail which substances exist within this. This element allows a basic coded ingredient to be used.'
    producedFrom: List_['Reference'] = Field(default_factory=list)
    "Indicates the specific manufactured items that are part of the 'formOf' product that are used in the preparation of this specific administrable form.  In some cases, an administrable form might use all of the items from the overall product (or there might only be one item), while in other cases, an administrable form might use only a subset of the items available in the overall product.  For example, an administrable form might involve combining a liquid and a powder available as part of an overall product, but not involve applying the also supplied cream."
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    unitOfPresentation: Optional_['CodeableConcept'] = Field(default=None)
    "The presentation type in which this item is given to a patient. e.g. for a spray - 'puff' (as in 'contains 100 mcg per puff'), or for a liquid - 'vial' (as in 'contains 5 ml per vial')."
    administrableDoseForm: Optional_['CodeableConcept'] = Field(default=None)
    "The dose form of the final product after necessary reconstitution or processing. Contrasts to the manufactured dose form (see ManufacturedItemDefinition). If the manufactured form was 'powder for solution for injection', the administrable dose form could be 'solution for injection' (once mixed with another item having manufactured form 'solvent for solution for injection')."
    routeOfAdministration: List_['AdministrableProductDefinitionRouteOfAdministration'] = Field(default=...)
    "The path by which the product is taken into or makes contact with the body. In some regions this is referred to as the licenced or approved route. RouteOfAdministration cannot be used when the 'formOf' product already uses MedicinalProductDefinition.route (and vice versa)."


class AdverseEventSuspectEntity(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes the entity that is suspected to have caused the adverse event."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    instance: 'Reference' = Field(default=...)
    'Identifies the actual instance of what caused the adverse event.  May be a substance, medication, medication administration, medication statement or a device.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    causality: List_['AdverseEventSuspectEntityCausality'] = Field(default_factory=list)
    'Information on the possible cause of the event.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AdverseEventSuspectEntityCausality(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information on the possible cause of the event."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    author: Optional_['Reference'] = Field(default=None)
    'AdverseEvent.suspectEntity.causalityAuthor.'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'ProbabilityScale | Bayesian | Checklist.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    assessment: Optional_['CodeableConcept'] = Field(default=None)
    'Assessment of if the entity caused the event.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    productRelatedness: Optional_['string'] = Field(default=None)
    'AdverseEvent.suspectEntity.causalityProductRelatedness.'


class AdverseEvent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Actual or  potential/avoided event causing unintended physical injury resulting from or contributed to by medical care, a research study or other healthcare setting factors that requires additional monitoring, treatment, or hospitalization, or that results in death."""
    resourceType: Literal_['AdverseEvent'] = Field(default=...)
    'Medical care, research study or other healthcare event causing physical injury'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date (and perhaps time) when the adverse event occurred.'
    event: Optional_['CodeableConcept'] = Field(default=None)
    'This element defines the specific type of event that occurred or that was prevented from occurring.'
    study: List_['Reference'] = Field(default_factory=list)
    'AdverseEvent.study.'
    subject: 'Reference' = Field(default=...)
    'This subject or group impacted by the event.'
    outcome: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the type of outcome from the adverse event.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'The overall type of event, intended for search and filtering purposes.'
    detected: Optional_['dateTime'] = Field(default=None)
    'Estimated or actual date the AdverseEvent began, in the opinion of the reporter.'
    location: Optional_['Reference'] = Field(default=None)
    'The information about where the adverse event occurred.'
    severity: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the severity of the adverse event, in relation to the subject. Contrast to AdverseEvent.seriousness - a severe rash might not be serious, but a mild heart problem is.'
    recorder: Optional_['Reference'] = Field(default=None)
    'Information on who recorded the adverse event.  May be the patient or a practitioner.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    actuality: 'code' = Field(default=...)
    'Whether the event actually happened, or just had the potential to. Note that this is independent of whether anyone was affected or harmed or how severely.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which AdverseEvent was created or to which the creation of this record is tightly associated.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Business identifiers assigned to this adverse event by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    seriousness: Optional_['CodeableConcept'] = Field(default=None)
    'Assessment whether this event was of real importance.'
    contributor: List_['Reference'] = Field(default_factory=list)
    'Parties that may or should contribute or have contributed information to the adverse event, which can consist of one or more activities.  Such information includes information leading to the decision to perform the activity and how to perform the activity (e.g. consultant), information that the activity itself seeks to reveal (e.g. informant of clinical history), or information about what activity was performed (e.g. informant witness).'
    recordedDate: Optional_['dateTime'] = Field(default=None)
    'The date on which the existence of the AdverseEvent was first recorded.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    suspectEntity: List_['AdverseEventSuspectEntity'] = Field(default_factory=list)
    'Describes the entity that is suspected to have caused the adverse event.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    referenceDocument: List_['Reference'] = Field(default_factory=list)
    'AdverseEvent.referenceDocument.'
    resultingCondition: List_['Reference'] = Field(default_factory=list)
    'Includes information about the reaction that occurred as a result of exposure to a substance (for example, a drug or a chemical).'
    subjectMedicalHistory: List_['Reference'] = Field(default_factory=list)
    'AdverseEvent.subjectMedicalHistory.'


class AllergyIntoleranceReaction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details about each adverse reaction event linked to exposure to the identified substance."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Additional text about the adverse reaction event not captured in other fields.'
    onset: Optional_['dateTime'] = Field(default=None)
    'Record of the date and/or time of the onset of the Reaction.'
    severity: Optional_['code'] = Field(default=None)
    'Clinical assessment of the severity of the reaction event as a whole, potentially considering multiple different manifestations.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    substance: Optional_['CodeableConcept'] = Field(default=None)
    "Identification of the specific substance (or pharmaceutical product) considered to be responsible for the Adverse Reaction event. Note: the substance for a specific reaction may be different from the substance identified as the cause of the risk, but it must be consistent with it. For instance, it may be a more specific substance (e.g. a brand medication) or a composite product that includes the identified substance. It must be clinically safe to only process the 'code' and ignore the 'reaction.substance'.  If a receiving system is unable to confirm that AllergyIntolerance.reaction.substance falls within the semantic scope of AllergyIntolerance.code, then the receiving system should ignore AllergyIntolerance.reaction.substance."
    description: Optional_['string'] = Field(default=None)
    'Text description about the reaction as a whole, including details of the manifestation if required.'
    manifestation: List_['CodeableConcept'] = Field(default=...)
    'Clinical symptoms and/or signs that are observed or associated with the adverse reaction event.'
    exposureRoute: Optional_['CodeableConcept'] = Field(default=None)
    'Identification of the route by which the subject was exposed to the substance.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AllergyIntolerance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Risk of harmful or undesirable, physiological response which is unique to an individual and associated with exposure to a substance."""
    resourceType: Literal_['AllergyIntolerance'] = Field(default=...)
    'Allergy or Intolerance (generally: Risk of adverse reaction to a substance)'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['code'] = Field(default=None)
    'Identification of the underlying physiological mechanism for the reaction risk.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Additional narrative about the propensity for the Adverse Reaction, not captured in other fields.'
    patient: 'Reference' = Field(default=...)
    'The patient who has the allergy or intolerance.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['code'] = Field(default_factory=list)
    'Category of the identified substance.'
    onsetDateTime: Optional_['dateTime'] = Field(default=None)
    'Estimated or actual date,  date-time, or age when allergy or intolerance was identified.'
    onsetAge: Optional_['Age'] = Field(default=None)
    'Estimated or actual date,  date-time, or age when allergy or intolerance was identified.'
    onsetPeriod: Optional_['Period'] = Field(default=None)
    'Estimated or actual date,  date-time, or age when allergy or intolerance was identified.'
    onsetRange: Optional_['Range'] = Field(default=None)
    'Estimated or actual date,  date-time, or age when allergy or intolerance was identified.'
    onsetString: Optional_['string'] = Field(default=None)
    'Estimated or actual date,  date-time, or age when allergy or intolerance was identified.'
    recorder: Optional_['Reference'] = Field(default=None)
    'Individual who recorded the record and takes responsibility for its content.'
    asserter: Optional_['Reference'] = Field(default=None)
    'The source of the information about the allergy that is recorded.'
    reaction: List_['AllergyIntoleranceReaction'] = Field(default_factory=list)
    'Details about each adverse reaction event linked to exposure to the identified substance.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The encounter when the allergy or intolerance was asserted.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this AllergyIntolerance by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    criticality: Optional_['code'] = Field(default=None)
    'Estimate of the potential clinical harm, or seriousness, of the reaction to the identified substance.'
    recordedDate: Optional_['dateTime'] = Field(default=None)
    'The recordedDate represents when this particular AllergyIntolerance record was created in the system, which is often a system-generated date.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    clinicalStatus: Optional_['CodeableConcept'] = Field(default=None)
    'The clinical status of the allergy or intolerance.'
    lastOccurrence: Optional_['dateTime'] = Field(default=None)
    'Represents the date and/or time of the last known occurrence of a reaction event.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    verificationStatus: Optional_['CodeableConcept'] = Field(default=None)
    'Assertion about certainty associated with the propensity, or potential risk, of a reaction to the identified substance (including pharmaceutical product).'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Code for an allergy or intolerance statement (either a positive or a negated/excluded statement).  This may be a code for a substance or pharmaceutical product that is considered to be responsible for the adverse reaction risk (e.g., "Latex"), an allergy or intolerance condition (e.g., "Latex allergy"), or a negated/excluded code for a specific substance or class (e.g., "No latex allergy") or a general or categorical negated statement (e.g.,  "No known allergy", "No known drug allergies").  Note: the substance for a specific reaction may be different from the substance identified as the cause of the risk, but it must be consistent with it. For instance, it may be a more specific substance (e.g. a brand medication) or a composite product that includes the identified substance. It must be clinically safe to only process the \'code\' and ignore the \'reaction.substance\'.  If a receiving system is unable to confirm that AllergyIntolerance.reaction.substance falls within the semantic scope of AllergyIntolerance.code, then the receiving system should ignore AllergyIntolerance.reaction.substance.'


class AppointmentParticipant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """List of participants involved in the appointment."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'Role of participant in the appointment.'
    actor: Optional_['Reference'] = Field(default=None)
    'A Person, Location/HealthcareService or Device that is participating in the appointment.'
    status: 'code' = Field(default=...)
    'Participation status of the actor.'
    period: Optional_['Period'] = Field(default=None)
    'Participation period of the actor.'
    required: Optional_['code'] = Field(default=None)
    'Whether this participant is required to be present at the meeting. This covers a use-case where two doctors need to meet to discuss the results for a specific patient, and the patient is not required to be present.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Appointment(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A booking of a healthcare event among patient(s), practitioner(s), related person(s) and/or device(s) for a specific date/time. This may result in one or more Encounter(s)."""
    resourceType: Literal_['Appointment'] = Field(default=...)
    'A booking of a healthcare event among patient(s), practitioner(s), related person(s) and/or device(s) for a specific date/time. This may result in one or more Encounter(s)'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    end: Optional_['instant'] = Field(default=None)
    'Date/Time that the appointment is to conclude.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    slot: List_['Reference'] = Field(default_factory=list)
    "The slots from the participants' schedules that will be filled by the appointment."
    start: Optional_['instant'] = Field(default=None)
    'Date/Time that the appointment is to take place.'
    status: 'code' = Field(default=...)
    'The overall status of the Appointment. Each of the participants has their own participation status which indicates their involvement in the process, however this status indicates the shared status.'
    created: Optional_['dateTime'] = Field(default=None)
    'The date that this appointment was initially created. This could be different to the meta.lastModified value on the initial entry, as this could have been before the resource was created on the FHIR server, and should remain unchanged over the lifespan of the appointment.'
    comment: Optional_['string'] = Field(default=None)
    'Additional comments about the appointment.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'The service request this appointment is allocated to assess (e.g. incoming referral or procedure request).'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    priority: Optional_['unsignedInt'] = Field(default=None)
    'The priority of the appointment. Can be used to make informed decisions if needing to re-prioritize appointments. (The iCal Standard specifies 0 as undefined, 1 as highest, 9 as lowest priority).'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    specialty: List_['CodeableConcept'] = Field(default_factory=list)
    'The specialty of a practitioner that would be required to perform the service requested in this appointment.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'This records identifiers associated with this appointment concern that are defined by business processes and/or used to refer to it when a direct URL reference to the resource itself is not appropriate (e.g. in CDA documents, or in written / printed documentation).'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'The coded reason that this appointment is being scheduled. This is more clinical than administrative.'
    serviceType: List_['CodeableConcept'] = Field(default_factory=list)
    'The specific service that is to be performed during this appointment.'
    description: Optional_['string'] = Field(default=None)
    'The brief description of the appointment as would be shown on a subject line in a meeting request, or appointment list. Detailed or expanded information should be put in the comment field.'
    participant: List_['AppointmentParticipant'] = Field(default=...)
    'List of participants involved in the appointment.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    serviceCategory: List_['CodeableConcept'] = Field(default_factory=list)
    'A broad categorization of the service that is to be performed during this appointment.'
    appointmentType: Optional_['CodeableConcept'] = Field(default=None)
    'The style of appointment or patient that has been booked in the slot (not service type).'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Reason the appointment has been scheduled to take place, as specified using information from another resource. When the patient arrives and the encounter begins it may be used as the admission diagnosis. The indication will typically be a Condition (with other resources referenced in the evidence.detail), or a Procedure.'
    minutesDuration: Optional_['positiveInt'] = Field(default=None)
    'Number of minutes that the appointment is to take. This can be less than the duration between the start and end times.  For example, where the actual time of appointment is only an estimate or if a 30 minute appointment is being requested, but any time would work.  Also, if there is, for example, a planned 15 minute break in the middle of a long appointment, the duration may be 15 minutes less than the difference between the start and end.'
    requestedPeriod: List_['Period'] = Field(default_factory=list)
    'A set of date ranges (potentially including times) that the appointment is preferred to be scheduled within.\n\nThe duration (usually in minutes) could also be provided to indicate the length of the appointment to fill and populate the start/end times for the actual allocated time. However, in other situations the duration may be calculated by the scheduling system.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    cancelationReason: Optional_['CodeableConcept'] = Field(default=None)
    'The coded reason for the appointment being cancelled. This is often used in reporting/billing/futher processing to determine if further actions are required, or specific fees apply.'
    patientInstruction: Optional_['string'] = Field(default=None)
    'While Appointment.comment contains information for internal use, Appointment.patientInstructions is used to capture patient facing information about the Appointment (e.g. please bring your referral or fast from 8pm night before).'
    supportingInformation: List_['Reference'] = Field(default_factory=list)
    'Additional information to support the appointment provided when making the appointment.'


class AppointmentResponse(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A reply to an appointment request for a patient and/or practitioner(s), such as a confirmation or rejection."""
    resourceType: Literal_['AppointmentResponse'] = Field(default=...)
    'A reply to an appointment request for a patient and/or practitioner(s), such as a confirmation or rejection'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    end: Optional_['instant'] = Field(default=None)
    'This may be either the same as the appointment request to confirm the details of the appointment, or alternately a new time to request a re-negotiation of the end time.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    start: Optional_['instant'] = Field(default=None)
    'Date/Time that the appointment is to take place, or requested new start time.'
    actor: Optional_['Reference'] = Field(default=None)
    'A Person, Location, HealthcareService, or Device that is participating in the appointment.'
    comment: Optional_['string'] = Field(default=None)
    'Additional comments about the appointment.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'This records identifiers associated with this appointment response concern that are defined by business processes and/ or used to refer to it when a direct URL reference to the resource itself is not appropriate.'
    appointment: 'Reference' = Field(default=...)
    'Appointment that this response is replying to.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    participantType: List_['CodeableConcept'] = Field(default_factory=list)
    'Role of participant in the appointment.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    participantStatus: 'code' = Field(default=...)
    'Participation status of the participant. When the status is declined or tentative if the start/end times are different to the appointment, then these times should be interpreted as a requested time change. When the status is accepted, the times can either be the time of the appointment (as a confirmation of the time) or can be empty.'


class AuditEventEntity(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specific instances of data or objects that have been accessed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    what: Optional_['Reference'] = Field(default=None)
    'Identifies a specific instance of the entity. The reference should be version specific.'
    type: Optional_['Coding'] = Field(default=None)
    'The type of the object that was involved in this audit event.'
    role: Optional_['Coding'] = Field(default=None)
    'Code representing the role the entity played in the event being audited.'
    name: Optional_['string'] = Field(default=None)
    'A name of the entity in the audit event.'
    query: Optional_['base64Binary'] = Field(default=None)
    'The query parameters for a query-type entities.'
    detail: List_['AuditEventEntityDetail'] = Field(default_factory=list)
    'Tagged value pairs for conveying additional information about the entity.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    lifecycle: Optional_['Coding'] = Field(default=None)
    'Identifier for the data life-cycle stage for the entity.'
    description: Optional_['string'] = Field(default=None)
    'Text that describes the entity in more detail.'
    securityLabel: List_['Coding'] = Field(default_factory=list)
    'Security labels for the identified entity.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AuditEventEntityDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Tagged value pairs for conveying additional information about the entity."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'string' = Field(default=...)
    'The type of extra detail provided in the value.'
    valueString: Optional_['string'] = Field(default=None)
    'The  value of the extra detail.'
    valueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'The  value of the extra detail.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AuditEventSource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The system that is reporting the event."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    site: Optional_['string'] = Field(default=None)
    'Logical source location within the healthcare enterprise network.  For example, a hospital or other provider location within a multi-entity provider group.'
    type: List_['Coding'] = Field(default_factory=list)
    'Code specifying the type of source where event originated.'
    observer: 'Reference' = Field(default=...)
    'Identifier of the source where the event was detected.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AuditEventAgent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An actor taking an active role in the event or activity that is logged."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    who: Optional_['Reference'] = Field(default=None)
    'Reference to who this agent is that was involved in the event.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Specification of the participation type the user plays when performing the event.'
    role: List_['CodeableConcept'] = Field(default_factory=list)
    'The security role that the user was acting under, that come from local codes defined by the access control security system (e.g. RBAC, ABAC) used in the local context.'
    name: Optional_['string'] = Field(default=None)
    'Human-meaningful name for the agent.'
    altId: Optional_['string'] = Field(default=None)
    'Alternative agent Identifier. For a human, this should be a user identifier text string from authentication system. This identifier would be one known to a common authentication system (e.g. single sign-on), if available.'
    media: Optional_['Coding'] = Field(default=None)
    'Type of media involved. Used when the event is about exporting/importing onto media.'
    policy: List_['uri'] = Field(default_factory=list)
    'The policy or plan that authorized the activity being recorded. Typically, a single activity may have multiple applicable policies, such as patient consent, guarantor funding, etc. The policy would also indicate the security token used.'
    network: Optional_['AuditEventAgentNetwork'] = Field(default=None)
    'Logical network location for application activity, if the activity has a network location.'
    location: Optional_['Reference'] = Field(default=None)
    'Where the event occurred.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    requestor: 'boolean' = Field(default=...)
    'Indicator that the user is or is not the requestor, or initiator, for the event being audited.'
    purposeOfUse: List_['CodeableConcept'] = Field(default_factory=list)
    'The reason (purpose of use), specific to this agent, that was used during the event being recorded.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AuditEventAgentNetwork(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Logical network location for application activity, if the activity has a network location."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['code'] = Field(default=None)
    'An identifier for the type of network access point that originated the audit event.'
    address: Optional_['string'] = Field(default=None)
    'An identifier for the network access point of the user device for the audit event.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class AuditEvent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A record of an event made for purposes of maintaining a security log. Typical uses include detection of intrusion attempts and monitoring for inappropriate usage."""
    resourceType: Literal_['AuditEvent'] = Field(default=...)
    'Event record kept for security purposes'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'Coding' = Field(default=...)
    'Identifier for a family of the event.  For example, a menu item, program, rule, policy, function code, application name or URL. It identifies the performed function.'
    agent: List_['AuditEventAgent'] = Field(default=...)
    'An actor taking an active role in the event or activity that is logged.'
    action: Optional_['code'] = Field(default=None)
    'Indicator for type of action performed during the event that generated the audit.'
    period: Optional_['Period'] = Field(default=None)
    'The period during which the activity occurred.'
    source: 'AuditEventSource' = Field(default=...)
    'The system that is reporting the event.'
    entity: List_['AuditEventEntity'] = Field(default_factory=list)
    'Specific instances of data or objects that have been accessed.'
    subtype: List_['Coding'] = Field(default_factory=list)
    'Identifier for the category of event.'
    outcome: Optional_['code'] = Field(default=None)
    'Indicates whether the event succeeded or failed.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    recorded: 'instant' = Field(default=...)
    'The time when the event was recorded.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    outcomeDesc: Optional_['string'] = Field(default=None)
    'A free text description of the outcome of the event.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    purposeOfEvent: List_['CodeableConcept'] = Field(default_factory=list)
    'The purposeOfUse (reason) that was used during the event being recorded.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Basic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Basic is used for handling concepts not yet defined in FHIR, narrative-only resources that don't map to an existing resource, and custom resources not appropriate for inclusion in the FHIR specification."""
    resourceType: Literal_['Basic'] = Field(default=...)
    'Resource for non-supported content'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    author: Optional_['Reference'] = Field(default=None)
    'Indicates who was responsible for creating the resource instance.'
    subject: Optional_['Reference'] = Field(default=None)
    'Identifies the patient, practitioner, device or any other resource that is the "focus" of this resource.'
    created: Optional_['date'] = Field(default=None)
    'Identifies when the resource was first created.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier assigned to the resource for business purposes, outside the context of FHIR.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'CodeableConcept' = Field(default=...)
    "Identifies the 'type' of resource - equivalent to the resource name for other resources."


class Binary(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A resource that represents the data of a single raw artifact as digital content accessible in its native format.  A Binary resource can contain any content, whether text, image, pdf, zip archive, etc."""
    resourceType: Literal_['Binary'] = Field(default=...)
    'Pure binary content defined by a format other than FHIR'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    data: Optional_['base64Binary'] = Field(default=None)
    'The actual content, base64 encoded.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contentType: 'code' = Field(default=...)
    'MimeType of the binary content represented as a standard MimeType (BCP 13).'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    securityContext: Optional_['Reference'] = Field(default=None)
    'This element identifies another resource that can be used as a proxy of the security sensitivity to use when deciding and enforcing access control rules for the Binary resource. Given that the Binary resource contains very few elements that can be used to determine the sensitivity of the data and relationships to individuals, the referenced resource stands in as a proxy equivalent for this purpose. This referenced resource may be related to the Binary (e.g. Media, DocumentReference), or may be some non-related Resource purely as a security proxy. E.g. to identify that the binary resource relates to a patient, and access should only be granted to applications that have access to the patient.'


class BiologicallyDerivedProductManipulation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Any manipulation of product post-collection that is intended to alter the product.  For example a buffy-coat enrichment or CD8 reduction of Peripheral Blood Stem Cells to make it more suitable for infusion."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    timeDateTime: Optional_['dateTime'] = Field(default=None)
    'Time of manipulation.'
    timePeriod: Optional_['Period'] = Field(default=None)
    'Time of manipulation.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'Description of manipulation.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class BiologicallyDerivedProductProcessing(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Any processing of the product during collection that does not change the fundamental nature of the product. For example adding anti-coagulants during the collection of Peripheral Blood Stem Cells."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    timeDateTime: Optional_['dateTime'] = Field(default=None)
    'Time of processing.'
    timePeriod: Optional_['Period'] = Field(default=None)
    'Time of processing.'
    additive: Optional_['Reference'] = Field(default=None)
    'Substance added during processing.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    procedure: Optional_['CodeableConcept'] = Field(default=None)
    'Procesing code.'
    description: Optional_['string'] = Field(default=None)
    'Description of of processing.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class BiologicallyDerivedProductCollection(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """How this product was collected."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    source: Optional_['Reference'] = Field(default=None)
    'The patient or entity, such as a hospital or vendor in the case of a processed/manipulated/manufactured product, providing the product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    collector: Optional_['Reference'] = Field(default=None)
    'Healthcare professional who is performing the collection.'
    collectedDateTime: Optional_['dateTime'] = Field(default=None)
    'Time of product collection.'
    collectedPeriod: Optional_['Period'] = Field(default=None)
    'Time of product collection.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class BiologicallyDerivedProductStorage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Product storage."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    scale: Optional_['code'] = Field(default=None)
    'Temperature scale used.'
    duration: Optional_['Period'] = Field(default=None)
    'Storage timeperiod.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'Description of storage.'
    temperature: Optional_['decimal'] = Field(default=None)
    'Storage temperature.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class BiologicallyDerivedProduct(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A material substance originating from a biological entity intended to be transplanted or infused
into another (possibly the same) biological entity."""
    resourceType: Literal_['BiologicallyDerivedProduct'] = Field(default=...)
    'A material substance originating from a biological entity'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: Optional_['code'] = Field(default=None)
    'Whether the product is currently available.'
    parent: List_['Reference'] = Field(default_factory=list)
    'Parent product (if any).'
    request: List_['Reference'] = Field(default_factory=list)
    'Procedure request to obtain this biologically derived product.'
    storage: List_['BiologicallyDerivedProductStorage'] = Field(default_factory=list)
    'Product storage.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    quantity: Optional_['integer'] = Field(default=None)
    'Number of discrete units within this product.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'This records identifiers associated with this biologically derived product instance that are defined by business processes and/or used to refer to it when a direct URL reference to the resource itself is not appropriate (e.g. in CDA documents, or in written / printed documentation).'
    collection: Optional_['BiologicallyDerivedProductCollection'] = Field(default=None)
    'How this product was collected.'
    processing: List_['BiologicallyDerivedProductProcessing'] = Field(default_factory=list)
    'Any processing of the product during collection that does not change the fundamental nature of the product. For example adding anti-coagulants during the collection of Peripheral Blood Stem Cells.'
    productCode: Optional_['CodeableConcept'] = Field(default=None)
    'A code that identifies the kind of this biologically derived product (SNOMED Ctcode).'
    manipulation: Optional_['BiologicallyDerivedProductManipulation'] = Field(default=None)
    'Any manipulation of product post-collection that is intended to alter the product.  For example a buffy-coat enrichment or CD8 reduction of Peripheral Blood Stem Cells to make it more suitable for infusion.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    productCategory: Optional_['code'] = Field(default=None)
    'Broad category of this product.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class BodyStructure(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Record details about an anatomical structure.  This resource may be used when a coded concept does not provide the necessary detail needed for the use case."""
    resourceType: Literal_['BodyStructure'] = Field(default=...)
    'Specific and identified anatomical structure'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    image: List_['Attachment'] = Field(default_factory=list)
    'Image or images used to identify a location.'
    active: Optional_['boolean'] = Field(default=None)
    'Whether this body site is in active use.'
    patient: 'Reference' = Field(default=...)
    'The person to which the body site belongs.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    location: Optional_['CodeableConcept'] = Field(default=None)
    'The anatomical location or region of the specimen, lesion, or body structure.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier for this instance of the anatomical structure.'
    morphology: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of structure being represented by the body structure at `BodyStructure.location`.  This can define both normal and abnormal morphologies.'
    description: Optional_['string'] = Field(default=None)
    'A summary, characterization or explanation of the body structure.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    locationQualifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Qualifier to refine the anatomical location.  These include qualifiers for laterality, relative location, directionality, number, and plane.'


class BundleEntry(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An entry in a bundle resource - will either contain a resource or information about a resource (transactions and history only)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    link: List_['BundleLink'] = Field(default_factory=list)
    'A series of links that provide context to this entry.'
    search: Optional_['BundleEntrySearch'] = Field(default=None)
    'Information about the search process that lead to the creation of this entry.'
    fullUrl: Optional_['uri'] = Field(default=None)
    'The Absolute URL for the resource.  The fullUrl SHALL NOT disagree with the id in the resource - i.e. if the fullUrl is not a urn:uuid, the URL shall be version-independent URL consistent with the Resource.id. The fullUrl is a version independent reference to the resource. The fullUrl element SHALL have a value except that: \n* fullUrl can be empty on a POST (although it does not need to when specifying a temporary id for reference in the bundle)\n* Results from operations might involve resources that are not identified.'
    request: Optional_['BundleEntryRequest'] = Field(default=None)
    'Additional information about how this entry should be processed as part of a transaction or batch.  For history, it shows how the entry was processed to create the version contained in the entry.'
    resource: Optional_['AnyResource'] = Field(default=None)
    'The Resource for the entry. The purpose/meaning of the resource is determined by the Bundle.type.'
    response: Optional_['BundleEntryResponse'] = Field(default=None)
    "Indicates the results of processing the corresponding 'request' entry in the batch or transaction being responded to or what the results of an operation where when returning history."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class BundleEntryResponse(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates the results of processing the corresponding 'request' entry in the batch or transaction being responded to or what the results of an operation where when returning history."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    etag: Optional_['string'] = Field(default=None)
    'The Etag for the resource, if the operation for the entry produced a versioned resource (see [Resource Metadata and Versioning](http.html#versioning) and [Managing Resource Contention](http.html#concurrency)).'
    status: 'string' = Field(default=...)
    'The status code returned by processing this entry. The status SHALL start with a 3 digit HTTP code (e.g. 404) and may contain the standard HTTP description associated with the status code.'
    outcome: Optional_['AnyResource'] = Field(default=None)
    'An OperationOutcome containing hints and warnings produced as part of processing this entry in a batch or transaction.'
    location: Optional_['uri'] = Field(default=None)
    'The location header created by processing this operation, populated if the operation returns a location.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    lastModified: Optional_['instant'] = Field(default=None)
    'The date/time that the resource was modified on the server.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class BundleEntryRequest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Additional information about how this entry should be processed as part of a transaction or batch.  For history, it shows how the entry was processed to create the version contained in the entry."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    url: 'uri' = Field(default=...)
    'The URL for this entry, relative to the root (the address to which the request is posted).'
    method: 'code' = Field(default=...)
    'In a transaction or batch, this is the HTTP action to be executed for this entry. In a history bundle, this indicates the HTTP action that occurred.'
    ifMatch: Optional_['string'] = Field(default=None)
    'Only perform the operation if the Etag value matches. For more information, see the API section ["Managing Resource Contention"](http.html#concurrency).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    ifNoneMatch: Optional_['string'] = Field(default=None)
    'If the ETag values match, return a 304 Not Modified status. See the API documentation for ["Conditional Read"](http.html#cread).'
    ifNoneExist: Optional_['string'] = Field(default=None)
    'Instruct the server not to perform the create if a specified resource already exists. For further information, see the API documentation for ["Conditional Create"](http.html#ccreate). This is just the query portion of the URL - what follows the "?" (not including the "?").'
    ifModifiedSince: Optional_['instant'] = Field(default=None)
    'Only perform the operation if the last updated date matches. See the API documentation for ["Conditional Read"](http.html#cread).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class BundleEntrySearch(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the search process that lead to the creation of this entry."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    mode: Optional_['code'] = Field(default=None)
    "Why this entry is in the result set - whether it's included as a match or because of an _include requirement, or to convey information or warning information about the search process."
    score: Optional_['decimal'] = Field(default=None)
    "When searching, the server's search ranking score for the entry."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class BundleLink(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A series of links that provide context to this bundle."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    url: 'uri' = Field(default=...)
    'The reference details for the link.'
    relation: 'string' = Field(default=...)
    'A name which details the functional use for this link - see [http://www.iana.org/assignments/link-relations/link-relations.xhtml#link-relations-1](http://www.iana.org/assignments/link-relations/link-relations.xhtml#link-relations-1).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Bundle(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A container for a collection of resources."""
    resourceType: Literal_['Bundle'] = Field(default=...)
    'Contains a collection of resources'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    type: 'code' = Field(default=...)
    'Indicates the purpose of this bundle - how it is intended to be used.'
    link: List_['BundleLink'] = Field(default_factory=list)
    'A series of links that provide context to this bundle.'
    total: Optional_['unsignedInt'] = Field(default=None)
    "If a set of search matches, this is the total number of entries of type 'match' across all pages in the search.  It does not include search.mode = 'include' or 'outcome' entries and it does not provide a count of the number of entries in the Bundle."
    entry: List_['BundleEntry'] = Field(default_factory=list)
    'An entry in a bundle resource - will either contain a resource or information about a resource (transactions and history only).'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    timestamp: Optional_['instant'] = Field(default=None)
    'The date/time that the bundle was assembled - i.e. when the resources were placed in the bundle.'
    signature: Optional_['Signature'] = Field(default=None)
    'Digital Signature - base64 encoded. XML-DSig or a JWT.'
    identifier: Optional_['Identifier'] = Field(default=None)
    "A persistent identifier for the bundle that won't change as a bundle is copied from server to server."
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'


class CapabilityStatementImplementation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies a specific implementation instance that is described by the capability statement - i.e. a particular installation, rather than the capabilities of a software program."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    custodian: Optional_['Reference'] = Field(default=None)
    'The organization responsible for the management of the instance and oversight of the data on the server at the specified URL.'
    description: 'string' = Field(default=...)
    'Information about the specific installation that this capability statement relates to.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    url: Optional_['url'] = Field(default=None)
    'An absolute base URL for the implementation.  This forms the base for REST interfaces as well as the mailbox and document interfaces.'


class CapabilityStatementMessaging(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A description of the messaging capabilities of the solution."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    endpoint: List_['CapabilityStatementMessagingEndpoint'] = Field(default_factory=list)
    'An endpoint (network accessible address) to which messages and/or replies are to be sent.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reliableCache: Optional_['unsignedInt'] = Field(default=None)
    "Length if the receiver's reliable messaging cache in minutes (if a receiver) or how long the cache length on the receiver should be (if a sender)."
    documentation: Optional_['markdown'] = Field(default=None)
    "Documentation about the system's messaging capabilities for this endpoint not otherwise documented by the capability statement.  For example, the process for becoming an authorized messaging exchange partner."
    supportedMessage: List_['CapabilityStatementMessagingSupportedMessage'] = Field(default_factory=list)
    'References to message definitions for messages this system can send or receive.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CapabilityStatementMessagingSupportedMessage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """References to message definitions for messages this system can send or receive."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    mode: 'code' = Field(default=...)
    'The mode of this event declaration - whether application is sender or receiver.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    definition: 'canonical' = Field(default=...)
    'Points to a message definition that identifies the messaging event, message structure, allowed responses, etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CapabilityStatementMessagingEndpoint(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An endpoint (network accessible address) to which messages and/or replies are to be sent."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    address: 'url' = Field(default=...)
    'The network address of the endpoint. For solutions that do not use network addresses for routing, it can be just an identifier.'
    protocol: 'Coding' = Field(default=...)
    'A list of the messaging transport protocol(s) identifiers, supported by this endpoint.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CapabilityStatementDocument(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A document definition."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    mode: 'code' = Field(default=...)
    'Mode of this document declaration - whether an application is a producer or consumer.'
    profile: 'canonical' = Field(default=...)
    'A profile on the document Bundle that constrains which resources are present, and their contents.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    documentation: Optional_['markdown'] = Field(default=None)
    'A description of how the application supports or uses the specified document profile.  For example, when documents are created, what action is taken with consumed documents, etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CapabilityStatementSoftware(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Software that is covered by this capability statement.  It is used when the capability statement describes the capabilities of a particular software version, independent of an installation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'Name the software is known by.'
    version: Optional_['string'] = Field(default=None)
    'The version identifier for the software covered by this statement.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    releaseDate: Optional_['dateTime'] = Field(default=None)
    'Date this version of the software was released.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CapabilityStatementRest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A definition of the restful capabilities of the solution, if any."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    mode: 'code' = Field(default=...)
    'Identifies whether this portion of the statement is describing the ability to initiate or receive restful operations.'
    security: Optional_['CapabilityStatementRestSecurity'] = Field(default=None)
    'Information about security implementation from an interface perspective - what a client needs to know.'
    resource: List_['CapabilityStatementRestResource'] = Field(default_factory=list)
    'A specification of the restful capabilities of the solution for a specific resource type.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: List_['CapabilityStatementRestResourceOperation'] = Field(default_factory=list)
    'Definition of an operation or a named query together with its parameters and their meaning and type.'
    interaction: List_['CapabilityStatementRestInteraction'] = Field(default_factory=list)
    'A specification of restful operations supported by the system.'
    searchParam: List_['CapabilityStatementRestResourceSearchParam'] = Field(default_factory=list)
    'Search parameters that are supported for searching all resources for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation.'
    compartment: List_['canonical'] = Field(default_factory=list)
    'An absolute URI which is a reference to the definition of a compartment that the system supports. The reference is to a CompartmentDefinition resource by its canonical URL .'
    documentation: Optional_['markdown'] = Field(default=None)
    "Information about the system's restful capabilities that apply across all applications, such as security."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CapabilityStatementRestInteraction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A specification of restful operations supported by the system."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    documentation: Optional_['markdown'] = Field(default=None)
    'Guidance specific to the implementation of this operation, such as limitations on the kind of transactions allowed, or information about system wide search is implemented.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'A coded identifier of the operation, supported by the system.'


class CapabilityStatementRestResource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A specification of the restful capabilities of the solution for a specific resource type."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'A type of resource exposed via the restful interface.'
    profile: Optional_['canonical'] = Field(default=None)
    "A specification of the profile that describes the solution's overall support for the resource, including any constraints on cardinality, bindings, lengths or other limitations. See further discussion in [Using Profiles](profiling.html#profile-uses)."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: List_['CapabilityStatementRestResourceOperation'] = Field(default_factory=list)
    'Definition of an operation or a named query together with its parameters and their meaning and type. Consult the definition of the operation for details about how to invoke the operation, and the parameters.'
    versioning: Optional_['code'] = Field(default=None)
    "This field is set to no-version to specify that the system does not support (server) or use (client) versioning for this resource type. If this has some other value, the server must at least correctly track and populate the versionId meta-property on resources. If the value is 'versioned-update', then the server supports all the versioning features, including using e-tags for version integrity in the API."
    interaction: List_['CapabilityStatementRestResourceInteraction'] = Field(default_factory=list)
    'Identifies a restful operation supported by the solution.'
    readHistory: Optional_['boolean'] = Field(default=None)
    'A flag for whether the server is able to return past versions as part of the vRead operation.'
    searchParam: List_['CapabilityStatementRestResourceSearchParam'] = Field(default_factory=list)
    'Search parameters for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation.'
    updateCreate: Optional_['boolean'] = Field(default=None)
    'A flag to indicate that the server allows or needs to allow the client to create new identities on the server (that is, the client PUTs to a location where there is no existing resource). Allowing this operation means that the server allows the client to create new identities on the server.'
    documentation: Optional_['markdown'] = Field(default=None)
    'Additional information about the resource type used by the system.'
    searchInclude: List_['string'] = Field(default_factory=list)
    'A list of _include values supported by the server.'
    conditionalRead: Optional_['code'] = Field(default=None)
    'A code that indicates how the server supports conditional read.'
    referencePolicy: List_['code'] = Field(default_factory=list)
    'A set of flags that defines how references are supported.'
    supportedProfile: List_['canonical'] = Field(default_factory=list)
    'A list of profiles that represent different use cases supported by the system. For a server, "supported by the system" means the system hosts/produces a set of resources that are conformant to a particular profile, and allows clients that use its services to search using this profile and to find appropriate data. For a client, it means the system will search by this profile and process data according to the guidance implicit in the profile. See further discussion in [Using Profiles](profiling.html#profile-uses).'
    searchRevInclude: List_['string'] = Field(default_factory=list)
    'A list of _revinclude (reverse include) values supported by the server.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    conditionalCreate: Optional_['boolean'] = Field(default=None)
    'A flag that indicates that the server supports conditional create.'
    conditionalUpdate: Optional_['boolean'] = Field(default=None)
    'A flag that indicates that the server supports conditional update.'
    conditionalDelete: Optional_['code'] = Field(default=None)
    'A code that indicates how the server supports conditional delete.'


class CapabilityStatementRestResourceSearchParam(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Search parameters for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'The name of the search parameter used in the interface.'
    type: 'code' = Field(default=...)
    'The type of value a search parameter refers to, and how the content is interpreted.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    definition: Optional_['canonical'] = Field(default=None)
    'An absolute URI that is a formal reference to where this parameter was first defined, so that a client can be confident of the meaning of the search parameter (a reference to [SearchParameter.url](searchparameter-definitions.html#SearchParameter.url)). This element SHALL be populated if the search parameter refers to a SearchParameter defined by the FHIR core specification or externally defined IGs.'
    documentation: Optional_['markdown'] = Field(default=None)
    'This allows documentation of any distinct behaviors about how the search parameter is used.  For example, text matching algorithms.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CapabilityStatementRestResourceInteraction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies a restful operation supported by the solution."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    documentation: Optional_['markdown'] = Field(default=None)
    "Guidance specific to the implementation of this operation, such as 'delete is a logical delete' or 'updates are only allowed with version id' or 'creates permitted from pre-authorized certificates only'."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'Coded identifier of the operation, supported by the system resource.'


class CapabilityStatementRestResourceOperation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Definition of an operation or a named query together with its parameters and their meaning and type. Consult the definition of the operation for details about how to invoke the operation, and the parameters."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'The name of the operation or query. For an operation, this is the name  prefixed with $ and used in the URL. For a query, this is the name used in the _query parameter when the query is called.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    definition: 'canonical' = Field(default=...)
    "Where the formal definition can be found. If a server references the base definition of an Operation (i.e. from the specification itself such as ```http://hl7.org/fhir/OperationDefinition/ValueSet-expand```), that means it supports the full capabilities of the operation - e.g. both GET and POST invocation.  If it only supports a subset, it must define its own custom [OperationDefinition](operationdefinition.html#) with a 'base' of the original OperationDefinition.  The custom definition would describe the specific subset of functionality supported."
    documentation: Optional_['markdown'] = Field(default=None)
    'Documentation that describes anything special about the operation behavior, possibly detailing different behavior for system, type and instance-level invocation of the operation.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CapabilityStatementRestSecurity(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about security implementation from an interface perspective - what a client needs to know."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    cors: Optional_['boolean'] = Field(default=None)
    'Server adds CORS headers when responding to requests - this enables Javascript applications to use the server.'
    service: List_['CodeableConcept'] = Field(default_factory=list)
    'Types of security services that are supported/required by the system.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['markdown'] = Field(default=None)
    'General description of how security works.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CapabilityStatement(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A Capability Statement documents a set of capabilities (behaviors) of a FHIR Server for a particular version of FHIR that may be used as a statement of actual server functionality or a statement of required or desired server implementation."""
    resourceType: Literal_['CapabilityStatement'] = Field(default=...)
    'A statement of system capabilities'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this capability statement when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this capability statement is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the capability statement is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the capability statement. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: 'dateTime' = Field(default=...)
    'The date  (and optionally time) when the capability statement was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the capability statement changes.'
    kind: 'code' = Field(default=...)
    'The way that this statement is intended to be used, to describe an actual running instance of software, a particular product (kind, not instance of software) or a class of implementation (e.g. a desired purchase).'
    rest: List_['CapabilityStatementRest'] = Field(default_factory=list)
    'A definition of the restful capabilities of the solution, if any.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the capability statement.'
    status: 'code' = Field(default=...)
    'The status of this capability statement. Enables tracking the life-cycle of the content.'
    format: List_['code'] = Field(default=...)
    'A list of the formats supported by this implementation using their content types.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the capability statement when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the capability statement author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this capability statement is needed and why it has been designed as it has.'
    imports: List_['canonical'] = Field(default_factory=list)
    'Reference to a canonical URL of another CapabilityStatement that this software adds to. The capability statement automatically includes everything in the other statement, and it is not duplicated, though the server may repeat the same resources, interactions and operations to add additional details to them.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    software: Optional_['CapabilityStatementSoftware'] = Field(default=None)
    'Software that is covered by this capability statement.  It is used when the capability statement describes the capabilities of a particular software version, independent of an installation.'
    document: List_['CapabilityStatementDocument'] = Field(default_factory=list)
    'A document definition.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the capability statement.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the capability statement and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the capability statement.'
    messaging: List_['CapabilityStatementMessaging'] = Field(default_factory=list)
    'A description of the messaging capabilities of the solution.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate capability statement instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the capability statement from a consumer's perspective. Typically, this is used when the capability statement describes a desired rather than an actual solution, for example as a formal expression of requirements as part of an RFP."
    fhirVersion: 'code' = Field(default=...)
    'The version of the FHIR specification that this CapabilityStatement describes (which SHALL be the same as the FHIR version of the CapabilityStatement itself). There is no default value.'
    patchFormat: List_['code'] = Field(default_factory=list)
    'A list of the patch formats supported by this implementation using their content types.'
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this capability statement is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the capability statement is intended to be used.'
    instantiates: List_['canonical'] = Field(default_factory=list)
    'Reference to a canonical URL of another CapabilityStatement that this software implements. This capability statement is a published API description that corresponds to a business service. The server may actually implement a subset of the capability statement it claims to implement, so the capability statement must specify the full capability details.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    implementation: Optional_['CapabilityStatementImplementation'] = Field(default=None)
    'Identifies a specific implementation instance that is described by the capability statement - i.e. a particular installation, rather than the capabilities of a software program.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    implementationGuide: List_['canonical'] = Field(default_factory=list)
    'A list of implementation guides that the server does (or should) support in their entirety.'


class CarePlanActivity(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies a planned action to occur as part of the plan.  For example, a medication to be used, lab tests to perform, self-monitoring, education, etc."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    detail: Optional_['CarePlanActivityDetail'] = Field(default=None)
    "A simple summary of a planned activity suitable for a general care plan system (e.g. form driven) that doesn't know about specific resources such as procedure etc."
    progress: List_['Annotation'] = Field(default_factory=list)
    'Notes about the adherence/status/progress of the activity.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: Optional_['Reference'] = Field(default=None)
    'The details of the proposed activity represented in a specific resource.'
    outcomeReference: List_['Reference'] = Field(default_factory=list)
    'Details of the outcome or action resulting from the activity.  The reference to an "event" resource, such as Procedure or Encounter or Observation, is the result/outcome of the activity itself.  The activity can be conveyed using CarePlan.activity.detail OR using the CarePlan.activity.reference (a reference to a “request” resource).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    outcomeCodeableConcept: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the outcome at the point when the status of the activity is assessed.  For example, the outcome of an education activity could be patient understands (or not).'


class CarePlanActivityDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A simple summary of a planned activity suitable for a general care plan system (e.g. form driven) that doesn't know about specific resources such as procedure etc."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    kind: Optional_['code'] = Field(default=None)
    'A description of the kind of resource the in-line definition of a care plan activity is representing.  The CarePlan.activity.detail is an in-line definition when a resource is not referenced using CarePlan.activity.reference.  For example, a MedicationRequest, a ServiceRequest, or a CommunicationRequest.'
    goal: List_['Reference'] = Field(default_factory=list)
    'Internal reference that identifies the goals that this activity is intended to contribute towards meeting.'
    status: 'code' = Field(default=...)
    'Identifies what progress is being made for the specific activity.'
    location: Optional_['Reference'] = Field(default=None)
    'Identifies the facility where the activity will occur; e.g. home, hospital, specific clinic, etc.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'Identifies the quantity expected to be supplied, administered or consumed by the subject.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    performer: List_['Reference'] = Field(default_factory=list)
    "Identifies who's expected to be involved in the activity."
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Provides the rationale that drove the inclusion of this particular activity as part of the plan or the reason why the activity was prohibited.'
    productCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the food, drug or other product to be consumed or supplied in the activity.'
    productReference: Optional_['Reference'] = Field(default=None)
    'Identifies the food, drug or other product to be consumed or supplied in the activity.'
    dailyAmount: Optional_['Quantity'] = Field(default=None)
    'Identifies the quantity expected to be consumed in a given day.'
    description: Optional_['string'] = Field(default=None)
    'This provides a textual description of constraints on the intended activity occurrence, including relation to other activities.  It may also include objectives, pre-conditions and end-conditions.  Finally, it may convey specifics about the activity such as body site, method, route, etc.'
    statusReason: Optional_['CodeableConcept'] = Field(default=None)
    "Provides reason why the activity isn't yet started, is on hold, was cancelled, etc."
    doNotPerform: Optional_['boolean'] = Field(default=None)
    'If true, indicates that the described activity is one that must NOT be engaged in when following the plan.  If false, or missing, indicates that the described activity is one that should be engaged in when following the plan.'
    scheduledTiming: Optional_['Timing'] = Field(default=None)
    'The period, timing or frequency upon which the described activity is to occur.'
    scheduledPeriod: Optional_['Period'] = Field(default=None)
    'The period, timing or frequency upon which the described activity is to occur.'
    scheduledString: Optional_['string'] = Field(default=None)
    'The period, timing or frequency upon which the described activity is to occur.'
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally maintained protocol, guideline, questionnaire or other definition that is adhered to in whole or in part by this CarePlan activity.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates another resource, such as the health condition(s), whose existence justifies this request and drove the inclusion of this particular activity as part of the plan.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'The URL pointing to a FHIR-defined protocol, guideline, questionnaire or other definition that is adhered to in whole or in part by this CarePlan activity.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Detailed description of the type of planned activity; e.g. what lab test, what procedure, what kind of encounter.'


class CarePlan(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes the intention of how one or more practitioners intend to deliver care for a particular patient, group or community for a period of time, possibly limited to care for a specific condition or set of conditions."""
    resourceType: Literal_['CarePlan'] = Field(default=...)
    'Healthcare plan for patient or group'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    goal: List_['Reference'] = Field(default_factory=list)
    'Describes the intended objective(s) of carrying out the care plan.'
    note: List_['Annotation'] = Field(default_factory=list)
    'General notes about the care plan not covered elsewhere.'
    title: Optional_['string'] = Field(default=None)
    'Human-friendly name for the care plan.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'A larger care plan of which this particular care plan is a component or step.'
    status: 'code' = Field(default=...)
    'Indicates whether the plan is currently being acted upon, represents future intentions or is now a historical record.'
    intent: 'code' = Field(default=...)
    'Indicates the level of authority/intentionality associated with the care plan and where the care plan fits into the workflow chain.'
    period: Optional_['Period'] = Field(default=None)
    'Indicates when the plan did (or is intended to) come into effect and end.'
    author: Optional_['Reference'] = Field(default=None)
    'When populated, the author is responsible for the care plan.  The care plan is attributed to the author.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A care plan that is fulfilled in whole or in part by this care plan.'
    subject: 'Reference' = Field(default=...)
    'Identifies the patient or group whose intended care is described by the plan.'
    created: Optional_['dateTime'] = Field(default=None)
    'Represents when this particular CarePlan record was created in the system, which is often a system-generated date.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    replaces: List_['Reference'] = Field(default_factory=list)
    'Completed or terminated care plan whose function is taken by this new care plan.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies what "kind" of plan this is to support differentiation between multiple co-existing plans; e.g. "Home health", "psychiatric", "asthma", "disease management", "wellness plan", etc.'
    careTeam: List_['Reference'] = Field(default_factory=list)
    'Identifies all people and organizations who are expected to be involved in the care envisioned by this plan.'
    activity: List_['CarePlanActivity'] = Field(default_factory=list)
    'Identifies a planned action to occur as part of the plan.  For example, a medication to be used, lab tests to perform, self-monitoring, education, etc.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which this CarePlan was created or to which the creation of this record is tightly associated.'
    addresses: List_['Reference'] = Field(default_factory=list)
    'Identifies the conditions/problems/concerns/diagnoses/etc. whose management and/or mitigation are handled by this plan.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this care plan by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    description: Optional_['string'] = Field(default=None)
    'A description of the scope and nature of the plan.'
    contributor: List_['Reference'] = Field(default_factory=list)
    'Identifies the individual(s) or organization who provided the contents of the care plan.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    supportingInfo: List_['Reference'] = Field(default_factory=list)
    "Identifies portions of the patient's record that specifically influenced the formation of the plan.  These might include comorbidities, recent procedures, limitations, recent assessments, etc."
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally maintained protocol, guideline, questionnaire or other definition that is adhered to in whole or in part by this CarePlan.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'The URL pointing to a FHIR-defined protocol, guideline, questionnaire or other definition that is adhered to in whole or in part by this CarePlan.'


class CareTeamParticipant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies all people and organizations who are expected to be involved in the care team."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: List_['CodeableConcept'] = Field(default_factory=list)
    'Indicates specific responsibility of an individual within the care team, such as "Primary care physician", "Trained social worker counselor", "Caregiver", etc.'
    member: Optional_['Reference'] = Field(default=None)
    'The specific person or organization who is participating/expected to participate in the care team.'
    period: Optional_['Period'] = Field(default=None)
    'Indicates when the specific member or organization did (or is intended to) come into effect and end.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    onBehalfOf: Optional_['Reference'] = Field(default=None)
    'The organization of the practitioner.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CareTeam(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The Care Team includes all the people and organizations who plan to participate in the coordination and delivery of care for a patient."""
    resourceType: Literal_['CareTeam'] = Field(default=...)
    'Planned participants in the coordination and delivery of care for a patient or group'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A label for human use intended to distinguish like teams.  E.g. the "red" vs. "green" trauma teams.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments made about the CareTeam.'
    status: Optional_['code'] = Field(default=None)
    'Indicates the current state of the care team.'
    period: Optional_['Period'] = Field(default=None)
    'Indicates when the team did (or is intended to) come into effect and end.'
    subject: Optional_['Reference'] = Field(default=None)
    'Identifies the patient or group whose intended care is handled by the team.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'A central contact detail for the care team (that applies to all members).'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies what kind of team.  This is to support differentiation between multiple co-existing teams, such as care plan team, episode of care team, longitudinal care team.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which this CareTeam was created or to which the creation of this record is tightly associated.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this care team by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Describes why the care team exists.'
    participant: List_['CareTeamParticipant'] = Field(default_factory=list)
    'Identifies all people and organizations who are expected to be involved in the care team.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Condition(s) that this care team addresses.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    managingOrganization: List_['Reference'] = Field(default_factory=list)
    'The organization responsible for the care team.'


class CatalogEntryRelatedEntry(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Used for example, to point to a substance, or to a device used to administer a medication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    item: 'Reference' = Field(default=...)
    'The reference to the related item.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    relationtype: 'code' = Field(default=...)
    'The type of relation to the related item: child, parent, packageContent, containerPackage, usedIn, uses, requires, etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CatalogEntry(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Catalog entries are wrappers that contextualize items included in a catalog."""
    resourceType: Literal_['CatalogEntry'] = Field(default=...)
    'An entry in a catalog'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of item - medication, device, service, protocol or other.'
    status: Optional_['code'] = Field(default=None)
    'Used to support catalog exchange even for unsupported products, e.g. getting list of medications even if not prescribable.'
    validTo: Optional_['dateTime'] = Field(default=None)
    'The date until which this catalog entry is expected to be active.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    orderable: 'boolean' = Field(default=...)
    'Whether the entry represents an orderable item.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Used in supporting different identifiers for the same product, e.g. manufacturer code and retailer code.'
    lastUpdated: Optional_['dateTime'] = Field(default=None)
    'Typically date of issue is different from the beginning of the validity. This can be used to see when an item was last updated.'
    relatedEntry: List_['CatalogEntryRelatedEntry'] = Field(default_factory=list)
    'Used for example, to point to a substance, or to a device used to administer a medication.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    referencedItem: 'Reference' = Field(default=...)
    'The item in a catalog or definition.'
    classification: List_['CodeableConcept'] = Field(default_factory=list)
    'Classes of devices, or ATC for medication.'
    validityPeriod: Optional_['Period'] = Field(default=None)
    'The time period in which this catalog entry is expected to be active.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    additionalIdentifier: List_['Identifier'] = Field(default_factory=list)
    'Used in supporting related concepts, e.g. NDC to RxNorm.'
    additionalCharacteristic: List_['CodeableConcept'] = Field(default_factory=list)
    'Used for examplefor Out of Formulary, or any specifics.'
    additionalClassification: List_['CodeableConcept'] = Field(default_factory=list)
    'User for example for ATC classification, or.'


class ChargeItemPerformer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates who or what performed or participated in the charged service."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    actor: 'Reference' = Field(default=...)
    'The device, practitioner, etc. who performed or participated in the service.'
    function: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the type of performance or participation(e.g. primary surgeon, anesthesiologiest, etc.).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ChargeItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The resource ChargeItem describes the provision of healthcare provider products for a certain patient, therefore referring not only to the product, but containing in addition details of the provision, like date, time, amounts and participating organizations and persons. Main Usage of the ChargeItem is to enable the billing process and internal cost allocation."""
    resourceType: Literal_['ChargeItem'] = Field(default=...)
    'Item containing charge code(s) associated with the provision of healthcare provider products'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments made about the event by the performer, subject or other participants.'
    status: 'code' = Field(default=...)
    'The current state of the ChargeItem.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'ChargeItems can be grouped to larger ChargeItems covering the whole set.'
    reason: List_['CodeableConcept'] = Field(default_factory=list)
    'Describes why the event occurred in coded or textual form.'
    subject: 'Reference' = Field(default=...)
    'The individual or set of individuals the action is being or was performed on.'
    context: Optional_['Reference'] = Field(default=None)
    'The encounter or episode of care that establishes the context for this event.'
    enterer: Optional_['Reference'] = Field(default=None)
    'The device, practitioner, etc. who entered the charge item.'
    service: List_['Reference'] = Field(default_factory=list)
    'Indicated the rendered service that caused this charge.'
    account: List_['Reference'] = Field(default_factory=list)
    'Account into which this ChargeItems belongs.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'Quantity of which the charge item has been serviced.'
    bodysite: List_['CodeableConcept'] = Field(default_factory=list)
    'The anatomical location where the related service has been applied.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    performer: List_['ChargeItemPerformer'] = Field(default_factory=list)
    'Indicates who or what performed or participated in the charged service.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers assigned to this event performer or other systems.'
    costCenter: Optional_['Reference'] = Field(default=None)
    'The financial cost center permits the tracking of charge attribution.'
    productReference: Optional_['Reference'] = Field(default=None)
    'Identifies the device, food, drug or other product being charged either by type code or reference to an instance.'
    productCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the device, food, drug or other product being charged either by type code or reference to an instance.'
    enteredDate: Optional_['dateTime'] = Field(default=None)
    'Date the charge item was entered.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    definitionUri: List_['uri'] = Field(default_factory=list)
    'References the (external) source of pricing information, rules of application for the code this ChargeItem uses.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'Date/time(s) or duration when the charged service was applied.'
    occurrencePeriod: Optional_['Period'] = Field(default=None)
    'Date/time(s) or duration when the charged service was applied.'
    occurrenceTiming: Optional_['Timing'] = Field(default=None)
    'Date/time(s) or duration when the charged service was applied.'
    priceOverride: Optional_['Money'] = Field(default=None)
    'Total price of the charge overriding the list price associated with the code.'
    factorOverride: Optional_['decimal'] = Field(default=None)
    'Factor overriding the factor determined by the rules associated with the code.'
    overrideReason: Optional_['string'] = Field(default=None)
    'If the list price or the rule-based factor associated with the code is overridden, this attribute can capture a text to indicate the  reason for this action.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    definitionCanonical: List_['canonical'] = Field(default_factory=list)
    'References the source of pricing information, rules of application for the code this ChargeItem uses.'
    supportingInformation: List_['Reference'] = Field(default_factory=list)
    'Further information supporting this charge.'
    performingOrganization: Optional_['Reference'] = Field(default=None)
    'The organization requesting the service.'
    requestingOrganization: Optional_['Reference'] = Field(default=None)
    'The organization performing the service.'
    code: 'CodeableConcept' = Field(default=...)
    'A code that identifies the charge, like a billing code.'


class ChargeItemDefinitionPropertyGroup(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Group of properties which are applicable under the same conditions. If no applicability rules are established for the group, then all properties always apply."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    applicability: List_['ChargeItemDefinitionApplicability'] = Field(default_factory=list)
    'Expressions that describe applicability criteria for the priceComponent.'
    priceComponent: List_['ChargeItemDefinitionPropertyGroupPriceComponent'] = Field(default_factory=list)
    'The price for a ChargeItem may be calculated as a base price with surcharges/deductions that apply in certain conditions. A ChargeItemDefinition resource that defines the prices, factors and conditions that apply to a billing code is currently under development. The priceComponent element can be used to offer transparency to the recipient of the Invoice of how the prices have been calculated.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ChargeItemDefinitionPropertyGroupPriceComponent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The price for a ChargeItem may be calculated as a base price with surcharges/deductions that apply in certain conditions. A ChargeItemDefinition resource that defines the prices, factors and conditions that apply to a billing code is currently under development. The priceComponent element can be used to offer transparency to the recipient of the Invoice of how the prices have been calculated."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'This code identifies the type of the component.'
    factor: Optional_['decimal'] = Field(default=None)
    'The factor that has been applied on the base price for calculating this component.'
    amount: Optional_['Money'] = Field(default=None)
    'The amount calculated for this component.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code that identifies the component. Codes may be used to differentiate between kinds of taxes, surcharges, discounts etc.'


class ChargeItemDefinitionApplicability(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Expressions that describe applicability criteria for the billing code."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    language: Optional_['string'] = Field(default=None)
    'The media type of the language for the expression, e.g. "text/cql" for Clinical Query Language expressions or "text/fhirpath" for FHIRPath expressions.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: Optional_['string'] = Field(default=None)
    'An expression that returns true or false, indicating whether the condition is satisfied. When using FHIRPath expressions, the %context environment variable must be replaced at runtime with the ChargeItem resource to which this definition is applied.'
    description: Optional_['string'] = Field(default=None)
    'A brief, natural language description of the condition that effectively communicates the intended semantics.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ChargeItemDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The ChargeItemDefinition resource provides the properties that apply to the (billing) codes necessary to calculate costs and prices. The properties may differ largely depending on type and realm, therefore this resource gives only a rough structure and requires profiling for each type of billing code system."""
    resourceType: Literal_['ChargeItemDefinition'] = Field(default=...)
    'Definition of properties and rules about how the price and the applicability of a ChargeItem can be determined'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: 'uri' = Field(default=...)
    'An absolute URI that is used to identify this charge item definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this charge item definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the charge item definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the charge item definition.'
    partOf: List_['canonical'] = Field(default_factory=list)
    'A larger definition of which this particular definition is a component or step.'
    status: 'code' = Field(default=...)
    'The current state of the ChargeItemDefinition.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the charge item definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the charge item definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active assets.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    replaces: List_['canonical'] = Field(default_factory=list)
    'As new versions of a protocol or guideline are defined, allows identification of what versions are replaced by a new instance.'
    instance: List_['Reference'] = Field(default_factory=list)
    'The defined billing details in this resource pertain to the given product instance(s).'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the charge item definition.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the charge item definition and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the charge item definition.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this charge item definition when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate charge item definition instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the charge item definition from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this charge item definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the charge item definition is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    applicability: List_['ChargeItemDefinitionApplicability'] = Field(default_factory=list)
    'Expressions that describe applicability criteria for the billing code.'
    propertyGroup: List_['ChargeItemDefinitionPropertyGroup'] = Field(default_factory=list)
    'Group of properties which are applicable under the same conditions. If no applicability rules are established for the group, then all properties always apply.'
    derivedFromUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally-defined charge item definition that is adhered to in whole or in part by this definition.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the charge item definition content was or is planned to be in active use.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the charge item definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the charge item definition changes.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The defined billing details in this resource pertain to the given billing code.'


class CitationClassification(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The assignment to an organizing scheme."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of classifier (e.g. publication type, keyword).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    classifier: List_['CodeableConcept'] = Field(default_factory=list)
    'The specific classification value.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifact(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The article or artifact being described."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    part: Optional_['CitationCitedArtifactPart'] = Field(default=None)
    'The component of the article or artifact.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Any additional information or content for the article or artifact.'
    title: List_['CitationCitedArtifactTitle'] = Field(default_factory=list)
    'The title details of the article or artifact.'
    version: Optional_['CitationCitedArtifactVersion'] = Field(default=None)
    'The defined version of the cited artifact.'
    abstract: List_['CitationCitedArtifactAbstract'] = Field(default_factory=list)
    'Summary of the article or artifact.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    relatesTo: List_['CitationCitedArtifactRelatesTo'] = Field(default_factory=list)
    'The artifact related to the cited artifact.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this citation when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    statusDate: List_['CitationCitedArtifactStatusDate'] = Field(default_factory=list)
    'An effective date or period for a status of the cited artifact.'
    webLocation: List_['CitationCitedArtifactWebLocation'] = Field(default_factory=list)
    'Used for any URL for the article or artifact cited.'
    dateAccessed: Optional_['dateTime'] = Field(default=None)
    'When the cited artifact was accessed.'
    currentState: List_['CodeableConcept'] = Field(default_factory=list)
    'The status of the cited artifact.'
    classification: List_['CitationCitedArtifactClassification'] = Field(default_factory=list)
    'The assignment to an organizing scheme.'
    publicationForm: List_['CitationCitedArtifactPublicationForm'] = Field(default_factory=list)
    'If multiple, used to represent alternative forms of the article that are not separate citations.'
    contributorship: Optional_['CitationCitedArtifactContributorship'] = Field(default=None)
    'This element is used to list authors and other contributors, their contact information, specific contributions, and summary statements.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    relatedIdentifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify things closely related to this citation.'


class CitationCitedArtifactContributorship(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This element is used to list authors and other contributors, their contact information, specific contributions, and summary statements."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    entry: List_['CitationCitedArtifactContributorshipEntry'] = Field(default_factory=list)
    'An individual entity named in the author list or contributor list.'
    summary: List_['CitationCitedArtifactContributorshipSummary'] = Field(default_factory=list)
    'Used to record a display of the author/contributor list without separate coding for each list member.'
    complete: Optional_['boolean'] = Field(default=None)
    'Indicates if the list includes all authors and/or contributors.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactContributorshipSummary(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Used to record a display of the author/contributor list without separate coding for each list member."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Used most commonly to express an author list or a contributorship statement.'
    style: Optional_['CodeableConcept'] = Field(default=None)
    'The format for the display string.'
    value: 'markdown' = Field(default=...)
    'The display string for the author list, contributor list, or contributorship statement.'
    source: Optional_['CodeableConcept'] = Field(default=None)
    'Used to code the producer or rule for creating the display string.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactContributorshipEntry(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An individual entity named in the author list or contributor list."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['HumanName'] = Field(default=None)
    'A name associated with the individual.'
    role: Optional_['CodeableConcept'] = Field(default=None)
    'The role of the contributor (e.g. author, editor, reviewer).'
    address: List_['Address'] = Field(default_factory=list)
    'Physical mailing address for the author or contributor.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'Email or telephone contact methods for the author or contributor.'
    initials: Optional_['string'] = Field(default=None)
    'Initials for forename.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    listOrder: Optional_['positiveInt'] = Field(default=None)
    'Used to code order of authors.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique person identifier.'
    collectiveName: Optional_['string'] = Field(default=None)
    'Used for collective or corporate name as an author.'
    affiliationInfo: List_['CitationCitedArtifactContributorshipEntryAffiliationInfo'] = Field(default_factory=list)
    'Organization affiliated with the entity.'
    contributionType: List_['CodeableConcept'] = Field(default_factory=list)
    'This element identifies the specific nature of an individual’s contribution with respect to the cited work.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    contributionInstance: List_['CitationCitedArtifactContributorshipEntryContributionInstance'] = Field(default_factory=list)
    'Contributions with accounting for time or number.'
    correspondingContact: Optional_['boolean'] = Field(default=None)
    'Indication of which contributor is the corresponding contributor for the role.'


class CitationCitedArtifactContributorshipEntryContributionInstance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Contributions with accounting for time or number."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'The specific contribution.'
    time: Optional_['dateTime'] = Field(default=None)
    'The time that the contribution was made.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactContributorshipEntryAffiliationInfo(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Organization affiliated with the entity."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: Optional_['string'] = Field(default=None)
    'Role within the organization, such as professional title.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier for the organization.'
    affiliation: Optional_['string'] = Field(default=None)
    'Display for the organization.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactPublicationForm(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """If multiple, used to represent alternative forms of the article that are not separate citations."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    language: List_['CodeableConcept'] = Field(default_factory=list)
    'Language in which this form of the article is published.'
    lastPage: Optional_['string'] = Field(default=None)
    'Used for isolated representation of last page.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    firstPage: Optional_['string'] = Field(default=None)
    'Used for isolated representation of first page.'
    pageCount: Optional_['string'] = Field(default=None)
    'Actual or approximate number of pages or screens.'
    copyright: Optional_['markdown'] = Field(default=None)
    'Copyright notice for the full article or artifact.'
    pageString: Optional_['string'] = Field(default=None)
    'Used for full display of pagination.'
    publishedIn: Optional_['CitationCitedArtifactPublicationFormPublishedIn'] = Field(default=None)
    'The collection the cited article or artifact is published in.'
    articleDate: Optional_['dateTime'] = Field(default=None)
    'The date the article was added to the database, or the date the article was released (which may differ from the journal issue publication date).'
    periodicRelease: Optional_['CitationCitedArtifactPublicationFormPeriodicRelease'] = Field(default=None)
    'The specific issue in which the cited article resides.'
    accessionNumber: Optional_['string'] = Field(default=None)
    'Entry number or identifier for inclusion in a database.'
    lastRevisionDate: Optional_['dateTime'] = Field(default=None)
    'The date the article was last revised or updated in the database.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactPublicationFormPeriodicRelease(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The specific issue in which the cited article resides."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    issue: Optional_['string'] = Field(default=None)
    'Issue, part or supplement of journal in which the article is published.'
    volume: Optional_['string'] = Field(default=None)
    'Volume number of journal in which the article is published.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    citedMedium: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the form of the medium cited. Common codes are "Internet" or "Print".'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    dateOfPublication: Optional_['CitationCitedArtifactPublicationFormPeriodicReleaseDateOfPublication'] = Field(default=None)
    'Defining the date on which the issue of the journal was published.'


class CitationCitedArtifactPublicationFormPeriodicReleaseDateOfPublication(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Defining the date on which the issue of the journal was published."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    day: Optional_['string'] = Field(default=None)
    'Day on which the issue of the journal was published.'
    year: Optional_['string'] = Field(default=None)
    'Year on which the issue of the journal was published.'
    text: Optional_['string'] = Field(default=None)
    'Text representation of the date of which the issue of the journal was published.'
    month: Optional_['string'] = Field(default=None)
    'Month on which the issue of the journal was published.'
    season: Optional_['string'] = Field(default=None)
    'Spring, Summer, Fall/Autumn, Winter.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['date'] = Field(default=None)
    'Date on which the issue of the journal was published.'


class CitationCitedArtifactPublicationFormPublishedIn(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The collection the cited article or artifact is published in."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Kind of container (e.g. Periodical, database, or book).'
    title: Optional_['string'] = Field(default=None)
    'Name of the database or title of the book or journal.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['Reference'] = Field(default=None)
    'Name of the publisher.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Journal identifiers include ISSN, ISO Abbreviation and NLMuniqueID; Book identifiers include ISBN.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    publisherLocation: Optional_['string'] = Field(default=None)
    'Geographic location of the publisher.'


class CitationCitedArtifactClassification(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The assignment to an organizing scheme."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of classifier (e.g. publication type, keyword).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    classifier: List_['CodeableConcept'] = Field(default_factory=list)
    'The specific classification value.'
    whoClassified: Optional_['CitationCitedArtifactClassificationWhoClassified'] = Field(default=None)
    'Provenance and copyright of classification.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactClassificationWhoClassified(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Provenance and copyright of classification."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    person: Optional_['Reference'] = Field(default=None)
    'Person who created the classification.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['Reference'] = Field(default=None)
    'The publisher of the classification, not the publisher of the article or artifact being cited.'
    freeToShare: Optional_['boolean'] = Field(default=None)
    'Acceptable to re-use the classification.'
    organization: Optional_['Reference'] = Field(default=None)
    'Organization who created the classification.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    classifierCopyright: Optional_['string'] = Field(default=None)
    'Rights management statement for the classification.'


class CitationCitedArtifactWebLocation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Used for any URL for the article or artifact cited."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    url: Optional_['uri'] = Field(default=None)
    'The specific URL.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Code the reason for different URLs, e.g. abstract and full-text.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactStatusDate(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An effective date or period for a status of the cited artifact."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    actual: Optional_['boolean'] = Field(default=None)
    'Either occurred or expected.'
    period: 'Period' = Field(default=...)
    'When the status started and/or ended.'
    activity: 'CodeableConcept' = Field(default=...)
    'Classification of the status.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactRelatesTo(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The artifact related to the cited artifact."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    targetUri: Optional_['uri'] = Field(default=None)
    'The article or artifact that the cited artifact is related to.'
    targetIdentifier: Optional_['Identifier'] = Field(default=None)
    'The article or artifact that the cited artifact is related to.'
    targetReference: Optional_['Reference'] = Field(default=None)
    'The article or artifact that the cited artifact is related to.'
    targetAttachment: Optional_['Attachment'] = Field(default=None)
    'The article or artifact that the cited artifact is related to.'
    relationshipType: 'CodeableConcept' = Field(default=...)
    'How the cited artifact relates to the target artifact.'
    targetClassifier: List_['CodeableConcept'] = Field(default_factory=list)
    'The clasification of the related artifact.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactAbstract(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Summary of the article or artifact."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Used to express the reason or specific aspect for the abstract.'
    text: 'markdown' = Field(default=...)
    'Abstract content.'
    language: Optional_['CodeableConcept'] = Field(default=None)
    'Used to express the specific language.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    copyright: Optional_['markdown'] = Field(default=None)
    'Copyright notice for the abstract.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactVersion(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The defined version of the cited artifact."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: 'string' = Field(default=...)
    'The version number or other version identifier.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    baseCitation: Optional_['Reference'] = Field(default=None)
    'Citation for the main version of the cited artifact.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactTitle(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The title details of the article or artifact."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'Used to express the reason or specific aspect for the title.'
    text: 'markdown' = Field(default=...)
    'The title of the article or artifact.'
    language: Optional_['CodeableConcept'] = Field(default=None)
    'Used to express the specific language.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationCitedArtifactPart(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The component of the article or artifact."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of component.'
    value: Optional_['string'] = Field(default=None)
    'The specification of the component.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    baseCitation: Optional_['Reference'] = Field(default=None)
    'The citation for the full article or artifact.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationStatusDate(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An effective date or period for a status of the citation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    actual: Optional_['boolean'] = Field(default=None)
    'Either occurred or expected.'
    period: 'Period' = Field(default=...)
    'When the status started and/or ended.'
    activity: 'CodeableConcept' = Field(default=...)
    'Classification of the status.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationRelatesTo(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Artifact related to the Citation Resource."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    targetUri: Optional_['uri'] = Field(default=None)
    'The article or artifact that the Citation Resource is related to.'
    targetIdentifier: Optional_['Identifier'] = Field(default=None)
    'The article or artifact that the Citation Resource is related to.'
    targetReference: Optional_['Reference'] = Field(default=None)
    'The article or artifact that the Citation Resource is related to.'
    targetAttachment: Optional_['Attachment'] = Field(default=None)
    'The article or artifact that the Citation Resource is related to.'
    relationshipType: 'CodeableConcept' = Field(default=...)
    'How the Citation resource relates to the target artifact.'
    targetClassifier: List_['CodeableConcept'] = Field(default_factory=list)
    'The clasification of the related artifact.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CitationSummary(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A human-readable display of the citation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    text: 'markdown' = Field(default=...)
    'The human-readable display of the citation.'
    style: Optional_['CodeableConcept'] = Field(default=None)
    'Format for display of the citation.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Citation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The Citation Resource enables reference to any knowledge artifact for purposes of identification and attribution. The Citation Resource supports existing reference structures and developing publication practices such as versioning, expressing complex contributorship roles, and referencing computable resources."""
    resourceType: Literal_['Citation'] = Field(default=...)
    'A description of identification, location, or contributorship of a publication (article or artifact)'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this citation when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this summary is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the summary is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the citation. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Used for general notes and annotations not coded elsewhere.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the citation.'
    status: 'code' = Field(default=...)
    'The status of this summary. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'Who authored the Citation.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'Who edited the Citation.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the citation when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the citation author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this citation is needed and why it has been designed as it has.'
    summary: List_['CitationSummary'] = Field(default_factory=list)
    'A human-readable display of the citation.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'Who reviewed the Citation.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'Who endorsed the Citation.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the citation.'
    copyright: Optional_['markdown'] = Field(default=None)
    'Use and/or publishing restrictions for the Citation, not for the cited artifact.'
    relatesTo: List_['CitationRelatesTo'] = Field(default_factory=list)
    'Artifact related to the Citation Resource.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this citation when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate citation instances.'
    statusDate: List_['CitationStatusDate'] = Field(default_factory=list)
    'An effective date or period for a status of the citation.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the citation from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this citation is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the citation is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    currentState: List_['CodeableConcept'] = Field(default_factory=list)
    'The status of the citation.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    citedArtifact: Optional_['CitationCitedArtifact'] = Field(default=None)
    'The article or artifact being described.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    classification: List_['CitationClassification'] = Field(default_factory=list)
    'The assignment to an organizing scheme.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the citation content was or is planned to be in active use.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the citation was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the citation changes.'


class ClaimSupportingInfo(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'System and code pertaining to the specific information regarding special conditions relating to the setting, treatment or patient  for which care is sought.'
    reason: Optional_['CodeableConcept'] = Field(default=None)
    'Provides the reason in the situation where a reason code is required in addition to the content.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify supporting information entries.'
    category: 'CodeableConcept' = Field(default=...)
    'The general class of the information supplied: information; exception; accident, employment; onset, etc.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    valueString: Optional_['string'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    timingDate: Optional_['date'] = Field(default=None)
    'The date when or period to which this information refers.'
    timingPeriod: Optional_['Period'] = Field(default=None)
    'The date when or period to which this information refers.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimInsurance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Financial instruments for reimbursement for the health care products and services specified on the claim."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    focal: 'boolean' = Field(default=...)
    'A flag to indicate that this Coverage is to be used for adjudication of this claim when set to true.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify insurance entries and provide a sequence of coverages to convey coordination of benefit order.'
    coverage: 'Reference' = Field(default=...)
    "Reference to the insurance card level information contained in the Coverage resource. The coverage issuing insurer will use these details to locate the patient's actual coverage within the insurer's information system."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'The business identifier to be used when the claim is sent for adjudication against this insurance policy.'
    preAuthRef: List_['string'] = Field(default_factory=list)
    'Reference numbers previously provided by the insurer to the provider to be quoted on subsequent claims containing services or products related to the prior authorization.'
    claimResponse: Optional_['Reference'] = Field(default=None)
    'The result of the adjudication of the line items for the Coverage specified in this insurance.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    businessArrangement: Optional_['string'] = Field(default=None)
    'A business agreement number established between the provider and the insurer for special business processing purposes.'


class ClaimProcedure(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Procedures performed on the patient relevant to the billing items with the claim."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    udi: List_['Reference'] = Field(default_factory=list)
    'Unique Device Identifiers associated with this line item.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'When the condition was observed or the relative ranking.'
    date: Optional_['dateTime'] = Field(default=None)
    'Date and optionally time the procedure was performed.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify procedure entries.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    procedureCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The code or reference to a Procedure resource which identifies the clinical intervention performed.'
    procedureReference: Optional_['Reference'] = Field(default=None)
    'The code or reference to a Procedure resource which identifies the clinical intervention performed.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimDiagnosis(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about diagnoses relevant to the claim items."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'When the condition was observed or the relative ranking.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify diagnosis entries.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    onAdmission: Optional_['CodeableConcept'] = Field(default=None)
    'Indication of whether the diagnosis was present on admission to a facility.'
    packageCode: Optional_['CodeableConcept'] = Field(default=None)
    'A package billing code or bundle code used to group products and services to a particular health condition (such as heart attack) which is based on a predetermined grouping code system.'
    diagnosisCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The nature of illness or problem in a coded form or as a reference to an external defined Condition.'
    diagnosisReference: Optional_['Reference'] = Field(default=None)
    'The nature of illness or problem in a coded form or as a reference to an external defined Condition.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimAccident(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details of an accident which resulted in injuries which required the products and services listed in the claim."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type or context of the accident event for the purposes of selection of potential insurance coverages and determination of coordination between insurers.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    locationAddress: Optional_['Address'] = Field(default=None)
    'The physical location of the accident event.'
    locationReference: Optional_['Reference'] = Field(default=None)
    'The physical location of the accident event.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: 'date' = Field(default=...)
    'Date of an accident event  related to the products and services contained in the claim.'


class ClaimCareTeam(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The members of the team who provided the products and services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: Optional_['CodeableConcept'] = Field(default=None)
    'The lead, assisting or supervising practitioner and their discipline if a multidisciplinary team.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify care team entries.'
    provider: 'Reference' = Field(default=...)
    'Member of the team who provided the product or service.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    responsible: Optional_['boolean'] = Field(default=None)
    'The party who is billing and/or responsible for the claimed products or services.'
    qualification: Optional_['CodeableConcept'] = Field(default=None)
    'The qualification of the practitioner which is applicable for this service.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimRelated(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Other claims which are related to this claim such as prior submissions or claims for related services or for the same event."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    claim: Optional_['Reference'] = Field(default=None)
    'Reference to a related claim.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: Optional_['Identifier'] = Field(default=None)
    'An alternate organizational reference to the case or file to which this particular claim pertains.'
    relationship: Optional_['CodeableConcept'] = Field(default=None)
    'A code to convey how the claims are related.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimPayee(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The party to be reimbursed for cost of the products and services according to the terms of the policy."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Type of Party to be reimbursed: subscriber, provider, other.'
    party: Optional_['Reference'] = Field(default=None)
    'Reference to the individual or organization to whom any payment will be made.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A claim line. Either a simple  product or service or a 'group' of details which can each be a simple items or groups of sub-details."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    udi: List_['Reference'] = Field(default_factory=list)
    'Unique Device Identifiers associated with this line item.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    detail: List_['ClaimItemDetail'] = Field(default_factory=list)
    "A claim detail line. Either a simple (a product or service) or a 'group' of sub-details which are simple items."
    revenue: Optional_['CodeableConcept'] = Field(default=None)
    'The type of revenue or cost center providing the product and/or service.'
    subSite: List_['CodeableConcept'] = Field(default_factory=list)
    'A region or surface of the bodySite, e.g. limb region or tooth surface(s).'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify item entries.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Code to identify the general type of benefits under which products and services are provided.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    bodySite: Optional_['CodeableConcept'] = Field(default=None)
    'Physical service site on the patient (limb, tooth, etc.).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    encounter: List_['Reference'] = Field(default_factory=list)
    'The Encounters during which this Claim was created or to which the creation of this record is tightly associated.'
    programCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the program under which this may be recovered.'
    servicedDate: Optional_['date'] = Field(default=None)
    'The date or dates when the service or product was supplied, performed or completed.'
    servicedPeriod: Optional_['Period'] = Field(default=None)
    'The date or dates when the service or product was supplied, performed or completed.'
    locationCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Where the product or service was provided.'
    locationAddress: Optional_['Address'] = Field(default=None)
    'Where the product or service was provided.'
    locationReference: Optional_['Reference'] = Field(default=None)
    'Where the product or service was provided.'
    careTeamSequence: List_['positiveInt'] = Field(default_factory=list)
    'CareTeam members related to this service or product.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    diagnosisSequence: List_['positiveInt'] = Field(default_factory=list)
    'Diagnosis applicable for this service or product.'
    procedureSequence: List_['positiveInt'] = Field(default_factory=list)
    'Procedures applicable for this service or product.'
    informationSequence: List_['positiveInt'] = Field(default_factory=list)
    'Exceptions, special conditions and supporting information applicable for this service or product.'


class ClaimItemDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A claim detail line. Either a simple (a product or service) or a 'group' of sub-details which are simple items."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    udi: List_['Reference'] = Field(default_factory=list)
    'Unique Device Identifiers associated with this line item.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    revenue: Optional_['CodeableConcept'] = Field(default=None)
    'The type of revenue or cost center providing the product and/or service.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify item entries.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Code to identify the general type of benefits under which products and services are provided.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    subDetail: List_['ClaimItemDetailSubDetail'] = Field(default_factory=list)
    "A claim detail line. Either a simple (a product or service) or a 'group' of sub-details which are simple items."
    programCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the program under which this may be recovered.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimItemDetailSubDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A claim detail line. Either a simple (a product or service) or a 'group' of sub-details which are simple items."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    udi: List_['Reference'] = Field(default_factory=list)
    'Unique Device Identifiers associated with this line item.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    revenue: Optional_['CodeableConcept'] = Field(default=None)
    'The type of revenue or cost center providing the product and/or service.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify item entries.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Code to identify the general type of benefits under which products and services are provided.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    programCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the program under which this may be recovered.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Claim(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement."""
    resourceType: Literal_['Claim'] = Field(default=...)
    'Claim, Pre-determination or Pre-authorization'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    use: 'code' = Field(default=...)
    'A code to indicate whether the nature of the request is: to request adjudication of products and services previously rendered; or requesting authorization and adjudication for provision in the future; or requesting the non-binding adjudication of the listed products and services which could be provided in the future.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'CodeableConcept' = Field(default=...)
    'The category of claim, e.g. oral, pharmacy, vision, institutional, professional.'
    item: List_['ClaimItem'] = Field(default_factory=list)
    "A claim line. Either a simple  product or service or a 'group' of details which can each be a simple items or groups of sub-details."
    payee: Optional_['ClaimPayee'] = Field(default=None)
    'The party to be reimbursed for cost of the products and services according to the terms of the policy.'
    total: Optional_['Money'] = Field(default=None)
    'The total value of the all the items in the claim.'
    status: 'code' = Field(default=...)
    'The status of the resource instance.'
    subType: Optional_['CodeableConcept'] = Field(default=None)
    'A finer grained suite of claim type codes which may convey additional information such as Inpatient vs Outpatient and/or a specialty service.'
    patient: 'Reference' = Field(default=...)
    'The party to whom the professional services and/or products have been supplied or are being considered and for whom actual or forecast reimbursement is sought.'
    created: 'dateTime' = Field(default=...)
    'The date this resource was created.'
    enterer: Optional_['Reference'] = Field(default=None)
    'Individual who created the claim, predetermination or preauthorization.'
    insurer: Optional_['Reference'] = Field(default=None)
    'The Insurer who is target of the request.'
    related: List_['ClaimRelated'] = Field(default_factory=list)
    'Other claims which are related to this claim such as prior submissions or claims for related services or for the same event.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    provider: 'Reference' = Field(default=...)
    'The provider which is responsible for the claim, predetermination or preauthorization.'
    priority: 'CodeableConcept' = Field(default=...)
    'The provider-required urgency of processing the request. Typical values include: stat, routine deferred.'
    referral: Optional_['Reference'] = Field(default=None)
    'A reference to a referral resource.'
    facility: Optional_['Reference'] = Field(default=None)
    'Facility where the services were provided.'
    careTeam: List_['ClaimCareTeam'] = Field(default_factory=list)
    'The members of the team who provided the products and services.'
    accident: Optional_['ClaimAccident'] = Field(default=None)
    'Details of an accident which resulted in injuries which required the products and services listed in the claim.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    diagnosis: List_['ClaimDiagnosis'] = Field(default_factory=list)
    'Information about diagnoses relevant to the claim items.'
    procedure: List_['ClaimProcedure'] = Field(default_factory=list)
    'Procedures performed on the patient relevant to the billing items with the claim.'
    insurance: List_['ClaimInsurance'] = Field(default=...)
    'Financial instruments for reimbursement for the health care products and services specified on the claim.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this claim.'
    fundsReserve: Optional_['CodeableConcept'] = Field(default=None)
    'A code to indicate whether and for whom funds are to be reserved for future claims.'
    prescription: Optional_['Reference'] = Field(default=None)
    'Prescription to support the dispensing of pharmacy, device or vision products.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    billablePeriod: Optional_['Period'] = Field(default=None)
    'The period for which charges are being submitted.'
    supportingInfo: List_['ClaimSupportingInfo'] = Field(default_factory=list)
    'Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    originalPrescription: Optional_['Reference'] = Field(default=None)
    'Original prescription which has been superseded by this prescription to support the dispensing of pharmacy services, medications or products.'


class ClaimResponseProcessNote(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A note that describes or explains adjudication results in a human readable form."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['code'] = Field(default=None)
    'The business purpose of the note text.'
    text: 'string' = Field(default=...)
    'The explanation or description associated with the processing.'
    number: Optional_['positiveInt'] = Field(default=None)
    'A number to uniquely identify a note entry.'
    language: Optional_['CodeableConcept'] = Field(default=None)
    'A code to define the language used in the text of the note.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimResponseInsurance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Financial instruments for reimbursement for the health care products and services specified on the claim."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    focal: 'boolean' = Field(default=...)
    'A flag to indicate that this Coverage is to be used for adjudication of this claim when set to true.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify insurance entries and provide a sequence of coverages to convey coordination of benefit order.'
    coverage: 'Reference' = Field(default=...)
    "Reference to the insurance card level information contained in the Coverage resource. The coverage issuing insurer will use these details to locate the patient's actual coverage within the insurer's information system."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    claimResponse: Optional_['Reference'] = Field(default=None)
    'The result of the adjudication of the line items for the Coverage specified in this insurance.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    businessArrangement: Optional_['string'] = Field(default=None)
    'A business agreement number established between the provider and the insurer for special business processing purposes.'


class ClaimResponsePayment(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Payment details for the adjudication of the claim."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Whether this represents partial or complete payment of the benefits payable.'
    amount: 'Money' = Field(default=...)
    'Benefits payable less any payment adjustment.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    adjustment: Optional_['Money'] = Field(default=None)
    "Total amount of all adjustments to this payment included in this transaction which are not related to this claim's adjudication."
    identifier: Optional_['Identifier'] = Field(default=None)
    "Issuer's unique identifier for the payment instrument."
    adjustmentReason: Optional_['CodeableConcept'] = Field(default=None)
    'Reason for the payment adjustment.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['date'] = Field(default=None)
    'Estimated date the payment will be issued or the actual issue date of payment.'


class ClaimResponseAddItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The first-tier service adjudications for payor added product or service lines."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    detail: List_['ClaimResponseAddItemDetail'] = Field(default_factory=list)
    'The second-tier service adjudications for payor added services.'
    subSite: List_['CodeableConcept'] = Field(default_factory=list)
    'A region or surface of the bodySite, e.g. limb region or tooth surface(s).'
    provider: List_['Reference'] = Field(default_factory=list)
    'The providers who are authorized for the services rendered to the patient.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    bodySite: Optional_['CodeableConcept'] = Field(default=None)
    'Physical service site on the patient (limb, tooth, etc.).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    programCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the program under which this may be recovered.'
    servicedDate: Optional_['date'] = Field(default=None)
    'The date or dates when the service or product was supplied, performed or completed.'
    servicedPeriod: Optional_['Period'] = Field(default=None)
    'The date or dates when the service or product was supplied, performed or completed.'
    locationCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Where the product or service was provided.'
    locationAddress: Optional_['Address'] = Field(default=None)
    'Where the product or service was provided.'
    locationReference: Optional_['Reference'] = Field(default=None)
    'Where the product or service was provided.'
    itemSequence: List_['positiveInt'] = Field(default_factory=list)
    'Claim items which this service line is intended to replace.'
    adjudication: List_['ClaimResponseItemAdjudication'] = Field(default=...)
    'The adjudication results.'
    detailSequence: List_['positiveInt'] = Field(default_factory=list)
    'The sequence number of the details within the claim item which this line is intended to replace.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    subdetailSequence: List_['positiveInt'] = Field(default_factory=list)
    'The sequence number of the sub-details within the details within the claim item which this line is intended to replace.'


class ClaimResponseAddItemDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The second-tier service adjudications for payor added services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    subDetail: List_['ClaimResponseAddItemDetailSubDetail'] = Field(default_factory=list)
    'The third-tier service adjudications for payor added services.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    adjudication: List_['ClaimResponseItemAdjudication'] = Field(default=...)
    'The adjudication results.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimResponseAddItemDetailSubDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The third-tier service adjudications for payor added services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    adjudication: List_['ClaimResponseItemAdjudication'] = Field(default=...)
    'The adjudication results.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimResponseError(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Errors encountered during the processing of the adjudication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'An error code, from a specified code system, which details why the claim could not be adjudicated.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    itemSequence: Optional_['positiveInt'] = Field(default=None)
    'The sequence number of the line item submitted which contains the error. This value is omitted when the error occurs outside of the item structure.'
    detailSequence: Optional_['positiveInt'] = Field(default=None)
    'The sequence number of the detail within the line item submitted which contains the error. This value is omitted when the error occurs outside of the item structure.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    subDetailSequence: Optional_['positiveInt'] = Field(default=None)
    'The sequence number of the sub-detail within the detail within the line item submitted which contains the error. This value is omitted when the error occurs outside of the item structure.'


class ClaimResponseTotal(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Categorized monetary totals for the adjudication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    amount: 'Money' = Field(default=...)
    'Monetary total amount associated with the category.'
    category: 'CodeableConcept' = Field(default=...)
    'A code to indicate the information type of this adjudication record. Information types may include: the value submitted, maximum values or percentages allowed or payable under the plan, amounts that the patient is responsible for in aggregate or pertaining to this item, amounts paid by other coverages, and the benefit payable for this item.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimResponseItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    detail: List_['ClaimResponseItemDetail'] = Field(default_factory=list)
    "A claim detail. Either a simple (a product or service) or a 'group' of sub-details which are simple items."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    itemSequence: 'positiveInt' = Field(default=...)
    'A number to uniquely reference the claim item entries.'
    adjudication: List_['ClaimResponseItemAdjudication'] = Field(default=...)
    'If this item is a group then the values here are a summary of the adjudication of the detail items. If this item is a simple product or service then this is the result of the adjudication of this item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimResponseItemAdjudication(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """If this item is a group then the values here are a summary of the adjudication of the detail items. If this item is a simple product or service then this is the result of the adjudication of this item."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: Optional_['decimal'] = Field(default=None)
    'A non-monetary value associated with the category. Mutually exclusive to the amount element above.'
    reason: Optional_['CodeableConcept'] = Field(default=None)
    'A code supporting the understanding of the adjudication result and explaining variance from expected amount.'
    amount: Optional_['Money'] = Field(default=None)
    'Monetary amount associated with the category.'
    category: 'CodeableConcept' = Field(default=...)
    'A code to indicate the information type of this adjudication record. Information types may include the value submitted, maximum values or percentages allowed or payable under the plan, amounts that: the patient is responsible for in aggregate or pertaining to this item; amounts paid by other coverages; and, the benefit payable for this item.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimResponseItemDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A claim detail. Either a simple (a product or service) or a 'group' of sub-details which are simple items."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    subDetail: List_['ClaimResponseItemDetailSubDetail'] = Field(default_factory=list)
    'A sub-detail adjudication of a simple product or service.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    adjudication: List_['ClaimResponseItemAdjudication'] = Field(default=...)
    'The adjudication results.'
    detailSequence: 'positiveInt' = Field(default=...)
    'A number to uniquely reference the claim detail entry.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClaimResponseItemDetailSubDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A sub-detail adjudication of a simple product or service."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    adjudication: List_['ClaimResponseItemAdjudication'] = Field(default_factory=list)
    'The adjudication results.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    subDetailSequence: 'positiveInt' = Field(default=...)
    'A number to uniquely reference the claim sub-detail entry.'


class ClaimResponse(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource provides the adjudication details from the processing of a Claim resource."""
    resourceType: Literal_['ClaimResponse'] = Field(default=...)
    'Response to a claim predetermination or preauthorization'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    use: 'code' = Field(default=...)
    'A code to indicate whether the nature of the request is: to request adjudication of products and services previously rendered; or requesting authorization and adjudication for provision in the future; or requesting the non-binding adjudication of the listed products and services which could be provided in the future.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'CodeableConcept' = Field(default=...)
    'A finer grained suite of claim type codes which may convey additional information such as Inpatient vs Outpatient and/or a specialty service.'
    item: List_['ClaimResponseItem'] = Field(default_factory=list)
    "A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details."
    form: Optional_['Attachment'] = Field(default=None)
    'The actual form, by reference or inclusion, for printing the content or an EOB.'
    total: List_['ClaimResponseTotal'] = Field(default_factory=list)
    'Categorized monetary totals for the adjudication.'
    error: List_['ClaimResponseError'] = Field(default_factory=list)
    'Errors encountered during the processing of the adjudication.'
    status: 'code' = Field(default=...)
    'The status of the resource instance.'
    subType: Optional_['CodeableConcept'] = Field(default=None)
    'A finer grained suite of claim type codes which may convey additional information such as Inpatient vs Outpatient and/or a specialty service.'
    patient: 'Reference' = Field(default=...)
    'The party to whom the professional services and/or products have been supplied or are being considered and for whom actual for facast reimbursement is sought.'
    created: 'dateTime' = Field(default=...)
    'The date this resource was created.'
    insurer: 'Reference' = Field(default=...)
    'The party responsible for authorization, adjudication and reimbursement.'
    request: Optional_['Reference'] = Field(default=None)
    'Original request resource reference.'
    outcome: 'code' = Field(default=...)
    'The outcome of the claim, predetermination, or preauthorization processing.'
    addItem: List_['ClaimResponseAddItem'] = Field(default_factory=list)
    'The first-tier service adjudications for payor added product or service lines.'
    payment: Optional_['ClaimResponsePayment'] = Field(default=None)
    'Payment details for the adjudication of the claim.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    formCode: Optional_['CodeableConcept'] = Field(default=None)
    'A code for the form to be used for printing the content.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    requestor: Optional_['Reference'] = Field(default=None)
    'The provider which is responsible for the claim, predetermination or preauthorization.'
    payeeType: Optional_['CodeableConcept'] = Field(default=None)
    'Type of Party to be reimbursed: subscriber, provider, other.'
    insurance: List_['ClaimResponseInsurance'] = Field(default_factory=list)
    'Financial instruments for reimbursement for the health care products and services specified on the claim.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this claim response.'
    preAuthRef: Optional_['string'] = Field(default=None)
    'Reference from the Insurer which is used in later communications which refers to this adjudication.'
    disposition: Optional_['string'] = Field(default=None)
    'A human readable description of the status of the adjudication.'
    processNote: List_['ClaimResponseProcessNote'] = Field(default_factory=list)
    'A note that describes or explains adjudication results in a human readable form.'
    adjudication: List_['ClaimResponseItemAdjudication'] = Field(default_factory=list)
    'The adjudication results which are presented at the header level rather than at the line-item or add-item levels.'
    fundsReserve: Optional_['CodeableConcept'] = Field(default=None)
    'A code, used only on a response to a preauthorization, to indicate whether the benefits payable have been reserved and for whom.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    preAuthPeriod: Optional_['Period'] = Field(default=None)
    'The time frame during which this authorization is effective.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    communicationRequest: List_['Reference'] = Field(default_factory=list)
    'Request for additional supporting or authorizing information.'


class ClinicalImpressionInvestigation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """One or more sets of investigations (signs, symptoms, etc.). The actual grouping of investigations varies greatly depending on the type and context of the assessment. These investigations may include data generated during the assessment process, or data previously generated and recorded that is pertinent to the outcomes."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'A name/code for the group ("set") of investigations. Typically, this will be something like "signs", "symptoms", "clinical", "diagnostic", but the list is not constrained, and others such groups such as (exposure|family|travel|nutritional) history may be used.'
    item: List_['Reference'] = Field(default_factory=list)
    'A record of a specific investigation that was undertaken.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClinicalImpressionFinding(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specific findings or diagnoses that were considered likely or relevant to ongoing treatment."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    basis: Optional_['string'] = Field(default=None)
    'Which investigations support finding or diagnosis.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    itemReference: Optional_['Reference'] = Field(default=None)
    'Specific reference for finding or diagnosis, which may include ruled-out or resolved conditions.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    itemCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Specific text or code for finding or diagnosis, which may include ruled-out or resolved conditions.'


class ClinicalImpression(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A record of a clinical assessment performed to determine what problem(s) may affect the patient and before planning the treatments or management strategies that are best to manage a patient's condition. Assessments are often 1:1 with a clinical consultation / encounter,  but this varies greatly depending on the clinical workflow. This resource is called "ClinicalImpression" rather than "ClinicalAssessment" to avoid confusion with the recording of assessment tools such as Apgar score."""
    resourceType: Literal_['ClinicalImpression'] = Field(default=...)
    'A clinical assessment performed when planning treatments and management strategies for a patient'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    date: Optional_['dateTime'] = Field(default=None)
    'Indicates when the documentation of the assessment was complete.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Commentary about the impression, typically recorded after the impression itself was made, though supplemental notes by the original author could also appear.'
    status: 'code' = Field(default=...)
    'Identifies the workflow status of the assessment.'
    subject: 'Reference' = Field(default=...)
    'The patient or group of individuals assessed as part of this record.'
    problem: List_['Reference'] = Field(default_factory=list)
    'A list of the relevant problems/conditions for a patient.'
    summary: Optional_['string'] = Field(default=None)
    'A text summary of the investigations and the diagnosis.'
    finding: List_['ClinicalImpressionFinding'] = Field(default_factory=list)
    'Specific findings or diagnoses that were considered likely or relevant to ongoing treatment.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    assessor: Optional_['Reference'] = Field(default=None)
    'The clinician performing the assessment.'
    previous: Optional_['Reference'] = Field(default=None)
    "A reference to the last assessment that was conducted on this patient. Assessments are often/usually ongoing in nature; a care provider (practitioner or team) will make new assessments on an ongoing basis as new data arises or the patient's conditions changes."
    protocol: List_['uri'] = Field(default_factory=list)
    'Reference to a specific published clinical protocol that was followed during this assessment, and/or that provides evidence in support of the diagnosis.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which this ClinicalImpression was created or to which the creation of this record is tightly associated.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this clinical impression by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    description: Optional_['string'] = Field(default=None)
    'A summary of the context and/or cause of the assessment - why / where it was performed, and what patient events/status prompted it.'
    statusReason: Optional_['CodeableConcept'] = Field(default=None)
    'Captures the reason for the current state of the ClinicalImpression.'
    effectiveDateTime: Optional_['dateTime'] = Field(default=None)
    'The point in time or period over which the subject was assessed.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The point in time or period over which the subject was assessed.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    investigation: List_['ClinicalImpressionInvestigation'] = Field(default_factory=list)
    'One or more sets of investigations (signs, symptoms, etc.). The actual grouping of investigations varies greatly depending on the type and context of the assessment. These investigations may include data generated during the assessment process, or data previously generated and recorded that is pertinent to the outcomes.'
    supportingInfo: List_['Reference'] = Field(default_factory=list)
    'Information supporting the clinical impression.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    prognosisReference: List_['Reference'] = Field(default_factory=list)
    'RiskAssessment expressing likely outcome.'
    prognosisCodeableConcept: List_['CodeableConcept'] = Field(default_factory=list)
    'Estimate of likely outcome.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Categorizes the type of clinical assessment performed.'


class ClinicalUseDefinitionUndesirableEffect(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    classification: Optional_['CodeableConcept'] = Field(default=None)
    'High level classification of the effect.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    frequencyOfOccurrence: Optional_['CodeableConcept'] = Field(default=None)
    'How often the effect is seen.'
    symptomConditionEffect: Optional_['CodeableReference'] = Field(default=None)
    'The situation in which the undesirable effect may manifest.'


class ClinicalUseDefinitionContraindication(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifics for when this is a contraindication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    indication: List_['Reference'] = Field(default_factory=list)
    'The indication which this is a contraidication for.'
    comorbidity: List_['CodeableReference'] = Field(default_factory=list)
    'A comorbidity (concurrent condition) or coinfection.'
    otherTherapy: List_['ClinicalUseDefinitionContraindicationOtherTherapy'] = Field(default_factory=list)
    'Information about the use of the medicinal product in relation to other therapies described as part of the contraindication.'
    diseaseStatus: Optional_['CodeableReference'] = Field(default=None)
    'The status of the disease or symptom for the contraindication, for example "chronic" or "metastatic".'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    diseaseSymptomProcedure: Optional_['CodeableReference'] = Field(default=None)
    'The situation that is being documented as contraindicating against this item.'


class ClinicalUseDefinitionContraindicationOtherTherapy(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the use of the medicinal product in relation to other therapies described as part of the contraindication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    therapy: 'CodeableReference' = Field(default=...)
    'Reference to a specific medication (active substance, medicinal product or class of products) as part of an indication or contraindication.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    relationshipType: 'CodeableConcept' = Field(default=...)
    'The type of relationship between the medicinal product indication or contraindication and another therapy.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClinicalUseDefinitionInteraction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifics for when this is an interaction."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of the interaction e.g. drug-drug interaction, drug-food interaction, drug-lab test interaction.'
    effect: Optional_['CodeableReference'] = Field(default=None)
    'The effect of the interaction, for example "reduced gastric absorption of primary medication".'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    incidence: Optional_['CodeableConcept'] = Field(default=None)
    'The incidence of the interaction, e.g. theoretical, observed.'
    management: List_['CodeableConcept'] = Field(default_factory=list)
    'Actions for managing the interaction.'
    interactant: List_['ClinicalUseDefinitionInteractionInteractant'] = Field(default_factory=list)
    'The specific medication, food, substance or laboratory test that interacts.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClinicalUseDefinitionInteractionInteractant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The specific medication, food, substance or laboratory test that interacts."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    itemReference: Optional_['Reference'] = Field(default=None)
    'The specific medication, food or laboratory test that interacts.'
    itemCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The specific medication, food or laboratory test that interacts.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClinicalUseDefinitionIndication(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifics for when this is an indication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    comorbidity: List_['CodeableReference'] = Field(default_factory=list)
    'A comorbidity (concurrent condition) or coinfection as part of the indication.'
    durationRange: Optional_['Range'] = Field(default=None)
    'Timing or duration information, that may be associated with use with the indicated condition e.g. Adult patients suffering from myocardial infarction (from a few days until less than 35 days), ischaemic stroke (from 7 days until less than 6 months).'
    durationString: Optional_['string'] = Field(default=None)
    'Timing or duration information, that may be associated with use with the indicated condition e.g. Adult patients suffering from myocardial infarction (from a few days until less than 35 days), ischaemic stroke (from 7 days until less than 6 months).'
    otherTherapy: List_['ClinicalUseDefinitionContraindicationOtherTherapy'] = Field(default_factory=list)
    'Information about the use of the medicinal product in relation to other therapies described as part of the indication.'
    diseaseStatus: Optional_['CodeableReference'] = Field(default=None)
    'The status of the disease or symptom for the indication, for example "chronic" or "metastatic".'
    intendedEffect: Optional_['CodeableReference'] = Field(default=None)
    'The intended effect, aim or strategy to be achieved.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    undesirableEffect: List_['Reference'] = Field(default_factory=list)
    'An unwanted side effect or negative outcome that may happen if you use the drug (or other subject of this resource) for this indication.'
    diseaseSymptomProcedure: Optional_['CodeableReference'] = Field(default=None)
    'The situation that is being documented as an indicaton for this item.'


class ClinicalUseDefinitionWarning(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A critical piece of information about environmental, health or physical risks or hazards that serve as caution to the user. For example 'Do not operate heavy machinery', 'May cause drowsiness', or 'Get medical advice/attention if you feel unwell'."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A coded or unformatted textual definition of this warning.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['markdown'] = Field(default=None)
    'A textual definition of this warning, with formatting.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ClinicalUseDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A single issue - either an indication, contraindication, interaction or an undesirable effect for a medicinal product, medication, device or procedure."""
    resourceType: Literal_['ClinicalUseDefinition'] = Field(default=...)
    'A single issue - either an indication, contraindication, interaction or an undesirable effect for a medicinal product, medication, device or procedure'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'code' = Field(default=...)
    'indication | contraindication | interaction | undesirable-effect | warning.'
    status: Optional_['CodeableConcept'] = Field(default=None)
    'Whether this is a current issue or one that has been retired etc.'
    subject: List_['Reference'] = Field(default_factory=list)
    'The medication or procedure for which this is an indication.'
    warning: Optional_['ClinicalUseDefinitionWarning'] = Field(default=None)
    "A critical piece of information about environmental, health or physical risks or hazards that serve as caution to the user. For example 'Do not operate heavy machinery', 'May cause drowsiness', or 'Get medical advice/attention if you feel unwell'."
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'A categorisation of the issue, primarily for dividing warnings into subject heading areas such as "Pregnancy and Lactation", "Overdose", "Effects on Ability to Drive and Use Machines".'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifier for this issue.'
    indication: Optional_['ClinicalUseDefinitionIndication'] = Field(default=None)
    'Specifics for when this is an indication.'
    population: List_['Reference'] = Field(default_factory=list)
    'The population group to which this applies.'
    interaction: Optional_['ClinicalUseDefinitionInteraction'] = Field(default=None)
    'Specifics for when this is an interaction.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    contraindication: Optional_['ClinicalUseDefinitionContraindication'] = Field(default=None)
    'Specifics for when this is a contraindication.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    undesirableEffect: Optional_['ClinicalUseDefinitionUndesirableEffect'] = Field(default=None)
    'Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment.'


class CodeSystemProperty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A property defines an additional slot through which additional information can be provided about a concept."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of the property value. Properties of type "code" contain a code defined by the code system (e.g. a reference to another defined concept).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'A description of the property- why it is defined, and how its value might be used.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    uri: Optional_['uri'] = Field(default=None)
    'Reference to the formal meaning of the property. One possible source of meaning is the [Concept Properties](codesystem-concept-properties.html) code system.'
    code: 'code' = Field(default=...)
    'A code that is used to identify the property. The code is used internally (in CodeSystem.concept.property.code) and also externally, such as in property filters.'


class CodeSystemConcept(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Concepts that are in the code system. The concept definitions are inherently hierarchical, but the definitions must be consulted to determine what the meanings of the hierarchical relationships are."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    display: Optional_['string'] = Field(default=None)
    'A human readable string that is the recommended default way to present this concept to a user.'
    concept: List_['CodeSystemConcept'] = Field(default_factory=list)
    'Defines children of a concept to produce a hierarchy of concepts. The nature of the relationships is variable (is-a/contains/categorizes) - see hierarchyMeaning.'
    property: List_['CodeSystemConceptProperty'] = Field(default_factory=list)
    'A property value for this concept.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    definition: Optional_['string'] = Field(default=None)
    'The formal definition of the concept. The code system resource does not make formal definitions required, because of the prevalence of legacy systems. However, they are highly recommended, as without them there is no formal meaning associated with the concept.'
    designation: List_['CodeSystemConceptDesignation'] = Field(default_factory=list)
    'Additional representations for the concept - other languages, aliases, specialized purposes, used for particular purposes, etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'A code - a text symbol - that uniquely identifies the concept within the code system.'


class CodeSystemConceptDesignation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Additional representations for the concept - other languages, aliases, specialized purposes, used for particular purposes, etc."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: Optional_['Coding'] = Field(default=None)
    'A code that details how this designation would be used.'
    value: 'string' = Field(default=...)
    'The text value for this designation.'
    language: Optional_['code'] = Field(default=None)
    'The language this designation is defined for.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CodeSystemConceptProperty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A property value for this concept."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    valueCode: Optional_['code'] = Field(default=None)
    'The value of this property.'
    valueCoding: Optional_['Coding'] = Field(default=None)
    'The value of this property.'
    valueString: Optional_['string'] = Field(default=None)
    'The value of this property.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'The value of this property.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The value of this property.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The value of this property.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'The value of this property.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'A code that is a reference to CodeSystem.property.code.'


class CodeSystemFilter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A filter that can be used in a value set compose statement when selecting concepts using a filter."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: 'string' = Field(default=...)
    'A description of what the value for the filter should be.'
    operator: List_['code'] = Field(default=...)
    'A list of operators that can be used with the filter.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'A description of how or why the filter is used.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'The code that identifies this filter when it is used as a filter in [ValueSet](valueset.html#).compose.include.filter.'


class CodeSystem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The CodeSystem resource is used to declare the existence of and describe a code system or code system supplement and its key properties, and optionally define a part or all of its content."""
    resourceType: Literal_['CodeSystem'] = Field(default=...)
    'Declares the existence of and describes a code system or code system supplement'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this code system when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this code system is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the code system is stored on different servers. This is used in [Coding](datatypes.html#Coding).system.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the code system. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the code system was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the code system changes.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the code system.'
    count: Optional_['unsignedInt'] = Field(default=None)
    'The total number of concepts defined by the code system. Where the code system has a compositional grammar, the basis of this count is defined by the system steward.'
    status: 'code' = Field(default=...)
    'The date (and optionally time) when the code system resource was created or revised.'
    filter: List_['CodeSystemFilter'] = Field(default_factory=list)
    'A filter that can be used in a value set compose statement when selecting concepts using a filter.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the code system when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the code system author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. This is used in [Coding](datatypes.html#Coding).version.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this code system is needed and why it has been designed as it has.'
    content: 'code' = Field(default=...)
    'The extent of the content of the code system (the concepts and codes it defines) are represented in this resource instance.'
    concept: List_['CodeSystemConcept'] = Field(default_factory=list)
    'Concepts that are in the code system. The concept definitions are inherently hierarchical, but the definitions must be consulted to determine what the meanings of the hierarchical relationships are.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    valueSet: Optional_['canonical'] = Field(default=None)
    'Canonical reference to the value set that contains the entire code system.'
    property: List_['CodeSystemProperty'] = Field(default_factory=list)
    'A property defines an additional slot through which additional information can be provided about a concept.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the code system.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the code system and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the code system.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this code system when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate code system instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the code system from a consumer's perspective."
    supplements: Optional_['canonical'] = Field(default=None)
    'The canonical URL of the code system that this code system supplement is adding designations and properties to.'
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this code system is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the code system is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    caseSensitive: Optional_['boolean'] = Field(default=None)
    'If code comparison is case sensitive when codes within this system are compared to each other.'
    compositional: Optional_['boolean'] = Field(default=None)
    'The code system defines a compositional (post-coordination) grammar.'
    versionNeeded: Optional_['boolean'] = Field(default=None)
    'This flag is used to signify that the code system does not commit to concept permanence across versions. If true, a version must be specified when referencing this code system.'
    hierarchyMeaning: Optional_['code'] = Field(default=None)
    'The meaning of the hierarchy of concepts as represented in this resource.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CommunicationPayload(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Text, attachment(s), or resource(s) that was communicated to the recipient."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    contentString: Optional_['string'] = Field(default=None)
    'A communicated content (or for multi-part communications, one portion of the communication).'
    contentAttachment: Optional_['Attachment'] = Field(default=None)
    'A communicated content (or for multi-part communications, one portion of the communication).'
    contentReference: Optional_['Reference'] = Field(default=None)
    'A communicated content (or for multi-part communications, one portion of the communication).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Communication(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An occurrence of information being transmitted; e.g. an alert that was sent to a responsible provider, a public health agency that was notified about a reportable condition."""
    resourceType: Literal_['Communication'] = Field(default=...)
    'A record of information transmitted from a sender to a receiver'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    sent: Optional_['dateTime'] = Field(default=None)
    'The time when this communication was sent.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Additional notes or commentary about the communication by the sender, receiver or other interested parties.'
    topic: Optional_['CodeableConcept'] = Field(default=None)
    'Description of the purpose/content, similar to a subject line in an email.'
    about: List_['Reference'] = Field(default_factory=list)
    'Other resources that pertain to this communication and to which this communication should be associated.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'Part of this action.'
    status: 'code' = Field(default=...)
    'The status of the transmission.'
    medium: List_['CodeableConcept'] = Field(default_factory=list)
    'A channel that was used for this communication (e.g. email, fax).'
    sender: Optional_['Reference'] = Field(default=None)
    'The entity (e.g. person, organization, clinical information system, or device) which was the source of the communication.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'An order, proposal or plan fulfilled in whole or in part by this Communication.'
    subject: Optional_['Reference'] = Field(default=None)
    'The patient or group that was the focus of this communication.'
    payload: List_['CommunicationPayload'] = Field(default_factory=list)
    'Text, attachment(s), or resource(s) that was communicated to the recipient.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'The type of message conveyed such as alert, notification, reminder, instruction, etc.'
    priority: Optional_['code'] = Field(default=None)
    'Characterizes how quickly the planned or in progress communication must be addressed. Includes concepts such as stat, urgent, routine.'
    received: Optional_['dateTime'] = Field(default=None)
    'The time when this communication arrived at the destination.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which this Communication was created or to which the creation of this record is tightly associated.'
    recipient: List_['Reference'] = Field(default_factory=list)
    'The entity (e.g. person, organization, clinical information system, care team or device) which was the target of the communication. If receipts need to be tracked by an individual, a separate resource instance will need to be created for each recipient.  Multiple recipient communications are intended where either receipts are not tracked (e.g. a mass mail-out) or a receipt is captured in aggregate (all emails confirmed received by a particular time).'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this communication by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'The reason or justification for the communication.'
    inResponseTo: List_['Reference'] = Field(default_factory=list)
    'Prior communication that this communication is in response to.'
    statusReason: Optional_['CodeableConcept'] = Field(default=None)
    'Captures the reason for the current state of the Communication.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally maintained protocol, guideline, orderset or other definition that is adhered to in whole or in part by this Communication.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates another resource whose existence justifies this communication.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'The URL pointing to a FHIR-defined protocol, guideline, orderset or other definition that is adhered to in whole or in part by this Communication.'


class CommunicationRequestPayload(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Text, attachment(s), or resource(s) to be communicated to the recipient."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    contentString: Optional_['string'] = Field(default=None)
    'The communicated content (or for multi-part communications, one portion of the communication).'
    contentAttachment: Optional_['Attachment'] = Field(default=None)
    'The communicated content (or for multi-part communications, one portion of the communication).'
    contentReference: Optional_['Reference'] = Field(default=None)
    'The communicated content (or for multi-part communications, one portion of the communication).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CommunicationRequest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A request to convey information; e.g. the CDS system proposes that an alert be sent to a responsible provider, the CDS system proposes that the public health agency be notified about a reportable condition."""
    resourceType: Literal_['CommunicationRequest'] = Field(default=...)
    'A request for information to be sent to a receiver'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments made about the request by the requester, sender, recipient, subject or other participants.'
    about: List_['Reference'] = Field(default_factory=list)
    'Other resources that pertain to this communication request and to which this communication request should be associated.'
    status: 'code' = Field(default=...)
    'The status of the proposal or order.'
    medium: List_['CodeableConcept'] = Field(default_factory=list)
    'A channel that was used for this communication (e.g. email, fax).'
    sender: Optional_['Reference'] = Field(default=None)
    'The entity (e.g. person, organization, clinical information system, or device) which is to be the source of the communication.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A plan or proposal that is fulfilled in whole or in part by this request.'
    subject: Optional_['Reference'] = Field(default=None)
    'The patient or group that is the focus of this communication request.'
    payload: List_['CommunicationRequestPayload'] = Field(default_factory=list)
    'Text, attachment(s), or resource(s) to be communicated to the recipient.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    replaces: List_['Reference'] = Field(default_factory=list)
    'Completed or terminated request(s) whose function is taken by this new request.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'The type of message to be sent such as alert, notification, reminder, instruction, etc.'
    priority: Optional_['code'] = Field(default=None)
    'Characterizes how quickly the proposed act must be initiated. Includes concepts such as stat, urgent, routine.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which this CommunicationRequest was created or to which the creation of this record is tightly associated.'
    requester: Optional_['Reference'] = Field(default=None)
    'The device, individual, or organization who initiated the request and has responsibility for its activation.'
    recipient: List_['Reference'] = Field(default_factory=list)
    'The entity (e.g. person, organization, clinical information system, device, group, or care team) which is the intended target of the communication.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this communication request by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    authoredOn: Optional_['dateTime'] = Field(default=None)
    'For draft requests, indicates the date of initial creation.  For requests with other statuses, indicates the date of activation.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Describes why the request is being made in coded or textual form.'
    statusReason: Optional_['CodeableConcept'] = Field(default=None)
    'Captures the reason for the current state of the CommunicationRequest.'
    doNotPerform: Optional_['boolean'] = Field(default=None)
    'If true indicates that the CommunicationRequest is asking for the specified action to *not* occur.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'The time when this communication is to occur.'
    occurrencePeriod: Optional_['Period'] = Field(default=None)
    'The time when this communication is to occur.'
    groupIdentifier: Optional_['Identifier'] = Field(default=None)
    'A shared identifier common to all requests that were authorized more or less simultaneously by a single author, representing the identifier of the requisition, prescription or similar form.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates another resource whose existence justifies this request.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CompartmentDefinitionResource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about how a resource is related to the compartment."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    param: List_['string'] = Field(default_factory=list)
    'The name of a search parameter that represents the link to the compartment. More than one may be listed because a resource may be linked to a compartment in more than one way,.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    documentation: Optional_['string'] = Field(default=None)
    'Additional documentation about the resource and compartment.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'The name of a resource supported by the server.'


class CompartmentDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A compartment definition that defines how resources are accessed on a server."""
    resourceType: Literal_['CompartmentDefinition'] = Field(default=...)
    'Compartment Definition for a resource'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: 'uri' = Field(default=...)
    'An absolute URI that is used to identify this compartment definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this compartment definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the compartment definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: 'string' = Field(default=...)
    'A natural language name identifying the compartment definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the compartment definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the compartment definition changes.'
    status: 'code' = Field(default=...)
    'The status of this compartment definition. Enables tracking the life-cycle of the content.'
    search: 'boolean' = Field(default=...)
    'Whether the search syntax is supported,.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the compartment definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the compartment definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this compartment definition is needed and why it has been designed as it has.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    resource: List_['CompartmentDefinitionResource'] = Field(default_factory=list)
    'Information about how a resource is related to the compartment.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the compartment definition.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate compartment definition instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the compartment definition from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this compartment definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'Which compartment this definition describes.'


class CompositionRelatesTo(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Relationships that this composition has with other compositions or documents that already exist."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    targetIdentifier: Optional_['Identifier'] = Field(default=None)
    'The target composition/document of this relationship.'
    targetReference: Optional_['Reference'] = Field(default=None)
    'The target composition/document of this relationship.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'The type of relationship that this composition has with anther composition or document.'


class CompositionAttester(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A participant who has attested to the accuracy of the composition/document."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    mode: 'code' = Field(default=...)
    'The type of attestation the authenticator offers.'
    time: Optional_['dateTime'] = Field(default=None)
    'When the composition was attested by the party.'
    party: Optional_['Reference'] = Field(default=None)
    'Who attested the composition in the specified way.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CompositionSection(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The root of the sections that make up the composition."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains the attested content of the section, used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative.'
    mode: Optional_['code'] = Field(default=None)
    'How the entry list was prepared - whether it is a working list that is suitable for being maintained on an ongoing basis, or if it represents a snapshot of a list of items from another source, or whether it is a prepared list where items may be marked as added, modified or deleted.'
    title: Optional_['string'] = Field(default=None)
    'The label for this particular section.  This will be part of the rendered content for the document, and is often used to build a table of contents.'
    focus: Optional_['Reference'] = Field(default=None)
    'The actual focus of the section when it is not the subject of the composition, but instead represents something or someone associated with the subject such as (for a patient subject) a spouse, parent, fetus, or donor. If not focus is specified, the focus is assumed to be focus of the parent section, or, for a section in the Composition itself, the subject of the composition. Sections with a focus SHALL only include resources where the logical subject (patient, subject, focus, etc.) matches the section focus, or the resources have no logical subject (few resources).'
    entry: List_['Reference'] = Field(default_factory=list)
    'A reference to the actual resource from which the narrative in the section is derived.'
    author: List_['Reference'] = Field(default_factory=list)
    'Identifies who is responsible for the information in this section, not necessarily who typed it in.'
    section: List_['CompositionSection'] = Field(default_factory=list)
    'A nested sub-section within this section.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    orderedBy: Optional_['CodeableConcept'] = Field(default=None)
    'Specifies the order applied to the items in the section entries.'
    emptyReason: Optional_['CodeableConcept'] = Field(default=None)
    'If the section is empty, why the list is empty. An empty section typically has some text explaining the empty reason.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code identifying the kind of content contained within the section. This must be consistent with the section title.'


class CompositionEvent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The clinical service, such as a colonoscopy or an appendectomy, being documented."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'This list of codes represents the main clinical acts, such as a colonoscopy or an appendectomy, being documented. In some cases, the event is inherent in the typeCode, such as a "History and Physical Report" in which the procedure being documented is necessarily a "History and Physical" act.'
    period: Optional_['Period'] = Field(default=None)
    'The period of time covered by the documentation. There is no assertion that the documentation is a complete representation for this period, only that it documents events during this time.'
    detail: List_['Reference'] = Field(default_factory=list)
    'The description and/or reference of the event(s) being documented. For example, this could be used to document such a colonoscopy or an appendectomy.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Composition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A set of healthcare-related information that is assembled together into a single logical package that provides a single coherent statement of meaning, establishes its own context and that has clinical attestation with regard to who is making the statement. A Composition defines the structure and narrative content necessary for a document. However, a Composition alone does not constitute a document. Rather, the Composition must be the first entry in a Bundle where Bundle.type=document, and any other resources referenced from Composition must be included as subsequent entries in the Bundle (for example Patient, Practitioner, Encounter, etc.)."""
    resourceType: Literal_['Composition'] = Field(default=...)
    'A set of resources composed into a single coherent clinical statement with clinical attestation'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'CodeableConcept' = Field(default=...)
    'Specifies the particular kind of composition (e.g. History and Physical, Discharge Summary, Progress Note). This usually equates to the purpose of making the composition.'
    date: 'dateTime' = Field(default=...)
    'The composition editing time, when the composition was last logically changed by the author.'
    title: 'string' = Field(default=...)
    'Official human-readable label for the composition.'
    event: List_['CompositionEvent'] = Field(default_factory=list)
    'The clinical service, such as a colonoscopy or an appendectomy, being documented.'
    status: 'code' = Field(default=...)
    'The workflow/clinical status of this composition. The status is a marker for the clinical standing of the document.'
    author: List_['Reference'] = Field(default=...)
    'Identifies who is responsible for the information in the composition, not necessarily who typed it in.'
    subject: Optional_['Reference'] = Field(default=None)
    'Who or what the composition is about. The composition can be about a person, (patient or healthcare practitioner), a device (e.g. a machine) or even a group of subjects (such as a document about a herd of livestock, or a set of patients that share a common exposure).'
    section: List_['CompositionSection'] = Field(default_factory=list)
    'The root of the sections that make up the composition.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'A categorization for the type of the composition - helps for indexing and searching. This may be implied by or derived from the code specified in the Composition Type.'
    attester: List_['CompositionAttester'] = Field(default_factory=list)
    'A participant who has attested to the accuracy of the composition/document.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'Describes the clinical encounter or type of care this documentation is associated with.'
    custodian: Optional_['Reference'] = Field(default=None)
    'Identifies the organization or group who is responsible for ongoing maintenance of and access to the composition/document information.'
    relatesTo: List_['CompositionRelatesTo'] = Field(default_factory=list)
    'Relationships that this composition has with other compositions or documents that already exist.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'A version-independent identifier for the Composition. This identifier stays constant as the composition is changed over time.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    confidentiality: Optional_['code'] = Field(default=None)
    'The code specifying the level of confidentiality of the Composition.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ConceptMapGroup(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A group of mappings that all have the same source and target system."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    source: Optional_['uri'] = Field(default=None)
    'An absolute URI that identifies the source system where the concepts to be mapped are defined.'
    target: Optional_['uri'] = Field(default=None)
    'An absolute URI that identifies the target system that the concepts will be mapped to.'
    element: List_['ConceptMapGroupElement'] = Field(default=...)
    'Mappings for an individual concept in the source to one or more concepts in the target.'
    unmapped: Optional_['ConceptMapGroupUnmapped'] = Field(default=None)
    'What to do when there is no mapping for the source concept. "Unmapped" does not include codes that are unmatched, and the unmapped element is ignored in a code is specified to have equivalence = unmatched.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    sourceVersion: Optional_['string'] = Field(default=None)
    'The specific version of the code system, as determined by the code system authority.'
    targetVersion: Optional_['string'] = Field(default=None)
    'The specific version of the code system, as determined by the code system authority.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ConceptMapGroupUnmapped(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """What to do when there is no mapping for the source concept. "Unmapped" does not include codes that are unmatched, and the unmapped element is ignored in a code is specified to have equivalence = unmatched."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    url: Optional_['canonical'] = Field(default=None)
    'The canonical reference to an additional ConceptMap resource instance to use for mapping if this ConceptMap resource contains no matching mapping for the source concept.'
    mode: 'code' = Field(default=...)
    'Defines which action to take if there is no match for the source concept in the target system designated for the group. One of 3 actions are possible: use the unmapped code (this is useful when doing a mapping between versions, and only a few codes have changed), use a fixed code (a default code), or alternatively, a reference to a different concept map can be provided (by canonical URL).'
    display: Optional_['string'] = Field(default=None)
    'The display for the code. The display is only provided to help editors when editing the concept map.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['code'] = Field(default=None)
    "The fixed code to use when the mode = 'fixed'  - all unmapped codes are mapped to a single fixed code."


class ConceptMapGroupElement(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Mappings for an individual concept in the source to one or more concepts in the target."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    target: List_['ConceptMapGroupElementTarget'] = Field(default_factory=list)
    'A concept from the target value set that this concept maps to.'
    display: Optional_['string'] = Field(default=None)
    'The display for the code. The display is only provided to help editors when editing the concept map.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['code'] = Field(default=None)
    'Identity (code or path) or the element/item being mapped.'


class ConceptMapGroupElementTarget(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A concept from the target value set that this concept maps to."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    display: Optional_['string'] = Field(default=None)
    'The display for the code. The display is only provided to help editors when editing the concept map.'
    comment: Optional_['string'] = Field(default=None)
    'A description of status/issues in mapping that conveys additional information not represented in  the structured data.'
    product: List_['ConceptMapGroupElementTargetDependsOn'] = Field(default_factory=list)
    'A set of additional outcomes from this mapping to other elements. To properly execute this mapping, the specified element must be mapped to some data element or source that is in context. The mapping may still be useful without a place for the additional data elements, but the equivalence cannot be relied on.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    dependsOn: List_['ConceptMapGroupElementTargetDependsOn'] = Field(default_factory=list)
    'A set of additional dependencies for this mapping to hold. This mapping is only applicable if the specified element can be resolved, and it has the specified value.'
    equivalence: 'code' = Field(default=...)
    "The equivalence between the source and target concepts (counting for the dependencies and products). The equivalence is read from target to source (e.g. the target is 'wider' than the source)."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['code'] = Field(default=None)
    'Identity (code or path) or the element/item that the map refers to.'


class ConceptMapGroupElementTargetDependsOn(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A set of additional dependencies for this mapping to hold. This mapping is only applicable if the specified element can be resolved, and it has the specified value."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: 'string' = Field(default=...)
    'Identity (code or path) or the element/item/ValueSet/text that the map depends on / refers to.'
    system: Optional_['canonical'] = Field(default=None)
    'An absolute URI that identifies the code system of the dependency code (if the source/dependency is a value set that crosses code systems).'
    display: Optional_['string'] = Field(default=None)
    'The display for the code. The display is only provided to help editors when editing the concept map.'
    property: 'uri' = Field(default=...)
    'A reference to an element that holds a coded value that corresponds to a code system property. The idea is that the information model carries an element somewhere that is labeled to correspond with a code system property.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ConceptMap(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A statement of relationships from one set of concepts to one or more other concepts - either concepts in code systems, or data element/data element concepts, or classes in class models."""
    resourceType: Literal_['ConceptMap'] = Field(default=...)
    'A map from one set of concepts to one or more other concepts'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this concept map when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this concept map is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the concept map is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the concept map. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the concept map was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the concept map changes.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the concept map.'
    group: List_['ConceptMapGroup'] = Field(default_factory=list)
    'A group of mappings that all have the same source and target system.'
    status: 'code' = Field(default=...)
    'The status of this concept map. Enables tracking the life-cycle of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the concept map when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the concept map author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this concept map is needed and why it has been designed as it has.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the concept map.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the concept map and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the concept map.'
    sourceUri: Optional_['uri'] = Field(default=None)
    'Identifier for the source value set that contains the concepts that are being mapped and provides context for the mappings.'
    sourceCanonical: Optional_['canonical'] = Field(default=None)
    'Identifier for the source value set that contains the concepts that are being mapped and provides context for the mappings.'
    targetUri: Optional_['uri'] = Field(default=None)
    'The target value set provides context for the mappings. Note that the mapping is made between concepts, not between value sets, but the value set provides important context about how the concept mapping choices are made.'
    targetCanonical: Optional_['canonical'] = Field(default=None)
    'The target value set provides context for the mappings. Note that the mapping is made between concepts, not between value sets, but the value set provides important context about how the concept mapping choices are made.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'A formal identifier that is used to identify this concept map when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate concept map instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the concept map from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this concept map is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the concept map is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ConditionEvidence(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Supporting evidence / manifestations that are the basis of the Condition's verification status, such as evidence that confirmed or refuted the condition."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'A manifestation or symptom that led to the recording of this condition.'
    detail: List_['Reference'] = Field(default_factory=list)
    'Links to other relevant information, including pathology reports.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ConditionStage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Clinical stage or grade of a condition. May include formal severity assessments."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of staging, such as pathological or clinical staging.'
    summary: Optional_['CodeableConcept'] = Field(default=None)
    'A simple summary of the stage such as "Stage 3". The determination of the stage is disease-specific.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    assessment: List_['Reference'] = Field(default_factory=list)
    'Reference to a formal record of the evidence on which the staging assessment is based.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Condition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A clinical condition, problem, diagnosis, or other event, situation, issue, or clinical concept that has risen to a level of concern."""
    resourceType: Literal_['Condition'] = Field(default=...)
    'Detailed information about conditions, problems or diagnoses'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Additional information about the Condition. This is a general notes/comments entry  for description of the Condition, its diagnosis and prognosis.'
    stage: List_['ConditionStage'] = Field(default_factory=list)
    'Clinical stage or grade of a condition. May include formal severity assessments.'
    subject: 'Reference' = Field(default=...)
    'Indicates the patient or group who the condition record is associated with.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'A category assigned to the condition.'
    severity: Optional_['CodeableConcept'] = Field(default=None)
    'A subjective assessment of the severity of the condition as evaluated by the clinician.'
    bodySite: List_['CodeableConcept'] = Field(default_factory=list)
    'The anatomical location where this condition manifests itself.'
    onsetDateTime: Optional_['dateTime'] = Field(default=None)
    'Estimated or actual date or date-time  the condition began, in the opinion of the clinician.'
    onsetAge: Optional_['Age'] = Field(default=None)
    'Estimated or actual date or date-time  the condition began, in the opinion of the clinician.'
    onsetPeriod: Optional_['Period'] = Field(default=None)
    'Estimated or actual date or date-time  the condition began, in the opinion of the clinician.'
    onsetRange: Optional_['Range'] = Field(default=None)
    'Estimated or actual date or date-time  the condition began, in the opinion of the clinician.'
    onsetString: Optional_['string'] = Field(default=None)
    'Estimated or actual date or date-time  the condition began, in the opinion of the clinician.'
    recorder: Optional_['Reference'] = Field(default=None)
    'Individual who recorded the record and takes responsibility for its content.'
    asserter: Optional_['Reference'] = Field(default=None)
    'Individual who is making the condition statement.'
    evidence: List_['ConditionEvidence'] = Field(default_factory=list)
    "Supporting evidence / manifestations that are the basis of the Condition's verification status, such as evidence that confirmed or refuted the condition."
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which this Condition was created or to which the creation of this record is tightly associated.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this condition by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    abatementDateTime: Optional_['dateTime'] = Field(default=None)
    'The date or estimated date that the condition resolved or went into remission. This is called "abatement" because of the many overloaded connotations associated with "remission" or "resolution" - Conditions are never really resolved, but they can abate.'
    abatementAge: Optional_['Age'] = Field(default=None)
    'The date or estimated date that the condition resolved or went into remission. This is called "abatement" because of the many overloaded connotations associated with "remission" or "resolution" - Conditions are never really resolved, but they can abate.'
    abatementPeriod: Optional_['Period'] = Field(default=None)
    'The date or estimated date that the condition resolved or went into remission. This is called "abatement" because of the many overloaded connotations associated with "remission" or "resolution" - Conditions are never really resolved, but they can abate.'
    abatementRange: Optional_['Range'] = Field(default=None)
    'The date or estimated date that the condition resolved or went into remission. This is called "abatement" because of the many overloaded connotations associated with "remission" or "resolution" - Conditions are never really resolved, but they can abate.'
    abatementString: Optional_['string'] = Field(default=None)
    'The date or estimated date that the condition resolved or went into remission. This is called "abatement" because of the many overloaded connotations associated with "remission" or "resolution" - Conditions are never really resolved, but they can abate.'
    recordedDate: Optional_['dateTime'] = Field(default=None)
    'The recordedDate represents when this particular Condition record was created in the system, which is often a system-generated date.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    clinicalStatus: Optional_['CodeableConcept'] = Field(default=None)
    'The clinical status of the condition.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    verificationStatus: Optional_['CodeableConcept'] = Field(default=None)
    'The verification status to support the clinical status of the condition.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Identification of the condition, problem or diagnosis.'


class ConsentVerification(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Whether a treatment instruction (e.g. artificial respiration yes or no) was verified with the patient, his/her family or another authorized person."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    verified: 'boolean' = Field(default=...)
    'Has the instruction been verified.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    verifiedWith: Optional_['Reference'] = Field(default=None)
    'Who verified the instruction (Patient, Relative or other Authorized Person).'
    verificationDate: Optional_['dateTime'] = Field(default=None)
    'Date verification was collected.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ConsentProvision(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An exception to the base policy of this consent. An exception can be an addition or removal of access permissions."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['code'] = Field(default=None)
    'Action  to take - permit or deny - when the rule conditions are met.  Not permitted in root rule, required in all nested rules.'
    data: List_['ConsentProvisionData'] = Field(default_factory=list)
    'The resources controlled by this rule if specific resources are referenced.'
    actor: List_['ConsentProvisionActor'] = Field(default_factory=list)
    "Who or what is controlled by this rule. Use group to identify a set of actors by some property they share (e.g. 'admitting officers')."
    class_: List_['Coding'] = Field(default_factory=list, alias='class')
    'The class of information covered by this rule. The type can be a FHIR resource type, a profile on a type, or a CDA document, or some other type that indicates what sort of information the consent relates to.'
    period: Optional_['Period'] = Field(default=None)
    'The timeframe in this rule is valid.'
    action: List_['CodeableConcept'] = Field(default_factory=list)
    'Actions controlled by this Rule.'
    purpose: List_['Coding'] = Field(default_factory=list)
    'The context of the activities a user is taking - why the user is accessing the data - that are controlled by this rule.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    provision: List_['ConsentProvision'] = Field(default_factory=list)
    'Rules which provide exceptions to the base rule or subrules.'
    dataPeriod: Optional_['Period'] = Field(default=None)
    'Clinical or Operational Relevant period of time that bounds the data controlled by this rule.'
    securityLabel: List_['Coding'] = Field(default_factory=list)
    'A security label, comprised of 0..* security label fields (Privacy tags), which define which resources are controlled by this exception.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'If this code is found in an instance, then the rule applies.'


class ConsentProvisionActor(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Who or what is controlled by this rule. Use group to identify a set of actors by some property they share (e.g. 'admitting officers')."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: 'CodeableConcept' = Field(default=...)
    'How the individual is involved in the resources content that is described in the exception.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: 'Reference' = Field(default=...)
    "The resource that identifies the actor. To identify actors by type, use group to identify a set of actors by some property they share (e.g. 'admitting officers')."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ConsentProvisionData(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The resources controlled by this rule if specific resources are referenced."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    meaning: 'code' = Field(default=...)
    'How the resource reference is interpreted when testing consent restrictions.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: 'Reference' = Field(default=...)
    'A reference to a specific resource that defines which resources are covered by this consent.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ConsentPolicy(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The references to the policies that are included in this consent scope. Policies may be organizational, but are often defined jurisdictionally, or in law."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    authority: Optional_['uri'] = Field(default=None)
    'Entity or Organization having regulatory jurisdiction or accountability for  enforcing policies pertaining to Consent Directives.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    uri: Optional_['uri'] = Field(default=None)
    'The references to the policies that are included in this consent scope. Policies may be organizational, but are often defined jurisdictionally, or in law.'


class Consent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A record of a healthcare consumer’s  choices, which permits or denies identified recipient(s) or recipient role(s) to perform one or more actions within a given policy context, for specific purposes and periods of time."""
    resourceType: Literal_['Consent'] = Field(default=...)
    "A healthcare consumer's  choices to permit or deny recipients or roles to perform actions for specific purposes and periods of time"
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    scope: 'CodeableConcept' = Field(default=...)
    'A selector of the type of consent being presented: ADR, Privacy, Treatment, Research.  This list is now extensible.'
    status: 'code' = Field(default=...)
    'Indicates the current state of this consent.'
    policy: List_['ConsentPolicy'] = Field(default_factory=list)
    'The references to the policies that are included in this consent scope. Policies may be organizational, but are often defined jurisdictionally, or in law.'
    patient: Optional_['Reference'] = Field(default=None)
    'The patient/healthcare consumer to whom this consent applies.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default=...)
    'A classification of the type of consents found in the statement. This element supports indexing and retrieval of consent statements.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    performer: List_['Reference'] = Field(default_factory=list)
    'Either the Grantor, which is the entity responsible for granting the rights listed in a Consent Directive or the Grantee, which is the entity responsible for complying with the Consent Directive, including any obligations or limitations on authorizations and enforcement of prohibitions.'
    sourceAttachment: Optional_['Attachment'] = Field(default=None)
    'The source on which this consent statement is based. The source might be a scanned original paper form, or a reference to a consent that links back to such a source, a reference to a document repository (e.g. XDS) that stores the original consent document.'
    sourceReference: Optional_['Reference'] = Field(default=None)
    'The source on which this consent statement is based. The source might be a scanned original paper form, or a reference to a consent that links back to such a source, a reference to a document repository (e.g. XDS) that stores the original consent document.'
    provision: Optional_['ConsentProvision'] = Field(default=None)
    'An exception to the base policy of this consent. An exception can be an addition or removal of access permissions.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique identifier for this copy of the Consent Statement.'
    policyRule: Optional_['CodeableConcept'] = Field(default=None)
    'A reference to the specific base computable regulation or policy.'
    organization: List_['Reference'] = Field(default_factory=list)
    'The organization that manages the consent, and the framework within which it is executed.'
    verification: List_['ConsentVerification'] = Field(default_factory=list)
    'Whether a treatment instruction (e.g. artificial respiration yes or no) was verified with the patient, his/her family or another authorized person.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    dateTime: Optional_['dateTime'] = Field(default=None)
    'When this  Consent was issued / created / indexed.'


class ContractContentDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Precusory content developed with a focus and intent of supporting the formation a Contract instance, which may be associated with and transformable into a Contract."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Precusory content structure and use, i.e., a boilerplate, template, application for a contract such as an insurance policy or benefits under a program, e.g., workers compensation.'
    subType: Optional_['CodeableConcept'] = Field(default=None)
    'Detailed Precusory content type.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['Reference'] = Field(default=None)
    'The  individual or organization that published the Contract precursor content.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to Contract precursor content. Copyright statements are generally legal restrictions on the use and publishing of the Contract precursor content.'
    publicationDate: Optional_['dateTime'] = Field(default=None)
    'The date (and optionally time) when the contract was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the contract changes.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    publicationStatus: 'code' = Field(default=...)
    'amended | appended | cancelled | disputed | entered-in-error | executable | executed | negotiable | offered | policy | rejected | renewed | revoked | resolved | terminated.'


class ContractFriendly(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The "patient friendly language" versionof the Contract in whole or in parts. "Patient friendly language" means the representation of the Contract and Contract Provisions in a manner that is readily accessible and understandable by a layperson in accordance with best practices for communication styles that ensure that those agreeing to or signing the Contract understand the roles, actions, obligations, responsibilities, and implication of the agreement."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    contentAttachment: Optional_['Attachment'] = Field(default=None)
    'Human readable rendering of this Contract in a format and representation intended to enhance comprehension and ensure understandability.'
    contentReference: Optional_['Reference'] = Field(default=None)
    'Human readable rendering of this Contract in a format and representation intended to enhance comprehension and ensure understandability.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ContractSigner(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Parties with legal standing in the Contract, including the principal parties, the grantor(s) and grantee(s), which are any person or organization bound by the contract, and any ancillary parties, which facilitate the execution of the contract such as a notary or witness."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'Coding' = Field(default=...)
    'Role of this Contract signer, e.g. notary, grantee.'
    party: 'Reference' = Field(default=...)
    'Party which is a signator to this Contract.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    signature: List_['Signature'] = Field(default=...)
    'Legally binding Contract DSIG signature contents in Base64.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ContractLegal(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """List of Legal expressions or representations of this Contract."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    contentAttachment: Optional_['Attachment'] = Field(default=None)
    'Contract legal text in human renderable form.'
    contentReference: Optional_['Reference'] = Field(default=None)
    'Contract legal text in human renderable form.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ContractRule(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """List of Computable Policy Rule Language Representations of this Contract."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    contentAttachment: Optional_['Attachment'] = Field(default=None)
    'Computable Contract conveyed using a policy rule language (e.g. XACML, DKAL, SecPal).'
    contentReference: Optional_['Reference'] = Field(default=None)
    'Computable Contract conveyed using a policy rule language (e.g. XACML, DKAL, SecPal).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ContractTerm(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """One or more Contract Provisions, which may be related and conveyed as a group, and may contain nested groups."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'A legal clause or condition contained within a contract that requires one or both parties to perform a particular requirement by some specified time or prevents one or both parties from performing a particular requirement by some specified time.'
    text: Optional_['string'] = Field(default=None)
    'Statement of a provision in a policy or a contract.'
    offer: 'ContractTermOffer' = Field(default=...)
    'The matter of concern in the context of this provision of the agrement.'
    asset: List_['ContractTermAsset'] = Field(default_factory=list)
    'Contract Term Asset List.'
    group: List_['ContractTerm'] = Field(default_factory=list)
    'Nested group of Contract Provisions.'
    issued: Optional_['dateTime'] = Field(default=None)
    'When this Contract Provision was issued.'
    action: List_['ContractTermAction'] = Field(default_factory=list)
    'An actor taking a role in an activity for which it can be assigned some degree of responsibility for the activity taking place.'
    applies: Optional_['Period'] = Field(default=None)
    'Relevant time or time-period when this Contract Provision is applicable.'
    subType: Optional_['CodeableConcept'] = Field(default=None)
    'A specialized legal clause or condition based on overarching contract type.'
    topicCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The entity that the term applies to.'
    topicReference: Optional_['Reference'] = Field(default=None)
    'The entity that the term applies to.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Unique identifier for this particular Contract Provision.'
    securityLabel: List_['ContractTermSecurityLabel'] = Field(default_factory=list)
    'Security labels that protect the handling of information about the term and its elements, which may be specifically identified..'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ContractTermSecurityLabel(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Security labels that protect the handling of information about the term and its elements, which may be specifically identified.."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    number: List_['unsignedInt'] = Field(default_factory=list)
    'Number used to link this term or term element to the applicable Security Label.'
    control: List_['Coding'] = Field(default_factory=list)
    'Security label privacy tag that species the manner in which term and/or term elements are to be protected.'
    category: List_['Coding'] = Field(default_factory=list)
    'Security label privacy tag that species the applicable privacy and security policies governing this term and/or term elements.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    classification: 'Coding' = Field(default=...)
    'Security label privacy tag that species the level of confidentiality protection required for this term and/or term elements.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ContractTermAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An actor taking a role in an activity for which it can be assigned some degree of responsibility for the activity taking place."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Activity or service obligation to be done or not done, performed or not performed, effectuated or not by this Contract term.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments made about the term action made by the requester, performer, subject or other participants.'
    intent: 'CodeableConcept' = Field(default=...)
    'Reason or purpose for the action stipulated by this Contract Provision.'
    linkId: List_['string'] = Field(default_factory=list)
    'Id [identifier??] of the clause or question text related to this action in the referenced form or QuestionnaireResponse.'
    status: 'CodeableConcept' = Field(default=...)
    'Current state of the term action.'
    reason: List_['string'] = Field(default_factory=list)
    'Describes why the action is to be performed or not performed in textual form.'
    subject: List_['ContractTermActionSubject'] = Field(default_factory=list)
    'Entity of the action.'
    context: Optional_['Reference'] = Field(default=None)
    'Encounter or Episode with primary association to specified term activity.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    requester: List_['Reference'] = Field(default_factory=list)
    'Who or what initiated the action and has responsibility for its activation.'
    performer: Optional_['Reference'] = Field(default=None)
    'Indicates who or what is being asked to perform (or not perform) the ction.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Rationale for the action to be performed or not performed. Describes why the action is permitted or prohibited.'
    doNotPerform: Optional_['boolean'] = Field(default=None)
    'True if the term prohibits the  action.'
    reasonLinkId: List_['string'] = Field(default_factory=list)
    'Id [identifier??] of the clause or question text related to the reason type or reference of this  action in the referenced form or QuestionnaireResponse.'
    contextLinkId: List_['string'] = Field(default_factory=list)
    'Id [identifier??] of the clause or question text related to the requester of this action in the referenced form or QuestionnaireResponse.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'When action happens.'
    occurrencePeriod: Optional_['Period'] = Field(default=None)
    'When action happens.'
    occurrenceTiming: Optional_['Timing'] = Field(default=None)
    'When action happens.'
    performerType: List_['CodeableConcept'] = Field(default_factory=list)
    'The type of individual that is desired or required to perform or not perform the action.'
    performerRole: Optional_['CodeableConcept'] = Field(default=None)
    'The type of role or competency of an individual desired or required to perform or not perform the action.'
    requesterLinkId: List_['string'] = Field(default_factory=list)
    'Id [identifier??] of the clause or question text related to the requester of this action in the referenced form or QuestionnaireResponse.'
    performerLinkId: List_['string'] = Field(default_factory=list)
    'Id [identifier??] of the clause or question text related to the reason type or reference of this  action in the referenced form or QuestionnaireResponse.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates another resource whose existence justifies permitting or not permitting this action.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    securityLabelNumber: List_['unsignedInt'] = Field(default_factory=list)
    'Security labels that protects the action.'


class ContractTermActionSubject(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Entity of the action."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: Optional_['CodeableConcept'] = Field(default=None)
    'Role type of agent assigned roles in this Contract.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: List_['Reference'] = Field(default=...)
    'The entity the action is performed or not performed on or for.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ContractTermAsset(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Contract Term Asset List."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'Target entity type about which the term may be concerned.'
    text: Optional_['string'] = Field(default=None)
    'Clause or question text (Prose Object) concerning the asset in a linked form, such as a QuestionnaireResponse used in the formation of the contract.'
    scope: Optional_['CodeableConcept'] = Field(default=None)
    'Differentiates the kind of the asset .'
    period: List_['Period'] = Field(default_factory=list)
    'Asset relevant contractual time period.'
    linkId: List_['string'] = Field(default_factory=list)
    'Id [identifier??] of the clause or question text about the asset in the referenced form or QuestionnaireResponse.'
    answer: List_['ContractTermOfferAnswer'] = Field(default_factory=list)
    'Response to assets.'
    subtype: List_['CodeableConcept'] = Field(default_factory=list)
    'May be a subtype or part of an offered asset.'
    context: List_['ContractTermAssetContext'] = Field(default_factory=list)
    'Circumstance of the asset.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    condition: Optional_['string'] = Field(default=None)
    'Description of the quality and completeness of the asset that imay be a factor in its valuation.'
    usePeriod: List_['Period'] = Field(default_factory=list)
    'Time period of asset use.'
    periodType: List_['CodeableConcept'] = Field(default_factory=list)
    'Type of Asset availability for use or ownership.'
    valuedItem: List_['ContractTermAssetValuedItem'] = Field(default_factory=list)
    'Contract Valued Item List.'
    relationship: Optional_['Coding'] = Field(default=None)
    'Specifies the applicability of the term to an asset resource instance, and instances it refers to orinstances that refer to it, and/or are owned by the offeree.'
    typeReference: List_['Reference'] = Field(default_factory=list)
    'Associated entities.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    securityLabelNumber: List_['unsignedInt'] = Field(default_factory=list)
    'Security labels that protects the asset.'


class ContractTermAssetValuedItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Contract Valued Item List."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'Expresses the product of the Contract Valued Item unitQuantity and the unitPriceAmt. For example, the formula: unit Quantity * unit Price (Cost per Point) * factor Number  * points = net Amount. Quantity, factor and points are assumed to be 1 if not supplied.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of the Contract Valued Item delivered. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    points: Optional_['decimal'] = Field(default=None)
    'An amount that expresses the weighting (based on difficulty, cost and/or resource intensiveness) associated with the Contract Valued Item delivered. The concept of Points allows for assignment of point values for a Contract Valued Item, such that a monetary amount can be assigned to each point.'
    linkId: List_['string'] = Field(default_factory=list)
    'Id  of the clause or question text related to the context of this valuedItem in the referenced form or QuestionnaireResponse.'
    payment: Optional_['string'] = Field(default=None)
    'Terms of valuation.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'Specifies the units by which the Contract Valued Item is measured or counted, and quantifies the countable or measurable Contract Valued Item instances.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    entityCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Specific type of Contract Valued Item that may be priced.'
    entityReference: Optional_['Reference'] = Field(default=None)
    'Specific type of Contract Valued Item that may be priced.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'A Contract Valued Item unit valuation measure.'
    recipient: Optional_['Reference'] = Field(default=None)
    'Who will receive payment.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Identifies a Contract Valued Item instance.'
    paymentDate: Optional_['dateTime'] = Field(default=None)
    'When payment is due.'
    responsible: Optional_['Reference'] = Field(default=None)
    'Who will make payment.'
    effectiveTime: Optional_['dateTime'] = Field(default=None)
    'Indicates the time during which this Contract ValuedItem information is effective.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    securityLabelNumber: List_['unsignedInt'] = Field(default_factory=list)
    'A set of security labels that define which terms are controlled by this condition.'


class ContractTermAssetContext(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Circumstance of the asset."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'Coded representation of the context generally or of the Referenced entity, such as the asset holder type or location.'
    text: Optional_['string'] = Field(default=None)
    'Context description.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: Optional_['Reference'] = Field(default=None)
    'Asset context reference may include the creator, custodian, or owning Person or Organization (e.g., bank, repository),  location held, e.g., building,  jurisdiction.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ContractTermOffer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The matter of concern in the context of this provision of the agrement."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Type of Contract Provision such as specific requirements, purposes for actions, obligations, prohibitions, e.g. life time maximum benefit.'
    text: Optional_['string'] = Field(default=None)
    'Human readable form of this Contract Offer.'
    party: List_['ContractTermOfferParty'] = Field(default_factory=list)
    'Offer Recipient.'
    topic: Optional_['Reference'] = Field(default=None)
    'The owner of an asset has the residual control rights over the asset: the right to decide all usages of the asset in any way not inconsistent with a prior contract, custom, or law (Hart, 1995, p. 30).'
    answer: List_['ContractTermOfferAnswer'] = Field(default_factory=list)
    'Response to offer text.'
    linkId: List_['string'] = Field(default_factory=list)
    'The id of the clause or question text of the offer in the referenced questionnaire/response.'
    decision: Optional_['CodeableConcept'] = Field(default=None)
    'Type of choice made by accepting party with respect to an offer made by an offeror/ grantee.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique identifier for this particular Contract Provision.'
    decisionMode: List_['CodeableConcept'] = Field(default_factory=list)
    'How the decision about a Contract was conveyed.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    securityLabelNumber: List_['unsignedInt'] = Field(default_factory=list)
    'Security labels that protects the offer.'


class ContractTermOfferAnswer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Response to offer text."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueDate: Optional_['date'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueTime: Optional_['time'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueString: Optional_['string'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueUri: Optional_['uri'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueCoding: Optional_['Coding'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'Response to an offer clause or question text,  which enables selection of values to be agreed to, e.g., the period of participation, the date of occupancy of a rental, warrently duration, or whether biospecimen may be used for further research.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ContractTermOfferParty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Offer Recipient."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: 'CodeableConcept' = Field(default=...)
    'How the party participates in the offer.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: List_['Reference'] = Field(default=...)
    'Participant in the offer.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Contract(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Legally enforceable, formally recorded unilateral or bilateral directive i.e., a policy or agreement."""
    resourceType: Literal_['Contract'] = Field(default=...)
    'Legal Agreement'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'Canonical identifier for this contract, represented as a URI (globally unique).'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    site: List_['Reference'] = Field(default_factory=list)
    'Sites in which the contract is complied with,  exercised, or in force.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying this Contract definition, derivative, or instance in any legal state. Provides additional information about its content. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    "A high-level category for the legal instrument, whether constructed as a Contract definition, derivative, or instance in any legal state.  Provides additional information about its content within the context of the Contract's scope to distinguish the kinds of systems that would be interested in the contract."
    term: List_['ContractTerm'] = Field(default_factory=list)
    'One or more Contract Provisions, which may be related and conveyed as a group, and may contain nested groups.'
    rule: List_['ContractRule'] = Field(default_factory=list)
    'List of Computable Policy Rule Language Representations of this Contract.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for this Contract definition, derivative, or instance in any legal state.t giving additional information about its content.'
    alias: List_['string'] = Field(default_factory=list)
    'Alternative representation of the title for this Contract definition, derivative, or instance in any legal state., e.g., a domain specific contract number related to legislation.'
    scope: Optional_['CodeableConcept'] = Field(default=None)
    'A selector of legal concerns for this Contract definition, derivative, or instance in any legal state.'
    legal: List_['ContractLegal'] = Field(default_factory=list)
    'List of Legal expressions or representations of this Contract.'
    status: Optional_['code'] = Field(default=None)
    'The status of the resource instance.'
    issued: Optional_['dateTime'] = Field(default=None)
    'When this  Contract was issued.'
    domain: List_['Reference'] = Field(default_factory=list)
    'Recognized governance framework or system operating with a circumscribed scope in accordance with specified principles, policies, processes or procedures for managing rights, actions, or behaviors of parties or principals relative to resources.'
    author: Optional_['Reference'] = Field(default=None)
    'The individual or organization that authored the Contract definition, derivative, or instance in any legal state.'
    signer: List_['ContractSigner'] = Field(default_factory=list)
    'Parties with legal standing in the Contract, including the principal parties, the grantor(s) and grantee(s), which are any person or organization bound by the contract, and any ancillary parties, which facilitate the execution of the contract such as a notary or witness.'
    version: Optional_['string'] = Field(default=None)
    'An edition identifier used for business purposes to label business significant variants.'
    applies: Optional_['Period'] = Field(default=None)
    'Relevant time or time-period when this Contract is applicable.'
    subject: List_['Reference'] = Field(default_factory=list)
    'The target entity impacted by or of interest to parties to the agreement.'
    subType: List_['CodeableConcept'] = Field(default_factory=list)
    "Sub-category for the Contract that distinguishes the kinds of systems that would be interested in the Contract within the context of the Contract's scope."
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    subtitle: Optional_['string'] = Field(default=None)
    'An explanatory or alternate user-friendly title for this Contract definition, derivative, or instance in any legal state.t giving additional information about its content.'
    topicCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Narrows the range of legal concerns to focus on the achievement of specific contractual objectives.'
    topicReference: Optional_['Reference'] = Field(default=None)
    'Narrows the range of legal concerns to focus on the achievement of specific contractual objectives.'
    friendly: List_['ContractFriendly'] = Field(default_factory=list)
    'The "patient friendly language" versionof the Contract in whole or in parts. "Patient friendly language" means the representation of the Contract and Contract Provisions in a manner that is readily accessible and understandable by a layperson in accordance with best practices for communication styles that ensure that those agreeing to or signing the Contract understand the roles, actions, obligations, responsibilities, and implication of the agreement.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    authority: List_['Reference'] = Field(default_factory=list)
    'A formally or informally recognized grouping of people, principals, organizations, or jurisdictions formed for the purpose of achieving some form of collective action such as the promulgation, administration and enforcement of contracts and policies.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique identifier for this Contract or a derivative that references a Source Contract.'
    legalState: Optional_['CodeableConcept'] = Field(default=None)
    'Legal states of the formation of a legal instrument, which is a formally executed written document that can be formally attributed to its author, records and formally expresses a legally enforceable act, process, or contractual duty, obligation, or right, and therefore evidences that act, process, or agreement.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    expirationType: Optional_['CodeableConcept'] = Field(default=None)
    'Event resulting in discontinuation or termination of this Contract instance by one or more parties to the contract.'
    supportingInfo: List_['Reference'] = Field(default_factory=list)
    'Information that may be needed by/relevant to the performer in their execution of this term action.'
    instantiatesUri: Optional_['uri'] = Field(default=None)
    'The URL pointing to an externally maintained definition that is adhered to in whole or in part by this Contract.'
    relevantHistory: List_['Reference'] = Field(default_factory=list)
    'Links to Provenance records for past versions of this Contract definition, derivative, or instance, which identify key state transitions or updates that are likely to be relevant to a user looking at the current version of the Contract.  The Provence.entity indicates the target that was changed in the update. http://build.fhir.org/provenance-definitions.html#Provenance.entity.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    contentDerivative: Optional_['CodeableConcept'] = Field(default=None)
    'The minimal content derived from the basal information source at a specific stage in its lifecycle.'
    contentDefinition: Optional_['ContractContentDefinition'] = Field(default=None)
    'Precusory content developed with a focus and intent of supporting the formation a Contract instance, which may be associated with and transformable into a Contract.'
    legallyBindingAttachment: Optional_['Attachment'] = Field(default=None)
    'Legally binding Contract: This is the signed and legally recognized representation of the Contract, which is considered the "source of truth" and which would be the basis for legal action related to enforcement of this Contract.'
    legallyBindingReference: Optional_['Reference'] = Field(default=None)
    'Legally binding Contract: This is the signed and legally recognized representation of the Contract, which is considered the "source of truth" and which would be the basis for legal action related to enforcement of this Contract.'
    instantiatesCanonical: Optional_['Reference'] = Field(default=None)
    'The URL pointing to a FHIR-defined Contract Definition that is adhered to in whole or part by this Contract.'


class CoverageCostToBeneficiary(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A suite of codes indicating the cost category and associated amount which have been detailed in the policy and may have been  included on the health card."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The category of patient centric costs associated with treatment.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The amount due from the patient for the cost category.'
    valueMoney: Optional_['Money'] = Field(default=None)
    'The amount due from the patient for the cost category.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    exception: List_['CoverageCostToBeneficiaryException'] = Field(default_factory=list)
    'A suite of codes indicating exceptions or reductions to patient costs and their effective periods.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CoverageCostToBeneficiaryException(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A suite of codes indicating exceptions or reductions to patient costs and their effective periods."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'The code for the specific exception.'
    period: Optional_['Period'] = Field(default=None)
    'The timeframe during when the exception is in force.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CoverageClass(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A suite of underwriter specific classifiers."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'The type of classification for which an insurer-specific class label or number and optional name is provided, for example may be used to identify a class of coverage or employer group, Policy, Plan.'
    name: Optional_['string'] = Field(default=None)
    'A short description for the class.'
    value: 'string' = Field(default=...)
    'The alphanumeric string value associated with the insurer issued label.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Coverage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Financial instrument which may be used to reimburse or pay for health care products and services. Includes both insurance and self-payment."""
    resourceType: Literal_['Coverage'] = Field(default=...)
    'Insurance or medical plan or a payment agreement'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of coverage: social program, medical plan, accident coverage (workers compensation, auto), group health or payment by an individual or organization.'
    payor: List_['Reference'] = Field(default=...)
    'The program or plan underwriter or payor including both insurance and non-insurance agreements, such as patient-pay agreements.'
    class_: List_['CoverageClass'] = Field(default_factory=list, alias='class')
    'A suite of underwriter specific classifiers.'
    order: Optional_['positiveInt'] = Field(default=None)
    'The order of applicability of this coverage relative to other coverages which are currently in force. Note, there may be gaps in the numbering and this does not imply primary, secondary etc. as the specific positioning of coverages depends upon the episode of care.'
    status: 'code' = Field(default=...)
    'The status of the resource instance.'
    period: Optional_['Period'] = Field(default=None)
    "Time period during which the coverage is in force. A missing start date indicates the start date isn't known, a missing end date means the coverage is continuing to be in force."
    network: Optional_['string'] = Field(default=None)
    "The insurer-specific identifier for the insurer-defined network of providers to which the beneficiary may seek treatment which will be covered at the 'in-network' rate, otherwise 'out of network' terms and conditions apply."
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contract: List_['Reference'] = Field(default_factory=list)
    'The policy(s) which constitute this insurance coverage.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    dependent: Optional_['string'] = Field(default=None)
    'A unique identifier for a dependent under the coverage.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this coverage.'
    subscriber: Optional_['Reference'] = Field(default=None)
    "The party who has signed-up for or 'owns' the contractual relationship to the policy or to whom the benefit of the policy for services rendered to them or their family is due."
    beneficiary: 'Reference' = Field(default=...)
    'The party who benefits from the insurance coverage; the patient when products and/or services are provided.'
    subrogation: Optional_['boolean'] = Field(default=None)
    "When 'subrogation=true' this insurance instance has been included not for adjudication but to provide insurers with the details to recover costs."
    policyHolder: Optional_['Reference'] = Field(default=None)
    "The party who 'owns' the insurance policy."
    subscriberId: Optional_['string'] = Field(default=None)
    'The insurer assigned ID for the Subscriber.'
    relationship: Optional_['CodeableConcept'] = Field(default=None)
    'The relationship of beneficiary (patient) to the subscriber.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    costToBeneficiary: List_['CoverageCostToBeneficiary'] = Field(default_factory=list)
    'A suite of codes indicating the cost category and associated amount which have been detailed in the policy and may have been  included on the health card.'


class CoverageEligibilityRequestSupportingInfo(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify supporting information entries.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    information: 'Reference' = Field(default=...)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    appliesToAll: Optional_['boolean'] = Field(default=None)
    'The supporting materials are applicable for all detail items, product/servce categories and specific billing codes.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CoverageEligibilityRequestInsurance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Financial instruments for reimbursement for the health care products and services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    focal: Optional_['boolean'] = Field(default=None)
    'A flag to indicate that this Coverage is to be used for evaluation of this request when set to true.'
    coverage: 'Reference' = Field(default=...)
    "Reference to the insurance card level information contained in the Coverage resource. The coverage issuing insurer will use these details to locate the patient's actual coverage within the insurer's information system."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    businessArrangement: Optional_['string'] = Field(default=None)
    'A business agreement number established between the provider and the insurer for special business processing purposes.'


class CoverageEligibilityRequestItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Service categories or billable services for which benefit details and/or an authorization prior to service delivery may be required by the payor."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    detail: List_['Reference'] = Field(default_factory=list)
    'The plan/proposal/order describing the proposed service in detail.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Code to identify the general type of benefits under which products and services are provided.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    provider: Optional_['Reference'] = Field(default=None)
    'The practitioner who is responsible for the product or service to be rendered to the patient.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    facility: Optional_['Reference'] = Field(default=None)
    'Facility where the services will be provided.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'The amount charged to the patient by the provider for a single unit.'
    diagnosis: List_['CoverageEligibilityRequestItemDiagnosis'] = Field(default_factory=list)
    'Patient diagnosis for which care is sought.'
    productOrService: Optional_['CodeableConcept'] = Field(default=None)
    'This contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    supportingInfoSequence: List_['positiveInt'] = Field(default_factory=list)
    'Exceptions, special conditions and supporting information applicable for this service or product line.'


class CoverageEligibilityRequestItemDiagnosis(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Patient diagnosis for which care is sought."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    diagnosisCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The nature of illness or problem in a coded form or as a reference to an external defined Condition.'
    diagnosisReference: Optional_['Reference'] = Field(default=None)
    'The nature of illness or problem in a coded form or as a reference to an external defined Condition.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CoverageEligibilityRequest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The CoverageEligibilityRequest provides patient and insurance coverage information to an insurer for them to respond, in the form of an CoverageEligibilityResponse, with information regarding whether the stated coverage is valid and in-force and optionally to provide the insurance details of the policy."""
    resourceType: Literal_['CoverageEligibilityRequest'] = Field(default=...)
    'CoverageEligibilityRequest resource'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    item: List_['CoverageEligibilityRequestItem'] = Field(default_factory=list)
    'Service categories or billable services for which benefit details and/or an authorization prior to service delivery may be required by the payor.'
    status: 'code' = Field(default=...)
    'The status of the resource instance.'
    purpose: List_['code'] = Field(default=...)
    "Code to specify whether requesting: prior authorization requirements for some service categories or billing codes; benefits for coverages specified or discovered; discovery and return of coverages for the patient; and/or validation that the specified coverage is in-force at the date/period specified or 'now' if not specified."
    patient: 'Reference' = Field(default=...)
    'The party who is the beneficiary of the supplied coverage and for whom eligibility is sought.'
    created: 'dateTime' = Field(default=...)
    'The date when this resource was created.'
    enterer: Optional_['Reference'] = Field(default=None)
    'Person who created the request.'
    insurer: 'Reference' = Field(default=...)
    'The Insurer who issued the coverage in question and is the recipient of the request.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    priority: Optional_['CodeableConcept'] = Field(default=None)
    'When the requestor expects the processor to complete processing.'
    provider: Optional_['Reference'] = Field(default=None)
    'The provider which is responsible for the request.'
    facility: Optional_['Reference'] = Field(default=None)
    'Facility where the services are intended to be provided.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    insurance: List_['CoverageEligibilityRequestInsurance'] = Field(default_factory=list)
    'Financial instruments for reimbursement for the health care products and services.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this coverage eligiblity request.'
    servicedDate: Optional_['date'] = Field(default=None)
    'The date or dates when the enclosed suite of services were performed or completed.'
    servicedPeriod: Optional_['Period'] = Field(default=None)
    'The date or dates when the enclosed suite of services were performed or completed.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    supportingInfo: List_['CoverageEligibilityRequestSupportingInfo'] = Field(default_factory=list)
    'Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CoverageEligibilityResponseInsurance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Financial instruments for reimbursement for the health care products and services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    item: List_['CoverageEligibilityResponseInsuranceItem'] = Field(default_factory=list)
    'Benefits and optionally current balances, and authorization details by category or service.'
    inforce: Optional_['boolean'] = Field(default=None)
    'Flag indicating if the coverage provided is inforce currently if no service date(s) specified or for the whole duration of the service dates.'
    coverage: 'Reference' = Field(default=...)
    "Reference to the insurance card level information contained in the Coverage resource. The coverage issuing insurer will use these details to locate the patient's actual coverage within the insurer's information system."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    benefitPeriod: Optional_['Period'] = Field(default=None)
    'The term of the benefits documented in this response.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CoverageEligibilityResponseInsuranceItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Benefits and optionally current balances, and authorization details by category or service."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'A short name or tag for the benefit.'
    unit: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates if the benefits apply to an individual or to the family.'
    term: Optional_['CodeableConcept'] = Field(default=None)
    "The term or period of the values such as 'maximum lifetime benefit' or 'maximum annual visits'."
    network: Optional_['CodeableConcept'] = Field(default=None)
    'Is a flag to indicate whether the benefits refer to in-network providers or out-of-network providers.'
    benefit: List_['CoverageEligibilityResponseInsuranceItemBenefit'] = Field(default_factory=list)
    'Benefits used to date.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Code to identify the general type of benefits under which products and services are provided.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    provider: Optional_['Reference'] = Field(default=None)
    'The practitioner who is eligible for the provision of the product or service.'
    excluded: Optional_['boolean'] = Field(default=None)
    'True if the indicated class of service is excluded from the plan, missing or False indicates the product or service is included in the coverage.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'A richer description of the benefit or services covered.'
    productOrService: Optional_['CodeableConcept'] = Field(default=None)
    'This contains the product, service, drug or other billing code for the item.'
    authorizationUrl: Optional_['uri'] = Field(default=None)
    'A web location for obtaining requirements or descriptive information regarding the preauthorization.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    authorizationRequired: Optional_['boolean'] = Field(default=None)
    'A boolean flag indicating whether a preauthorization is required prior to actual service delivery.'
    authorizationSupporting: List_['CodeableConcept'] = Field(default_factory=list)
    'Codes or comments regarding information or actions associated with the preauthorization.'


class CoverageEligibilityResponseInsuranceItemBenefit(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Benefits used to date."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Classification of benefit being provided.'
    usedUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'The quantity of the benefit which have been consumed to date.'
    usedString: Optional_['string'] = Field(default=None)
    'The quantity of the benefit which have been consumed to date.'
    usedMoney: Optional_['Money'] = Field(default=None)
    'The quantity of the benefit which have been consumed to date.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    allowedUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'The quantity of the benefit which is permitted under the coverage.'
    allowedString: Optional_['string'] = Field(default=None)
    'The quantity of the benefit which is permitted under the coverage.'
    allowedMoney: Optional_['Money'] = Field(default=None)
    'The quantity of the benefit which is permitted under the coverage.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CoverageEligibilityResponseError(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Errors encountered during the processing of the request."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'An error code,from a specified code system, which details why the eligibility check could not be performed.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class CoverageEligibilityResponse(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource provides eligibility and plan details from the processing of an CoverageEligibilityRequest resource."""
    resourceType: Literal_['CoverageEligibilityResponse'] = Field(default=...)
    'CoverageEligibilityResponse resource'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    form: Optional_['CodeableConcept'] = Field(default=None)
    'A code for the form to be used for printing the content.'
    error: List_['CoverageEligibilityResponseError'] = Field(default_factory=list)
    'Errors encountered during the processing of the request.'
    status: 'code' = Field(default=...)
    'The status of the resource instance.'
    purpose: List_['code'] = Field(default=...)
    "Code to specify whether requesting: prior authorization requirements for some service categories or billing codes; benefits for coverages specified or discovered; discovery and return of coverages for the patient; and/or validation that the specified coverage is in-force at the date/period specified or 'now' if not specified."
    patient: 'Reference' = Field(default=...)
    'The party who is the beneficiary of the supplied coverage and for whom eligibility is sought.'
    created: 'dateTime' = Field(default=...)
    'The date this resource was created.'
    request: 'Reference' = Field(default=...)
    'Reference to the original request resource.'
    outcome: 'code' = Field(default=...)
    'The outcome of the request processing.'
    insurer: 'Reference' = Field(default=...)
    'The Insurer who issued the coverage in question and is the author of the response.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    requestor: Optional_['Reference'] = Field(default=None)
    'The provider which is responsible for the request.'
    insurance: List_['CoverageEligibilityResponseInsurance'] = Field(default_factory=list)
    'Financial instruments for reimbursement for the health care products and services.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this coverage eligiblity request.'
    preAuthRef: Optional_['string'] = Field(default=None)
    'A reference from the Insurer to which these services pertain to be used on further communication and as proof that the request occurred.'
    servicedDate: Optional_['date'] = Field(default=None)
    'The date or dates when the enclosed suite of services were performed or completed.'
    servicedPeriod: Optional_['Period'] = Field(default=None)
    'The date or dates when the enclosed suite of services were performed or completed.'
    disposition: Optional_['string'] = Field(default=None)
    'A human readable description of the status of the adjudication.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DetectedIssueMitigation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates an action that has been taken or is committed to reduce or eliminate the likelihood of the risk identified by the detected issue from manifesting.  Can also reflect an observation of known mitigating factors that may reduce/eliminate the need for any action."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    date: Optional_['dateTime'] = Field(default=None)
    'Indicates when the mitigating action was documented.'
    action: 'CodeableConcept' = Field(default=...)
    'Describes the action that was taken or the observation that was made that reduces/eliminates the risk associated with the identified issue.'
    author: Optional_['Reference'] = Field(default=None)
    'Identifies the practitioner who determined the mitigation and takes responsibility for the mitigation step occurring.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DetectedIssueEvidence(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Supporting evidence or manifestations that provide the basis for identifying the detected issue such as a GuidanceResponse or MeasureReport."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'A manifestation that led to the recording of this detected issue.'
    detail: List_['Reference'] = Field(default_factory=list)
    'Links to resources that constitute evidence for the detected issue such as a GuidanceResponse or MeasureReport.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DetectedIssue(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates an actual or potential clinical issue with or between one or more active or proposed clinical actions for a patient; e.g. Drug-drug interaction, Ineffective treatment frequency, Procedure-condition conflict, etc."""
    resourceType: Literal_['DetectedIssue'] = Field(default=...)
    'Clinical issue with action'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: 'code' = Field(default=...)
    'Indicates the status of the detected issue.'
    author: Optional_['Reference'] = Field(default=None)
    'Individual or device responsible for the issue being raised.  For example, a decision support application or a pharmacist conducting a medication review.'
    detail: Optional_['string'] = Field(default=None)
    'A textual explanation of the detected issue.'
    patient: Optional_['Reference'] = Field(default=None)
    'Indicates the patient whose record the detected issue is associated with.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    severity: Optional_['code'] = Field(default=None)
    'Indicates the degree of importance associated with the identified issue based on the potential impact on the patient.'
    evidence: List_['DetectedIssueEvidence'] = Field(default_factory=list)
    'Supporting evidence or manifestations that provide the basis for identifying the detected issue such as a GuidanceResponse or MeasureReport.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: Optional_['uri'] = Field(default=None)
    'The literature, knowledge-base or similar reference that describes the propensity for the detected issue identified.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifier associated with the detected issue record.'
    implicated: List_['Reference'] = Field(default_factory=list)
    'Indicates the resource representing the current activity or proposed activity that is potentially problematic.'
    mitigation: List_['DetectedIssueMitigation'] = Field(default_factory=list)
    'Indicates an action that has been taken or is committed to reduce or eliminate the likelihood of the risk identified by the detected issue from manifesting.  Can also reflect an observation of known mitigating factors that may reduce/eliminate the need for any action.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    identifiedDateTime: Optional_['dateTime'] = Field(default=None)
    'The date or period when the detected issue was initially identified.'
    identifiedPeriod: Optional_['Period'] = Field(default=None)
    'The date or period when the detected issue was initially identified.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the general type of issue identified.'


class DeviceSpecialization(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The capabilities supported on a  device, the standards to which the device conforms for a particular purpose, and used for the communication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    version: Optional_['string'] = Field(default=None)
    'The version of the standard that is used to operate and communicate.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    systemType: 'CodeableConcept' = Field(default=...)
    'The standard that is used to operate and communicate.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceDeviceName(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This represents the manufacturer's name of the device as provided by the device, from a UDI label, or by a person describing the Device.  This typically would be used when a person provides the name(s) or when the device represents one of the names available from DeviceDefinition."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'The name that identifies the device.'
    type: 'code' = Field(default=...)
    'The type of deviceName.\nUDILabelName | UserFriendlyName | PatientReportedName | ManufactureDeviceName | ModelName.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceUdiCarrier(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    issuer: Optional_['uri'] = Field(default=None)
    'Organization that is charged with issuing UDIs for devices.  For example, the US FDA issuers include :\n1) GS1: \nhttp://hl7.org/fhir/NamingSystem/gs1-di, \n2) HIBCC:\nhttp://hl7.org/fhir/NamingSystem/hibcc-dI, \n3) ICCBBA for blood containers:\nhttp://hl7.org/fhir/NamingSystem/iccbba-blood-di, \n4) ICCBA for other devices:\nhttp://hl7.org/fhir/NamingSystem/iccbba-other-di.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    entryType: Optional_['code'] = Field(default=None)
    'A coded entry to indicate how the data was entered.'
    carrierHRF: Optional_['string'] = Field(default=None)
    'The full UDI carrier as the human readable form (HRF) representation of the barcode string as printed on the packaging of the device.'
    carrierAIDC: Optional_['base64Binary'] = Field(default=None)
    'The full UDI carrier of the Automatic Identification and Data Capture (AIDC) technology representation of the barcode string as printed on the packaging of the device - e.g., a barcode or RFID.   Because of limitations on character sets in XML and the need to round-trip JSON data through XML, AIDC Formats *SHALL* be base64 encoded.'
    jurisdiction: Optional_['uri'] = Field(default=None)
    'The identity of the authoritative source for UDI generation within a  jurisdiction.  All UDIs are globally unique within a single namespace with the appropriate repository uri as the system.  For example,  UDIs of devices managed in the U.S. by the FDA, the value is  http://hl7.org/fhir/NamingSystem/fda-udi.'
    deviceIdentifier: Optional_['string'] = Field(default=None)
    'The device identifier (DI) is a mandatory, fixed portion of a UDI that identifies the labeler and the specific version or model of a device.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceProperty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The actual configuration settings of a device as it actually operates, e.g., regulation status, time properties."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Code that specifies the property DeviceDefinitionPropetyCode (Extensible).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    valueCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Property value as a code, e.g., NTP4 (synced to NTP).'
    valueQuantity: List_['Quantity'] = Field(default_factory=list)
    'Property value as a quantity.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceVersion(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The actual design of the device or software version running on the device."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of the device version, e.g. manufacturer, approved, internal.'
    value: 'string' = Field(default=...)
    'The version text.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    component: Optional_['Identifier'] = Field(default=None)
    'A single component of the device version.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Device(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A type of a manufactured item that is used in the provision of healthcare without being substantially changed through that activity. The device may be a medical or non-medical device."""
    resourceType: Literal_['Device'] = Field(default=...)
    'Item used in healthcare'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'A network address on which the device may be contacted directly.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind or type of device.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Descriptive information, usage information or implantation information that is not captured in an existing element.'
    owner: Optional_['Reference'] = Field(default=None)
    'An organization that is responsible for the provision and ongoing maintenance of the device.'
    status: Optional_['code'] = Field(default=None)
    'Status of the Device availability.'
    safety: List_['CodeableConcept'] = Field(default_factory=list)
    'Provides additional safety characteristics about a medical device.  For example devices containing latex.'
    parent: Optional_['Reference'] = Field(default=None)
    'The device that this device is attached to or is part of.'
    version: List_['DeviceVersion'] = Field(default_factory=list)
    'The actual design of the device or software version running on the device.'
    patient: Optional_['Reference'] = Field(default=None)
    'Patient information, If the device is affixed to a person.'
    contact: List_['ContactPoint'] = Field(default_factory=list)
    'Contact details for an organization or a particular human that is responsible for the device.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    property: List_['DeviceProperty'] = Field(default_factory=list)
    'The actual configuration settings of a device as it actually operates, e.g., regulation status, time properties.'
    location: Optional_['Reference'] = Field(default=None)
    'The place where the device can be found.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    lotNumber: Optional_['string'] = Field(default=None)
    'Lot number assigned by the manufacturer.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique instance identifiers assigned to a device by manufacturers other organizations or owners.'
    definition: Optional_['Reference'] = Field(default=None)
    'The reference to the definition for the device.'
    udiCarrier: List_['DeviceUdiCarrier'] = Field(default_factory=list)
    'Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.'
    deviceName: List_['DeviceDeviceName'] = Field(default_factory=list)
    "This represents the manufacturer's name of the device as provided by the device, from a UDI label, or by a person describing the Device.  This typically would be used when a person provides the name(s) or when the device represents one of the names available from DeviceDefinition."
    partNumber: Optional_['string'] = Field(default=None)
    'The part number or catalog number of the device.'
    modelNumber: Optional_['string'] = Field(default=None)
    "The manufacturer's model number for the device."
    statusReason: List_['CodeableConcept'] = Field(default_factory=list)
    'Reason for the dtatus of the Device availability.'
    manufacturer: Optional_['string'] = Field(default=None)
    'A name of the manufacturer.'
    serialNumber: Optional_['string'] = Field(default=None)
    'The serial number assigned by the organization when the device was manufactured.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    expirationDate: Optional_['dateTime'] = Field(default=None)
    'The date and time beyond which this device is no longer valid or should not be used (if applicable).'
    specialization: List_['DeviceSpecialization'] = Field(default_factory=list)
    'The capabilities supported on a  device, the standards to which the device conforms for a particular purpose, and used for the communication.'
    manufactureDate: Optional_['dateTime'] = Field(default=None)
    'The date and time when the device was manufactured.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    distinctIdentifier: Optional_['string'] = Field(default=None)
    'The distinct identification string as required by regulation for a human cell, tissue, or cellular and tissue-based product.'


class DeviceDefinitionUdiDeviceIdentifier(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    issuer: 'uri' = Field(default=...)
    'The organization that assigns the identifier algorithm.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    jurisdiction: 'uri' = Field(default=...)
    'The jurisdiction to which the deviceIdentifier applies.'
    deviceIdentifier: 'string' = Field(default=...)
    'The identifier that is to be associated with every Device that references this DeviceDefintiion for the issuer and jurisdication porvided in the DeviceDefinition.udiDeviceIdentifier.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceDefinitionSpecialization(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The capabilities supported on a  device, the standards to which the device conforms for a particular purpose, and used for the communication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    version: Optional_['string'] = Field(default=None)
    'The version of the standard that is used to operate and communicate.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    systemType: 'string' = Field(default=...)
    'The standard that is used to operate and communicate.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceDefinitionCapability(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Device capabilities."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Type of capability.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: List_['CodeableConcept'] = Field(default_factory=list)
    'Description of capability.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceDefinitionDeviceName(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A name given to the device to identify it."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'The name of the device.'
    type: 'code' = Field(default=...)
    'The type of deviceName.\nUDILabelName | UserFriendlyName | PatientReportedName | ManufactureDeviceName | ModelName.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceDefinitionMaterial(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A substance used to create the material(s) of which the device is made."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    substance: 'CodeableConcept' = Field(default=...)
    'The substance.'
    alternate: Optional_['boolean'] = Field(default=None)
    'Indicates an alternative material of the device.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    allergenicIndicator: Optional_['boolean'] = Field(default=None)
    'Whether the substance is a known or suspected allergen.'


class DeviceDefinitionProperty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The actual configuration settings of a device as it actually operates, e.g., regulation status, time properties."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Code that specifies the property DeviceDefinitionPropetyCode (Extensible).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    valueCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Property value as a code, e.g., NTP4 (synced to NTP).'
    valueQuantity: List_['Quantity'] = Field(default_factory=list)
    'Property value as a quantity.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The characteristics, operational status and capabilities of a medical-related component of a medical device."""
    resourceType: Literal_['DeviceDefinition'] = Field(default=...)
    'An instance of a medical-related component of a medical device'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'A network address on which the device may be contacted directly.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'What kind of device or device system this is.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Descriptive information, usage information or implantation information that is not captured in an existing element.'
    owner: Optional_['Reference'] = Field(default=None)
    'An organization that is responsible for the provision and ongoing maintenance of the device.'
    safety: List_['CodeableConcept'] = Field(default_factory=list)
    'Safety characteristics of the device.'
    version: List_['string'] = Field(default_factory=list)
    'The available versions of the device, e.g., software versions.'
    contact: List_['ContactPoint'] = Field(default_factory=list)
    'Contact details for an organization or a particular human that is responsible for the device.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    property: List_['DeviceDefinitionProperty'] = Field(default_factory=list)
    'The actual configuration settings of a device as it actually operates, e.g., regulation status, time properties.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The quantity of the device present in the packaging (e.g. the number of devices present in a pack, or the number of devices in the same package of the medicinal product).'
    material: List_['DeviceDefinitionMaterial'] = Field(default_factory=list)
    'A substance used to create the material(s) of which the device is made.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique instance identifiers assigned to a device by the software, manufacturers, other organizations or owners. For example: handle ID.'
    deviceName: List_['DeviceDefinitionDeviceName'] = Field(default_factory=list)
    'A name given to the device to identify it.'
    capability: List_['DeviceDefinitionCapability'] = Field(default_factory=list)
    'Device capabilities.'
    modelNumber: Optional_['string'] = Field(default=None)
    'The model number for the device.'
    languageCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Language code for the human-readable text strings produced by the device (all supported).'
    parentDevice: Optional_['Reference'] = Field(default=None)
    'The parent device it can be part of.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    specialization: List_['DeviceDefinitionSpecialization'] = Field(default_factory=list)
    'The capabilities supported on a  device, the standards to which the device conforms for a particular purpose, and used for the communication.'
    manufacturerString: Optional_['string'] = Field(default=None)
    'A name of the manufacturer.'
    manufacturerReference: Optional_['Reference'] = Field(default=None)
    'A name of the manufacturer.'
    shelfLifeStorage: List_['ProductShelfLife'] = Field(default_factory=list)
    'Shelf Life and storage information.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    onlineInformation: Optional_['uri'] = Field(default=None)
    'Access to on-line information about the device.'
    udiDeviceIdentifier: List_['DeviceDefinitionUdiDeviceIdentifier'] = Field(default_factory=list)
    'Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.'
    physicalCharacteristics: Optional_['ProdCharacteristic'] = Field(default=None)
    'Dimensions, color etc.'


class DeviceMetricCalibration(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes the calibrations that have been performed or that are required to be performed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['code'] = Field(default=None)
    'Describes the type of the calibration method.'
    time: Optional_['instant'] = Field(default=None)
    'Describes the time last calibration has been performed.'
    state: Optional_['code'] = Field(default=None)
    'Describes the state of the calibration.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceMetric(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes a measurement, calculation or setting capability of a medical device."""
    resourceType: Literal_['DeviceMetric'] = Field(default=...)
    'Measurement, calculation or setting capability of a medical device'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'CodeableConcept' = Field(default=...)
    'Describes the type of the metric. For example: Heart Rate, PEEP Setting, etc.'
    unit: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the unit that an observed value determined for this metric will have. For example: Percent, Seconds, etc.'
    color: Optional_['code'] = Field(default=None)
    'Describes the color representation for the metric. This is often used to aid clinicians to track and identify parameter types by color. In practice, consider a Patient Monitor that has ECG/HR and Pleth for example; the parameters are displayed in different characteristic colors, such as HR-blue, BP-green, and PR and SpO2- magenta.'
    source: Optional_['Reference'] = Field(default=None)
    'Describes the link to the  Device that this DeviceMetric belongs to and that contains administrative device information such as manufacturer, serial number, etc.'
    parent: Optional_['Reference'] = Field(default=None)
    'Describes the link to the  Device that this DeviceMetric belongs to and that provide information about the location of this DeviceMetric in the containment structure of the parent Device. An example would be a Device that represents a Channel. This reference can be used by a client application to distinguish DeviceMetrics that have the same type, but should be interpreted based on their containment location.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: 'code' = Field(default=...)
    'Indicates the category of the observation generation process. A DeviceMetric can be for example a setting, measurement, or calculation.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique instance identifiers assigned to a device by the device or gateway software, manufacturers, other organizations or owners. For example: handle ID.'
    calibration: List_['DeviceMetricCalibration'] = Field(default_factory=list)
    'Describes the calibrations that have been performed or that are required to be performed.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    operationalStatus: Optional_['code'] = Field(default=None)
    'Indicates current operational state of the device. For example: On, Off, Standby, etc.'
    measurementPeriod: Optional_['Timing'] = Field(default=None)
    'Describes the measurement repetition time. This is not necessarily the same as the update period. The measurement repetition time can range from milliseconds up to hours. An example for a measurement repetition time in the range of milliseconds is the sampling rate of an ECG. An example for a measurement repetition time in the range of hours is a NIBP that is triggered automatically every hour. The update period may be different than the measurement repetition time, if the device does not update the published observed value with the same frequency as it was measured.'


class DeviceRequestParameter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specific parameters for the ordered item.  For example, the prism value for lenses."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code or string that identifies the device detail being asserted.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The value of the device detail.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The value of the device detail.'
    valueRange: Optional_['Range'] = Field(default=None)
    'The value of the device detail.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The value of the device detail.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DeviceRequest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Represents a request for a patient to employ a medical device. The device may be an implantable device, or an external assistive device, such as a walker."""
    resourceType: Literal_['DeviceRequest'] = Field(default=...)
    'Medical device request'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Details about this request that were not represented at all or sufficiently in one of the attributes provided in a class. These may include for example a comment, an instruction, or a note associated with the statement.'
    status: Optional_['code'] = Field(default=None)
    'The status of the request.'
    intent: 'code' = Field(default=...)
    'Whether the request is a proposal, plan, an original order or a reflex order.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'Plan/proposal/order fulfilled by this request.'
    subject: 'Reference' = Field(default=...)
    'The patient who will use the device.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    priority: Optional_['code'] = Field(default=None)
    'Indicates how quickly the {{title}} should be addressed with respect to other requests.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    parameter: List_['DeviceRequestParameter'] = Field(default_factory=list)
    'Specific parameters for the ordered item.  For example, the prism value for lenses.'
    encounter: Optional_['Reference'] = Field(default=None)
    'An encounter that provides additional context in which this request is made.'
    requester: Optional_['Reference'] = Field(default=None)
    'The individual who initiated the request and has responsibility for its activation.'
    performer: Optional_['Reference'] = Field(default=None)
    'The desired performer for doing the diagnostic testing.'
    insurance: List_['Reference'] = Field(default_factory=list)
    'Insurance plans, coverage extensions, pre-authorizations and/or pre-determinations that may be required for delivering the requested service.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers assigned to this order by the orderer or by the receiver.'
    authoredOn: Optional_['dateTime'] = Field(default=None)
    'When the request transitioned to being actionable.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Reason or justification for the use of this device.'
    priorRequest: List_['Reference'] = Field(default_factory=list)
    'The request takes the place of the referenced completed or terminated request(s).'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'The timing schedule for the use of the device. The Schedule data type allows many different expressions, for example. "Every 8 hours"; "Three times a day"; "1/2 an hour before breakfast for 10 days from 23-Dec 2011:"; "15 Oct 2013, 17 Oct 2013 and 1 Nov 2013".'
    occurrencePeriod: Optional_['Period'] = Field(default=None)
    'The timing schedule for the use of the device. The Schedule data type allows many different expressions, for example. "Every 8 hours"; "Three times a day"; "1/2 an hour before breakfast for 10 days from 23-Dec 2011:"; "15 Oct 2013, 17 Oct 2013 and 1 Nov 2013".'
    occurrenceTiming: Optional_['Timing'] = Field(default=None)
    'The timing schedule for the use of the device. The Schedule data type allows many different expressions, for example. "Every 8 hours"; "Three times a day"; "1/2 an hour before breakfast for 10 days from 23-Dec 2011:"; "15 Oct 2013, 17 Oct 2013 and 1 Nov 2013".'
    performerType: Optional_['CodeableConcept'] = Field(default=None)
    'Desired type of performer for doing the diagnostic testing.'
    supportingInfo: List_['Reference'] = Field(default_factory=list)
    "Additional clinical information about the patient that may influence the request fulfilment.  For example, this may include where on the subject's body the device will be used (i.e. the target site)."
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally maintained protocol, guideline, orderset or other definition that is adhered to in whole or in part by this DeviceRequest.'
    groupIdentifier: Optional_['Identifier'] = Field(default=None)
    'Composite request this is part of.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Reason or justification for the use of this device.'
    relevantHistory: List_['Reference'] = Field(default_factory=list)
    'Key events in the history of the request.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'The URL pointing to a FHIR-defined protocol, guideline, orderset or other definition that is adhered to in whole or in part by this DeviceRequest.'
    codeReference: Optional_['Reference'] = Field(default=None)
    'The details of the device to be used.'
    codeCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The details of the device to be used.'


class DeviceUseStatement(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A record of a device being used by a patient where the record is the result of a report from the patient or another clinician."""
    resourceType: Literal_['DeviceUseStatement'] = Field(default=...)
    'Record of use of a device'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Details about the device statement that were not represented at all or sufficiently in one of the attributes provided in a class. These may include for example a comment, an instruction, or a note associated with the statement.'
    status: 'code' = Field(default=...)
    "A code representing the patient or other source's judgment about the state of the device used that this statement is about.  Generally this will be active or completed."
    source: Optional_['Reference'] = Field(default=None)
    'Who reported the device was being used by the patient.'
    device: 'Reference' = Field(default=...)
    'The details of the device used.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A plan, proposal or order that is fulfilled in whole or in part by this DeviceUseStatement.'
    subject: 'Reference' = Field(default=...)
    'The patient who used the device.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    bodySite: Optional_['CodeableConcept'] = Field(default=None)
    "Indicates the anotomic location on the subject's body where the device was used ( i.e. the target)."
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    timingTiming: Optional_['Timing'] = Field(default=None)
    'How often the device was used.'
    timingPeriod: Optional_['Period'] = Field(default=None)
    'How often the device was used.'
    timingDateTime: Optional_['dateTime'] = Field(default=None)
    'How often the device was used.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'An external identifier for this statement such as an IRI.'
    recordedOn: Optional_['dateTime'] = Field(default=None)
    'The time at which the statement was made/recorded.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Reason or justification for the use of the device.'
    derivedFrom: List_['Reference'] = Field(default_factory=list)
    'Allows linking the DeviceUseStatement to the underlying Request, or to other information that supports or is used to derive the DeviceUseStatement.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates another resource whose existence justifies this DeviceUseStatement.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DiagnosticReportMedia(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A list of key images associated with this report. The images are generally created during the diagnostic process, and may be directly of the patient, or of treated specimens (i.e. slides of interest)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    link: 'Reference' = Field(default=...)
    'Reference to the image source.'
    comment: Optional_['string'] = Field(default=None)
    "A comment about the image. Typically, this is used to provide an explanation for why the image is included, or to draw the viewer's attention to important features."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DiagnosticReport(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The findings and interpretation of diagnostic  tests performed on patients, groups of patients, devices, and locations, and/or specimens derived from these. The report includes clinical context such as requesting and provider information, and some mix of atomic results, images, textual and coded interpretations, and formatted representation of diagnostic reports."""
    resourceType: Literal_['DiagnosticReport'] = Field(default=...)
    'A Diagnostic report - a combination of request information, atomic results, images, interpretation, as well as formatted reports'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    media: List_['DiagnosticReportMedia'] = Field(default_factory=list)
    'A list of key images associated with this report. The images are generally created during the diagnostic process, and may be directly of the patient, or of treated specimens (i.e. slides of interest).'
    status: 'code' = Field(default=...)
    'The status of the diagnostic report.'
    issued: Optional_['instant'] = Field(default=None)
    'The date and time that this version of the report was made available to providers, typically after the report was reviewed and verified.'
    result: List_['Reference'] = Field(default_factory=list)
    '[Observations](observation.html)  that are part of this diagnostic report.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'Details concerning a service requested.'
    subject: Optional_['Reference'] = Field(default=None)
    'The subject of the report. Usually, but not always, this is a patient. However, diagnostic services also perform analyses on specimens collected from a variety of other sources.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'A code that classifies the clinical discipline, department or diagnostic service that created the report (e.g. cardiology, biochemistry, hematology, MRI). This is used for searching, sorting and display purposes.'
    specimen: List_['Reference'] = Field(default_factory=list)
    'Details about the specimens on which this diagnostic report is based.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The healthcare event  (e.g. a patient and healthcare provider interaction) which this DiagnosticReport is about.'
    performer: List_['Reference'] = Field(default_factory=list)
    'The diagnostic service that is responsible for issuing the report.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers assigned to this report by the performer or other systems.'
    conclusion: Optional_['string'] = Field(default=None)
    'Concise and clinically contextualized summary conclusion (interpretation/impression) of the diagnostic report.'
    effectiveDateTime: Optional_['dateTime'] = Field(default=None)
    'The time or time-period the observed values are related to. When the subject of the report is a patient, this is usually either the time of the procedure or of specimen collection(s), but very often the source of the date/time is not known, only the date/time itself.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The time or time-period the observed values are related to. When the subject of the report is a patient, this is usually either the time of the procedure or of specimen collection(s), but very often the source of the date/time is not known, only the date/time itself.'
    imagingStudy: List_['Reference'] = Field(default_factory=list)
    'One or more links to full details of any imaging performed during the diagnostic investigation. Typically, this is imaging performed by DICOM enabled modalities, but this is not required. A fully enabled PACS viewer can use this information to provide views of the source images.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    presentedForm: List_['Attachment'] = Field(default_factory=list)
    'Rich text representation of the entire result as issued by the diagnostic service. Multiple formats are allowed but they SHALL be semantically equivalent.'
    conclusionCode: List_['CodeableConcept'] = Field(default_factory=list)
    'One or more codes that represent the summary conclusion (interpretation/impression) of the diagnostic report.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    resultsInterpreter: List_['Reference'] = Field(default_factory=list)
    "The practitioner or organization that is responsible for the report's conclusions and interpretations."
    code: 'CodeableConcept' = Field(default=...)
    'A code or name that describes this diagnostic report.'


class DocumentManifestRelated(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Related identifiers or resources associated with the DocumentManifest."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    ref: Optional_['Reference'] = Field(default=None)
    'Related Resource to this DocumentManifest. For example, Order, ServiceRequest,  Procedure, EligibilityRequest, etc.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Related identifier to this DocumentManifest.  For example, Order numbers, accession numbers, XDW workflow numbers.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DocumentManifest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A collection of documents compiled for a purpose together with metadata that applies to the collection."""
    resourceType: Literal_['DocumentManifest'] = Field(default=...)
    'A list that defines a set of documents'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The code specifying the type of clinical activity that resulted in placing the associated content into the DocumentManifest.'
    status: 'code' = Field(default=...)
    'The status of this document manifest.'
    author: List_['Reference'] = Field(default_factory=list)
    'Identifies who is the author of the manifest. Manifest author is not necessarly the author of the references included.'
    source: Optional_['uri'] = Field(default=None)
    'Identifies the source system, application, or software that produced the document manifest.'
    subject: Optional_['Reference'] = Field(default=None)
    'Who or what the set of documents is about. The documents can be about a person, (patient or healthcare practitioner), a device (i.e. machine) or even a group of subjects (such as a document about a herd of farm animals, or a set of patients that share a common exposure). If the documents cross more than one subject, then more than one subject is allowed here (unusual use case).'
    created: Optional_['dateTime'] = Field(default=None)
    'When the document manifest was created for submission to the server (not necessarily the same thing as the actual resource last modified time, since it may be modified, replicated, etc.).'
    content: List_['Reference'] = Field(default=...)
    'The list of Resources that consist of the parts of this manifest.'
    related: List_['DocumentManifestRelated'] = Field(default_factory=list)
    'Related identifiers or resources associated with the DocumentManifest.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    recipient: List_['Reference'] = Field(default_factory=list)
    'A patient, practitioner, or organization for which this set of documents is intended.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Other identifiers associated with the document manifest, including version independent  identifiers.'
    description: Optional_['string'] = Field(default=None)
    'Human-readable description of the source document. This is sometimes known as the "title".'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    masterIdentifier: Optional_['Identifier'] = Field(default=None)
    'A single identifier that uniquely identifies this manifest. Principally used to refer to the manifest in non-FHIR contexts.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DocumentReferenceRelatesTo(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Relationships that this document has with other document references that already exist."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    target: 'Reference' = Field(default=...)
    'The target document of this relationship.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'The type of relationship that this document has with anther document.'


class DocumentReferenceContext(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The clinical context in which the document was prepared."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    event: List_['CodeableConcept'] = Field(default_factory=list)
    'This list of codes represents the main clinical acts, such as a colonoscopy or an appendectomy, being documented. In some cases, the event is inherent in the type Code, such as a "History and Physical Report" in which the procedure being documented is necessarily a "History and Physical" act.'
    period: Optional_['Period'] = Field(default=None)
    'The time period over which the service that is described by the document was provided.'
    related: List_['Reference'] = Field(default_factory=list)
    'Related identifiers or resources associated with the DocumentReference.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: List_['Reference'] = Field(default_factory=list)
    'Describes the clinical encounter or type of care that the document content is associated with.'
    facilityType: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of facility where the patient was seen.'
    practiceSetting: Optional_['CodeableConcept'] = Field(default=None)
    'This property may convey specifics about the practice setting where the content was created, often reflecting the clinical specialty.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    sourcePatientInfo: Optional_['Reference'] = Field(default=None)
    'The Patient Information as known when the document was published. May be a reference to a version specific, or contained.'


class DocumentReferenceContent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The document and format referenced. There may be multiple content element repetitions, each with a different format."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    format: Optional_['Coding'] = Field(default=None)
    'An identifier of the document encoding, structure, and template that the document conforms to beyond the base format indicated in the mimeType.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    attachment: 'Attachment' = Field(default=...)
    'The document or URL of the document along with critical metadata to prove content has integrity.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DocumentReference(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A reference to a document of any kind for any purpose. Provides metadata about the document so that the document can be discovered and managed. The scope of a document is any seralized object with a mime-type, so includes formal patient centric documents (CDA), cliical notes, scanned paper, and non-patient specific documents like policy text."""
    resourceType: Literal_['DocumentReference'] = Field(default=...)
    'A reference to a document'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Specifies the particular kind of document referenced  (e.g. History and Physical, Discharge Summary, Progress Note). This usually equates to the purpose of making the document referenced.'
    date: Optional_['instant'] = Field(default=None)
    'When the document reference was created.'
    status: 'code' = Field(default=...)
    'The status of this document reference.'
    author: List_['Reference'] = Field(default_factory=list)
    'Identifies who is responsible for adding the information to the document.'
    subject: Optional_['Reference'] = Field(default=None)
    'Who or what the document is about. The document can be about a person, (patient or healthcare practitioner), a device (e.g. a machine) or even a group of subjects (such as a document about a herd of farm animals, or a set of patients that share a common exposure).'
    content: List_['DocumentReferenceContent'] = Field(default=...)
    'The document and format referenced. There may be multiple content element repetitions, each with a different format.'
    context: Optional_['DocumentReferenceContext'] = Field(default=None)
    'The clinical context in which the document was prepared.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'A categorization for the type of document referenced - helps for indexing and searching. This may be implied by or derived from the code specified in the DocumentReference.type.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    docStatus: Optional_['code'] = Field(default=None)
    'The status of the underlying document.'
    custodian: Optional_['Reference'] = Field(default=None)
    'Identifies the organization or group who is responsible for ongoing maintenance of and access to the document.'
    relatesTo: List_['DocumentReferenceRelatesTo'] = Field(default_factory=list)
    'Relationships that this document has with other document references that already exist.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Other identifiers associated with the document, including version independent identifiers.'
    description: Optional_['string'] = Field(default=None)
    'Human-readable description of the source document.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    authenticator: Optional_['Reference'] = Field(default=None)
    'Which person or organization authenticates that this document is valid.'
    securityLabel: List_['CodeableConcept'] = Field(default_factory=list)
    'A set of Security-Tag codes specifying the level of privacy/security of the Document. Note that DocumentReference.meta.security contains the security labels of the "reference" to the document, while DocumentReference.securityLabel contains a snapshot of the security labels on the document the reference refers to.'
    masterIdentifier: Optional_['Identifier'] = Field(default=None)
    'Document identifier as assigned by the source of the document. This identifier is specific to this version of the document. This unique identifier may be used elsewhere to identify this version of the document.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class DomainResource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A resource that includes narrative, extensions, and contained resources."""
    resourceType: Literal_['DomainResource'] = Field(default=...)
    'A resource with narrative, extensions, and contained resources'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EncounterHospitalization(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details about the admission to a healthcare service."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    origin: Optional_['Reference'] = Field(default=None)
    'The location/organization from which the patient came before admission.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    admitSource: Optional_['CodeableConcept'] = Field(default=None)
    'From where patient was admitted (physician referral, transfer).'
    reAdmission: Optional_['CodeableConcept'] = Field(default=None)
    'Whether this hospitalization is a readmission and why if known.'
    destination: Optional_['Reference'] = Field(default=None)
    'Location/organization to which the patient is discharged.'
    dietPreference: List_['CodeableConcept'] = Field(default_factory=list)
    'Diet preferences reported by the patient.'
    specialCourtesy: List_['CodeableConcept'] = Field(default_factory=list)
    'Special courtesies (VIP, board member).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    specialArrangement: List_['CodeableConcept'] = Field(default_factory=list)
    'Any special requests that have been made for this hospitalization encounter, such as the provision of specific equipment or other things.'
    dischargeDisposition: Optional_['CodeableConcept'] = Field(default=None)
    'Category or kind of location after discharge.'
    preAdmissionIdentifier: Optional_['Identifier'] = Field(default=None)
    'Pre-admission identifier.'


class EncounterStatusHistory(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The status history permits the encounter resource to contain the status history without needing to read through the historical versions of the resource, or even have the server store them."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    status: 'code' = Field(default=...)
    'planned | arrived | triaged | in-progress | onleave | finished | cancelled +.'
    period: 'Period' = Field(default=...)
    'The time that the episode was in the specified status.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EncounterClassHistory(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The class history permits the tracking of the encounters transitions without needing to go  through the resource history.  This would be used for a case where an admission starts of as an emergency encounter, then transitions into an inpatient scenario. Doing this and not restarting a new encounter ensures that any lab/diagnostic results can more easily follow the patient and not require re-processing and not get lost or cancelled during a kind of discharge from emergency to inpatient."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    class_: 'Coding' = Field(default=..., alias='class')
    'inpatient | outpatient | ambulatory | emergency +.'
    period: 'Period' = Field(default=...)
    'The time that the episode was in the specified class.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EncounterParticipant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The list of people responsible for providing the service."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'Role of participant in encounter.'
    period: Optional_['Period'] = Field(default=None)
    "The period of time that the specified participant participated in the encounter. These can overlap or be sub-sets of the overall encounter's period."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    individual: Optional_['Reference'] = Field(default=None)
    'Persons involved in the encounter other than the patient.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EncounterDiagnosis(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The list of diagnosis relevant to this encounter."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: Optional_['CodeableConcept'] = Field(default=None)
    'Role that this diagnosis has within the encounter (e.g. admission, billing, discharge …).'
    rank: Optional_['positiveInt'] = Field(default=None)
    'Ranking of the diagnosis (for each role type).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    condition: 'Reference' = Field(default=...)
    'Reason the encounter takes place, as specified using information from another resource. For admissions, this is the admission diagnosis. The indication will typically be a Condition (with other resources referenced in the evidence.detail), or a Procedure.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EncounterLocation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """List of locations where  the patient has been during this encounter."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    status: Optional_['code'] = Field(default=None)
    "The status of the participants' presence at the specified location during the period specified. If the participant is no longer at the location, then the period will have an end date/time."
    period: Optional_['Period'] = Field(default=None)
    'Time period during which the patient was present at the location.'
    location: 'Reference' = Field(default=...)
    'The location where the encounter takes place.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    physicalType: Optional_['CodeableConcept'] = Field(default=None)
    'This will be used to specify the required levels (bed/ward/room/etc.) desired to be recorded to simplify either messaging or query.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Encounter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An interaction between a patient and healthcare provider(s) for the purpose of providing healthcare service(s) or assessing the health status of a patient."""
    resourceType: Literal_['Encounter'] = Field(default=...)
    'An interaction during which services are provided to the patient'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'Specific type of encounter (e.g. e-mail consultation, surgical day-care, skilled nursing, rehabilitation).'
    class_: 'Coding' = Field(default=..., alias='class')
    'Concepts representing classification of patient encounter such as ambulatory (outpatient), inpatient, emergency, home health or others due to local variations.'
    status: 'code' = Field(default=...)
    'planned | arrived | triaged | in-progress | onleave | finished | cancelled +.'
    period: Optional_['Period'] = Field(default=None)
    'The start and end time of the encounter.'
    length: Optional_['Duration'] = Field(default=None)
    'Quantity of time the encounter lasted. This excludes the time during leaves of absence.'
    partOf: Optional_['Reference'] = Field(default=None)
    'Another Encounter of which this encounter is a part of (administratively or in time).'
    subject: Optional_['Reference'] = Field(default=None)
    'The patient or group present at the encounter.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'The request this encounter satisfies (e.g. incoming referral or procedure request).'
    account: List_['Reference'] = Field(default_factory=list)
    'The set of accounts that may be used for billing for this Encounter.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    priority: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the urgency of the encounter.'
    location: List_['EncounterLocation'] = Field(default_factory=list)
    'List of locations where  the patient has been during this encounter.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    diagnosis: List_['EncounterDiagnosis'] = Field(default_factory=list)
    'The list of diagnosis relevant to this encounter.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier(s) by which this encounter is known.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Reason the encounter takes place, expressed as a code. For admissions, this can be used for a coded admission diagnosis.'
    serviceType: Optional_['CodeableConcept'] = Field(default=None)
    'Broad categorization of the service that is to be provided (e.g. cardiology).'
    participant: List_['EncounterParticipant'] = Field(default_factory=list)
    'The list of people responsible for providing the service.'
    appointment: List_['Reference'] = Field(default_factory=list)
    'The appointment that scheduled this encounter.'
    classHistory: List_['EncounterClassHistory'] = Field(default_factory=list)
    'The class history permits the tracking of the encounters transitions without needing to go  through the resource history.  This would be used for a case where an admission starts of as an emergency encounter, then transitions into an inpatient scenario. Doing this and not restarting a new encounter ensures that any lab/diagnostic results can more easily follow the patient and not require re-processing and not get lost or cancelled during a kind of discharge from emergency to inpatient.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    statusHistory: List_['EncounterStatusHistory'] = Field(default_factory=list)
    'The status history permits the encounter resource to contain the status history without needing to read through the historical versions of the resource, or even have the server store them.'
    episodeOfCare: List_['Reference'] = Field(default_factory=list)
    'Where a specific encounter should be classified as a part of a specific episode(s) of care this field should be used. This association can facilitate grouping of related encounters together for a specific purpose, such as government reporting, issue tracking, association via a common problem.  The association is recorded on the encounter as these are typically created after the episode of care and grouped on entry rather than editing the episode of care to append another encounter to it (the episode of care could span years).'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Reason the encounter takes place, expressed as a code. For admissions, this can be used for a coded admission diagnosis.'
    hospitalization: Optional_['EncounterHospitalization'] = Field(default=None)
    'Details about the admission to a healthcare service.'
    serviceProvider: Optional_['Reference'] = Field(default=None)
    "The organization that is primarily responsible for this Encounter's services. This MAY be the same as the organization on the Patient record, however it could be different, such as if the actor performing the services was from an external organization (which may be billed seperately) for an external consultation.  Refer to the example bundle showing an abbreviated set of Encounters for a colonoscopy."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Endpoint(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The technical details of an endpoint that can be used for electronic services, such as for web services providing XDS.b or a REST endpoint for another FHIR server. This may include any security context information."""
    resourceType: Literal_['Endpoint'] = Field(default=...)
    'The technical details of an endpoint that can be used for electronic services'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A friendly name that this endpoint can be referred to with.'
    status: 'code' = Field(default=...)
    'active | suspended | error | off | test.'
    period: Optional_['Period'] = Field(default=None)
    'The interval during which the endpoint is expected to be operational.'
    header: List_['string'] = Field(default_factory=list)
    'Additional headers / information to send as part of the notification.'
    contact: List_['ContactPoint'] = Field(default_factory=list)
    'Contact details for a human to contact about the subscription. The primary use of this for system administrator troubleshooting.'
    address: 'url' = Field(default=...)
    'The uri that describes the actual end-point to connect to.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier for the organization that is used to identify the endpoint across multiple disparate systems.'
    payloadType: List_['CodeableConcept'] = Field(default=...)
    'The payload type describes the acceptable content that can be communicated on the endpoint.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    connectionType: 'Coding' = Field(default=...)
    'A coded value that represents the technical details of the usage of this endpoint, such as what WSDLs should be used in what way. (e.g. XDS.b/DICOM/cds-hook).'
    payloadMimeType: List_['code'] = Field(default_factory=list)
    'The mime type to send the payload in - e.g. application/fhir+xml, application/fhir+json. If the mime type is not specified, then the sender could send any content (including no content depending on the connectionType).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    managingOrganization: Optional_['Reference'] = Field(default=None)
    'The organization that manages this endpoint (even if technically another organization is hosting this in the cloud, it is the organization associated with the data).'


class EnrollmentRequest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource provides the insurance enrollment details to the insurer regarding a specified coverage."""
    resourceType: Literal_['EnrollmentRequest'] = Field(default=...)
    'Enroll in coverage'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: Optional_['code'] = Field(default=None)
    'The status of the resource instance.'
    created: Optional_['dateTime'] = Field(default=None)
    'The date when this resource was created.'
    insurer: Optional_['Reference'] = Field(default=None)
    'The Insurer who is target  of the request.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    provider: Optional_['Reference'] = Field(default=None)
    'The practitioner who is responsible for the services rendered to the patient.'
    coverage: Optional_['Reference'] = Field(default=None)
    'Reference to the program or plan identification, underwriter or payor.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    candidate: Optional_['Reference'] = Field(default=None)
    'Patient Resource.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'The Response business identifier.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EnrollmentResponse(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource provides enrollment and plan details from the processing of an EnrollmentRequest resource."""
    resourceType: Literal_['EnrollmentResponse'] = Field(default=...)
    'EnrollmentResponse resource'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: Optional_['code'] = Field(default=None)
    'The status of the resource instance.'
    request: Optional_['Reference'] = Field(default=None)
    'Original request resource reference.'
    outcome: Optional_['code'] = Field(default=None)
    'Processing status: error, complete.'
    created: Optional_['dateTime'] = Field(default=None)
    'The date when the enclosed suite of services were performed or completed.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'The Response business identifier.'
    disposition: Optional_['string'] = Field(default=None)
    'A description of the status of the adjudication.'
    organization: Optional_['Reference'] = Field(default=None)
    'The Insurer who produced this adjudicated response.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    requestProvider: Optional_['Reference'] = Field(default=None)
    'The practitioner who is responsible for the services rendered to the patient.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EpisodeOfCareStatusHistory(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The history of statuses that the EpisodeOfCare has been through (without requiring processing the history of the resource)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    status: 'code' = Field(default=...)
    'planned | waitlist | active | onhold | finished | cancelled.'
    period: 'Period' = Field(default=...)
    'The period during this EpisodeOfCare that the specific status applied.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EpisodeOfCareDiagnosis(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The list of diagnosis relevant to this episode of care."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: Optional_['CodeableConcept'] = Field(default=None)
    'Role that this diagnosis has within the episode of care (e.g. admission, billing, discharge …).'
    rank: Optional_['positiveInt'] = Field(default=None)
    'Ranking of the diagnosis (for each role type).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    condition: 'Reference' = Field(default=...)
    'A list of conditions/problems/diagnoses that this episode of care is intended to be providing care for.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EpisodeOfCare(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An association between a patient and an organization / healthcare provider(s) during which time encounters may occur. The managing organization assumes a level of responsibility for the patient during this time."""
    resourceType: Literal_['EpisodeOfCare'] = Field(default=...)
    'An association of a Patient with an Organization and  Healthcare Provider(s) for a period of time that the Organization assumes some level of responsibility'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'A classification of the type of episode of care; e.g. specialist referral, disease management, type of funded care.'
    team: List_['Reference'] = Field(default_factory=list)
    'The list of practitioners that may be facilitating this episode of care for specific purposes.'
    status: 'code' = Field(default=...)
    'planned | waitlist | active | onhold | finished | cancelled.'
    period: Optional_['Period'] = Field(default=None)
    'The interval during which the managing organization assumes the defined responsibility.'
    patient: 'Reference' = Field(default=...)
    'The patient who is the focus of this episode of care.'
    account: List_['Reference'] = Field(default_factory=list)
    'The set of accounts that may be used for billing for this EpisodeOfCare.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    diagnosis: List_['EpisodeOfCareDiagnosis'] = Field(default_factory=list)
    'The list of diagnosis relevant to this episode of care.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'The EpisodeOfCare may be known by different identifiers for different contexts of use, such as when an external agency is tracking the Episode for funding purposes.'
    careManager: Optional_['Reference'] = Field(default=None)
    'The practitioner that is the care manager/care coordinator for this patient.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    statusHistory: List_['EpisodeOfCareStatusHistory'] = Field(default_factory=list)
    'The history of statuses that the EpisodeOfCare has been through (without requiring processing the history of the resource).'
    referralRequest: List_['Reference'] = Field(default_factory=list)
    'Referral Request(s) that are fulfilled by this EpisodeOfCare, incoming referrals.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    managingOrganization: Optional_['Reference'] = Field(default=None)
    'The organization that has assumed the specific responsibilities for the specified duration.'


class EventDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The EventDefinition resource provides a reusable description of when a particular event can occur."""
    resourceType: Literal_['EventDefinition'] = Field(default=...)
    'A description of when an event can occur'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this event definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this event definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the event definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the event definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the event definition.'
    usage: Optional_['string'] = Field(default=None)
    'A detailed description of how the event definition is used from a clinical perspective.'
    topic: List_['CodeableConcept'] = Field(default_factory=list)
    'Descriptive topics related to the module. Topics provide a high-level categorization of the module that can be useful for filtering and searching.'
    status: 'code' = Field(default=...)
    'The status of this event definition. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual or organization primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for internal coherence of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the event definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the event definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this event definition is needed and why it has been designed as it has.'
    trigger: List_['TriggerDefinition'] = Field(default=...)
    'The trigger element defines when the event occurs. If more than one trigger condition is specified, the event fires whenever any one of the trigger conditions is met.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    subtitle: Optional_['string'] = Field(default=None)
    'An explanatory or alternate title for the event definition giving additional information about its content.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization responsible for officially endorsing the content for use in some setting.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the event definition.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the event definition and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the event definition.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this event definition when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    subjectCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A code or group definition that describes the intended subject of the event definition.'
    subjectReference: Optional_['Reference'] = Field(default=None)
    'A code or group definition that describes the intended subject of the event definition.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate event definition instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the event definition from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this event definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the event definition is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the event definition content was or is planned to be in active use.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Related resources such as additional documentation, justification, or bibliographic references.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the event definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the event definition changes.'


class EvidenceVariableDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Evidence variable such as population, exposure, or outcome."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Footnotes and/or explanatory notes.'
    observed: Optional_['Reference'] = Field(default=None)
    'Definition of the actual variable related to the statistic(s).'
    intended: Optional_['Reference'] = Field(default=None)
    'Definition of the intended variable related to the Evidence.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['markdown'] = Field(default=None)
    'A text description or summary of the variable.'
    variableRole: 'CodeableConcept' = Field(default=...)
    'population | subpopulation | exposure | referenceExposure | measuredVariable | confounder.'
    directnessMatch: Optional_['CodeableConcept'] = Field(default=None)
    'Indication of quality of match between intended variable to actual variable.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EvidenceCertainty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Assessment of certainty, confidence in the estimates, or quality of the evidence."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Footnotes and/or explanatory notes.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Aspect of certainty being rated.'
    rater: Optional_['string'] = Field(default=None)
    'Individual or group who did the rating.'
    rating: Optional_['CodeableConcept'] = Field(default=None)
    'Assessment or judgement of the aspect.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'Textual description of certainty.'
    subcomponent: List_['EvidenceCertainty'] = Field(default_factory=list)
    'A domain or subdomain of certainty.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EvidenceStatistic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Values and parameters for a single statistic."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Footnotes and/or explanatory notes.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'When the measured variable is handled categorically, the category element is used to define which category the statistic is reporting.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'Statistic value.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    sampleSize: Optional_['EvidenceStatisticSampleSize'] = Field(default=None)
    'Number of samples in the statistic.'
    description: Optional_['string'] = Field(default=None)
    'A description of the content value of the statistic.'
    statisticType: Optional_['CodeableConcept'] = Field(default=None)
    'Type of statistic, eg relative risk.'
    numberOfEvents: Optional_['unsignedInt'] = Field(default=None)
    'The number of events associated with the statistic, where the unit of analysis is different from numberAffected, sampleSize.knownDataCount and sampleSize.numberOfParticipants.'
    numberAffected: Optional_['unsignedInt'] = Field(default=None)
    'The number of participants affected where the unit of analysis is the same as sampleSize.knownDataCount and sampleSize.numberOfParticipants.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    attributeEstimate: List_['EvidenceStatisticAttributeEstimate'] = Field(default_factory=list)
    'A statistical attribute of the statistic such as a measure of heterogeneity.'
    modelCharacteristic: List_['EvidenceStatisticModelCharacteristic'] = Field(default_factory=list)
    'A component of the method to generate the statistic.'


class EvidenceStatisticModelCharacteristic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A component of the method to generate the statistic."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'Description of a component of the method to generate the statistic.'
    value: Optional_['Quantity'] = Field(default=None)
    'Further specification of the quantified value of the component of the method to generate the statistic.'
    variable: List_['EvidenceStatisticModelCharacteristicVariable'] = Field(default_factory=list)
    'A variable adjusted for in the adjusted analysis.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    attributeEstimate: List_['EvidenceStatisticAttributeEstimate'] = Field(default_factory=list)
    'An attribute of the statistic used as a model characteristic.'


class EvidenceStatisticModelCharacteristicVariable(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A variable adjusted for in the adjusted analysis."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    handling: Optional_['code'] = Field(default=None)
    'How the variable is classified for use in adjusted analysis.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    valueRange: List_['Range'] = Field(default_factory=list)
    'Range of values for grouping of ordinal or polychotomous variables.'
    valueCategory: List_['CodeableConcept'] = Field(default_factory=list)
    'Description for grouping of ordinal or polychotomous variables.'
    valueQuantity: List_['Quantity'] = Field(default_factory=list)
    'Discrete value for grouping of ordinal or polychotomous variables.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    variableDefinition: 'Reference' = Field(default=...)
    'Description of the variable.'


class EvidenceStatisticAttributeEstimate(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A statistical attribute of the statistic such as a measure of heterogeneity."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Footnote or explanatory note about the estimate.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of attribute estimate, eg confidence interval or p value.'
    level: Optional_['decimal'] = Field(default=None)
    'Use 95 for a 95% confidence interval.'
    range: Optional_['Range'] = Field(default=None)
    'Lower bound of confidence interval.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The singular quantity of the attribute estimate, for attribute estimates represented as single values; also used to report unit of measure.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'Human-readable summary of the estimate.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    attributeEstimate: List_['EvidenceStatisticAttributeEstimate'] = Field(default_factory=list)
    'A nested attribute estimate; which is the attribute estimate of an attribute estimate.'


class EvidenceStatisticSampleSize(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Number of samples in the statistic."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Footnote or explanatory note about the sample size.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'Human-readable summary of population sample size.'
    knownDataCount: Optional_['unsignedInt'] = Field(default=None)
    'Number of participants with known results for measured variables.'
    numberOfStudies: Optional_['unsignedInt'] = Field(default=None)
    'Number of participants in the population.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    numberOfParticipants: Optional_['unsignedInt'] = Field(default=None)
    'A human-readable string to clarify or explain concepts about the sample size.'


class Evidence(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The Evidence Resource provides a machine-interpretable expression of an evidence concept including the evidence variables (eg population, exposures/interventions, comparators, outcomes, measured variables, confounding variables), the statistics, and the certainty of this evidence."""
    resourceType: Literal_['Evidence'] = Field(default=...)
    'Single evidence bit'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this evidence when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this summary is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the summary is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Footnotes and/or explanatory notes.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the summary.'
    status: 'code' = Field(default=...)
    'The status of this summary. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual, organization, or device primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual, organization, or device primarily responsible for internal coherence of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the summary when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the summary author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual, organization, or device primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual, organization, or device responsible for officially endorsing the content for use in some setting.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    citeAsReference: Optional_['Reference'] = Field(default=None)
    'Citation Resource or display of suggested citation for this evidence.'
    citeAsMarkdown: Optional_['markdown'] = Field(default=None)
    'Citation Resource or display of suggested citation for this evidence.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the evidence.'
    assertion: Optional_['markdown'] = Field(default=None)
    'Declarative description of the Evidence.'
    studyType: Optional_['CodeableConcept'] = Field(default=None)
    'The type of study that produced this evidence.'
    statistic: List_['EvidenceStatistic'] = Field(default_factory=list)
    'Values and parameters for a single statistic.'
    certainty: List_['EvidenceCertainty'] = Field(default_factory=list)
    'Assessment of certainty, confidence in the estimates, or quality of the evidence.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this summary when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate evidence instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the evidence from a consumer's perspective."
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    synthesisType: Optional_['CodeableConcept'] = Field(default=None)
    'The method to combine studies.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Link or citation to artifact associated with the summary.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    variableDefinition: List_['EvidenceVariableDefinition'] = Field(default=...)
    'Evidence variable such as population, exposure, or outcome.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the summary was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the summary changes.'


class EvidenceReportRelatesTo(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Relationships that this composition has with other compositions or documents that already exist."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    targetIdentifier: Optional_['Identifier'] = Field(default=None)
    'The target composition/document of this relationship.'
    targetReference: Optional_['Reference'] = Field(default=None)
    'The target composition/document of this relationship.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'The type of relationship that this composition has with anther composition or document.'


class EvidenceReportSection(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The root of the sections that make up the composition."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains the attested content of the section, used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is peferred to contain sufficient detail to make it acceptable for a human to just read the narrative.'
    mode: Optional_['code'] = Field(default=None)
    'How the entry list was prepared - whether it is a working list that is suitable for being maintained on an ongoing basis, or if it represents a snapshot of a list of items from another source, or whether it is a prepared list where items may be marked as added, modified or deleted.'
    title: Optional_['string'] = Field(default=None)
    'The label for this particular section.  This will be part of the rendered content for the document, and is often used to build a table of contents.'
    focus: Optional_['CodeableConcept'] = Field(default=None)
    'A code identifying the kind of content contained within the section. This should be consistent with the section title.'
    author: List_['Reference'] = Field(default_factory=list)
    'Identifies who is responsible for the information in this section, not necessarily who typed it in.'
    section: List_['EvidenceReportSection'] = Field(default_factory=list)
    'A nested sub-section within this section.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    orderedBy: Optional_['CodeableConcept'] = Field(default=None)
    'Specifies the order applied to the items in the section entries.'
    emptyReason: Optional_['CodeableConcept'] = Field(default=None)
    'If the section is empty, why the list is empty. An empty section typically has some text explaining the empty reason.'
    entryQuantity: List_['Quantity'] = Field(default_factory=list)
    'Quantity as content.'
    focusReference: Optional_['Reference'] = Field(default=None)
    'A definitional Resource identifying the kind of content contained within the section. This should be consistent with the section title.'
    entryReference: List_['Reference'] = Field(default_factory=list)
    'A reference to the actual resource from which the narrative in the section is derived.'
    entryClassifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Specifies any type of classification of the evidence report.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EvidenceReportSubject(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies the subject or focus of the report. Answers "What is this report about?"."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Used for general notes and annotations not coded elsewhere.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    characteristic: List_['EvidenceReportSubjectCharacteristic'] = Field(default_factory=list)
    'Characteristic.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EvidenceReportSubjectCharacteristic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Characteristic."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'Characteristic code.'
    period: Optional_['Period'] = Field(default=None)
    'Timeframe for the characteristic.'
    exclude: Optional_['boolean'] = Field(default=None)
    'Is used to express not the characteristic.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'Characteristic value.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Characteristic value.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'Characteristic value.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'Characteristic value.'
    valueRange: Optional_['Range'] = Field(default=None)
    'Characteristic value.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EvidenceReport(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The EvidenceReport Resource is a specialized container for a collection of resources and codable concepts, adapted to support compositions of Evidence, EvidenceVariable, and Citation resources and related concepts."""
    resourceType: Literal_['EvidenceReport'] = Field(default=...)
    'A EvidenceReport'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this EvidenceReport when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this summary is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the summary is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Specifies the kind of report, such as grouping of classifiers, search results, or human-compiled expression.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Used for footnotes and annotations.'
    status: 'code' = Field(default=...)
    'The status of this summary. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual, organization, or device primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual, organization, or device primarily responsible for internal coherence of the content.'
    subject: 'EvidenceReportSubject' = Field(default=...)
    'Specifies the subject or focus of the report. Answers "What is this report about?".'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    section: List_['EvidenceReportSection'] = Field(default_factory=list)
    'The root of the sections that make up the composition.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual, organization, or device primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual, organization, or device responsible for officially endorsing the content for use in some setting.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    citeAsReference: Optional_['Reference'] = Field(default=None)
    'Citation Resource or display of suggested citation for this report.'
    citeAsMarkdown: Optional_['markdown'] = Field(default=None)
    'Citation Resource or display of suggested citation for this report.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the evidence report.'
    relatesTo: List_['EvidenceReportRelatesTo'] = Field(default_factory=list)
    'Relationships that this composition has with other compositions or documents that already exist.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate evidence report instances.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this EvidenceReport when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Link, description or reference to artifact associated with the report.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    relatedIdentifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify things closely related to this EvidenceReport.'


class EvidenceVariableCharacteristic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A characteristic that defines the members of the evidence element. Multiple characteristics are applied with "and" semantics."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'Method used for describing characteristic.'
    device: Optional_['Reference'] = Field(default=None)
    'Device used for determining characteristic.'
    exclude: Optional_['boolean'] = Field(default=None)
    'When true, members with this characteristic are excluded from the element.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'A short, natural language description of the characteristic that could be used to communicate the criteria to an end-user.'
    groupMeasure: Optional_['code'] = Field(default=None)
    'Indicates how elements are aggregated within the study effective period.'
    definitionReference: Optional_['Reference'] = Field(default=None)
    'Define members of the evidence element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).'
    definitionCanonical: Optional_['canonical'] = Field(default=None)
    'Define members of the evidence element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).'
    definitionCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Define members of the evidence element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).'
    definitionExpression: Optional_['Expression'] = Field(default=None)
    'Define members of the evidence element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).'
    timeFromStart: Optional_['EvidenceVariableCharacteristicTimeFromStart'] = Field(default=None)
    "Indicates duration, period, or point of observation from the participant's study entry."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EvidenceVariableCharacteristicTimeFromStart(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates duration, period, or point of observation from the participant's study entry."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    note: List_['Annotation'] = Field(default_factory=list)
    'A human-readable string to clarify or explain concepts about the resource.'
    range: Optional_['Range'] = Field(default=None)
    'Used to express the observation within a period after the study start.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'Used to express the observation at a defined amount of time after the study start.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'A short, natural language description.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EvidenceVariableCategory(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A grouping (or set of values) described along with other groupings to specify the set of groupings allowed for the variable."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'A human-readable title or representation of the grouping.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Value or set of values that define the grouping.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'Value or set of values that define the grouping.'
    valueRange: Optional_['Range'] = Field(default=None)
    'Value or set of values that define the grouping.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class EvidenceVariable(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The EvidenceVariable resource describes an element that knowledge (Evidence) is about."""
    resourceType: Literal_['EvidenceVariable'] = Field(default=...)
    'A definition of an exposure, outcome, or other variable'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this evidence variable when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this evidence variable is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the evidence variable is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the evidence variable. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the evidence variable was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the evidence variable changes.'
    note: List_['Annotation'] = Field(default_factory=list)
    'A human-readable string to clarify or explain concepts about the resource.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the evidence variable.'
    status: 'code' = Field(default=...)
    'The status of this evidence variable. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual or organization primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for internal coherence of the content.'
    actual: Optional_['boolean'] = Field(default=None)
    'True if the actual variable measured, false if a conceptual representation of the intended variable.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the evidence variable when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the evidence variable author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active artifacts.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    subtitle: Optional_['string'] = Field(default=None)
    'An explanatory or alternate title for the EvidenceVariable giving additional information about its content.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization responsible for officially endorsing the content for use in some setting.'
    handling: Optional_['code'] = Field(default=None)
    'Used for an outcome to classify.'
    category: List_['EvidenceVariableCategory'] = Field(default_factory=list)
    'A grouping (or set of values) described along with other groupings to specify the set of groupings allowed for the variable.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the evidence variable.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this evidence variable when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    shortTitle: Optional_['string'] = Field(default=None)
    'The short title provides an alternate title for use in informal descriptive contexts where the full, formal title is not necessary.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate evidence variable instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the evidence variable from a consumer's perspective."
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    characteristic: List_['EvidenceVariableCharacteristic'] = Field(default_factory=list)
    'A characteristic that defines the members of the evidence element. Multiple characteristics are applied with "and" semantics.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Related artifacts such as additional documentation, justification, or bibliographic references.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    characteristicCombination: Optional_['code'] = Field(default=None)
    'Used to specify if two or more characteristics are combined with OR or AND.'


class ExampleScenarioInstance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Each resource and each version that is present in the workflow."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'A short name for the resource instance.'
    version: List_['ExampleScenarioInstanceVersion'] = Field(default_factory=list)
    'A specific version of the resource.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    resourceId: 'string' = Field(default=...)
    'The id of the resource for referencing.'
    description: Optional_['markdown'] = Field(default=None)
    'Human-friendly description of the resource instance.'
    resourceType: 'code' = Field(default=...)
    'The type of the resource.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    containedInstance: List_['ExampleScenarioInstanceContainedInstance'] = Field(default_factory=list)
    'Resources contained in the instance (e.g. the observations contained in a bundle).'


class ExampleScenarioInstanceContainedInstance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Resources contained in the instance (e.g. the observations contained in a bundle)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    versionId: Optional_['string'] = Field(default=None)
    'A specific version of a resource contained in the instance.'
    resourceId: 'string' = Field(default=...)
    'Each resource contained in the instance.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExampleScenarioInstanceVersion(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A specific version of the resource."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    versionId: 'string' = Field(default=...)
    'The identifier of a specific version of a resource.'
    description: 'markdown' = Field(default=...)
    'The description of the resource version.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExampleScenarioProcess(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Each major process - a group of operations."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    step: List_['ExampleScenarioProcessStep'] = Field(default_factory=list)
    'Each step of the process.'
    title: 'string' = Field(default=...)
    'The diagram title of the group of operations.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['markdown'] = Field(default=None)
    'A longer description of the group of operations.'
    preConditions: Optional_['markdown'] = Field(default=None)
    'Description of initial status before the process starts.'
    postConditions: Optional_['markdown'] = Field(default=None)
    'Description of final status after the process ends.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExampleScenarioProcessStep(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Each step of the process."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    pause: Optional_['boolean'] = Field(default=None)
    'If there is a pause in the flow.'
    process: List_['ExampleScenarioProcess'] = Field(default_factory=list)
    'Nested process.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: Optional_['ExampleScenarioProcessStepOperation'] = Field(default=None)
    'Each interaction or action.'
    alternative: List_['ExampleScenarioProcessStepAlternative'] = Field(default_factory=list)
    'Indicates an alternative step that can be taken instead of the operations on the base step in exceptional/atypical circumstances.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExampleScenarioProcessStepAlternative(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates an alternative step that can be taken instead of the operations on the base step in exceptional/atypical circumstances."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    step: List_['ExampleScenarioProcessStep'] = Field(default_factory=list)
    'What happens in each alternative option.'
    title: 'string' = Field(default=...)
    'The label to display for the alternative that gives a sense of the circumstance in which the alternative should be invoked.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['markdown'] = Field(default=None)
    'A human-readable description of the alternative explaining when the alternative should occur rather than the base step.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExampleScenarioProcessStepOperation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Each interaction or action."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['string'] = Field(default=None)
    'The type of operation - CRUD.'
    name: Optional_['string'] = Field(default=None)
    'The human-friendly name of the interaction.'
    number: 'string' = Field(default=...)
    'The sequential number of the interaction, e.g. 1.2.5.'
    request: Optional_['ExampleScenarioInstanceContainedInstance'] = Field(default=None)
    'Each resource instance used by the initiator.'
    receiver: Optional_['string'] = Field(default=None)
    'Who receives the transaction.'
    response: Optional_['ExampleScenarioInstanceContainedInstance'] = Field(default=None)
    'Each resource instance used by the responder.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    initiator: Optional_['string'] = Field(default=None)
    'Who starts the transaction.'
    description: Optional_['markdown'] = Field(default=None)
    'A comment to be inserted in the diagram.'
    receiverActive: Optional_['boolean'] = Field(default=None)
    'Whether the receiver is deactivated right after the transaction.'
    initiatorActive: Optional_['boolean'] = Field(default=None)
    'Whether the initiator is deactivated right after the transaction.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExampleScenarioActor(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Actor participating in the resource."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of actor - person or system.'
    name: Optional_['string'] = Field(default=None)
    'The name of the actor as shown in the page.'
    actorId: 'string' = Field(default=...)
    'ID or acronym of actor.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['markdown'] = Field(default=None)
    'The description of the actor.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExampleScenario(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Example of workflow instance."""
    resourceType: Literal_['ExampleScenario'] = Field(default=...)
    'Example of workflow instance'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this example scenario when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this example scenario is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the example scenario is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the example scenario. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    "The date  (and optionally time) when the example scenario was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the example scenario changes. (e.g. the 'content logical definition')."
    actor: List_['ExampleScenarioActor'] = Field(default_factory=list)
    'Actor participating in the resource.'
    status: 'code' = Field(default=...)
    'The status of this example scenario. Enables tracking the life-cycle of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the example scenario when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the example scenario author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'What the example scenario resource is created for. This should not be used to show the business purpose of the scenario itself, but the purpose of documenting a scenario.'
    process: List_['ExampleScenarioProcess'] = Field(default_factory=list)
    'Each major process - a group of operations.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    instance: List_['ExampleScenarioInstance'] = Field(default_factory=list)
    'Each resource and each version that is present in the workflow.'
    workflow: List_['canonical'] = Field(default_factory=list)
    'Another nested workflow.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the example scenario.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the example scenario and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the example scenario.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this example scenario when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate example scenario instances.'
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this example scenario is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the example scenario is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitBenefitBalance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Balance by Benefit Category."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'A short name or tag for the benefit.'
    unit: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates if the benefits apply to an individual or to the family.'
    term: Optional_['CodeableConcept'] = Field(default=None)
    "The term or period of the values such as 'maximum lifetime benefit' or 'maximum annual visits'."
    network: Optional_['CodeableConcept'] = Field(default=None)
    'Is a flag to indicate whether the benefits refer to in-network providers or out-of-network providers.'
    category: 'CodeableConcept' = Field(default=...)
    'Code to identify the general type of benefits under which products and services are provided.'
    excluded: Optional_['boolean'] = Field(default=None)
    'True if the indicated class of service is excluded from the plan, missing or False indicates the product or service is included in the coverage.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    financial: List_['ExplanationOfBenefitBenefitBalanceFinancial'] = Field(default_factory=list)
    'Benefits Used to date.'
    description: Optional_['string'] = Field(default=None)
    'A richer description of the benefit or services covered.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitBenefitBalanceFinancial(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Benefits Used to date."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Classification of benefit being provided.'
    usedUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'The quantity of the benefit which have been consumed to date.'
    usedMoney: Optional_['Money'] = Field(default=None)
    'The quantity of the benefit which have been consumed to date.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    allowedUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'The quantity of the benefit which is permitted under the coverage.'
    allowedString: Optional_['string'] = Field(default=None)
    'The quantity of the benefit which is permitted under the coverage.'
    allowedMoney: Optional_['Money'] = Field(default=None)
    'The quantity of the benefit which is permitted under the coverage.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitSupportingInfo(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'System and code pertaining to the specific information regarding special conditions relating to the setting, treatment or patient  for which care is sought.'
    reason: Optional_['Coding'] = Field(default=None)
    'Provides the reason in the situation where a reason code is required in addition to the content.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify supporting information entries.'
    category: 'CodeableConcept' = Field(default=...)
    'The general class of the information supplied: information; exception; accident, employment; onset, etc.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    valueString: Optional_['string'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    timingDate: Optional_['date'] = Field(default=None)
    'The date when or period to which this information refers.'
    timingPeriod: Optional_['Period'] = Field(default=None)
    'The date when or period to which this information refers.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitProcessNote(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A note that describes or explains adjudication results in a human readable form."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['code'] = Field(default=None)
    'The business purpose of the note text.'
    text: Optional_['string'] = Field(default=None)
    'The explanation or description associated with the processing.'
    number: Optional_['positiveInt'] = Field(default=None)
    'A number to uniquely identify a note entry.'
    language: Optional_['CodeableConcept'] = Field(default=None)
    'A code to define the language used in the text of the note.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitInsurance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Financial instruments for reimbursement for the health care products and services specified on the claim."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    focal: 'boolean' = Field(default=...)
    'A flag to indicate that this Coverage is to be used for adjudication of this claim when set to true.'
    coverage: 'Reference' = Field(default=...)
    "Reference to the insurance card level information contained in the Coverage resource. The coverage issuing insurer will use these details to locate the patient's actual coverage within the insurer's information system."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    preAuthRef: List_['string'] = Field(default_factory=list)
    'Reference numbers previously provided by the insurer to the provider to be quoted on subsequent claims containing services or products related to the prior authorization.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitProcedure(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Procedures performed on the patient relevant to the billing items with the claim."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    udi: List_['Reference'] = Field(default_factory=list)
    'Unique Device Identifiers associated with this line item.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'When the condition was observed or the relative ranking.'
    date: Optional_['dateTime'] = Field(default=None)
    'Date and optionally time the procedure was performed.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify procedure entries.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    procedureCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The code or reference to a Procedure resource which identifies the clinical intervention performed.'
    procedureReference: Optional_['Reference'] = Field(default=None)
    'The code or reference to a Procedure resource which identifies the clinical intervention performed.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitDiagnosis(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about diagnoses relevant to the claim items."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'When the condition was observed or the relative ranking.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify diagnosis entries.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    onAdmission: Optional_['CodeableConcept'] = Field(default=None)
    'Indication of whether the diagnosis was present on admission to a facility.'
    packageCode: Optional_['CodeableConcept'] = Field(default=None)
    'A package billing code or bundle code used to group products and services to a particular health condition (such as heart attack) which is based on a predetermined grouping code system.'
    diagnosisCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The nature of illness or problem in a coded form or as a reference to an external defined Condition.'
    diagnosisReference: Optional_['Reference'] = Field(default=None)
    'The nature of illness or problem in a coded form or as a reference to an external defined Condition.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitAccident(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details of a accident which resulted in injuries which required the products and services listed in the claim."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type or context of the accident event for the purposes of selection of potential insurance coverages and determination of coordination between insurers.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    locationAddress: Optional_['Address'] = Field(default=None)
    'The physical location of the accident event.'
    locationReference: Optional_['Reference'] = Field(default=None)
    'The physical location of the accident event.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['date'] = Field(default=None)
    'Date of an accident event  related to the products and services contained in the claim.'


class ExplanationOfBenefitCareTeam(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The members of the team who provided the products and services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: Optional_['CodeableConcept'] = Field(default=None)
    'The lead, assisting or supervising practitioner and their discipline if a multidisciplinary team.'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify care team entries.'
    provider: 'Reference' = Field(default=...)
    'Member of the team who provided the product or service.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    responsible: Optional_['boolean'] = Field(default=None)
    'The party who is billing and/or responsible for the claimed products or services.'
    qualification: Optional_['CodeableConcept'] = Field(default=None)
    'The qualification of the practitioner which is applicable for this service.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitPayment(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Payment details for the adjudication of the claim."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Whether this represents partial or complete payment of the benefits payable.'
    amount: Optional_['Money'] = Field(default=None)
    'Benefits payable less any payment adjustment.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    adjustment: Optional_['Money'] = Field(default=None)
    "Total amount of all adjustments to this payment included in this transaction which are not related to this claim's adjudication."
    identifier: Optional_['Identifier'] = Field(default=None)
    "Issuer's unique identifier for the payment instrument."
    adjustmentReason: Optional_['CodeableConcept'] = Field(default=None)
    'Reason for the payment adjustment.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['date'] = Field(default=None)
    'Estimated date the payment will be issued or the actual issue date of payment.'


class ExplanationOfBenefitAddItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The first-tier service adjudications for payor added product or service lines."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    detail: List_['ExplanationOfBenefitAddItemDetail'] = Field(default_factory=list)
    'The second-tier service adjudications for payor added services.'
    subSite: List_['CodeableConcept'] = Field(default_factory=list)
    'A region or surface of the bodySite, e.g. limb region or tooth surface(s).'
    provider: List_['Reference'] = Field(default_factory=list)
    'The providers who are authorized for the services rendered to the patient.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    bodySite: Optional_['CodeableConcept'] = Field(default=None)
    'Physical service site on the patient (limb, tooth, etc.).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    programCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the program under which this may be recovered.'
    servicedDate: Optional_['date'] = Field(default=None)
    'The date or dates when the service or product was supplied, performed or completed.'
    servicedPeriod: Optional_['Period'] = Field(default=None)
    'The date or dates when the service or product was supplied, performed or completed.'
    locationCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Where the product or service was provided.'
    locationAddress: Optional_['Address'] = Field(default=None)
    'Where the product or service was provided.'
    locationReference: Optional_['Reference'] = Field(default=None)
    'Where the product or service was provided.'
    itemSequence: List_['positiveInt'] = Field(default_factory=list)
    'Claim items which this service line is intended to replace.'
    adjudication: List_['ExplanationOfBenefitItemAdjudication'] = Field(default_factory=list)
    'The adjudication results.'
    detailSequence: List_['positiveInt'] = Field(default_factory=list)
    'The sequence number of the details within the claim item which this line is intended to replace.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    subDetailSequence: List_['positiveInt'] = Field(default_factory=list)
    'The sequence number of the sub-details woithin the details within the claim item which this line is intended to replace.'


class ExplanationOfBenefitAddItemDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The second-tier service adjudications for payor added services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    subDetail: List_['ExplanationOfBenefitAddItemDetailSubDetail'] = Field(default_factory=list)
    'The third-tier service adjudications for payor added services.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    adjudication: List_['ExplanationOfBenefitItemAdjudication'] = Field(default_factory=list)
    'The adjudication results.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitAddItemDetailSubDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The third-tier service adjudications for payor added services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    adjudication: List_['ExplanationOfBenefitItemAdjudication'] = Field(default_factory=list)
    'The adjudication results.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitRelated(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Other claims which are related to this claim such as prior submissions or claims for related services or for the same event."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    claim: Optional_['Reference'] = Field(default=None)
    'Reference to a related claim.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: Optional_['Identifier'] = Field(default=None)
    'An alternate organizational reference to the case or file to which this particular claim pertains.'
    relationship: Optional_['CodeableConcept'] = Field(default=None)
    'A code to convey how the claims are related.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitTotal(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Categorized monetary totals for the adjudication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    amount: 'Money' = Field(default=...)
    'Monetary total amount associated with the category.'
    category: 'CodeableConcept' = Field(default=...)
    'A code to indicate the information type of this adjudication record. Information types may include: the value submitted, maximum values or percentages allowed or payable under the plan, amounts that the patient is responsible for in aggregate or pertaining to this item, amounts paid by other coverages, and the benefit payable for this item.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitPayee(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The party to be reimbursed for cost of the products and services according to the terms of the policy."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Type of Party to be reimbursed: Subscriber, provider, other.'
    party: Optional_['Reference'] = Field(default=None)
    'Reference to the individual or organization to whom any payment will be made.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    udi: List_['Reference'] = Field(default_factory=list)
    'Unique Device Identifiers associated with this line item.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    detail: List_['ExplanationOfBenefitItemDetail'] = Field(default_factory=list)
    'Second-tier of goods and services.'
    revenue: Optional_['CodeableConcept'] = Field(default=None)
    'The type of revenue or cost center providing the product and/or service.'
    subSite: List_['CodeableConcept'] = Field(default_factory=list)
    'A region or surface of the bodySite, e.g. limb region or tooth surface(s).'
    sequence: 'positiveInt' = Field(default=...)
    'A number to uniquely identify item entries.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Code to identify the general type of benefits under which products and services are provided.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    bodySite: Optional_['CodeableConcept'] = Field(default=None)
    'Physical service site on the patient (limb, tooth, etc.).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    encounter: List_['Reference'] = Field(default_factory=list)
    'A billed item may include goods or services provided in multiple encounters.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    programCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the program under which this may be recovered.'
    servicedDate: Optional_['date'] = Field(default=None)
    'The date or dates when the service or product was supplied, performed or completed.'
    servicedPeriod: Optional_['Period'] = Field(default=None)
    'The date or dates when the service or product was supplied, performed or completed.'
    locationCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Where the product or service was provided.'
    locationAddress: Optional_['Address'] = Field(default=None)
    'Where the product or service was provided.'
    locationReference: Optional_['Reference'] = Field(default=None)
    'Where the product or service was provided.'
    adjudication: List_['ExplanationOfBenefitItemAdjudication'] = Field(default_factory=list)
    'If this item is a group then the values here are a summary of the adjudication of the detail items. If this item is a simple product or service then this is the result of the adjudication of this item.'
    careTeamSequence: List_['positiveInt'] = Field(default_factory=list)
    'Care team members related to this service or product.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    diagnosisSequence: List_['positiveInt'] = Field(default_factory=list)
    'Diagnoses applicable for this service or product.'
    procedureSequence: List_['positiveInt'] = Field(default_factory=list)
    'Procedures applicable for this service or product.'
    informationSequence: List_['positiveInt'] = Field(default_factory=list)
    'Exceptions, special conditions and supporting information applicable for this service or product.'


class ExplanationOfBenefitItemAdjudication(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """If this item is a group then the values here are a summary of the adjudication of the detail items. If this item is a simple product or service then this is the result of the adjudication of this item."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: Optional_['decimal'] = Field(default=None)
    'A non-monetary value associated with the category. Mutually exclusive to the amount element above.'
    reason: Optional_['CodeableConcept'] = Field(default=None)
    'A code supporting the understanding of the adjudication result and explaining variance from expected amount.'
    amount: Optional_['Money'] = Field(default=None)
    'Monetary amount associated with the category.'
    category: 'CodeableConcept' = Field(default=...)
    'A code to indicate the information type of this adjudication record. Information types may include: the value submitted, maximum values or percentages allowed or payable under the plan, amounts that the patient is responsible for in-aggregate or pertaining to this item, amounts paid by other coverages, and the benefit payable for this item.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitItemDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Second-tier of goods and services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    udi: List_['Reference'] = Field(default_factory=list)
    'Unique Device Identifiers associated with this line item.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    revenue: Optional_['CodeableConcept'] = Field(default=None)
    'The type of revenue or cost center providing the product and/or service.'
    sequence: 'positiveInt' = Field(default=...)
    "A claim detail line. Either a simple (a product or service) or a 'group' of sub-details which are simple items."
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Code to identify the general type of benefits under which products and services are provided.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    subDetail: List_['ExplanationOfBenefitItemDetailSubDetail'] = Field(default_factory=list)
    'Third-tier of goods and services.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    programCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the program under which this may be recovered.'
    adjudication: List_['ExplanationOfBenefitItemAdjudication'] = Field(default_factory=list)
    'The adjudication results.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefitItemDetailSubDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Third-tier of goods and services."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    net: Optional_['Money'] = Field(default=None)
    'The quantity times the unit price for an additional service or product or charge.'
    udi: List_['Reference'] = Field(default_factory=list)
    'Unique Device Identifiers associated with this line item.'
    factor: Optional_['decimal'] = Field(default=None)
    'A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.'
    revenue: Optional_['CodeableConcept'] = Field(default=None)
    'The type of revenue or cost center providing the product and/or service.'
    sequence: 'positiveInt' = Field(default=...)
    "A claim detail line. Either a simple (a product or service) or a 'group' of sub-details which are simple items."
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Code to identify the general type of benefits under which products and services are provided.'
    modifier: List_['CodeableConcept'] = Field(default_factory=list)
    'Item typification or modifiers codes to convey additional context for the product or service.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of repetitions of a service or product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    unitPrice: Optional_['Money'] = Field(default=None)
    'If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.'
    noteNumber: List_['positiveInt'] = Field(default_factory=list)
    'The numbers associated with notes below which apply to the adjudication of this item.'
    programCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the program under which this may be recovered.'
    adjudication: List_['ExplanationOfBenefitItemAdjudication'] = Field(default_factory=list)
    'The adjudication results.'
    productOrService: 'CodeableConcept' = Field(default=...)
    'When the value is a group code then this item collects a set of related claim details, otherwise this contains the product, service, drug or other billing code for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ExplanationOfBenefit(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource provides: the claim details; adjudication details from the processing of a Claim; and optionally account balance information, for informing the subscriber of the benefits provided."""
    resourceType: Literal_['ExplanationOfBenefit'] = Field(default=...)
    'Explanation of Benefit resource'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    use: 'code' = Field(default=...)
    'A code to indicate whether the nature of the request is: to request adjudication of products and services previously rendered; or requesting authorization and adjudication for provision in the future; or requesting the non-binding adjudication of the listed products and services which could be provided in the future.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'CodeableConcept' = Field(default=...)
    'The category of claim, e.g. oral, pharmacy, vision, institutional, professional.'
    item: List_['ExplanationOfBenefitItem'] = Field(default_factory=list)
    "A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details."
    form: Optional_['Attachment'] = Field(default=None)
    'The actual form, by reference or inclusion, for printing the content or an EOB.'
    payee: Optional_['ExplanationOfBenefitPayee'] = Field(default=None)
    'The party to be reimbursed for cost of the products and services according to the terms of the policy.'
    claim: Optional_['Reference'] = Field(default=None)
    'The business identifier for the instance of the adjudication request: claim predetermination or preauthorization.'
    total: List_['ExplanationOfBenefitTotal'] = Field(default_factory=list)
    'Categorized monetary totals for the adjudication.'
    status: 'code' = Field(default=...)
    'The status of the resource instance.'
    subType: Optional_['CodeableConcept'] = Field(default=None)
    'A finer grained suite of claim type codes which may convey additional information such as Inpatient vs Outpatient and/or a specialty service.'
    patient: 'Reference' = Field(default=...)
    'The party to whom the professional services and/or products have been supplied or are being considered and for whom actual for forecast reimbursement is sought.'
    created: 'dateTime' = Field(default=...)
    'The date this resource was created.'
    enterer: Optional_['Reference'] = Field(default=None)
    'Individual who created the claim, predetermination or preauthorization.'
    insurer: 'Reference' = Field(default=...)
    'The party responsible for authorization, adjudication and reimbursement.'
    related: List_['ExplanationOfBenefitRelated'] = Field(default_factory=list)
    'Other claims which are related to this claim such as prior submissions or claims for related services or for the same event.'
    outcome: 'code' = Field(default=...)
    'The outcome of the claim, predetermination, or preauthorization processing.'
    addItem: List_['ExplanationOfBenefitAddItem'] = Field(default_factory=list)
    'The first-tier service adjudications for payor added product or service lines.'
    payment: Optional_['ExplanationOfBenefitPayment'] = Field(default=None)
    'Payment details for the adjudication of the claim.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    provider: 'Reference' = Field(default=...)
    'The provider which is responsible for the claim, predetermination or preauthorization.'
    priority: Optional_['CodeableConcept'] = Field(default=None)
    'The provider-required urgency of processing the request. Typical values include: stat, routine deferred.'
    referral: Optional_['Reference'] = Field(default=None)
    'A reference to a referral resource.'
    facility: Optional_['Reference'] = Field(default=None)
    'Facility where the services were provided.'
    careTeam: List_['ExplanationOfBenefitCareTeam'] = Field(default_factory=list)
    'The members of the team who provided the products and services.'
    accident: Optional_['ExplanationOfBenefitAccident'] = Field(default=None)
    'Details of a accident which resulted in injuries which required the products and services listed in the claim.'
    formCode: Optional_['CodeableConcept'] = Field(default=None)
    'A code for the form to be used for printing the content.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    diagnosis: List_['ExplanationOfBenefitDiagnosis'] = Field(default_factory=list)
    'Information about diagnoses relevant to the claim items.'
    procedure: List_['ExplanationOfBenefitProcedure'] = Field(default_factory=list)
    'Procedures performed on the patient relevant to the billing items with the claim.'
    insurance: List_['ExplanationOfBenefitInsurance'] = Field(default=...)
    'Financial instruments for reimbursement for the health care products and services specified on the claim.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this explanation of benefit.'
    preAuthRef: List_['string'] = Field(default_factory=list)
    'Reference from the Insurer which is used in later communications which refers to this adjudication.'
    precedence: Optional_['positiveInt'] = Field(default=None)
    'This indicates the relative order of a series of EOBs related to different coverages for the same suite of services.'
    disposition: Optional_['string'] = Field(default=None)
    'A human readable description of the status of the adjudication.'
    processNote: List_['ExplanationOfBenefitProcessNote'] = Field(default_factory=list)
    'A note that describes or explains adjudication results in a human readable form.'
    fundsReserve: Optional_['CodeableConcept'] = Field(default=None)
    'A code, used only on a response to a preauthorization, to indicate whether the benefits payable have been reserved and for whom.'
    prescription: Optional_['Reference'] = Field(default=None)
    'Prescription to support the dispensing of pharmacy, device or vision products.'
    adjudication: List_['ExplanationOfBenefitItemAdjudication'] = Field(default_factory=list)
    'The adjudication results which are presented at the header level rather than at the line-item or add-item levels.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    claimResponse: Optional_['Reference'] = Field(default=None)
    'The business identifier for the instance of the adjudication response: claim, predetermination or preauthorization response.'
    benefitPeriod: Optional_['Period'] = Field(default=None)
    'The term of the benefits documented in this response.'
    billablePeriod: Optional_['Period'] = Field(default=None)
    'The period for which charges are being submitted.'
    supportingInfo: List_['ExplanationOfBenefitSupportingInfo'] = Field(default_factory=list)
    'Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues.'
    benefitBalance: List_['ExplanationOfBenefitBenefitBalance'] = Field(default_factory=list)
    'Balance by Benefit Category.'
    preAuthRefPeriod: List_['Period'] = Field(default_factory=list)
    'The timeframe during which the supplied preauthorization reference may be quoted on claims to obtain the adjudication as provided.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    originalPrescription: Optional_['Reference'] = Field(default=None)
    'Original prescription which has been superseded by this prescription to support the dispensing of pharmacy services, medications or products.'
    fundsReserveRequested: Optional_['CodeableConcept'] = Field(default=None)
    'A code to indicate whether and for whom funds are to be reserved for future claims.'


class FamilyMemberHistoryCondition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The significant Conditions (or condition) that the family member had. This is a repeating section to allow a system to represent more than one condition per resource, though there is nothing stopping multiple resources - one per condition."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    "The actual condition specified. Could be a coded condition (like MI or Diabetes) or a less specific string like 'cancer' depending on how much is known about the condition and the capabilities of the creating system."
    note: List_['Annotation'] = Field(default_factory=list)
    'An area where general notes can be placed about this specific condition.'
    outcome: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates what happened following the condition.  If the condition resulted in death, deceased date is captured on the relation.'
    onsetAge: Optional_['Age'] = Field(default=None)
    'Either the age of onset, range of approximate age or descriptive string can be recorded.  For conditions with multiple occurrences, this describes the first known occurrence.'
    onsetRange: Optional_['Range'] = Field(default=None)
    'Either the age of onset, range of approximate age or descriptive string can be recorded.  For conditions with multiple occurrences, this describes the first known occurrence.'
    onsetPeriod: Optional_['Period'] = Field(default=None)
    'Either the age of onset, range of approximate age or descriptive string can be recorded.  For conditions with multiple occurrences, this describes the first known occurrence.'
    onsetString: Optional_['string'] = Field(default=None)
    'Either the age of onset, range of approximate age or descriptive string can be recorded.  For conditions with multiple occurrences, this describes the first known occurrence.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    contributedToDeath: Optional_['boolean'] = Field(default=None)
    'This condition contributed to the cause of death of the related person. If contributedToDeath is not populated, then it is unknown.'


class FamilyMemberHistory(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Significant health conditions for a person related to the patient relevant in the context of care for the patient."""
    resourceType: Literal_['FamilyMemberHistory'] = Field(default=...)
    "Information about patient's relatives, relevant for patient"
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    sex: Optional_['CodeableConcept'] = Field(default=None)
    'The birth sex of the family member.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'This will either be a name or a description; e.g. "Aunt Susan", "my cousin with the red hair".'
    note: List_['Annotation'] = Field(default_factory=list)
    'This property allows a non condition-specific note to the made about the related person. Ideally, the note would be in the condition property, but this is not always possible.'
    status: 'code' = Field(default=...)
    'A code specifying the status of the record of the family history of a specific family member.'
    ageAge: Optional_['Age'] = Field(default=None)
    'The age of the relative at the time the family member history is recorded.'
    ageRange: Optional_['Range'] = Field(default=None)
    'The age of the relative at the time the family member history is recorded.'
    ageString: Optional_['string'] = Field(default=None)
    'The age of the relative at the time the family member history is recorded.'
    patient: 'Reference' = Field(default=...)
    'The person who this history concerns.'
    bornPeriod: Optional_['Period'] = Field(default=None)
    'The actual or approximate date of birth of the relative.'
    bornDate: Optional_['date'] = Field(default=None)
    'The actual or approximate date of birth of the relative.'
    bornString: Optional_['string'] = Field(default=None)
    'The actual or approximate date of birth of the relative.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    condition: List_['FamilyMemberHistoryCondition'] = Field(default_factory=list)
    'The significant Conditions (or condition) that the family member had. This is a repeating section to allow a system to represent more than one condition per resource, though there is nothing stopping multiple resources - one per condition.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this family member history by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Describes why the family member history occurred in coded or textual form.'
    deceasedBoolean: Optional_['boolean'] = Field(default=None)
    'Deceased flag or the actual or approximate age of the relative at the time of death for the family member history record.'
    deceasedAge: Optional_['Age'] = Field(default=None)
    'Deceased flag or the actual or approximate age of the relative at the time of death for the family member history record.'
    deceasedRange: Optional_['Range'] = Field(default=None)
    'Deceased flag or the actual or approximate age of the relative at the time of death for the family member history record.'
    deceasedDate: Optional_['date'] = Field(default=None)
    'Deceased flag or the actual or approximate age of the relative at the time of death for the family member history record.'
    deceasedString: Optional_['string'] = Field(default=None)
    'Deceased flag or the actual or approximate age of the relative at the time of death for the family member history record.'
    relationship: 'CodeableConcept' = Field(default=...)
    'The type of relationship this person has to the patient (father, mother, brother etc.).'
    estimatedAge: Optional_['boolean'] = Field(default=None)
    'If true, indicates that the age value specified is an estimated value.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally maintained protocol, guideline, orderset or other definition that is adhered to in whole or in part by this FamilyMemberHistory.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates a Condition, Observation, AllergyIntolerance, or QuestionnaireResponse that justifies this family member history event.'
    dataAbsentReason: Optional_['CodeableConcept'] = Field(default=None)
    "Describes why the family member's history is not available."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'The URL pointing to a FHIR-defined protocol, guideline, orderset or other definition that is adhered to in whole or in part by this FamilyMemberHistory.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date (and possibly time) when the family member history was recorded or last updated.'


class Flag(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Prospective warnings of potential issues when providing care to the patient."""
    resourceType: Literal_['Flag'] = Field(default=...)
    'Key information to flag to healthcare providers'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: 'code' = Field(default=...)
    'Supports basic workflow.'
    period: Optional_['Period'] = Field(default=None)
    'The period of time from the activation of the flag to inactivation of the flag. If the flag is active, the end of the period should be unspecified.'
    author: Optional_['Reference'] = Field(default=None)
    'The person, organization or device that created the flag.'
    subject: 'Reference' = Field(default=...)
    'The patient, location, group, organization, or practitioner etc. this is about record this flag is associated with.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'Allows a flag to be divided into different categories like clinical, administrative etc. Intended to be used as a means of filtering which flags are displayed to particular user or in a given context.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'This alert is only relevant during the encounter.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this flag by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'CodeableConcept' = Field(default=...)
    'The coded value or textual component of the flag to display to the user.'


class GoalTarget(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates what should be done by when."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    dueDate: Optional_['date'] = Field(default=None)
    'Indicates either the date or the duration after start by which the goal should be met.'
    dueDuration: Optional_['Duration'] = Field(default=None)
    'Indicates either the date or the duration after start by which the goal should be met.'
    measure: Optional_['CodeableConcept'] = Field(default=None)
    'The parameter whose value is being tracked, e.g. body weight, blood pressure, or hemoglobin A1c level.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    detailQuantity: Optional_['Quantity'] = Field(default=None)
    'The target value of the focus to be achieved to signify the fulfillment of the goal, e.g. 150 pounds, 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any focus value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any focus value at or above the low value.'
    detailRange: Optional_['Range'] = Field(default=None)
    'The target value of the focus to be achieved to signify the fulfillment of the goal, e.g. 150 pounds, 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any focus value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any focus value at or above the low value.'
    detailCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The target value of the focus to be achieved to signify the fulfillment of the goal, e.g. 150 pounds, 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any focus value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any focus value at or above the low value.'
    detailString: Optional_['string'] = Field(default=None)
    'The target value of the focus to be achieved to signify the fulfillment of the goal, e.g. 150 pounds, 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any focus value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any focus value at or above the low value.'
    detailBoolean: Optional_['boolean'] = Field(default=None)
    'The target value of the focus to be achieved to signify the fulfillment of the goal, e.g. 150 pounds, 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any focus value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any focus value at or above the low value.'
    detailInteger: Optional_['integer'] = Field(default=None)
    'The target value of the focus to be achieved to signify the fulfillment of the goal, e.g. 150 pounds, 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any focus value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any focus value at or above the low value.'
    detailRatio: Optional_['Ratio'] = Field(default=None)
    'The target value of the focus to be achieved to signify the fulfillment of the goal, e.g. 150 pounds, 7.0%. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any focus value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any focus value at or above the low value.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Goal(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes the intended objective(s) for a patient, group or organization care, for example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, etc."""
    resourceType: Literal_['Goal'] = Field(default=...)
    'Describes the intended objective(s) for a patient, group or organization'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Any comments related to the goal.'
    target: List_['GoalTarget'] = Field(default_factory=list)
    'Indicates what should be done by when.'
    subject: 'Reference' = Field(default=...)
    'Identifies the patient, group or organization for whom the goal is being established.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'Indicates a category the goal falls within.'
    priority: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the mutually agreed level of importance associated with reaching/sustaining the goal.'
    startDate: Optional_['date'] = Field(default=None)
    'The date or event after which the goal should begin being pursued.'
    startCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The date or event after which the goal should begin being pursued.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    addresses: List_['Reference'] = Field(default_factory=list)
    'The identified conditions and other health record elements that are intended to be addressed by the goal.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this goal by the performer or other systems which remain constant as the resource is updated and propagates from server to server.'
    statusDate: Optional_['date'] = Field(default=None)
    'Identifies when the current status.  I.e. When initially created, when achieved, when cancelled, etc.'
    description: 'CodeableConcept' = Field(default=...)
    'Human-readable and/or coded description of a specific desired objective of care, such as "control blood pressure" or "negotiate an obstacle course" or "dance with child at wedding".'
    expressedBy: Optional_['Reference'] = Field(default=None)
    'Indicates whose goal this is - patient goal, practitioner goal, etc.'
    outcomeCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the change (or lack of change) at the point when the status of the goal is assessed.'
    statusReason: Optional_['string'] = Field(default=None)
    'Captures the reason for the current status.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lifecycleStatus: 'code' = Field(default=...)
    'The state of the goal throughout its lifecycle.'
    outcomeReference: List_['Reference'] = Field(default_factory=list)
    "Details of what's changed (or not changed)."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    achievementStatus: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the progression, or lack thereof, towards the goal against the target.'


class GraphDefinitionLink(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Links this graph makes rules about."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    min: Optional_['integer'] = Field(default=None)
    'Minimum occurrences for this link.'
    max: Optional_['string'] = Field(default=None)
    'Maximum occurrences for this link.'
    path: Optional_['string'] = Field(default=None)
    'A FHIR expression that identifies one of FHIR References to other resources.'
    target: List_['GraphDefinitionLinkTarget'] = Field(default_factory=list)
    'Potential target for the link.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    sliceName: Optional_['string'] = Field(default=None)
    'Which slice (if profiled).'
    description: Optional_['string'] = Field(default=None)
    'Information about why this link is of interest in this graph definition.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class GraphDefinitionLinkTarget(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Potential target for the link."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'Type of resource this link refers to.'
    link: List_['GraphDefinitionLink'] = Field(default_factory=list)
    'Additional links from target resource.'
    params: Optional_['string'] = Field(default=None)
    'A set of parameters to look up.'
    profile: Optional_['canonical'] = Field(default=None)
    'Profile for the target resource.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    compartment: List_['GraphDefinitionLinkTargetCompartment'] = Field(default_factory=list)
    'Compartment Consistency Rules.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class GraphDefinitionLinkTargetCompartment(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Compartment Consistency Rules."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: 'code' = Field(default=...)
    'Defines how the compartment rule is used - whether it it is used to test whether resources are subject to the rule, or whether it is a rule that must be followed.'
    rule: 'code' = Field(default=...)
    'identical | matching | different | no-rule | custom.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: Optional_['string'] = Field(default=None)
    'Custom rule, as a FHIRPath expression.'
    description: Optional_['string'] = Field(default=None)
    'Documentation for FHIRPath expression.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'Identifies the compartment.'


class GraphDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A formal computable definition of a graph of resources - that is, a coherent set of resources that form a graph by following references. The Graph Definition resource defines a set and makes rules about the set."""
    resourceType: Literal_['GraphDefinition'] = Field(default=...)
    'Definition of a graph of resources'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this graph definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this graph definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the graph definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: 'string' = Field(default=...)
    'A natural language name identifying the graph definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the graph definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the graph definition changes.'
    link: List_['GraphDefinitionLink'] = Field(default_factory=list)
    'Links this graph makes rules about.'
    start: 'code' = Field(default=...)
    'The type of FHIR resource at which instances of this graph start.'
    status: 'code' = Field(default=...)
    'The status of this graph definition. Enables tracking the life-cycle of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the graph definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the graph definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this graph definition is needed and why it has been designed as it has.'
    profile: Optional_['canonical'] = Field(default=None)
    'The profile that describes the use of the base resource.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the graph definition.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate graph definition instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the graph definition from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this graph definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the graph definition is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class GroupCharacteristic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies traits whose presence r absence is shared by members of the group."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'A code that identifies the kind of trait being asserted.'
    period: Optional_['Period'] = Field(default=None)
    'The period over which the characteristic is tested; e.g. the patient had an operation during the month of June.'
    exclude: 'boolean' = Field(default=...)
    'If true, indicates the characteristic is one that is NOT held by members of the group.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    "The value of the trait that holds (or does not hold - see 'exclude') for members of the group."
    valueBoolean: Optional_['boolean'] = Field(default=None)
    "The value of the trait that holds (or does not hold - see 'exclude') for members of the group."
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    "The value of the trait that holds (or does not hold - see 'exclude') for members of the group."
    valueRange: Optional_['Range'] = Field(default=None)
    "The value of the trait that holds (or does not hold - see 'exclude') for members of the group."
    valueReference: Optional_['Reference'] = Field(default=None)
    "The value of the trait that holds (or does not hold - see 'exclude') for members of the group."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class GroupMember(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies the resource instances that are members of the group."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    entity: 'Reference' = Field(default=...)
    'A reference to the entity that is a member of the group. Must be consistent with Group.type. If the entity is another group, then the type must be the same.'
    period: Optional_['Period'] = Field(default=None)
    'The period that the member was in the group, if known.'
    inactive: Optional_['boolean'] = Field(default=None)
    'A flag to indicate that the member is no longer in the group, but previously may have been a member.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Group(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Represents a defined collection of entities that may be discussed or acted upon collectively but which are not expected to act collectively, and are not formally or legally recognized; i.e. a collection of entities that isn't an Organization."""
    resourceType: Literal_['Group'] = Field(default=...)
    'Group of multiple entities'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'code' = Field(default=...)
    'Identifies the broad classification of the kind of resources the group includes.'
    name: Optional_['string'] = Field(default=None)
    'A label assigned to the group for human identification and communication.'
    active: Optional_['boolean'] = Field(default=None)
    'Indicates whether the record for the group is available for use or is merely being retained for historical purposes.'
    actual: 'boolean' = Field(default=...)
    'If true, indicates that the resource refers to a specific group of real individuals.  If false, the group defines a set of intended individuals.'
    member: List_['GroupMember'] = Field(default_factory=list)
    'Identifies the resource instances that are members of the group.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    quantity: Optional_['unsignedInt'] = Field(default=None)
    'A count of the number of resource instances that are part of the group.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique business identifier for this group.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    managingEntity: Optional_['Reference'] = Field(default=None)
    'Entity responsible for defining and maintaining Group characteristics and/or registered members.'
    characteristic: List_['GroupCharacteristic'] = Field(default_factory=list)
    'Identifies traits whose presence r absence is shared by members of the group.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Provides a specific type of resource the group includes; e.g. "cow", "syringe", etc.'


class GuidanceResponse(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A guidance response is the formal response to a guidance request, including any output parameters returned by the evaluation, as well as the description of any proposed actions to be taken."""
    resourceType: Literal_['GuidanceResponse'] = Field(default=...)
    'The formal response to a guidance request'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Provides a mechanism to communicate additional information about the response.'
    status: 'code' = Field(default=...)
    'The status of the response. If the evaluation is completed successfully, the status will indicate success. However, in order to complete the evaluation, the engine may require more information. In this case, the status will be data-required, and the response will contain a description of the additional required information. If the evaluation completed successfully, but the engine determines that a potentially more accurate response could be provided if more data was available, the status will be data-requested, and the response will contain a description of the additional requested information.'
    result: Optional_['Reference'] = Field(default=None)
    'The actions, if any, produced by the evaluation of the artifact.'
    subject: Optional_['Reference'] = Field(default=None)
    'The patient for which the request was processed.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    moduleUri: Optional_['uri'] = Field(default=None)
    'An identifier, CodeableConcept or canonical reference to the guidance that was requested.'
    moduleCanonical: Optional_['canonical'] = Field(default=None)
    'An identifier, CodeableConcept or canonical reference to the guidance that was requested.'
    moduleCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'An identifier, CodeableConcept or canonical reference to the guidance that was requested.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The encounter during which this response was created or to which the creation of this record is tightly associated.'
    performer: Optional_['Reference'] = Field(default=None)
    'Provides a reference to the device that performed the guidance.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Allows a service to provide  unique, business identifiers for the response.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Describes the reason for the guidance response in coded or textual form.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates the reason the request was initiated. This is typically provided as a parameter to the evaluation and echoed by the service, although for some use cases, such as subscription- or event-based scenarios, it may provide an indication of the cause for the response.'
    dataRequirement: List_['DataRequirement'] = Field(default_factory=list)
    'If the evaluation could not be completed due to lack of information, or additional information would potentially result in a more accurate response, this element will a description of the data required in order to proceed with the evaluation. A subsequent request to the service should include this data.'
    outputParameters: Optional_['Reference'] = Field(default=None)
    'The output parameters of the evaluation, if any. Many modules will result in the return of specific resources such as procedure or communication requests that are returned as part of the operation result. However, modules may define specific outputs that would be returned as the result of the evaluation, and these would be returned in this element.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    requestIdentifier: Optional_['Identifier'] = Field(default=None)
    'The identifier of the request associated with this response. If an identifier was given as part of the request, it will be reproduced here to enable the requester to more easily identify the response in a multi-request scenario.'
    evaluationMessage: List_['Reference'] = Field(default_factory=list)
    'Messages resulting from the evaluation of the artifact or artifacts. As part of evaluating the request, the engine may produce informational or warning messages. These messages will be provided by this element.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'Indicates when the guidance response was processed.'


class HealthcareServiceAvailableTime(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A collection of times that the Service Site is available."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    allDay: Optional_['boolean'] = Field(default=None)
    'Is this always available? (hence times are irrelevant) e.g. 24 hour service.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    daysOfWeek: List_['code'] = Field(default_factory=list)
    'Indicates which days of the week are available between the start and end Times.'
    availableEndTime: Optional_['time'] = Field(default=None)
    'The closing time of day. Note: If the AllDay flag is set, then this time is ignored.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    availableStartTime: Optional_['time'] = Field(default=None)
    'The opening time of day. Note: If the AllDay flag is set, then this time is ignored.'


class HealthcareServiceNotAvailable(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The HealthcareService is not available during this period of time due to the provided reason."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    during: Optional_['Period'] = Field(default=None)
    'Service is not available (seasonally or for a public holiday) from this date.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: 'string' = Field(default=...)
    'The reason that can be presented to the user as to why this time is not available.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class HealthcareServiceEligibility(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Does this service have specific eligibility requirements that need to be met in order to use the service?"""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Coded value for the eligibility.'
    comment: Optional_['markdown'] = Field(default=None)
    'Describes the eligibility conditions for the service.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class HealthcareService(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The details of a healthcare service available at a location."""
    resourceType: Literal_['HealthcareService'] = Field(default=...)
    'The details of a healthcare service available at a location'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'The specific type of service that may be delivered or performed.'
    name: Optional_['string'] = Field(default=None)
    'Further description of the service as it would be presented to a consumer while searching.'
    photo: Optional_['Attachment'] = Field(default=None)
    'If there is a photo/symbol associated with this HealthcareService, it may be included here to facilitate quick identification of the service in a list.'
    active: Optional_['boolean'] = Field(default=None)
    'This flag is used to mark the record to not be used. This is not used when a center is closed for maintenance, or for holidays, the notAvailable period is to be used for this.'
    comment: Optional_['string'] = Field(default=None)
    'Any additional description of the service and/or any specific issues not covered by the other attributes, which can be displayed as further detail under the serviceName.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'List of contacts related to this specific healthcare service.'
    program: List_['CodeableConcept'] = Field(default_factory=list)
    'Programs that this service is applicable to.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies the broad category of service being performed or delivered.'
    location: List_['Reference'] = Field(default_factory=list)
    'The location(s) where this healthcare service may be provided.'
    endpoint: List_['Reference'] = Field(default_factory=list)
    'Technical endpoints providing access to services operated for the specific healthcare services defined at this resource.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    specialty: List_['CodeableConcept'] = Field(default_factory=list)
    'Collection of specialties handled by the service site. This is more of a medical term.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'External identifiers for this item.'
    providedBy: Optional_['Reference'] = Field(default=None)
    'The organization that provides this healthcare service.'
    eligibility: List_['HealthcareServiceEligibility'] = Field(default_factory=list)
    'Does this service have specific eligibility requirements that need to be met in order to use the service?'
    extraDetails: Optional_['markdown'] = Field(default=None)
    "Extra details about the service that can't be placed in the other fields."
    coverageArea: List_['Reference'] = Field(default_factory=list)
    'The location(s) that this service is available to (not where the service is provided).'
    notAvailable: List_['HealthcareServiceNotAvailable'] = Field(default_factory=list)
    'The HealthcareService is not available during this period of time due to the provided reason.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    communication: List_['CodeableConcept'] = Field(default_factory=list)
    'Some services are specifically made available in multiple languages, this property permits a directory to declare the languages this is offered in. Typically this is only provided where a service operates in communities with mixed languages used.'
    availableTime: List_['HealthcareServiceAvailableTime'] = Field(default_factory=list)
    'A collection of times that the Service Site is available.'
    characteristic: List_['CodeableConcept'] = Field(default_factory=list)
    'Collection of characteristics (attributes).'
    referralMethod: List_['CodeableConcept'] = Field(default_factory=list)
    'Ways that the service accepts referrals, if this is not provided then it is implied that no referral is required.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    appointmentRequired: Optional_['boolean'] = Field(default=None)
    'Indicates whether or not a prospective consumer will require an appointment for a particular service at a site to be provided by the Organization. Indicates if an appointment is required for access to this service.'
    serviceProvisionCode: List_['CodeableConcept'] = Field(default_factory=list)
    'The code(s) that detail the conditions under which the healthcare service is available/offered.'
    availabilityExceptions: Optional_['string'] = Field(default=None)
    'A description of site availability exceptions, e.g. public holiday availability. Succinctly describing all possible exceptions to normal site availability as details in the available Times and not available Times.'


class ImagingStudySeries(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Each study has one or more series of images or other content."""
    uid: 'id' = Field(default=...)
    'The DICOM Series Instance UID for the series.'
    number: Optional_['unsignedInt'] = Field(default=None)
    'The numeric identifier of this series in the study.'
    started: Optional_['dateTime'] = Field(default=None)
    'The date and time the series was started.'
    modality: 'Coding' = Field(default=...)
    'The modality of this series sequence.'
    endpoint: List_['Reference'] = Field(default_factory=list)
    'The network service providing access (e.g., query, view, or retrieval) for this series. See implementation notes for information about using DICOM endpoints. A series-level endpoint, if present, has precedence over a study-level endpoint with the same Endpoint.connectionType.'
    bodySite: Optional_['Coding'] = Field(default=None)
    'The anatomic structures examined. See DICOM Part 16 Annex L (http://dicom.nema.org/medical/dicom/current/output/chtml/part16/chapter_L.html) for DICOM to SNOMED-CT mappings. The bodySite may indicate the laterality of body part imaged; if so, it shall be consistent with any content of ImagingStudy.series.laterality.'
    specimen: List_['Reference'] = Field(default_factory=list)
    'The specimen imaged, e.g., for whole slide imaging of a biopsy.'
    instance: List_['ImagingStudySeriesInstance'] = Field(default_factory=list)
    'A single SOP instance within the series, e.g. an image, or presentation state.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    performer: List_['ImagingStudySeriesPerformer'] = Field(default_factory=list)
    'Indicates who or what performed the series and how they were involved.'
    laterality: Optional_['Coding'] = Field(default=None)
    'The laterality of the (possibly paired) anatomic structures examined. E.g., the left knee, both lungs, or unpaired abdomen. If present, shall be consistent with any laterality information indicated in ImagingStudy.series.bodySite.'
    description: Optional_['string'] = Field(default=None)
    'A description of the series.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    numberOfInstances: Optional_['unsignedInt'] = Field(default=None)
    'Number of SOP Instances in the Study. The value given may be larger than the number of instance elements this resource contains due to resource availability, security, or other factors. This element should be present if any instance elements are present.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class ImagingStudySeriesPerformer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates who or what performed the series and how they were involved."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    actor: 'Reference' = Field(default=...)
    'Indicates who or what performed the series.'
    function: Optional_['CodeableConcept'] = Field(default=None)
    'Distinguishes the type of involvement of the performer in the series.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImagingStudySeriesInstance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A single SOP instance within the series, e.g. an image, or presentation state."""
    uid: 'id' = Field(default=...)
    'The DICOM SOP Instance UID for this image or other DICOM content.'
    title: Optional_['string'] = Field(default=None)
    'The description of the instance.'
    number: Optional_['unsignedInt'] = Field(default=None)
    'The number of instance in the series.'
    sopClass: 'Coding' = Field(default=...)
    'DICOM instance  type.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class ImagingStudy(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Representation of the content produced in a DICOM imaging study. A study comprises a set of series, each of which includes a set of Service-Object Pair Instances (SOP Instances - images or other data) acquired or produced in a common context.  A series is of only one modality (e.g. X-ray, CT, MR, ultrasound), but a study may have multiple series of different modalities."""
    resourceType: Literal_['ImagingStudy'] = Field(default=...)
    'A set of images produced in single study (one or more series of references images)'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Per the recommended DICOM mapping, this element is derived from the Study Description attribute (0008,1030). Observations or findings about the imaging study should be recorded in another resource, e.g. Observation, and not in this element.'
    status: 'code' = Field(default=...)
    'The current state of the ImagingStudy.'
    series: List_['ImagingStudySeries'] = Field(default_factory=list)
    'Each study has one or more series of images or other content.'
    subject: 'Reference' = Field(default=...)
    'The subject, typically a patient, of the imaging study.'
    started: Optional_['dateTime'] = Field(default=None)
    'Date and time the study started.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A list of the diagnostic requests that resulted in this imaging study being performed.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    modality: List_['Coding'] = Field(default_factory=list)
    'A list of all the series.modality values that are actual acquisition modalities, i.e. those in the DICOM Context Group 29 (value set OID 1.2.840.10008.6.1.19).'
    referrer: Optional_['Reference'] = Field(default=None)
    'The requesting/referring physician.'
    endpoint: List_['Reference'] = Field(default_factory=list)
    'The network service providing access (e.g., query, view, or retrieval) for the study. See implementation notes for information about using DICOM endpoints. A study-level endpoint applies to each series in the study, unless overridden by a series-level endpoint with the same Endpoint.connectionType.'
    location: Optional_['Reference'] = Field(default=None)
    'The principal physical location where the ImagingStudy was performed.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The healthcare event (e.g. a patient and healthcare provider interaction) during which this ImagingStudy is made.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers for the ImagingStudy such as DICOM Study Instance UID, and Accession Number.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Description of clinical condition indicating why the ImagingStudy was requested.'
    interpreter: List_['Reference'] = Field(default_factory=list)
    'Who read the study and interpreted the images or other content.'
    description: Optional_['string'] = Field(default=None)
    'The Imaging Manager description of the study. Institution-generated description or classification of the Study (component) performed.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    procedureCode: List_['CodeableConcept'] = Field(default_factory=list)
    'The code for the performed procedure type.'
    numberOfSeries: Optional_['unsignedInt'] = Field(default=None)
    'Number of Series in the Study. This value given may be larger than the number of series elements this Resource contains due to resource availability, security, or other factors. This element should be present if any series elements are present.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates another resource whose existence justifies this Study.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    numberOfInstances: Optional_['unsignedInt'] = Field(default=None)
    'Number of SOP Instances in Study. This value given may be larger than the number of instance elements this resource contains due to resource availability, security, or other factors. This element should be present if any instance elements are present.'
    procedureReference: Optional_['Reference'] = Field(default=None)
    'The procedure which this ImagingStudy was part of.'


class ImmunizationProtocolApplied(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The protocol (set of recommendations) being followed by the provider who administered the dose."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    series: Optional_['string'] = Field(default=None)
    'One possible path to achieve presumed immunity against a disease - within the context of an authority.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    authority: Optional_['Reference'] = Field(default=None)
    'Indicates the authority who published the protocol (e.g. ACIP) that is being followed.'
    targetDisease: List_['CodeableConcept'] = Field(default_factory=list)
    'The vaccine preventable disease the dose is being administered against.'
    doseNumberPositiveInt: Optional_['positiveInt'] = Field(default=None)
    'Nominal position in a series.'
    doseNumberString: Optional_['string'] = Field(default=None)
    'Nominal position in a series.'
    seriesDosesPositiveInt: Optional_['positiveInt'] = Field(default=None)
    'The recommended number of doses to achieve immunity.'
    seriesDosesString: Optional_['string'] = Field(default=None)
    'The recommended number of doses to achieve immunity.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImmunizationEducation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Educational material presented to the patient (or guardian) at the time of vaccine administration."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: Optional_['uri'] = Field(default=None)
    'Reference pointer to the educational material given to the patient if the information was on line.'
    documentType: Optional_['string'] = Field(default=None)
    'Identifier of the material presented to the patient.'
    publicationDate: Optional_['dateTime'] = Field(default=None)
    'Date the educational material was published.'
    presentationDate: Optional_['dateTime'] = Field(default=None)
    'Date the educational material was given to the patient.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImmunizationPerformer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates who performed the immunization event."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    actor: 'Reference' = Field(default=...)
    'The practitioner or organization who performed the action.'
    function: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the type of performance (e.g. ordering provider, administering provider, etc.).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImmunizationReaction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Categorical data indicating that an adverse event is associated in time to an immunization."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    date: Optional_['dateTime'] = Field(default=None)
    'Date of reaction to the immunization.'
    detail: Optional_['Reference'] = Field(default=None)
    'Details of the reaction.'
    reported: Optional_['boolean'] = Field(default=None)
    'Self-reported indicator.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Immunization(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes the event of a patient being administered a vaccine or a record of an immunization as reported by a patient, a clinician or another party."""
    resourceType: Literal_['Immunization'] = Field(default=...)
    'Immunization event information'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    site: Optional_['CodeableConcept'] = Field(default=None)
    'Body site where vaccine was administered.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Extra information about the immunization that is not conveyed by the other attributes.'
    route: Optional_['CodeableConcept'] = Field(default=None)
    'The path by which the vaccine product is taken into the body.'
    status: 'code' = Field(default=...)
    'Indicates the current status of the immunization event.'
    patient: 'Reference' = Field(default=...)
    'The patient who either received or did not receive the immunization.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    recorded: Optional_['dateTime'] = Field(default=None)
    'The date the occurrence of the immunization was first captured in the record - potentially significantly after the occurrence of the event.'
    location: Optional_['Reference'] = Field(default=None)
    'The service delivery location where the vaccine administration occurred.'
    reaction: List_['ImmunizationReaction'] = Field(default_factory=list)
    'Categorical data indicating that an adverse event is associated in time to an immunization.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The visit or admission or other contact between patient and health care provider the immunization was performed as part of.'
    lotNumber: Optional_['string'] = Field(default=None)
    'Lot number of the  vaccine product.'
    performer: List_['ImmunizationPerformer'] = Field(default_factory=list)
    'Indicates who performed the immunization event.'
    education: List_['ImmunizationEducation'] = Field(default_factory=list)
    'Educational material presented to the patient (or guardian) at the time of vaccine administration.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this immunization record.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Reasons why the vaccine was administered.'
    vaccineCode: 'CodeableConcept' = Field(default=...)
    'Vaccine that was administered or was to be administered.'
    isSubpotent: Optional_['boolean'] = Field(default=None)
    'Indication if a dose is considered to be subpotent. By default, a dose should be considered to be potent.'
    statusReason: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the reason the immunization event was not performed.'
    reportOrigin: Optional_['CodeableConcept'] = Field(default=None)
    'The source of the data when the report of the immunization event is not based on information from the person who administered the vaccine.'
    manufacturer: Optional_['Reference'] = Field(default=None)
    'Name of vaccine manufacturer.'
    doseQuantity: Optional_['Quantity'] = Field(default=None)
    'The quantity of vaccine product that was administered.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'Date vaccine administered or was to be administered.'
    occurrenceString: Optional_['string'] = Field(default=None)
    'Date vaccine administered or was to be administered.'
    primarySource: Optional_['boolean'] = Field(default=None)
    'An indication that the content of the record is based on information from the person who administered the vaccine. This reflects the context under which the data was originally recorded.'
    fundingSource: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the source of the vaccine actually administered. This may be different than the patient eligibility (e.g. the patient may be eligible for a publically purchased vaccine but due to inventory issues, vaccine purchased with private funds was actually administered).'
    expirationDate: Optional_['date'] = Field(default=None)
    'Date vaccine batch expires.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Condition, Observation or DiagnosticReport that supports why the immunization was administered.'
    subpotentReason: List_['CodeableConcept'] = Field(default_factory=list)
    'Reason why a dose is considered to be subpotent.'
    protocolApplied: List_['ImmunizationProtocolApplied'] = Field(default_factory=list)
    'The protocol (set of recommendations) being followed by the provider who administered the dose.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    programEligibility: List_['CodeableConcept'] = Field(default_factory=list)
    "Indicates a patient's eligibility for a funding program."


class ImmunizationEvaluation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes a comparison of an immunization event against published recommendations to determine if the administration is "valid" in relation to those  recommendations."""
    resourceType: Literal_['ImmunizationEvaluation'] = Field(default=...)
    'Immunization evaluation information'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date the evaluation of the vaccine administration event was performed.'
    status: 'code' = Field(default=...)
    'Indicates the current status of the evaluation of the vaccination administration event.'
    series: Optional_['string'] = Field(default=None)
    'One possible path to achieve presumed immunity against a disease - within the context of an authority.'
    patient: 'Reference' = Field(default=...)
    'The individual for whom the evaluation is being done.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    authority: Optional_['Reference'] = Field(default=None)
    'Indicates the authority who published the protocol (e.g. ACIP).'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this immunization evaluation record.'
    doseStatus: 'CodeableConcept' = Field(default=...)
    'Indicates if the dose is valid or not valid with respect to the published recommendations.'
    description: Optional_['string'] = Field(default=None)
    'Additional information about the evaluation.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    targetDisease: 'CodeableConcept' = Field(default=...)
    'The vaccine preventable disease the dose is being evaluated against.'
    doseNumberPositiveInt: Optional_['positiveInt'] = Field(default=None)
    'Nominal position in a series.'
    doseNumberString: Optional_['string'] = Field(default=None)
    'Nominal position in a series.'
    seriesDosesPositiveInt: Optional_['positiveInt'] = Field(default=None)
    'The recommended number of doses to achieve immunity.'
    seriesDosesString: Optional_['string'] = Field(default=None)
    'The recommended number of doses to achieve immunity.'
    doseStatusReason: List_['CodeableConcept'] = Field(default_factory=list)
    'Provides an explanation as to why the vaccine administration event is valid or not relative to the published recommendations.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    immunizationEvent: 'Reference' = Field(default=...)
    'The vaccine administration event being evaluated.'


class ImmunizationRecommendationRecommendation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Vaccine administration recommendations."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    series: Optional_['string'] = Field(default=None)
    'One possible path to achieve presumed immunity against a disease - within the context of an authority.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    vaccineCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Vaccine(s) or vaccine group that pertain to the recommendation.'
    description: Optional_['string'] = Field(default=None)
    'Contains the description about the protocol under which the vaccine was administered.'
    targetDisease: Optional_['CodeableConcept'] = Field(default=None)
    'The targeted disease for the recommendation.'
    dateCriterion: List_['ImmunizationRecommendationRecommendationDateCriterion'] = Field(default_factory=list)
    'Vaccine date recommendations.  For example, earliest date to administer, latest date to administer, etc.'
    doseNumberPositiveInt: Optional_['positiveInt'] = Field(default=None)
    'Nominal position of the recommended dose in a series (e.g. dose 2 is the next recommended dose).'
    doseNumberString: Optional_['string'] = Field(default=None)
    'Nominal position of the recommended dose in a series (e.g. dose 2 is the next recommended dose).'
    forecastStatus: 'CodeableConcept' = Field(default=...)
    'Indicates the patient status with respect to the path to immunity for the target disease.'
    forecastReason: List_['CodeableConcept'] = Field(default_factory=list)
    'The reason for the assigned forecast status.'
    seriesDosesPositiveInt: Optional_['positiveInt'] = Field(default=None)
    'The recommended number of doses to achieve immunity.'
    seriesDosesString: Optional_['string'] = Field(default=None)
    'The recommended number of doses to achieve immunity.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    supportingImmunization: List_['Reference'] = Field(default_factory=list)
    'Immunization event history and/or evaluation that supports the status and recommendation.'
    contraindicatedVaccineCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Vaccine(s) which should not be used to fulfill the recommendation.'
    supportingPatientInformation: List_['Reference'] = Field(default_factory=list)
    'Patient Information that supports the status and recommendation.  This includes patient observations, adverse reactions and allergy/intolerance information.'


class ImmunizationRecommendationRecommendationDateCriterion(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Vaccine date recommendations.  For example, earliest date to administer, latest date to administer, etc."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'Date classification of recommendation.  For example, earliest date to give, latest date to give, etc.'
    value: 'dateTime' = Field(default=...)
    'The date whose meaning is specified by dateCriterion.code.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImmunizationRecommendation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A patient's point-in-time set of recommendations (i.e. forecasting) according to a published schedule with optional supporting justification."""
    resourceType: Literal_['ImmunizationRecommendation'] = Field(default=...)
    'Guidance or advice relating to an immunization'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    date: 'dateTime' = Field(default=...)
    'The date the immunization recommendation(s) were created.'
    patient: 'Reference' = Field(default=...)
    'The patient the recommendation(s) are for.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    authority: Optional_['Reference'] = Field(default=None)
    'Indicates the authority who published the protocol (e.g. ACIP).'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this particular recommendation record.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    recommendation: List_['ImmunizationRecommendationRecommendation'] = Field(default=...)
    'Vaccine administration recommendations.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImplementationGuideDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The information needed by an IG publisher tool to publish the whole implementation guide."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    page: Optional_['ImplementationGuideDefinitionPage'] = Field(default=None)
    'A page / section in the implementation guide. The root page is the implementation guide home page.'
    grouping: List_['ImplementationGuideDefinitionGrouping'] = Field(default_factory=list)
    'A logical group of resources. Logical groups can be used when building pages.'
    resource: List_['ImplementationGuideDefinitionResource'] = Field(default=...)
    'A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.'
    template: List_['ImplementationGuideDefinitionTemplate'] = Field(default_factory=list)
    'A template for building resources.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    parameter: List_['ImplementationGuideDefinitionParameter'] = Field(default_factory=list)
    'Defines how IG is built by tools.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImplementationGuideDefinitionParameter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Defines how IG is built by tools."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: 'string' = Field(default=...)
    'Value for named type.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'apply | path-resource | path-pages | path-tx-cache | expansion-parameter | rule-broken-links | generate-xml | generate-json | generate-turtle | html-template.'


class ImplementationGuideDefinitionTemplate(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A template for building resources."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    scope: Optional_['string'] = Field(default=None)
    'The scope in which the template applies.'
    source: 'string' = Field(default=...)
    'The source location for the template.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'Type of template specified.'


class ImplementationGuideDefinitionResource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource."""
    name: Optional_['string'] = Field(default=None)
    'A human assigned name for the resource. All resources SHOULD have a name, but the name may be extracted from the resource (e.g. ValueSet.name).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: 'Reference' = Field(default=...)
    'Where this resource is found.'
    exampleBoolean: Optional_['boolean'] = Field(default=None)
    'If true or a reference, indicates the resource is an example instance.  If a reference is present, indicates that the example is an example of the specified profile.'
    exampleCanonical: Optional_['canonical'] = Field(default=None)
    'If true or a reference, indicates the resource is an example instance.  If a reference is present, indicates that the example is an example of the specified profile.'
    groupingId: Optional_['id'] = Field(default=None)
    'Reference to the id of the grouping this resource appears in.'
    fhirVersion: List_['code'] = Field(default_factory=list)
    'Indicates the FHIR Version(s) this artifact is intended to apply to. If no versions are specified, the resource is assumed to apply to all the versions stated in ImplementationGuide.fhirVersion.'
    description: Optional_['string'] = Field(default=None)
    'A description of the reason that a resource has been included in the implementation guide.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class ImplementationGuideDefinitionGrouping(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A logical group of resources. Logical groups can be used when building pages."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'The human-readable title to display for the package of resources when rendering the implementation guide.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'Human readable text describing the package.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImplementationGuideDefinitionPage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A page / section in the implementation guide. The root page is the implementation guide home page."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    page: List_['ImplementationGuideDefinitionPage'] = Field(default_factory=list)
    'Nested Pages/Sections under this page.'
    title: 'string' = Field(default=...)
    'A short title used to represent this page in navigational structures such as table of contents, bread crumbs, etc.'
    nameUrl: Optional_['url'] = Field(default=None)
    'The source address for the page.'
    nameReference: Optional_['Reference'] = Field(default=None)
    'The source address for the page.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    generation: 'code' = Field(default=...)
    'A code that indicates how the page is generated.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImplementationGuideDependsOn(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Another implementation guide that this implementation depends on. Typically, an implementation guide uses value sets, profiles etc.defined in other implementation guides."""
    uri: 'canonical' = Field(default=...)
    'A canonical reference to the Implementation guide for the dependency.'
    version: Optional_['string'] = Field(default=None)
    'The version of the IG that is depended on, when the correct version is required to understand the IG correctly.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    packageId: Optional_['id'] = Field(default=None)
    'The NPM package name for the Implementation Guide that this IG depends on.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class ImplementationGuideManifest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about an assembled implementation guide, created by the publication tooling."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    page: List_['ImplementationGuideManifestPage'] = Field(default_factory=list)
    'Information about a page within the IG.'
    image: List_['string'] = Field(default_factory=list)
    'Indicates a relative path to an image that exists within the IG.'
    other: List_['string'] = Field(default_factory=list)
    'Indicates the relative path of an additional non-page, non-image file that is part of the IG - e.g. zip, jar and similar files that could be the target of a hyperlink in a derived IG.'
    resource: List_['ImplementationGuideManifestResource'] = Field(default=...)
    'A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    rendering: Optional_['url'] = Field(default=None)
    'A pointer to official web page, PDF or other rendering of the implementation guide.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImplementationGuideManifestResource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: 'Reference' = Field(default=...)
    'Where this resource is found.'
    exampleBoolean: Optional_['boolean'] = Field(default=None)
    'If true or a reference, indicates the resource is an example instance.  If a reference is present, indicates that the example is an example of the specified profile.'
    exampleCanonical: Optional_['canonical'] = Field(default=None)
    'If true or a reference, indicates the resource is an example instance.  If a reference is present, indicates that the example is an example of the specified profile.'
    relativePath: Optional_['url'] = Field(default=None)
    'The relative path for primary page for this resource within the IG.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImplementationGuideManifestPage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about a page within the IG."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'Relative path to the page.'
    title: Optional_['string'] = Field(default=None)
    'Label for the page intended for human display.'
    anchor: List_['string'] = Field(default_factory=list)
    'The name of an anchor available on the page.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImplementationGuideGlobal(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A set of profiles that all resources covered by this implementation guide must conform to."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of resource that all instances must conform to.'
    profile: 'canonical' = Field(default=...)
    'A reference to the profile that all instances must conform to.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ImplementationGuide(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts."""
    resourceType: Literal_['ImplementationGuide'] = Field(default=...)
    'A set of rules about how FHIR is used'
    url: 'uri' = Field(default=...)
    'An absolute URI that is used to identify this implementation guide when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this implementation guide is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the implementation guide is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: 'string' = Field(default=...)
    'A natural language name identifying the implementation guide. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the implementation guide was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the implementation guide changes.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the implementation guide.'
    status: 'code' = Field(default=...)
    'The status of this implementation guide. Enables tracking the life-cycle of the content.'
    global_: List_['ImplementationGuideGlobal'] = Field(default_factory=list, alias='global')
    'A set of profiles that all resources covered by this implementation guide must conform to.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the implementation guide when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the implementation guide author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    license: Optional_['code'] = Field(default=None)
    "The license that applies to this Implementation Guide, using an SPDX license code, or 'not-open-source'."
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    manifest: Optional_['ImplementationGuideManifest'] = Field(default=None)
    'Information about an assembled implementation guide, created by the publication tooling.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the implementation guide.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the implementation guide and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the implementation guide.'
    packageId: 'id' = Field(default=...)
    'The NPM package name for this Implementation Guide, used in the NPM package distribution, which is the primary mechanism by which FHIR based tooling manages IG dependencies. This value must be globally unique, and should be assigned with care.'
    dependsOn: List_['ImplementationGuideDependsOn'] = Field(default_factory=list)
    'Another implementation guide that this implementation depends on. Typically, an implementation guide uses value sets, profiles etc.defined in other implementation guides.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate implementation guide instances.'
    definition: Optional_['ImplementationGuideDefinition'] = Field(default=None)
    'The information needed by an IG publisher tool to publish the whole implementation guide.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the implementation guide from a consumer's perspective."
    fhirVersion: List_['code'] = Field(default=...)
    'The version(s) of the FHIR specification that this ImplementationGuide targets - e.g. describes how to use. The value of this element is the formal version of the specification, without the revision number, e.g. [publication].[major].[minor], which is 4.3.0 for this version.'
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this implementation guide is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the implementation guide is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'


class IngredientManufacturer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The organization(s) that manufacture this ingredient. Can be used to indicate:         1) Organizations we are aware of that manufacture this ingredient         2) Specific Manufacturer(s) currently being used         3) Set of organisations allowed to manufacture this ingredient for this product         Users must be clear on the application of context relevant to their use case."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: Optional_['code'] = Field(default=None)
    'The way in which this manufacturer is associated with the ingredient. For example whether it is a possible one (others allowed), or an exclusive authorized one for this ingredient. Note that this is not the manufacturing process role.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    manufacturer: 'Reference' = Field(default=...)
    'An organization that manufactures this ingredient.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class IngredientSubstance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The substance that comprises this ingredient."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableReference' = Field(default=...)
    "A code or full resource that represents the ingredient's substance."
    strength: List_['IngredientSubstanceStrength'] = Field(default_factory=list)
    'The quantity of substance in the unit of presentation, or in the volume (or mass) of the single pharmaceutical product or manufactured item. The allowed repetitions do not represent different strengths, but are different representations - mathematically equivalent - of a single strength.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class IngredientSubstanceStrength(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The quantity of substance in the unit of presentation, or in the volume (or mass) of the single pharmaceutical product or manufactured item. The allowed repetitions do not represent different strengths, but are different representations - mathematically equivalent - of a single strength."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    country: List_['CodeableConcept'] = Field(default_factory=list)
    'The country or countries for which the strength range applies.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    presentationRatio: Optional_['Ratio'] = Field(default=None)
    "The quantity of substance in the unit of presentation, or in the volume (or mass) of the single pharmaceutical product or manufactured item. Unit of presentation refers to the quantity that the item occurs in e.g. a strength per tablet size, perhaps 'per 20mg' (the size of the tablet). It is not generally normalized as a unitary unit, which would be 'per mg')."
    presentationRatioRange: Optional_['RatioRange'] = Field(default=None)
    "The quantity of substance in the unit of presentation, or in the volume (or mass) of the single pharmaceutical product or manufactured item. Unit of presentation refers to the quantity that the item occurs in e.g. a strength per tablet size, perhaps 'per 20mg' (the size of the tablet). It is not generally normalized as a unitary unit, which would be 'per mg')."
    textPresentation: Optional_['string'] = Field(default=None)
    'A textual represention of either the whole of the presentation strength or a part of it - with the rest being in Strength.presentation as a ratio.'
    concentrationRatio: Optional_['Ratio'] = Field(default=None)
    'The strength per unitary volume (or mass).'
    concentrationRatioRange: Optional_['RatioRange'] = Field(default=None)
    'The strength per unitary volume (or mass).'
    measurementPoint: Optional_['string'] = Field(default=None)
    'For when strength is measured at a particular point or distance. There are products where strength is measured at a particular point. For example, the strength of the ingredient in some inhalers is measured at a particular position relative to the point of aerosolization.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    textConcentration: Optional_['string'] = Field(default=None)
    'A textual represention of either the whole of the concentration strength or a part of it - with the rest being in Strength.concentration as a ratio.'
    referenceStrength: List_['IngredientSubstanceStrengthReferenceStrength'] = Field(default_factory=list)
    'Strength expressed in terms of a reference substance. For when the ingredient strength is additionally expressed as equivalent to the strength of some other closely related substance (e.g. salt vs. base). Reference strength represents the strength (quantitative composition) of the active moiety of the active substance. There are situations when the active substance and active moiety are different, therefore both a strength and a reference strength are needed.'


class IngredientSubstanceStrengthReferenceStrength(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Strength expressed in terms of a reference substance. For when the ingredient strength is additionally expressed as equivalent to the strength of some other closely related substance (e.g. salt vs. base). Reference strength represents the strength (quantitative composition) of the active moiety of the active substance. There are situations when the active substance and active moiety are different, therefore both a strength and a reference strength are needed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    country: List_['CodeableConcept'] = Field(default_factory=list)
    'The country or countries for which the strength range applies.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    substance: Optional_['CodeableReference'] = Field(default=None)
    'Relevant reference substance.'
    strengthRatio: Optional_['Ratio'] = Field(default=None)
    'Strength expressed in terms of a reference substance.'
    strengthRatioRange: Optional_['RatioRange'] = Field(default=None)
    'Strength expressed in terms of a reference substance.'
    measurementPoint: Optional_['string'] = Field(default=None)
    'For when strength is measured at a particular point or distance.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Ingredient(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An ingredient of a manufactured item or pharmaceutical product."""
    resourceType: Literal_['Ingredient'] = Field(default=...)
    'An ingredient of a manufactured item or pharmaceutical product'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    for_: List_['Reference'] = Field(default_factory=list, alias='for')
    'The product which this ingredient is a constituent part of.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    role: 'CodeableConcept' = Field(default=...)
    'A classification of the ingredient identifying its purpose within the product, e.g. active, inactive.'
    status: 'code' = Field(default=...)
    'The status of this ingredient. Enables tracking the life-cycle of the content.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    function: List_['CodeableConcept'] = Field(default_factory=list)
    'A classification of the ingredient identifying its precise purpose(s) in the drug product. This extends the Ingredient.role to add more detail. Example: antioxidant, alkalizing agent.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    substance: 'IngredientSubstance' = Field(default=...)
    'The substance that comprises this ingredient.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'The identifier(s) of this Ingredient that are assigned by business processes and/or used to refer to it when a direct URL reference to the resource itself is not appropriate.'
    manufacturer: List_['IngredientManufacturer'] = Field(default_factory=list)
    'The organization(s) that manufacture this ingredient. Can be used to indicate:         1) Organizations we are aware of that manufacture this ingredient         2) Specific Manufacturer(s) currently being used         3) Set of organisations allowed to manufacture this ingredient for this product         Users must be clear on the application of context relevant to their use case.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    allergenicIndicator: Optional_['boolean'] = Field(default=None)
    'If the ingredient is a known or suspected allergen. Note that this is a property of the substance, so if a reference to a SubstanceDefinition is used to decribe that (rather than just a code), the allergen information should go there, not here.'


class InsurancePlanCoverage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details about the coverage offered by the insurance product."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Type of coverage  (Medical; Dental; Mental Health; Substance Abuse; Vision; Drug; Short Term; Long Term Care; Hospice; Home Health).'
    network: List_['Reference'] = Field(default_factory=list)
    'Reference to the network that providing the type of coverage.'
    benefit: List_['InsurancePlanCoverageBenefit'] = Field(default=...)
    'Specific benefits under this type of coverage.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InsurancePlanCoverageBenefit(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specific benefits under this type of coverage."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Type of benefit (primary care; speciality care; inpatient; outpatient).'
    limit: List_['InsurancePlanCoverageBenefitLimit'] = Field(default_factory=list)
    'The specific limits on the benefit.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    requirement: Optional_['string'] = Field(default=None)
    'The referral requirements to have access/coverage for this benefit.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InsurancePlanCoverageBenefitLimit(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The specific limits on the benefit."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The specific limit on the benefit.'
    value: Optional_['Quantity'] = Field(default=None)
    'The maximum amount of a service item a plan will pay for a covered benefit.  For examples. wellness visits, or eyeglasses.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InsurancePlanContact(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The contact for the health insurance product for a certain purpose."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['HumanName'] = Field(default=None)
    'A name associated with the contact.'
    purpose: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates a purpose for which the contact can be reached.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'A contact detail (e.g. a telephone number or an email address) by which the party may be contacted.'
    address: Optional_['Address'] = Field(default=None)
    'Visiting or postal addresses for the contact.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InsurancePlanPlan(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details about an insurance plan."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Type of plan. For example, "Platinum" or "High Deductable".'
    network: List_['Reference'] = Field(default_factory=list)
    'Reference to the network that providing the type of coverage.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this health insurance plan which remain constant as the resource is updated and propagates from server to server.'
    generalCost: List_['InsurancePlanPlanGeneralCost'] = Field(default_factory=list)
    'Overall costs associated with the plan.'
    coverageArea: List_['Reference'] = Field(default_factory=list)
    "The geographic region in which a health insurance plan's benefits apply."
    specificCost: List_['InsurancePlanPlanSpecificCost'] = Field(default_factory=list)
    'Costs associated with the coverage provided by the product.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InsurancePlanPlanSpecificCost(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Costs associated with the coverage provided by the product."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    benefit: List_['InsurancePlanPlanSpecificCostBenefit'] = Field(default_factory=list)
    'List of the specific benefits under this category of benefit.'
    category: 'CodeableConcept' = Field(default=...)
    'General category of benefit (Medical; Dental; Vision; Drug; Mental Health; Substance Abuse; Hospice, Home Health).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InsurancePlanPlanSpecificCostBenefit(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """List of the specific benefits under this category of benefit."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Type of specific benefit (preventative; primary care office visit; speciality office visit; hospitalization; emergency room; urgent care).'
    cost: List_['InsurancePlanPlanSpecificCostBenefitCost'] = Field(default_factory=list)
    'List of the costs associated with a specific benefit.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InsurancePlanPlanSpecificCostBenefitCost(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """List of the costs associated with a specific benefit."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Type of cost (copay; individual cap; family cap; coinsurance; deductible).'
    value: Optional_['Quantity'] = Field(default=None)
    'The actual cost value. (some of the costs may be represented as percentages rather than currency, e.g. 10% coinsurance).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    qualifiers: List_['CodeableConcept'] = Field(default_factory=list)
    'Additional information about the cost, such as information about funding sources (e.g. HSA, HRA, FSA, RRA).'
    applicability: Optional_['CodeableConcept'] = Field(default=None)
    'Whether the cost applies to in-network or out-of-network providers (in-network; out-of-network; other).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InsurancePlanPlanGeneralCost(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Overall costs associated with the plan."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Type of cost.'
    cost: Optional_['Money'] = Field(default=None)
    'Value of the cost.'
    comment: Optional_['string'] = Field(default=None)
    'Additional information about the general costs associated with this plan.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    groupSize: Optional_['positiveInt'] = Field(default=None)
    'Number of participants enrolled in the plan.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InsurancePlan(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details of a Health Insurance product/plan provided by an organization."""
    resourceType: Literal_['InsurancePlan'] = Field(default=...)
    'Details of a Health Insurance product/plan provided by an organization'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'The kind of health insurance product.'
    name: Optional_['string'] = Field(default=None)
    'Official name of the health insurance product as designated by the owner.'
    plan: List_['InsurancePlanPlan'] = Field(default_factory=list)
    'Details about an insurance plan.'
    alias: List_['string'] = Field(default_factory=list)
    'A list of alternate names that the product is known as, or was known as in the past.'
    status: Optional_['code'] = Field(default=None)
    'The current state of the health insurance product.'
    period: Optional_['Period'] = Field(default=None)
    'The period of time that the health insurance product is available.'
    ownedBy: Optional_['Reference'] = Field(default=None)
    "The entity that is providing  the health insurance product and underwriting the risk.  This is typically an insurance carriers, other third-party payers, or health plan sponsors comonly referred to as 'payers'."
    contact: List_['InsurancePlanContact'] = Field(default_factory=list)
    'The contact for the health insurance product for a certain purpose.'
    network: List_['Reference'] = Field(default_factory=list)
    'Reference to the network included in the health insurance product.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    endpoint: List_['Reference'] = Field(default_factory=list)
    'The technical endpoints providing access to services operated for the health insurance product.'
    coverage: List_['InsurancePlanCoverage'] = Field(default_factory=list)
    'Details about the coverage offered by the insurance product.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this health insurance product which remain constant as the resource is updated and propagates from server to server.'
    coverageArea: List_['Reference'] = Field(default_factory=list)
    "The geographic region in which a health insurance product's benefits apply."
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    administeredBy: Optional_['Reference'] = Field(default=None)
    'An organization which administer other services such as underwriting, customer service and/or claims processing on behalf of the health insurance product owner.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InvoiceParticipant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates who or what performed or participated in the charged service."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the type of involvement (e.g. transcriptionist, creator etc.). If the invoice has been created automatically, the Participant may be a billing engine or another kind of device.'
    actor: 'Reference' = Field(default=...)
    'The device, practitioner, etc. who performed or participated in the service.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InvoiceLineItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Each line item represents one charge for goods and services rendered. Details such as date, code and amount are found in the referenced ChargeItem resource."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    sequence: Optional_['positiveInt'] = Field(default=None)
    'Sequence in which the items appear on the invoice.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    chargeItemReference: Optional_['Reference'] = Field(default=None)
    'The ChargeItem contains information such as the billing code, date, amount etc. If no further details are required for the lineItem, inline billing codes can be added using the CodeableConcept data type instead of the Reference.'
    chargeItemCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The ChargeItem contains information such as the billing code, date, amount etc. If no further details are required for the lineItem, inline billing codes can be added using the CodeableConcept data type instead of the Reference.'
    priceComponent: List_['InvoiceLineItemPriceComponent'] = Field(default_factory=list)
    'The price for a ChargeItem may be calculated as a base price with surcharges/deductions that apply in certain conditions. A ChargeItemDefinition resource that defines the prices, factors and conditions that apply to a billing code is currently under development. The priceComponent element can be used to offer transparency to the recipient of the Invoice as to how the prices have been calculated.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class InvoiceLineItemPriceComponent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The price for a ChargeItem may be calculated as a base price with surcharges/deductions that apply in certain conditions. A ChargeItemDefinition resource that defines the prices, factors and conditions that apply to a billing code is currently under development. The priceComponent element can be used to offer transparency to the recipient of the Invoice as to how the prices have been calculated."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'This code identifies the type of the component.'
    factor: Optional_['decimal'] = Field(default=None)
    'The factor that has been applied on the base price for calculating this component.'
    amount: Optional_['Money'] = Field(default=None)
    'The amount calculated for this component.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code that identifies the component. Codes may be used to differentiate between kinds of taxes, surcharges, discounts etc.'


class Invoice(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Invoice containing collected ChargeItems from an Account with calculated individual and total price for Billing purpose."""
    resourceType: Literal_['Invoice'] = Field(default=...)
    'Invoice containing ChargeItems from an Account'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Type of Invoice depending on domain, realm an usage (e.g. internal/external, dental, preliminary).'
    date: Optional_['dateTime'] = Field(default=None)
    'Date/time(s) of when this Invoice was posted.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments made about the invoice by the issuer, subject, or other participants.'
    status: 'code' = Field(default=...)
    'The current state of the Invoice.'
    issuer: Optional_['Reference'] = Field(default=None)
    'The organizationissuing the Invoice.'
    subject: Optional_['Reference'] = Field(default=None)
    'The individual or set of individuals receiving the goods and services billed in this invoice.'
    account: Optional_['Reference'] = Field(default=None)
    'Account which is supposed to be balanced with this Invoice.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    lineItem: List_['InvoiceLineItem'] = Field(default_factory=list)
    'Each line item represents one charge for goods and services rendered. Details such as date, code and amount are found in the referenced ChargeItem resource.'
    totalNet: Optional_['Money'] = Field(default=None)
    'Invoice total , taxes excluded.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    recipient: Optional_['Reference'] = Field(default=None)
    'The individual or Organization responsible for balancing of this invoice.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier of this Invoice, often used for reference in correspondence about this invoice or for tracking of payments.'
    totalGross: Optional_['Money'] = Field(default=None)
    'Invoice total, tax included.'
    participant: List_['InvoiceParticipant'] = Field(default_factory=list)
    'Indicates who or what performed or participated in the charged service.'
    paymentTerms: Optional_['markdown'] = Field(default=None)
    'Payment details such as banking details, period of payment, deductibles, methods of payment.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    cancelledReason: Optional_['string'] = Field(default=None)
    'In case of Invoice cancellation a reason must be given (entered in error, superseded by corrected invoice etc.).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    totalPriceComponent: List_['InvoiceLineItemPriceComponent'] = Field(default_factory=list)
    'The total amount for the Invoice may be calculated as the sum of the line items with surcharges/deductions that apply in certain conditions.  The priceComponent element can be used to offer transparency to the recipient of the Invoice of how the total price was calculated.'


class Library(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The Library resource is a general-purpose container for knowledge asset definitions. It can be used to describe and expose existing knowledge assets such as logic libraries and information model descriptions, as well as to describe a collection of knowledge assets."""
    resourceType: Literal_['Library'] = Field(default=...)
    'Represents a library of quality improvement components'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this library when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this library is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the library is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the library. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    type: 'CodeableConcept' = Field(default=...)
    'Identifies the type of library such as a Logic Library, Model Definition, Asset Collection, or Module Definition.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the library.'
    usage: Optional_['string'] = Field(default=None)
    'A detailed description of how the library is used from a clinical perspective.'
    topic: List_['CodeableConcept'] = Field(default_factory=list)
    'Descriptive topics related to the content of the library. Topics provide a high-level categorization of the library that can be useful for filtering and searching.'
    status: 'code' = Field(default=...)
    'The status of this library. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual or organization primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for internal coherence of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the library when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the library author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active artifacts.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this library is needed and why it has been designed as it has.'
    content: List_['Attachment'] = Field(default_factory=list)
    'The content of the library as an Attachment. The content may be a reference to a url, or may be directly embedded as a base-64 string. Either way, the contentType of the attachment determines how to interpret the content.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    subtitle: Optional_['string'] = Field(default=None)
    'An explanatory or alternate title for the library giving additional information about its content.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization responsible for officially endorsing the content for use in some setting.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the library.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the library and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the library.'
    parameter: List_['ParameterDefinition'] = Field(default_factory=list)
    'The parameter element defines parameters used by the library.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this library when it is represented in other formats, or referenced in a specification, model, design or an instance. e.g. CMS or NQF identifiers for a measure artifact. Note that at least one identifier is required for non-experimental active artifacts.'
    subjectCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A code or group definition that describes the intended subject of the contents of the library.'
    subjectReference: Optional_['Reference'] = Field(default=None)
    'A code or group definition that describes the intended subject of the contents of the library.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate library instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the library from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this library is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the library is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the library content was or is planned to be in active use.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Related artifacts such as additional documentation, justification, or bibliographic references.'
    dataRequirement: List_['DataRequirement'] = Field(default_factory=list)
    'Describes a set of data that must be provided in order to be able to successfully perform the computations defined by the library.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the library was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the library changes.'


class LinkageItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies which record considered as the reference to the same real-world occurrence as well as how the items should be evaluated within the collection of linked items."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'Distinguishes which item is "source of truth" (if any) and which items are no longer considered to be current representations.'
    resource: 'Reference' = Field(default=...)
    'The resource instance being linked as part of the group.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Linkage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies two or more records (resource instances) that refer to the same real-world "occurrence"."""
    resourceType: Literal_['Linkage'] = Field(default=...)
    "Links records for 'same' item"
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    item: List_['LinkageItem'] = Field(default=...)
    'Identifies which record considered as the reference to the same real-world occurrence as well as how the items should be evaluated within the collection of linked items.'
    active: Optional_['boolean'] = Field(default=None)
    'Indicates whether the asserted set of linkages are considered to be "in effect".'
    author: Optional_['Reference'] = Field(default=None)
    'Identifies the user or organization responsible for asserting the linkages as well as the user or organization who establishes the context in which the nature of each linkage is evaluated.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ListEntry(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Entries in this list."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    flag: Optional_['CodeableConcept'] = Field(default=None)
    'The flag allows the system constructing the list to indicate the role and significance of the item in the list.'
    date: Optional_['dateTime'] = Field(default=None)
    'When this item was added to the list.'
    item: 'Reference' = Field(default=...)
    'A reference to the actual resource from which data was derived.'
    deleted: Optional_['boolean'] = Field(default=None)
    'True if this item is marked as deleted in the list.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class List(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A list is a curated collection of resources."""
    resourceType: Literal_['List'] = Field(default=...)
    'A list is a curated collection of resources'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    mode: 'code' = Field(default=...)
    'How this list was prepared - whether it is a working list that is suitable for being maintained on an ongoing basis, or if it represents a snapshot of a list of items from another source, or whether it is a prepared list where items may be marked as added, modified or deleted.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date that the list was prepared.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments that apply to the overall list.'
    title: Optional_['string'] = Field(default=None)
    'A label for the list assigned by the author.'
    entry: List_['ListEntry'] = Field(default_factory=list)
    'Entries in this list.'
    status: 'code' = Field(default=...)
    'Indicates the current state of this list.'
    source: Optional_['Reference'] = Field(default=None)
    'The entity responsible for deciding what the contents of the list were. Where the list was created by a human, this is the same as the author of the list.'
    subject: Optional_['Reference'] = Field(default=None)
    'The common subject (or patient) of the resources that are in the list if there is one.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The encounter that is the context in which this list was created.'
    orderedBy: Optional_['CodeableConcept'] = Field(default=None)
    'What order applies to the items in the list.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier for the List assigned for business purposes outside the context of FHIR.'
    emptyReason: Optional_['CodeableConcept'] = Field(default=None)
    'If the list is empty, why the list is empty.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['CodeableConcept'] = Field(default=None)
    'This code defines the purpose of the list - why it was created.'


class LocationHoursOfOperation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """What days/times during a week is this location usually open."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    allDay: Optional_['boolean'] = Field(default=None)
    'The Location is open all day.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    daysOfWeek: List_['code'] = Field(default_factory=list)
    'Indicates which days of the week are available between the start and end Times.'
    openingTime: Optional_['time'] = Field(default=None)
    'Time that the Location opens.'
    closingTime: Optional_['time'] = Field(default=None)
    'Time that the Location closes.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class LocationPosition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The absolute geographic location of the Location, expressed using the WGS84 datum (This is the same co-ordinate system used in KML)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    latitude: 'decimal' = Field(default=...)
    'Latitude. The value domain and the interpretation are the same as for the text of the latitude element in KML (see notes below).'
    altitude: Optional_['decimal'] = Field(default=None)
    'Altitude. The value domain and the interpretation are the same as for the text of the altitude element in KML (see notes below).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    longitude: 'decimal' = Field(default=...)
    'Longitude. The value domain and the interpretation are the same as for the text of the longitude element in KML (see notes below).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Location(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details and position information for a physical place where services are provided and resources and participants may be stored, found, contained, or accommodated."""
    resourceType: Literal_['Location'] = Field(default=...)
    'Details and position information for a physical place'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'Name of the location as used by humans. Does not need to be unique.'
    mode: Optional_['code'] = Field(default=None)
    'Indicates whether a resource instance represents a specific location or a class of locations.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'Indicates the type of function performed at the location.'
    alias: List_['string'] = Field(default_factory=list)
    'A list of alternate names that the location is known as, or was known as, in the past.'
    status: Optional_['code'] = Field(default=None)
    'The status property covers the general availability of the resource, not the current value which may be covered by the operationStatus, or by a schedule/slots if they are configured for the location.'
    partOf: Optional_['Reference'] = Field(default=None)
    'Another Location of which this Location is physically a part of.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'The contact details of communication devices available at the location. This can include phone numbers, fax numbers, mobile numbers, email addresses and web sites.'
    address: Optional_['Address'] = Field(default=None)
    'Physical location.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    position: Optional_['LocationPosition'] = Field(default=None)
    'The absolute geographic location of the Location, expressed using the WGS84 datum (This is the same co-ordinate system used in KML).'
    endpoint: List_['Reference'] = Field(default_factory=list)
    'Technical endpoints providing access to services operated for the location.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique code or number identifying the location to its users.'
    description: Optional_['string'] = Field(default=None)
    'Description of the Location, which helps in finding or referencing the place.'
    physicalType: Optional_['CodeableConcept'] = Field(default=None)
    'Physical form of the location, e.g. building, room, vehicle, road.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    hoursOfOperation: List_['LocationHoursOfOperation'] = Field(default_factory=list)
    'What days/times during a week is this location usually open.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    operationalStatus: Optional_['Coding'] = Field(default=None)
    'The operational status covers operation values most relevant to beds (but can also apply to rooms/units/chairs/etc. such as an isolation unit/dialysis chair). This typically covers concepts such as contamination, housekeeping, and other activities like maintenance.'
    managingOrganization: Optional_['Reference'] = Field(default=None)
    'The organization responsible for the provisioning and upkeep of the location.'
    availabilityExceptions: Optional_['string'] = Field(default=None)
    'A description of when the locations opening ours are different to normal, e.g. public holiday availability. Succinctly describing all possible exceptions to normal site availability as detailed in the opening hours Times.'


class ManufacturedItemDefinitionProperty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """General characteristics of this item."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'A code expressing the type of characteristic.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A value for the characteristic.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'A value for the characteristic.'
    valueDate: Optional_['date'] = Field(default=None)
    'A value for the characteristic.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'A value for the characteristic.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'A value for the characteristic.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ManufacturedItemDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The definition and characteristics of a medicinal manufactured item, such as a tablet or capsule, as contained in a packaged medicinal product."""
    resourceType: Literal_['ManufacturedItemDefinition'] = Field(default=...)
    'The definition and characteristics of a medicinal manufactured item, such as a tablet or capsule, as contained in a packaged medicinal product'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: 'code' = Field(default=...)
    'The status of this item. Enables tracking the life-cycle of the content.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    property: List_['ManufacturedItemDefinitionProperty'] = Field(default_factory=list)
    'General characteristics of this item.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique identifier.'
    ingredient: List_['CodeableConcept'] = Field(default_factory=list)
    'The ingredients of this manufactured item. This is only needed if the ingredients are not specified by incoming references from the Ingredient resource.'
    manufacturer: List_['Reference'] = Field(default_factory=list)
    'Manufacturer of the item (Note that this should be named "manufacturer" but it currently causes technical issues).'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    unitOfPresentation: Optional_['CodeableConcept'] = Field(default=None)
    'The “real world” units in which the quantity of the manufactured item is described.'
    manufacturedDoseForm: 'CodeableConcept' = Field(default=...)
    'Dose form as manufactured and before any transformation into the pharmaceutical product.'


class MeasureSupplementalData(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The supplemental data criteria for the measure report, specified as either the name of a valid CQL expression within a referenced library, or a valid FHIR Resource Path."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates a meaning for the supplemental data. This can be as simple as a unique identifier, or it can establish meaning in a broader context by drawing from a terminology, allowing supplemental data to be correlated across measures.'
    usage: List_['CodeableConcept'] = Field(default_factory=list)
    'An indicator of the intended usage for the supplemental data element. Supplemental data indicates the data is additional information requested to augment the measure information. Risk adjustment factor indicates the data is additional information used to calculate risk adjustment factors when applying a risk model to the measure calculation.'
    criteria: 'Expression' = Field(default=...)
    'The criteria for the supplemental data. This is typically the name of a valid expression defined within a referenced library, but it may also be a path to a specific data element. The criteria defines the data to be returned for this element.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'The human readable description of this supplemental data.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureGroup(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A group of population criteria for the measure."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates a meaning for the group. This can be as simple as a unique identifier, or it can establish meaning in a broader context by drawing from a terminology, allowing groups to be correlated across measures.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    population: List_['MeasureGroupPopulation'] = Field(default_factory=list)
    'A population criteria for the measure.'
    stratifier: List_['MeasureGroupStratifier'] = Field(default_factory=list)
    'The stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.'
    description: Optional_['string'] = Field(default=None)
    'The human readable description of this population group.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureGroupStratifier(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates a meaning for the stratifier. This can be as simple as a unique identifier, or it can establish meaning in a broader context by drawing from a terminology, allowing stratifiers to be correlated across measures.'
    criteria: Optional_['Expression'] = Field(default=None)
    'An expression that specifies the criteria for the stratifier. This is typically the name of an expression defined within a referenced library, but it may also be a path to a stratifier element.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    component: List_['MeasureGroupStratifierComponent'] = Field(default_factory=list)
    'A component of the stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.'
    description: Optional_['string'] = Field(default=None)
    'The human readable description of this stratifier criteria.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureGroupStratifierComponent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A component of the stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates a meaning for the stratifier component. This can be as simple as a unique identifier, or it can establish meaning in a broader context by drawing from a terminology, allowing stratifiers to be correlated across measures.'
    criteria: 'Expression' = Field(default=...)
    'An expression that specifies the criteria for this component of the stratifier. This is typically the name of an expression defined within a referenced library, but it may also be a path to a stratifier element.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'The human readable description of this stratifier criteria component.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureGroupPopulation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A population criteria for the measure."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The type of population criteria.'
    criteria: 'Expression' = Field(default=...)
    'An expression that specifies the criteria for the population, typically the name of an expression in a library.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'The human readable description of this population criteria.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Measure(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The Measure resource provides the definition of a quality measure."""
    resourceType: Literal_['Measure'] = Field(default=...)
    'A quality measure definition'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this measure when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this measure is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the measure is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the measure. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'Indicates whether the measure is used to examine a process, an outcome over time, a patient-reported outcome, or a structure measure such as utilization.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the measure.'
    usage: Optional_['string'] = Field(default=None)
    'A detailed description, from a clinical perspective, of how the measure is used.'
    topic: List_['CodeableConcept'] = Field(default_factory=list)
    'Descriptive topics related to the content of the measure. Topics provide a high-level categorization grouping types of measures that can be useful for filtering and searching.'
    group: List_['MeasureGroup'] = Field(default_factory=list)
    'A group of population criteria for the measure.'
    status: 'code' = Field(default=...)
    'The status of this measure. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual or organization primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for internal coherence of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the measure when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the measure author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active artifacts.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this measure is needed and why it has been designed as it has.'
    library: List_['canonical'] = Field(default_factory=list)
    'A reference to a Library resource containing the formal logic used by the measure.'
    scoring: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates how the calculation is performed for the measure, including proportion, ratio, continuous-variable, and cohort. The value set is extensible, allowing additional measure scoring types to be represented.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    subtitle: Optional_['string'] = Field(default=None)
    'An explanatory or alternate title for the measure giving additional information about its content.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization responsible for officially endorsing the content for use in some setting.'
    guidance: Optional_['markdown'] = Field(default=None)
    'Additional guidance for the measure including how it can be used in a clinical context, and the intent of the measure.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the measure.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the measure and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the measure.'
    rationale: Optional_['markdown'] = Field(default=None)
    'Provides a succinct statement of the need for the measure. Usually includes statements pertaining to importance criterion: impact, gap in care, and evidence.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this measure when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    subjectCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The intended subjects for the measure. If this element is not provided, a Patient subject is assumed, but the subject of the measure can be anything.'
    subjectReference: Optional_['Reference'] = Field(default=None)
    'The intended subjects for the measure. If this element is not provided, a Patient subject is assumed, but the subject of the measure can be anything.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate measure instances.'
    disclaimer: Optional_['markdown'] = Field(default=None)
    'Notices and disclaimers regarding the use of the measure or related to intellectual property (such as code systems) referenced by the measure.'
    definition: List_['markdown'] = Field(default_factory=list)
    'Provides a description of an individual term used within the measure.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the measure from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this measure is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the measure is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    riskAdjustment: Optional_['string'] = Field(default=None)
    'A description of the risk adjustment factors that may impact the resulting score for the measure and how they may be accounted for when computing and reporting measure results.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the measure content was or is planned to be in active use.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Related artifacts such as additional documentation, justification, or bibliographic references.'
    rateAggregation: Optional_['string'] = Field(default=None)
    'Describes how to combine the information calculated, based on logic in each of several populations, into one summarized result.'
    compositeScoring: Optional_['CodeableConcept'] = Field(default=None)
    'If this is a composite measure, the scoring method used to combine the component measures to determine the composite score.'
    supplementalData: List_['MeasureSupplementalData'] = Field(default_factory=list)
    'The supplemental data criteria for the measure report, specified as either the name of a valid CQL expression within a referenced library, or a valid FHIR Resource Path.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    improvementNotation: Optional_['CodeableConcept'] = Field(default=None)
    'Information on whether an increase or decrease in score is the preferred result (e.g., a higher score indicates better quality OR a lower score indicates better quality OR quality is within a range).'
    clinicalRecommendationStatement: Optional_['markdown'] = Field(default=None)
    'Provides a summary of relevant clinical guidelines or other clinical recommendations supporting the measure.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the measure was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the measure changes.'


class MeasureReportGroup(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The results of the calculation, one for each population group in the measure."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The meaning of the population group as defined in the measure definition.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    population: List_['MeasureReportGroupPopulation'] = Field(default_factory=list)
    'The populations that make up the population group, one for each type of population appropriate for the measure.'
    stratifier: List_['MeasureReportGroupStratifier'] = Field(default_factory=list)
    'When a measure includes multiple stratifiers, there will be a stratifier group for each stratifier defined by the measure.'
    measureScore: Optional_['Quantity'] = Field(default=None)
    'The measure score for this population group, calculated as appropriate for the measure type and scoring method, and based on the contents of the populations defined in the group.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureReportGroupStratifier(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """When a measure includes multiple stratifiers, there will be a stratifier group for each stratifier defined by the measure."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'The meaning of this stratifier, as defined in the measure definition.'
    stratum: List_['MeasureReportGroupStratifierStratum'] = Field(default_factory=list)
    'This element contains the results for a single stratum within the stratifier. For example, when stratifying on administrative gender, there will be four strata, one for each possible gender value.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureReportGroupStratifierStratum(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This element contains the results for a single stratum within the stratifier. For example, when stratifying on administrative gender, there will be four strata, one for each possible gender value."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: Optional_['CodeableConcept'] = Field(default=None)
    'The value for this stratum, expressed as a CodeableConcept. When defining stratifiers on complex values, the value must be rendered such that the value for each stratum within the stratifier is unique.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    component: List_['MeasureReportGroupStratifierStratumComponent'] = Field(default_factory=list)
    'A stratifier component value.'
    population: List_['MeasureReportGroupStratifierStratumPopulation'] = Field(default_factory=list)
    'The populations that make up the stratum, one for each type of population appropriate to the measure.'
    measureScore: Optional_['Quantity'] = Field(default=None)
    'The measure score for this stratum, calculated as appropriate for the measure type and scoring method, and based on only the members of this stratum.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureReportGroupStratifierStratumPopulation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The populations that make up the stratum, one for each type of population appropriate to the measure."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The type of the population.'
    count: Optional_['integer'] = Field(default=None)
    'The number of members of the population in this stratum.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    subjectResults: Optional_['Reference'] = Field(default=None)
    'This element refers to a List of subject level MeasureReport resources, one for each subject in this population in this stratum.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureReportGroupStratifierStratumComponent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A stratifier component value."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'The code for the stratum component value.'
    value: 'CodeableConcept' = Field(default=...)
    'The stratum component value.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureReportGroupPopulation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The populations that make up the population group, one for each type of population appropriate for the measure."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The type of the population.'
    count: Optional_['integer'] = Field(default=None)
    'The number of members of the population.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    subjectResults: Optional_['Reference'] = Field(default=None)
    'This element refers to a List of subject level MeasureReport resources, one for each subject in this population.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MeasureReport(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The MeasureReport resource contains the results of the calculation of a measure; and optionally a reference to the resources involved in that calculation."""
    resourceType: Literal_['MeasureReport'] = Field(default=...)
    'Results of a measure evaluation'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'code' = Field(default=...)
    'The type of measure report. This may be an individual report, which provides the score for the measure for an individual member of the population; a subject-listing, which returns the list of members that meet the various criteria in the measure; a summary report, which returns a population count for each of the criteria in the measure; or a data-collection, which enables the MeasureReport to be used to exchange the data-of-interest for a quality measure.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date this measure report was generated.'
    group: List_['MeasureReportGroup'] = Field(default_factory=list)
    'The results of the calculation, one for each population group in the measure.'
    status: 'code' = Field(default=...)
    'The MeasureReport status. No data will be available until the MeasureReport status is complete.'
    period: 'Period' = Field(default=...)
    'The reporting period for which the report was calculated.'
    measure: 'canonical' = Field(default=...)
    'A reference to the Measure that was calculated to produce this report.'
    subject: Optional_['Reference'] = Field(default=None)
    'Optional subject identifying the individual or individuals the report is for.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    reporter: Optional_['Reference'] = Field(default=None)
    'The individual, location, or organization that is reporting the data.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this MeasureReport when it is represented in other formats or referenced in a specification, model, design or an instance.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    evaluatedResource: List_['Reference'] = Field(default_factory=list)
    'A reference to a Bundle containing the Resources that were used in the calculation of this measure.'
    improvementNotation: Optional_['CodeableConcept'] = Field(default=None)
    'Whether improvement in the measure is noted by an increase or decrease in the measure score.'


class Media(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A photo, video, or audio recording acquired or used in healthcare. The actual content may be inline or provided by direct reference."""
    resourceType: Literal_['Media'] = Field(default=...)
    'A photo, video, or audio recording acquired or used in healthcare. The actual content may be inline or provided by direct reference'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'A code that classifies whether the media is an image, video or audio recording or some other media category.'
    view: Optional_['CodeableConcept'] = Field(default=None)
    'The name of the imaging view e.g. Lateral or Antero-posterior (AP).'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments made about the media by the performer, subject or other participants.'
    width: Optional_['positiveInt'] = Field(default=None)
    'Width of the image in pixels (photo/video).'
    partOf: List_['Reference'] = Field(default_factory=list)
    'A larger event of which this particular event is a component or step.'
    status: 'code' = Field(default=...)
    'The current state of the {{title}}.'
    issued: Optional_['instant'] = Field(default=None)
    'The date and time this version of the media was made available to providers, typically after having been reviewed.'
    device: Optional_['Reference'] = Field(default=None)
    'The device used to collect the media.'
    height: Optional_['positiveInt'] = Field(default=None)
    'Height of the image in pixels (photo/video).'
    frames: Optional_['positiveInt'] = Field(default=None)
    'The number of frames in a photo. This is used with a multi-page fax, or an imaging acquisition context that takes multiple slices in a single image, or an animated gif. If there is more than one frame, this SHALL have a value in order to alert interface software that a multi-frame capable rendering widget is required.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A procedure that is fulfilled in whole or in part by the creation of this media.'
    subject: Optional_['Reference'] = Field(default=None)
    'Who/What this Media is a record of.'
    content: 'Attachment' = Field(default=...)
    'The actual content of the media - inline or by direct reference to the media source file.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    modality: Optional_['CodeableConcept'] = Field(default=None)
    'Details of the type of the media - usually, how it was acquired (what type of device). If images sourced from a DICOM system, are wrapped in a Media resource, then this is the modality.'
    operator: Optional_['Reference'] = Field(default=None)
    'The person who administered the collection of the image.'
    bodySite: Optional_['CodeableConcept'] = Field(default=None)
    "Indicates the site on the subject's body where the observation was made (i.e. the target site)."
    duration: Optional_['decimal'] = Field(default=None)
    'The duration of the recording in seconds - for audio and video.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The encounter that establishes the context for this media.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers associated with the image - these may include identifiers for the image itself, identifiers for the context of its collection (e.g. series ids) and context ids such as accession numbers or other workflow identifiers.'
    createdDateTime: Optional_['dateTime'] = Field(default=None)
    'The date and time(s) at which the media was collected.'
    createdPeriod: Optional_['Period'] = Field(default=None)
    'The date and time(s) at which the media was collected.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Describes why the event occurred in coded or textual form.'
    deviceName: Optional_['string'] = Field(default=None)
    'The name of the device / manufacturer of the device  that was used to make the recording.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationIngredient(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies a particular constituent of interest in the product."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    itemCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The actual ingredient - either a substance (simple ingredient) or another medication of a medication.'
    itemReference: Optional_['Reference'] = Field(default=None)
    'The actual ingredient - either a substance (simple ingredient) or another medication of a medication.'
    isActive: Optional_['boolean'] = Field(default=None)
    'Indication of whether this ingredient affects the therapeutic action of the drug.'
    strength: Optional_['Ratio'] = Field(default=None)
    'Specifies how many (or how much) of the items there are in this Medication.  For example, 250 mg per tablet.  This is expressed as a ratio where the numerator is 250mg and the denominator is 1 tablet.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationBatch(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information that only applies to packages (not products)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    lotNumber: Optional_['string'] = Field(default=None)
    'The assigned lot number of a batch of the specified product.'
    expirationDate: Optional_['dateTime'] = Field(default=None)
    'When this specific batch of product will expire.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Medication(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource is primarily used for the identification and definition of a medication for the purposes of prescribing, dispensing, and administering a medication as well as for making statements about medication use."""
    resourceType: Literal_['Medication'] = Field(default=...)
    'Definition of a Medication'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    form: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the form of the item.  Powder; tablets; capsule.'
    batch: Optional_['MedicationBatch'] = Field(default=None)
    'Information that only applies to packages (not products).'
    status: Optional_['code'] = Field(default=None)
    'A code to indicate if the medication is in active use.'
    amount: Optional_['Ratio'] = Field(default=None)
    'Specific amount of the drug in the packaged product.  For example, when specifying a product that has the same strength (For example, Insulin glargine 100 unit per mL solution for injection), this attribute provides additional clarification of the package amount (For example, 3 mL, 10mL, etc.).'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifier for this medication.'
    ingredient: List_['MedicationIngredient'] = Field(default_factory=list)
    'Identifies a particular constituent of interest in the product.'
    manufacturer: Optional_['Reference'] = Field(default=None)
    'Describes the details of the manufacturer of the medication product.  This is not intended to represent the distributor of a medication product.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code (or set of codes) that specify this medication, or a textual description if no code is available. Usage note: This could be a standard medication code such as a code from RxNorm, SNOMED CT, IDMP etc. It could also be a national or local formulary code, optionally with translations to other code systems.'


class MedicationAdministrationPerformer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates who or what performed the medication administration and how they were involved."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    actor: 'Reference' = Field(default=...)
    'Indicates who or what performed the medication administration.'
    function: Optional_['CodeableConcept'] = Field(default=None)
    'Distinguishes the type of involvement of the performer in the medication administration.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationAdministrationDosage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes the medication dosage information details e.g. dose, rate, site, route, etc."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    text: Optional_['string'] = Field(default=None)
    'Free text dosage can be used for cases where the dosage administered is too complex to code. When coded dosage is present, the free text dosage may still be present for display to humans.\r\rThe dosage instructions should reflect the dosage of the medication that was administered.'
    site: Optional_['CodeableConcept'] = Field(default=None)
    'A coded specification of the anatomic site where the medication first entered the body.  For example, "left arm".'
    dose: Optional_['Quantity'] = Field(default=None)
    'The amount of the medication given at one administration event.   Use this value when the administration is essentially an instantaneous event such as a swallowing a tablet or giving an injection.'
    route: Optional_['CodeableConcept'] = Field(default=None)
    'A code specifying the route or physiological path of administration of a therapeutic agent into or onto the patient.  For example, topical, intravenous, etc.'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'A coded value indicating the method by which the medication is intended to be or was introduced into or on the body.  This attribute will most often NOT be populated.  It is most commonly used for injections.  For example, Slow Push, Deep IV.'
    rateRatio: Optional_['Ratio'] = Field(default=None)
    'Identifies the speed with which the medication was or will be introduced into the patient.  Typically, the rate for an infusion e.g. 100 ml per 1 hour or 100 ml/hr.  May also be expressed as a rate per unit of time, e.g. 500 ml per 2 hours.  Other examples:  200 mcg/min or 200 mcg/1 minute; 1 liter/8 hours.'
    rateQuantity: Optional_['Quantity'] = Field(default=None)
    'Identifies the speed with which the medication was or will be introduced into the patient.  Typically, the rate for an infusion e.g. 100 ml per 1 hour or 100 ml/hr.  May also be expressed as a rate per unit of time, e.g. 500 ml per 2 hours.  Other examples:  200 mcg/min or 200 mcg/1 minute; 1 liter/8 hours.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationAdministration(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes the event of a patient consuming or otherwise being administered a medication.  This may be as simple as swallowing a tablet or it may be a long running infusion.  Related resources tie this event to the authorizing prescription, and the specific encounter between patient and health care practitioner."""
    resourceType: Literal_['MedicationAdministration'] = Field(default=...)
    'Administration of medication to a patient'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Extra information about the medication administration that is not conveyed by the other attributes.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'A larger event of which this particular event is a component or step.'
    status: 'code' = Field(default=...)
    'Will generally be set to show that the administration has been completed.  For some long running administrations such as infusions, it is possible for an administration to be started but not completed or it may be paused while some other process is under way.'
    device: List_['Reference'] = Field(default_factory=list)
    'The device used in administering the medication to the patient.  For example, a particular infusion pump.'
    dosage: Optional_['MedicationAdministrationDosage'] = Field(default=None)
    'Describes the medication dosage information details e.g. dose, rate, site, route, etc.'
    subject: 'Reference' = Field(default=...)
    'The person or animal or group receiving the medication.'
    context: Optional_['Reference'] = Field(default=None)
    'The visit, admission, or other contact between patient and health care provider during which the medication administration was performed.'
    request: Optional_['Reference'] = Field(default=None)
    'The original request, instruction or authority to perform the administration.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates where the medication is expected to be consumed or administered.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    performer: List_['MedicationAdministrationPerformer'] = Field(default_factory=list)
    'Indicates who or what performed the medication administration and how they were involved.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers associated with this Medication Administration that are defined by business processes and/or used to refer to it when a direct URL reference to the resource itself is not appropriate. They are business identifiers assigned to this resource by the performer or other systems and remain constant as the resource is updated and propagates from server to server.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'A code indicating why the medication was given.'
    instantiates: List_['uri'] = Field(default_factory=list)
    'A protocol, guideline, orderset, or other definition that was adhered to in whole or in part by this event.'
    statusReason: List_['CodeableConcept'] = Field(default_factory=list)
    'A code indicating why the administration was not performed.'
    effectiveDateTime: Optional_['dateTime'] = Field(default=None)
    "A specific date/time or interval of time during which the administration took place (or did not take place, when the 'notGiven' attribute is true). For many administrations, such as swallowing a tablet the use of dateTime is more appropriate."
    effectivePeriod: Optional_['Period'] = Field(default=None)
    "A specific date/time or interval of time during which the administration took place (or did not take place, when the 'notGiven' attribute is true). For many administrations, such as swallowing a tablet the use of dateTime is more appropriate."
    eventHistory: List_['Reference'] = Field(default_factory=list)
    'A summary of the events of interest that have occurred, such as when the administration was verified.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    medicationCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the medication that was administered. This is either a link to a resource representing the details of the medication or a simple attribute carrying a code that identifies the medication from a known list of medications.'
    medicationReference: Optional_['Reference'] = Field(default=None)
    'Identifies the medication that was administered. This is either a link to a resource representing the details of the medication or a simple attribute carrying a code that identifies the medication from a known list of medications.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Condition or observation that supports why the medication was administered.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    supportingInformation: List_['Reference'] = Field(default_factory=list)
    'Additional information (for example, patient height and weight) that supports the administration of the medication.'


class MedicationDispenseSubstitution(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates whether or not substitution was made as part of the dispense.  In some cases, substitution will be expected but does not happen, in other cases substitution is not expected but does happen.  This block explains what substitution did or did not happen and why.  If nothing is specified, substitution was not done."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'A code signifying whether a different drug was dispensed from what was prescribed.'
    reason: List_['CodeableConcept'] = Field(default_factory=list)
    'Indicates the reason for the substitution (or lack of substitution) from what was prescribed.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    wasSubstituted: 'boolean' = Field(default=...)
    'True if the dispenser dispensed a different drug or product from what was prescribed.'
    responsibleParty: List_['Reference'] = Field(default_factory=list)
    'The person or organization that has primary responsibility for the substitution.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationDispensePerformer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates who or what performed the event."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    actor: 'Reference' = Field(default=...)
    'The device, practitioner, etc. who performed the action.  It should be assumed that the actor is the dispenser of the medication.'
    function: Optional_['CodeableConcept'] = Field(default=None)
    'Distinguishes the type of performer in the dispense.  For example, date enterer, packager, final checker.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationDispense(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates that a medication product is to be or has been dispensed for a named person/patient.  This includes a description of the medication product (supply) provided and the instructions for administering the medication.  The medication dispense is the result of a pharmacy system responding to a medication order."""
    resourceType: Literal_['MedicationDispense'] = Field(default=...)
    'Dispensing a medication to a named patient'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the type of dispensing event that is performed. For example, Trial Fill, Completion of Trial, Partial Fill, Emergency Fill, Samples, etc.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Extra information about the dispense that could not be conveyed in the other attributes.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'The procedure that trigger the dispense.'
    status: 'code' = Field(default=...)
    'A code specifying the state of the set of dispense events.'
    subject: Optional_['Reference'] = Field(default=None)
    'A link to a resource representing the person or the group to whom the medication will be given.'
    context: Optional_['Reference'] = Field(default=None)
    'The encounter or episode of care that establishes the context for this event.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the type of medication dispense (for example, where the medication is expected to be consumed or administered (i.e. inpatient or outpatient)).'
    location: Optional_['Reference'] = Field(default=None)
    'The principal physical location where the dispense was performed.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The amount of medication that has been dispensed. Includes unit of measure.'
    receiver: List_['Reference'] = Field(default_factory=list)
    'Identifies the person who picked up the medication.  This will usually be a patient or their caregiver, but some cases exist where it can be a healthcare professional.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    performer: List_['MedicationDispensePerformer'] = Field(default_factory=list)
    'Indicates who or what performed the event.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers associated with this Medication Dispense that are defined by business processes and/or used to refer to it when a direct URL reference to the resource itself is not appropriate. They are business identifiers assigned to this resource by the performer or other systems and remain constant as the resource is updated and propagates from server to server.'
    daysSupply: Optional_['Quantity'] = Field(default=None)
    'The amount of medication expressed as a timing amount.'
    destination: Optional_['Reference'] = Field(default=None)
    'Identification of the facility/location where the medication was shipped to, as part of the dispense event.'
    whenPrepared: Optional_['dateTime'] = Field(default=None)
    'The time when the dispensed product was packaged and reviewed.'
    substitution: Optional_['MedicationDispenseSubstitution'] = Field(default=None)
    'Indicates whether or not substitution was made as part of the dispense.  In some cases, substitution will be expected but does not happen, in other cases substitution is not expected but does happen.  This block explains what substitution did or did not happen and why.  If nothing is specified, substitution was not done.'
    eventHistory: List_['Reference'] = Field(default_factory=list)
    'A summary of the events of interest that have occurred, such as when the dispense was verified.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    medicationCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the medication being administered. This is either a link to a resource representing the details of the medication or a simple attribute carrying a code that identifies the medication from a known list of medications.'
    medicationReference: Optional_['Reference'] = Field(default=None)
    'Identifies the medication being administered. This is either a link to a resource representing the details of the medication or a simple attribute carrying a code that identifies the medication from a known list of medications.'
    detectedIssue: List_['Reference'] = Field(default_factory=list)
    'Indicates an actual or potential clinical issue with or between one or more active or proposed clinical actions for a patient; e.g. drug-drug interaction, duplicate therapy, dosage alert etc.'
    whenHandedOver: Optional_['dateTime'] = Field(default=None)
    'The time the dispensed product was provided to the patient or their representative.'
    statusReasonCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the reason why a dispense was not performed.'
    statusReasonReference: Optional_['Reference'] = Field(default=None)
    'Indicates the reason why a dispense was not performed.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    dosageInstruction: List_['Dosage'] = Field(default_factory=list)
    'Indicates how the medication is to be used by the patient.'
    supportingInformation: List_['Reference'] = Field(default_factory=list)
    'Additional information that supports the medication being dispensed.'
    authorizingPrescription: List_['Reference'] = Field(default_factory=list)
    'Indicates the medication order that is being dispensed against.'


class MedicationKnowledgeRelatedMedicationKnowledge(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Associated or related knowledge about a medication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'The category of the associated medication knowledge reference.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    reference: List_['Reference'] = Field(default=...)
    'Associated documentation about the associated medication knowledge.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeAdministrationGuidelines(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Guidelines for the administration of the medication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    dosage: List_['MedicationKnowledgeAdministrationGuidelinesDosage'] = Field(default_factory=list)
    'Dosage for the medication for the specific guidelines.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    indicationCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Indication for use that apply to the specific administration guidelines.'
    indicationReference: Optional_['Reference'] = Field(default=None)
    'Indication for use that apply to the specific administration guidelines.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    patientCharacteristics: List_['MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics'] = Field(default_factory=list)
    'Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.).'


class MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    value: List_['string'] = Field(default_factory=list)
    'The specific characteristic (e.g. height, weight, gender, etc.).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    characteristicCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Specific characteristic that is relevant to the administration guideline (e.g. height, weight, gender).'
    characteristicQuantity: Optional_['Quantity'] = Field(default=None)
    'Specific characteristic that is relevant to the administration guideline (e.g. height, weight, gender).'


class MedicationKnowledgeAdministrationGuidelinesDosage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Dosage for the medication for the specific guidelines."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'The type of dosage (for example, prophylaxis, maintenance, therapeutic, etc.).'
    dosage: List_['Dosage'] = Field(default=...)
    'Dosage for the medication for the specific guidelines.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeMedicineClassification(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Categorization of the medication within a formulary or classification system."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'The type of category for the medication (for example, therapeutic classification, therapeutic sub-classification).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    classification: List_['CodeableConcept'] = Field(default_factory=list)
    'Specific category assigned to the medication (e.g. anti-infective, anti-hypertensive, antibiotic, etc.).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeDrugCharacteristic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies descriptive properties of the medicine, such as color, shape, imprints, etc."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'A code specifying which characteristic of the medicine is being described (for example, colour, shape, imprint).'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Description of the characteristic.'
    valueString: Optional_['string'] = Field(default=None)
    'Description of the characteristic.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'Description of the characteristic.'
    valueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'Description of the characteristic.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeMonitoringProgram(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The program under which the medication is reviewed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Type of program under which the medication is monitored.'
    name: Optional_['string'] = Field(default=None)
    'Name of the reviewing program.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeRegulatory(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Regulatory information about a medication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    schedule: List_['MedicationKnowledgeRegulatorySchedule'] = Field(default_factory=list)
    'Specifies the schedule of a medication in jurisdiction.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    maxDispense: Optional_['MedicationKnowledgeRegulatoryMaxDispense'] = Field(default=None)
    'The maximum number of units of the medication that can be dispensed in a period.'
    substitution: List_['MedicationKnowledgeRegulatorySubstitution'] = Field(default_factory=list)
    'Specifies if changes are allowed when dispensing a medication from a regulatory perspective.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    regulatoryAuthority: 'Reference' = Field(default=...)
    'The authority that is specifying the regulations.'


class MedicationKnowledgeRegulatorySubstitution(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies if changes are allowed when dispensing a medication from a regulatory perspective."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Specifies the type of substitution allowed.'
    allowed: 'boolean' = Field(default=...)
    'Specifies if regulation allows for changes in the medication when dispensing.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeRegulatoryMaxDispense(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The maximum number of units of the medication that can be dispensed in a period."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    period: Optional_['Duration'] = Field(default=None)
    'The period that applies to the maximum number of units.'
    quantity: 'Quantity' = Field(default=...)
    'The maximum number of units of the medication that can be dispensed.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeRegulatorySchedule(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies the schedule of a medication in jurisdiction."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    schedule: 'CodeableConcept' = Field(default=...)
    'Specifies the specific drug schedule.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeIngredient(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies a particular constituent of interest in the product."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    itemCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The actual ingredient - either a substance (simple ingredient) or another medication.'
    itemReference: Optional_['Reference'] = Field(default=None)
    'The actual ingredient - either a substance (simple ingredient) or another medication.'
    isActive: Optional_['boolean'] = Field(default=None)
    'Indication of whether this ingredient affects the therapeutic action of the drug.'
    strength: Optional_['Ratio'] = Field(default=None)
    'Specifies how many (or how much) of the items there are in this Medication.  For example, 250 mg per tablet.  This is expressed as a ratio where the numerator is 250mg and the denominator is 1 tablet.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgePackaging(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information that only applies to packages (not products)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'A code that defines the specific type of packaging that the medication can be found in (e.g. blister sleeve, tube, bottle).'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of product units the package would contain if fully loaded.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeMonograph(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Associated documentation about the medication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The category of documentation about the medication. (e.g. professional monograph, patient education monograph).'
    source: Optional_['Reference'] = Field(default=None)
    'Associated documentation about the medication.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeKinetics(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The time course of drug absorption, distribution, metabolism and excretion of a medication from the body."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    lethalDose50: List_['Quantity'] = Field(default_factory=list)
    'The median lethal dose of a drug.'
    areaUnderCurve: List_['Quantity'] = Field(default_factory=list)
    'The drug concentration measured at certain discrete points in time.'
    halfLifePeriod: Optional_['Duration'] = Field(default=None)
    'The time required for any specified property (e.g., the concentration of a substance in the body) to decrease by half.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledgeCost(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The price of the medication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    "The category of the cost information.  For example, manufacturers' cost, patient cost, claim reimbursement cost, actual acquisition cost."
    cost: 'Money' = Field(default=...)
    'The price of the medication.'
    source: Optional_['string'] = Field(default=None)
    'The source or owner that assigns the price to the medication.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationKnowledge(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about a medication that is used to support knowledge."""
    resourceType: Literal_['MedicationKnowledge'] = Field(default=...)
    'Definition of Medication Knowledge'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    cost: List_['MedicationKnowledgeCost'] = Field(default_factory=list)
    'The price of the medication.'
    status: Optional_['code'] = Field(default=None)
    'A code to indicate if the medication is in active use.  The status refers to the validity about the information of the medication and not to its medicinal properties.'
    amount: Optional_['Quantity'] = Field(default=None)
    'Specific amount of the drug in the packaged product.  For example, when specifying a product that has the same strength (For example, Insulin glargine 100 unit per mL solution for injection), this attribute provides additional clarification of the package amount (For example, 3 mL, 10mL, etc.).'
    synonym: List_['string'] = Field(default_factory=list)
    'Additional names for a medication, for example, the name(s) given to a medication in different countries.  For example, acetaminophen and paracetamol or salbutamol and albuterol.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    doseForm: Optional_['CodeableConcept'] = Field(default=None)
    'Describes the form of the item.  Powder; tablets; capsule.'
    kinetics: List_['MedicationKnowledgeKinetics'] = Field(default_factory=list)
    'The time course of drug absorption, distribution, metabolism and excretion of a medication from the body.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    monograph: List_['MedicationKnowledgeMonograph'] = Field(default_factory=list)
    'Associated documentation about the medication.'
    packaging: Optional_['MedicationKnowledgePackaging'] = Field(default=None)
    'Information that only applies to packages (not products).'
    ingredient: List_['MedicationKnowledgeIngredient'] = Field(default_factory=list)
    'Identifies a particular constituent of interest in the product.'
    regulatory: List_['MedicationKnowledgeRegulatory'] = Field(default_factory=list)
    'Regulatory information about a medication.'
    productType: List_['CodeableConcept'] = Field(default_factory=list)
    'Category of the medication or product (e.g. branded product, therapeutic moeity, generic product, innovator product, etc.).'
    manufacturer: Optional_['Reference'] = Field(default=None)
    'Describes the details of the manufacturer of the medication product.  This is not intended to represent the distributor of a medication product.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    intendedRoute: List_['CodeableConcept'] = Field(default_factory=list)
    'The intended or approved route of administration.'
    contraindication: List_['Reference'] = Field(default_factory=list)
    'Potential clinical issue with or between medication(s) (for example, drug-drug interaction, drug-disease contraindication, drug-allergy interaction, etc.).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    monitoringProgram: List_['MedicationKnowledgeMonitoringProgram'] = Field(default_factory=list)
    'The program under which the medication is reviewed.'
    drugCharacteristic: List_['MedicationKnowledgeDrugCharacteristic'] = Field(default_factory=list)
    'Specifies descriptive properties of the medicine, such as color, shape, imprints, etc.'
    associatedMedication: List_['Reference'] = Field(default_factory=list)
    'Associated or related medications.  For example, if the medication is a branded product (e.g. Crestor), this is the Therapeutic Moeity (e.g. Rosuvastatin) or if this is a generic medication (e.g. Rosuvastatin), this would link to a branded product (e.g. Crestor).'
    preparationInstruction: Optional_['markdown'] = Field(default=None)
    'The instructions for preparing the medication.'
    medicineClassification: List_['MedicationKnowledgeMedicineClassification'] = Field(default_factory=list)
    'Categorization of the medication within a formulary or classification system.'
    administrationGuidelines: List_['MedicationKnowledgeAdministrationGuidelines'] = Field(default_factory=list)
    'Guidelines for the administration of the medication.'
    relatedMedicationKnowledge: List_['MedicationKnowledgeRelatedMedicationKnowledge'] = Field(default_factory=list)
    'Associated or related knowledge about a medication.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code that specifies this medication, or a textual description if no code is available. Usage note: This could be a standard medication code such as a code from RxNorm, SNOMED CT, IDMP etc. It could also be a national or local formulary code, optionally with translations to other code systems.'


class MedicationRequestDispenseRequest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The amount that is to be dispensed for one fill.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    performer: Optional_['Reference'] = Field(default=None)
    'Indicates the intended dispensing Organization specified by the prescriber.'
    initialFill: Optional_['MedicationRequestDispenseRequestInitialFill'] = Field(default=None)
    'Indicates the quantity or duration for the first dispense of the medication.'
    validityPeriod: Optional_['Period'] = Field(default=None)
    'This indicates the validity period of a prescription (stale dating the Prescription).'
    dispenseInterval: Optional_['Duration'] = Field(default=None)
    'The minimum period of time that must occur between dispenses of the medication.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    numberOfRepeatsAllowed: Optional_['unsignedInt'] = Field(default=None)
    'An integer indicating the number of times, in addition to the original dispense, (aka refills or repeats) that the patient can receive the prescribed medication. Usage Notes: This integer does not include the original order dispense. This means that if an order indicates dispense 30 tablets plus "3 repeats", then the order can be dispensed a total of 4 times and the patient can receive a total of 120 tablets.  A prescriber may explicitly say that zero refills are permitted after the initial dispense.'
    expectedSupplyDuration: Optional_['Duration'] = Field(default=None)
    'Identifies the period time over which the supplied product is expected to be used, or the length of time the dispense is expected to last.'


class MedicationRequestDispenseRequestInitialFill(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates the quantity or duration for the first dispense of the medication."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The amount or quantity to provide as part of the first dispense.'
    duration: Optional_['Duration'] = Field(default=None)
    'The length of time that the first dispense is expected to last.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationRequestSubstitution(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    reason: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the reason for the substitution, or why substitution must or must not be performed.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    allowedBoolean: Optional_['boolean'] = Field(default=None)
    'True if the prescriber allows a different drug to be dispensed from what was prescribed.'
    allowedCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'True if the prescriber allows a different drug to be dispensed from what was prescribed.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicationRequest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An order or request for both supply of the medication and the instructions for administration of the medication to a patient. The resource is called "MedicationRequest" rather than "MedicationPrescription" or "MedicationOrder" to generalize the use across inpatient and outpatient settings, including care plans, etc., and to harmonize with workflow patterns."""
    resourceType: Literal_['MedicationRequest'] = Field(default=...)
    'Ordering of medication for patient or group'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Extra information about the prescription that could not be conveyed by the other attributes.'
    status: 'code' = Field(default=...)
    'A code specifying the current state of the order.  Generally, this will be active or completed state.'
    intent: 'code' = Field(default=...)
    'Whether the request is a proposal, plan, or an original order.'
    subject: 'Reference' = Field(default=...)
    'A link to a resource representing the person or set of individuals to whom the medication will be given.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A plan or request that is fulfilled in whole or in part by this medication request.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'Indicates the type of medication request (for example, where the medication is expected to be consumed or administered (i.e. inpatient or outpatient)).'
    priority: Optional_['code'] = Field(default=None)
    'Indicates how quickly the Medication Request should be addressed with respect to other requests.'
    recorder: Optional_['Reference'] = Field(default=None)
    'The person who entered the order on behalf of another individual for example in the case of a verbal or a telephone order.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which this [x] was created or to which the creation of this record is tightly associated.'
    requester: Optional_['Reference'] = Field(default=None)
    'The individual, organization, or device that initiated the request and has responsibility for its activation.'
    performer: Optional_['Reference'] = Field(default=None)
    'The specified desired performer of the medication treatment (e.g. the performer of the medication administration).'
    insurance: List_['Reference'] = Field(default_factory=list)
    'Insurance plans, coverage extensions, pre-authorizations and/or pre-determinations that may be required for delivering the requested service.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers associated with this medication request that are defined by business processes and/or used to refer to it when a direct URL reference to the resource itself is not appropriate. They are business identifiers assigned to this resource by the performer or other systems and remain constant as the resource is updated and propagates from server to server.'
    authoredOn: Optional_['dateTime'] = Field(default=None)
    'The date (and perhaps time) when the prescription was initially written or authored on.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'The reason or the indication for ordering or not ordering the medication.'
    reportedBoolean: Optional_['boolean'] = Field(default=None)
    "Indicates if this record was captured as a secondary 'reported' record rather than as an original primary source-of-truth record.  It may also indicate the source of the report."
    reportedReference: Optional_['Reference'] = Field(default=None)
    "Indicates if this record was captured as a secondary 'reported' record rather than as an original primary source-of-truth record.  It may also indicate the source of the report."
    statusReason: Optional_['CodeableConcept'] = Field(default=None)
    'Captures the reason for the current state of the MedicationRequest.'
    doNotPerform: Optional_['boolean'] = Field(default=None)
    'If true indicates that the provider is asking for the medication request not to occur.'
    substitution: Optional_['MedicationRequestSubstitution'] = Field(default=None)
    "Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done."
    eventHistory: List_['Reference'] = Field(default_factory=list)
    'Links to Provenance records for past versions of this resource or fulfilling request or event resources that identify key state transitions or updates that are likely to be relevant to a user looking at the current version of the resource.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    medicationCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the medication being requested. This is a link to a resource that represents the medication which may be the details of the medication or simply an attribute carrying a code that identifies the medication from a known list of medications.'
    medicationReference: Optional_['Reference'] = Field(default=None)
    'Identifies the medication being requested. This is a link to a resource that represents the medication which may be the details of the medication or simply an attribute carrying a code that identifies the medication from a known list of medications.'
    performerType: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the type of performer of the administration of the medication.'
    detectedIssue: List_['Reference'] = Field(default_factory=list)
    'Indicates an actual or potential clinical issue with or between one or more active or proposed clinical actions for a patient; e.g. Drug-drug interaction, duplicate therapy, dosage alert etc.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Condition or observation that supports why the medication was ordered.'
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally maintained protocol, guideline, orderset or other definition that is adhered to in whole or in part by this MedicationRequest.'
    groupIdentifier: Optional_['Identifier'] = Field(default=None)
    'A shared identifier common to all requests that were authorized more or less simultaneously by a single author, representing the identifier of the requisition or prescription.'
    dispenseRequest: Optional_['MedicationRequestDispenseRequest'] = Field(default=None)
    'Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    dosageInstruction: List_['Dosage'] = Field(default_factory=list)
    'Indicates how the medication is to be used by the patient.'
    priorPrescription: Optional_['Reference'] = Field(default=None)
    'A link to a resource representing an earlier order related order or prescription.'
    courseOfTherapyType: Optional_['CodeableConcept'] = Field(default=None)
    'The description of the overall patte3rn of the administration of the medication to the patient.'
    supportingInformation: List_['Reference'] = Field(default_factory=list)
    'Include additional information (for example, patient height and weight) that supports the ordering of the medication.'
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'The URL pointing to a protocol, guideline, orderset, or other definition that is adhered to in whole or in part by this MedicationRequest.'


class MedicationStatement(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A record of a medication that is being consumed by a patient.   A MedicationStatement may indicate that the patient may be taking the medication now or has taken the medication in the past or will be taking the medication in the future.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay.   The medication information may come from sources such as the patient's memory, from a prescription bottle,  or from a list of medications the patient, clinician or other party maintains. 

The primary difference between a medication statement and a medication administration is that the medication administration has complete administration information and is based on actual administration information from the person who administered the medication.  A medication statement is often, if not always, less specific.  There is no required date/time when the medication was administered, in fact we only know that a source has reported the patient is taking this medication, where details such as time, quantity, or rate or even medication product may be incomplete or missing or less precise.  As stated earlier, the medication statement information may come from the patient's memory, from a prescription bottle or from a list of medications the patient, clinician or other party maintains.  Medication administration is more formal and is not missing detailed information."""
    resourceType: Literal_['MedicationStatement'] = Field(default=...)
    'Record of medication being taken by a patient'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Provides extra information about the medication statement that is not conveyed by the other attributes.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'A larger event of which this particular event is a component or step.'
    status: 'code' = Field(default=...)
    "A code representing the patient or other source's judgment about the state of the medication used that this statement is about.  Generally, this will be active or completed."
    dosage: List_['Dosage'] = Field(default_factory=list)
    'Indicates how the medication is/was or should be taken by the patient.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A plan, proposal or order that is fulfilled in whole or in part by this event.'
    subject: 'Reference' = Field(default=...)
    'The person, animal or group who is/was taking the medication.'
    context: Optional_['Reference'] = Field(default=None)
    'The encounter or episode of care that establishes the context for this MedicationStatement.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates where the medication is expected to be consumed or administered.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers associated with this Medication Statement that are defined by business processes and/or used to refer to it when a direct URL reference to the resource itself is not appropriate. They are business identifiers assigned to this resource by the performer or other systems and remain constant as the resource is updated and propagates from server to server.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'A reason for why the medication is being/was taken.'
    derivedFrom: List_['Reference'] = Field(default_factory=list)
    'Allows linking the MedicationStatement to the underlying MedicationRequest, or to other information that supports or is used to derive the MedicationStatement.'
    statusReason: List_['CodeableConcept'] = Field(default_factory=list)
    'Captures the reason for the current state of the MedicationStatement.'
    effectiveDateTime: Optional_['dateTime'] = Field(default=None)
    'The interval of time during which it is being asserted that the patient is/was/will be taking the medication (or was not taking, when the MedicationStatement.taken element is No).'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The interval of time during which it is being asserted that the patient is/was/will be taking the medication (or was not taking, when the MedicationStatement.taken element is No).'
    dateAsserted: Optional_['dateTime'] = Field(default=None)
    'The date when the medication statement was asserted by the information source.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    medicationCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the medication being administered. This is either a link to a resource representing the details of the medication or a simple attribute carrying a code that identifies the medication from a known list of medications.'
    medicationReference: Optional_['Reference'] = Field(default=None)
    'Identifies the medication being administered. This is either a link to a resource representing the details of the medication or a simple attribute carrying a code that identifies the medication from a known list of medications.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Condition or observation that supports why the medication is being/was taken.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    informationSource: Optional_['Reference'] = Field(default=None)
    'The person or organization that provided the information about the taking of this medication. Note: Use derivedFrom when a MedicationStatement is derived from other resources, e.g. Claim or MedicationRequest.'


class MedicinalProductDefinitionCharacteristic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Allows the key product features to be recorded, such as "sugar free", "modified release", "parallel import"."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'A code expressing the type of characteristic.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A value for the characteristic.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'A value for the characteristic.'
    valueDate: Optional_['date'] = Field(default=None)
    'A value for the characteristic.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'A value for the characteristic.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'A value for the characteristic.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicinalProductDefinitionCrossReference(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Reference to another product, e.g. for linking authorised to investigational product, or a virtual product."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of relationship, for instance branded to generic, virtual to actual product, product to development product (investigational), parallel import version.'
    product: 'CodeableReference' = Field(default=...)
    'Reference to another product, e.g. for linking authorised to investigational product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicinalProductDefinitionOperation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A manufacturing or administrative process or step associated with (or performed on) the medicinal product."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableReference'] = Field(default=None)
    'The type of manufacturing operation e.g. manufacturing itself, re-packaging. For the authorization of this, a RegulatedAuthorization would point to the same plan or activity referenced here.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    organization: List_['Reference'] = Field(default_factory=list)
    'The organization or establishment responsible for (or associated with) the particular process or step, examples include the manufacturer, importer, agent.'
    effectiveDate: Optional_['Period'] = Field(default=None)
    'Date range of applicability.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    confidentialityIndicator: Optional_['CodeableConcept'] = Field(default=None)
    'Specifies whether this particular business or manufacturing process is considered proprietary or confidential.'


class MedicinalProductDefinitionContact(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A product specific contact, person (in a role), or an organization."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Allows the contact to be classified, for example QPPV, Pharmacovigilance Enquiry Information.'
    contact: 'Reference' = Field(default=...)
    'A product specific contact, person (in a role), or an organization.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicinalProductDefinitionName(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The product's name, including full name and possibly coded parts."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Type of product name, such as rINN, BAN, Proprietary, Non-Proprietary.'
    namePart: List_['MedicinalProductDefinitionNameNamePart'] = Field(default_factory=list)
    'Coding words or phrases of the name.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    productName: 'string' = Field(default=...)
    'The full product name.'
    countryLanguage: List_['MedicinalProductDefinitionNameCountryLanguage'] = Field(default_factory=list)
    'Country and jurisdiction where the name applies, and associated language.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicinalProductDefinitionNameCountryLanguage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Country and jurisdiction where the name applies, and associated language."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    country: 'CodeableConcept' = Field(default=...)
    'Country code for where this name applies.'
    language: 'CodeableConcept' = Field(default=...)
    'Language code for this name.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    jurisdiction: Optional_['CodeableConcept'] = Field(default=None)
    'Jurisdiction code for where this name applies. A jurisdiction may be a sub- or supra-national entity (e.g. a state or a geographic region).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicinalProductDefinitionNameNamePart(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Coding words or phrases of the name."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    part: 'string' = Field(default=...)
    'A fragment of a product name.'
    type: 'CodeableConcept' = Field(default=...)
    'Identifying type for this part of the name (e.g. strength part).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MedicinalProductDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A medicinal product, being a substance or combination of substances that is intended to treat, prevent or diagnose a disease, or to restore, correct or modify physiological functions by exerting a pharmacological, immunological or metabolic action. This resource is intended to define and detail such products and their properties, for uses other than direct patient care (e.g. regulatory use, or drug catalogs)."""
    resourceType: Literal_['MedicinalProductDefinition'] = Field(default=...)
    'Detailed definition of a medicinal product'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Regulatory type, e.g. Investigational or Authorized.'
    name: List_['MedicinalProductDefinitionName'] = Field(default=...)
    "The product's name, including full name and possibly coded parts."
    route: List_['CodeableConcept'] = Field(default_factory=list)
    'The path by which the product is taken into or makes contact with the body. In some regions this is referred to as the licenced or approved route. See also AdministrableProductDefinition resource. MedicinalProductDefinition.route is the same concept as AdministrableProductDefinition.routeOfAdministration.code, and they cannot be used together.'
    domain: Optional_['CodeableConcept'] = Field(default=None)
    'If this medicine applies to human or veterinary uses.'
    status: Optional_['CodeableConcept'] = Field(default=None)
    'The status within the lifecycle of this product record. A high-level status, this is not intended to duplicate details carried elsewhere such as legal status, or authorization status.'
    version: Optional_['string'] = Field(default=None)
    'A business identifier relating to a specific version of the product, this is commonly used to support revisions to an existing product.'
    contact: List_['MedicinalProductDefinitionContact'] = Field(default_factory=list)
    'A product specific contact, person (in a role), or an organization.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    impurity: List_['CodeableReference'] = Field(default_factory=list)
    'Any component of the drug product which is not the chemical entity defined as the drug substance, or an excipient in the drug product. This includes process-related impurities and contaminants, product-related impurities including degradation products.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: List_['MedicinalProductDefinitionOperation'] = Field(default_factory=list)
    'A manufacturing or administrative process or step associated with (or performed on) the medicinal product.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifier for this product. Could be an MPID. When in development or being regulated, products are typically referenced by official identifiers, assigned by a manufacturer or regulator, and unique to a product (which, when compared to a product instance being prescribed, is actually a product type). See also MedicinalProductDefinition.code.'
    statusDate: Optional_['dateTime'] = Field(default=None)
    'The date at which the given status became applicable.'
    indication: Optional_['markdown'] = Field(default=None)
    'Description of indication(s) for this product, used when structured indications are not required. In cases where structured indications are required, they are captured using the ClinicalUseDefinition resource. An indication is a medical situation for which using the product is appropriate.'
    ingredient: List_['CodeableConcept'] = Field(default_factory=list)
    'The ingredients of this medicinal product - when not detailed in other resources. This is only needed if the ingredients are not specified by incoming references from the Ingredient resource, or indirectly via incoming AdministrableProductDefinition, PackagedProductDefinition or ManufacturedItemDefinition references. In cases where those levels of detail are not used, the ingredients may be specified directly here as codes.'
    masterFile: List_['Reference'] = Field(default_factory=list)
    'A master file for the medicinal product (e.g. Pharmacovigilance System Master File). Drug master files (DMFs) are documents submitted to regulatory agencies to provide confidential detailed information about facilities, processes or articles used in the manufacturing, processing, packaging and storing of drug products.'
    description: Optional_['markdown'] = Field(default=None)
    'General description of this product.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    clinicalTrial: List_['Reference'] = Field(default_factory=list)
    'Clinical trials or studies that this product is involved in.'
    classification: List_['CodeableConcept'] = Field(default_factory=list)
    'Allows the product to be classified by various systems, commonly WHO ATC.'
    crossReference: List_['MedicinalProductDefinitionCrossReference'] = Field(default_factory=list)
    'Reference to another product, e.g. for linking authorised to investigational product, or a virtual product.'
    characteristic: List_['MedicinalProductDefinitionCharacteristic'] = Field(default_factory=list)
    'Allows the key product features to be recorded, such as "sugar free", "modified release", "parallel import".'
    specialMeasures: List_['CodeableConcept'] = Field(default_factory=list)
    'Whether the Medicinal Product is subject to special measures for regulatory reasons, such as a requirement to conduct post-authorisation studies.'
    marketingStatus: List_['MarketingStatus'] = Field(default_factory=list)
    "Marketing status of the medicinal product, in contrast to marketing authorization. This refers to the product being actually 'on the market' as opposed to being allowed to be on the market (which is an authorization)."
    attachedDocument: List_['Reference'] = Field(default_factory=list)
    'Additional information or supporting documentation about the medicinal product.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    legalStatusOfSupply: Optional_['CodeableConcept'] = Field(default=None)
    'The legal status of supply of the medicinal product as classified by the regulator.'
    pediatricUseIndicator: Optional_['CodeableConcept'] = Field(default=None)
    'If authorised for use in children, or infants, neonates etc.'
    packagedMedicinalProduct: List_['CodeableConcept'] = Field(default_factory=list)
    'Package type for the product. See also the PackagedProductDefinition resource.'
    additionalMonitoringIndicator: Optional_['CodeableConcept'] = Field(default=None)
    'Whether the Medicinal Product is subject to additional monitoring for regulatory reasons, such as heightened reporting requirements.'
    combinedPharmaceuticalDoseForm: Optional_['CodeableConcept'] = Field(default=None)
    'The dose form for a single part product, or combined form of a multiple part product. This is one concept that describes all the components. It does not represent the form with components physically mixed, if that might be necessary, for which see (AdministrableProductDefinition.administrableDoseForm).'
    code: List_['Coding'] = Field(default_factory=list)
    'A code that this product is known by, usually within some formal terminology, perhaps assigned by a third party (i.e. not the manufacturer or regulator). Products (types of medications) tend to be known by identifiers during development and within regulatory process. However when they are prescribed they tend to be identified by codes. The same product may be have multiple codes, applied to it by multiple organizations.'


class MessageDefinitionAllowedResponse(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates what types of messages may be sent as an application-level response to this message."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    message: 'canonical' = Field(default=...)
    'A reference to the message definition that must be adhered to by this supported response.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    situation: Optional_['markdown'] = Field(default=None)
    'Provides a description of the circumstances in which this response should be used (as opposed to one of the alternative responses).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MessageDefinitionFocus(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies the resource (or resources) that are being addressed by the event.  For example, the Encounter for an admit message or two Account records for a merge."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    min: 'unsignedInt' = Field(default=...)
    'Identifies the minimum number of resources of this type that must be pointed to by a message in order for it to be valid against this MessageDefinition.'
    max: Optional_['string'] = Field(default=None)
    'Identifies the maximum number of resources of this type that must be pointed to by a message in order for it to be valid against this MessageDefinition.'
    profile: Optional_['canonical'] = Field(default=None)
    'A profile that reflects constraints for the focal resource (and potentially for related resources).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'The kind of resource that must be the focus for this message.'


class MessageDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Defines the characteristics of a message that can be shared between systems, including the type of event that initiates the message, the content to be transmitted and what response(s), if any, are permitted."""
    resourceType: Literal_['MessageDefinition'] = Field(default=...)
    'A resource that defines a type of message that can be exchanged between systems'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'The business identifier that is used to reference the MessageDefinition and *is* expected to be consistent from server to server.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the message definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: 'dateTime' = Field(default=...)
    'The date  (and optionally time) when the message definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the message definition changes.'
    base: Optional_['canonical'] = Field(default=None)
    'The MessageDefinition that is the basis for the contents of this resource.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the message definition.'
    focus: List_['MessageDefinitionFocus'] = Field(default_factory=list)
    'Identifies the resource (or resources) that are being addressed by the event.  For example, the Encounter for an admit message or two Account records for a merge.'
    graph: List_['canonical'] = Field(default_factory=list)
    'Canonical reference to a GraphDefinition. If a URL is provided, it is the canonical reference to a [GraphDefinition](graphdefinition.html) that it controls what resources are to be added to the bundle when building the document. The GraphDefinition can also specify profiles that apply to the various resources.'
    status: 'code' = Field(default=...)
    'The status of this message definition. Enables tracking the life-cycle of the content.'
    parent: List_['canonical'] = Field(default_factory=list)
    'Identifies a protocol or workflow that this MessageDefinition represents a step in.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the message definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the message definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this message definition is needed and why it has been designed as it has.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    replaces: List_['canonical'] = Field(default_factory=list)
    'A MessageDefinition that is superseded by this definition.'
    eventCoding: Optional_['Coding'] = Field(default=None)
    'Event code or link to the EventDefinition.'
    eventUri: Optional_['uri'] = Field(default=None)
    'Event code or link to the EventDefinition.'
    category: Optional_['code'] = Field(default=None)
    'The impact of the content of the message.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the message definition.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the message definition and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the message definition.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this message definition when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate message definition instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the message definition from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this message definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the message definition is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    allowedResponse: List_['MessageDefinitionAllowedResponse'] = Field(default_factory=list)
    'Indicates what types of messages may be sent as an application-level response to this message.'
    responseRequired: Optional_['code'] = Field(default=None)
    'Declare at a message definition level whether a response is required or only upon error or success, or never.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MessageHeaderDestination(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The destination application which the message is intended for."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'Human-readable name for the target system.'
    target: Optional_['Reference'] = Field(default=None)
    'Identifies the target end system in situations where the initial message transmission is to an intermediary system.'
    endpoint: 'url' = Field(default=...)
    'Indicates where the message should be routed to.'
    receiver: Optional_['Reference'] = Field(default=None)
    "Allows data conveyed by a message to be addressed to a particular person or department when routing to a specific application isn't sufficient."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MessageHeaderResponse(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the message that this message is a response to.  Only present if this message is a response."""
    details: Optional_['Reference'] = Field(default=None)
    'Full details of any issues found in the message.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: 'id' = Field(default=...)
    'The MessageHeader.id of the message to which this message is a response.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'code' = Field(default=...)
    'Code that identifies the type of response to the message - whether it was successful or not, and whether it should be resent or not.'


class MessageHeaderSource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The source application from which this message originated."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'Human-readable name for the source system.'
    version: Optional_['string'] = Field(default=None)
    'Can convey versions of multiple systems in situations where a message passes through multiple hands.'
    contact: Optional_['ContactPoint'] = Field(default=None)
    'An e-mail, phone, website or other contact point to use to resolve issues with message communications.'
    software: Optional_['string'] = Field(default=None)
    'May include configuration or other information useful in debugging.'
    endpoint: 'url' = Field(default=...)
    'Identifies the routing target to send acknowledgements to.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MessageHeader(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The header for a message exchange that is either requesting or responding to an action.  The reference(s) that are the subject of the action as well as other information related to the action are typically transmitted in a bundle in which the MessageHeader resource instance is the first resource in the bundle."""
    resourceType: Literal_['MessageHeader'] = Field(default=...)
    'A resource that describes a message that is exchanged between systems'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    focus: List_['Reference'] = Field(default_factory=list)
    'The actual data of the message - a reference to the root/focus class of the event.'
    sender: Optional_['Reference'] = Field(default=None)
    'Identifies the sending system to allow the use of a trust relationship.'
    author: Optional_['Reference'] = Field(default=None)
    'The logical author of the message - the person or device that decided the described event should happen. When there is more than one candidate, pick the most proximal to the MessageHeader. Can provide other authors in extensions.'
    source: 'MessageHeaderSource' = Field(default=...)
    'The source application from which this message originated.'
    reason: Optional_['CodeableConcept'] = Field(default=None)
    'Coded indication of the cause for the event - indicates  a reason for the occurrence of the event that is a focus of this message.'
    enterer: Optional_['Reference'] = Field(default=None)
    'The person or device that performed the data entry leading to this message. When there is more than one candidate, pick the most proximal to the message. Can provide other enterers in extensions.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    eventCoding: Optional_['Coding'] = Field(default=None)
    'Code that identifies the event this message represents and connects it with its definition. Events defined as part of the FHIR specification have the system value "http://terminology.hl7.org/CodeSystem/message-events".  Alternatively uri to the EventDefinition.'
    eventUri: Optional_['uri'] = Field(default=None)
    'Code that identifies the event this message represents and connects it with its definition. Events defined as part of the FHIR specification have the system value "http://terminology.hl7.org/CodeSystem/message-events".  Alternatively uri to the EventDefinition.'
    response: Optional_['MessageHeaderResponse'] = Field(default=None)
    'Information about the message that this message is a response to.  Only present if this message is a response.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    definition: Optional_['canonical'] = Field(default=None)
    'Permanent link to the MessageDefinition for this message.'
    destination: List_['MessageHeaderDestination'] = Field(default_factory=list)
    'The destination application which the message is intended for.'
    responsible: Optional_['Reference'] = Field(default=None)
    'The person or organization that accepts overall responsibility for the contents of the message. The implication is that the message event happened under the policies of the responsible party.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MolecularSequenceStructureVariant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about chromosome structure variation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    exact: Optional_['boolean'] = Field(default=None)
    'Used to indicate if the outer and inner start-end values have the same meaning.'
    outer: Optional_['MolecularSequenceStructureVariantOuter'] = Field(default=None)
    'Structural variant outer.'
    inner: Optional_['MolecularSequenceStructureVariantInner'] = Field(default=None)
    'Structural variant inner.'
    length: Optional_['integer'] = Field(default=None)
    'Length of the variant chromosome.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    variantType: Optional_['CodeableConcept'] = Field(default=None)
    'Information about chromosome structure variation DNA change type.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MolecularSequenceStructureVariantInner(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Structural variant inner."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    end: Optional_['integer'] = Field(default=None)
    'Structural variant inner end. If the coordinate system is 0-based then end is exclusive and does not include the last position. If the coordinate system is 1-base, then end is inclusive and includes the last position.'
    start: Optional_['integer'] = Field(default=None)
    'Structural variant inner start. If the coordinate system is either 0-based or 1-based, then start position is inclusive.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MolecularSequenceStructureVariantOuter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Structural variant outer."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    end: Optional_['integer'] = Field(default=None)
    'Structural variant outer end. If the coordinate system is 0-based then end is exclusive and does not include the last position. If the coordinate system is 1-base, then end is inclusive and includes the last position.'
    start: Optional_['integer'] = Field(default=None)
    'Structural variant outer start. If the coordinate system is either 0-based or 1-based, then start position is inclusive.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MolecularSequenceReferenceSeq(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A sequence that is used as a reference to describe variants that are present in a sequence analyzed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    strand: Optional_['code'] = Field(default=None)
    "An absolute reference to a strand. The Watson strand is the strand whose 5'-end is on the short arm of the chromosome, and the Crick strand as the one whose 5'-end is on the long arm."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    windowEnd: Optional_['integer'] = Field(default=None)
    'End position of the window on the reference sequence. If the coordinate system is 0-based then end is exclusive and does not include the last position. If the coordinate system is 1-base, then end is inclusive and includes the last position.'
    chromosome: Optional_['CodeableConcept'] = Field(default=None)
    'Structural unit composed of a nucleic acid molecule which controls its own replication through the interaction of specific proteins at one or more origins of replication ([SO:0000340](http://www.sequenceontology.org/browser/current_svn/term/SO:0000340)).'
    genomeBuild: Optional_['string'] = Field(default=None)
    "The Genome Build used for reference, following GRCh build versions e.g. 'GRCh 37'.  Version number must be included if a versioned release of a primary build was used."
    orientation: Optional_['code'] = Field(default=None)
    'A relative reference to a DNA strand based on gene orientation. The strand that contains the open reading frame of the gene is the "sense" strand, and the opposite complementary strand is the "antisense" strand.'
    windowStart: Optional_['integer'] = Field(default=None)
    'Start position of the window on the reference sequence. If the coordinate system is either 0-based or 1-based, then start position is inclusive.'
    referenceSeqId: Optional_['CodeableConcept'] = Field(default=None)
    'Reference identifier of reference sequence submitted to NCBI. It must match the type in the MolecularSequence.type field. For example, the prefix, “NG_” identifies reference sequence for genes, “NM_” for messenger RNA transcripts, and “NP_” for amino acid sequences.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    referenceSeqString: Optional_['string'] = Field(default=None)
    'A string like "ACGT".'
    referenceSeqPointer: Optional_['Reference'] = Field(default=None)
    'A pointer to another MolecularSequence entity as reference sequence.'


class MolecularSequenceRepository(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Configurations of the external repository. The repository shall store target's observedSeq or records related with target's observedSeq."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    url: Optional_['uri'] = Field(default=None)
    'URI of an external repository which contains further details about the genetics data.'
    type: 'code' = Field(default=...)
    'Click and see / RESTful API / Need login to see / RESTful API with authentication / Other ways to see resource.'
    name: Optional_['string'] = Field(default=None)
    'URI of an external repository which contains further details about the genetics data.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    datasetId: Optional_['string'] = Field(default=None)
    'Id of the variant in this external repository. The server will understand how to use this id to call for more info about datasets in external repository.'
    readsetId: Optional_['string'] = Field(default=None)
    'Id of the read in this external repository.'
    variantsetId: Optional_['string'] = Field(default=None)
    'Id of the variantset in this external repository. The server will understand how to use this id to call for more info about variantsets in external repository.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MolecularSequenceQuality(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An experimental feature attribute that defines the quality of the feature in a quantitative way, such as a phred quality score ([SO:0001686](http://www.sequenceontology.org/browser/current_svn/term/SO:0001686))."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    end: Optional_['integer'] = Field(default=None)
    'End position of the sequence. If the coordinate system is 0-based then end is exclusive and does not include the last position. If the coordinate system is 1-base, then end is inclusive and includes the last position.'
    roc: Optional_['MolecularSequenceQualityRoc'] = Field(default=None)
    'Receiver Operator Characteristic (ROC) Curve  to give sensitivity/specificity tradeoff.'
    type: 'code' = Field(default=...)
    'INDEL / SNP / Undefined variant.'
    gtFP: Optional_['decimal'] = Field(default=None)
    'The number of false positives where the non-REF alleles in the Truth and Query Call Sets match (i.e. cases where the truth is 1/1 and the query is 0/1 or similar).'
    start: Optional_['integer'] = Field(default=None)
    'Start position of the sequence. If the coordinate system is either 0-based or 1-based, then start position is inclusive.'
    score: Optional_['Quantity'] = Field(default=None)
    'The score of an experimentally derived feature such as a p-value ([SO:0001685](http://www.sequenceontology.org/browser/current_svn/term/SO:0001685)).'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'Which method is used to get sequence quality.'
    recall: Optional_['decimal'] = Field(default=None)
    'TRUTH.TP / (TRUTH.TP + TRUTH.FN).'
    fScore: Optional_['decimal'] = Field(default=None)
    'Harmonic mean of Recall and Precision, computed as: 2 * precision * recall / (precision + recall).'
    truthTP: Optional_['decimal'] = Field(default=None)
    'True positives, from the perspective of the truth data, i.e. the number of sites in the Truth Call Set for which there are paths through the Query Call Set that are consistent with all of the alleles at this site, and for which there is an accurate genotype call for the event.'
    queryTP: Optional_['decimal'] = Field(default=None)
    'True positives, from the perspective of the query data, i.e. the number of sites in the Query Call Set for which there are paths through the Truth Call Set that are consistent with all of the alleles at this site, and for which there is an accurate genotype call for the event.'
    truthFN: Optional_['decimal'] = Field(default=None)
    'False negatives, i.e. the number of sites in the Truth Call Set for which there is no path through the Query Call Set that is consistent with all of the alleles at this site, or sites for which there is an inaccurate genotype call for the event. Sites with correct variant but incorrect genotype are counted here.'
    queryFP: Optional_['decimal'] = Field(default=None)
    'False positives, i.e. the number of sites in the Query Call Set for which there is no path through the Truth Call Set that is consistent with this site. Sites with correct variant but incorrect genotype are counted here.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    precision: Optional_['decimal'] = Field(default=None)
    'QUERY.TP / (QUERY.TP + QUERY.FP).'
    standardSequence: Optional_['CodeableConcept'] = Field(default=None)
    'Gold standard sequence used for comparing against.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MolecularSequenceQualityRoc(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Receiver Operator Characteristic (ROC) Curve  to give sensitivity/specificity tradeoff."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    score: List_['integer'] = Field(default_factory=list)
    'Invidual data point representing the GQ (genotype quality) score threshold.'
    numTP: List_['integer'] = Field(default_factory=list)
    'The number of true positives if the GQ score threshold was set to "score" field value.'
    numFP: List_['integer'] = Field(default_factory=list)
    'The number of false positives if the GQ score threshold was set to "score" field value.'
    numFN: List_['integer'] = Field(default_factory=list)
    'The number of false negatives if the GQ score threshold was set to "score" field value.'
    fMeasure: List_['decimal'] = Field(default_factory=list)
    'Calculated fScore if the GQ score threshold was set to "score" field value.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    precision: List_['decimal'] = Field(default_factory=list)
    'Calculated precision if the GQ score threshold was set to "score" field value.'
    sensitivity: List_['decimal'] = Field(default_factory=list)
    'Calculated sensitivity if the GQ score threshold was set to "score" field value.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MolecularSequenceVariant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The definition of variant here originates from Sequence ontology ([variant_of](http://www.sequenceontology.org/browser/current_svn/term/variant_of)). This element can represent amino acid or nucleic sequence change(including insertion,deletion,SNP,etc.)  It can represent some complex mutation or segment variation with the assist of CIGAR string."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    end: Optional_['integer'] = Field(default=None)
    'End position of the variant on the reference sequence. If the coordinate system is 0-based then end is exclusive and does not include the last position. If the coordinate system is 1-base, then end is inclusive and includes the last position.'
    start: Optional_['integer'] = Field(default=None)
    'Start position of the variant on the  reference sequence. If the coordinate system is either 0-based or 1-based, then start position is inclusive.'
    cigar: Optional_['string'] = Field(default=None)
    'Extended CIGAR string for aligning the sequence with reference bases. See detailed documentation [here](http://support.illumina.com/help/SequencingAnalysisWorkflow/Content/Vault/Informatics/Sequencing_Analysis/CASAVA/swSEQ_mCA_ExtendedCIGARFormat.htm).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    observedAllele: Optional_['string'] = Field(default=None)
    'An allele is one of a set of coexisting sequence variants of a gene ([SO:0001023](http://www.sequenceontology.org/browser/current_svn/term/SO:0001023)).  Nucleotide(s)/amino acids from start position of sequence to stop position of sequence on the positive (+) strand of the observed  sequence. When the sequence  type is DNA, it should be the sequence on the positive (+) strand. This will lay in the range between variant.start and variant.end.'
    variantPointer: Optional_['Reference'] = Field(default=None)
    'A pointer to an Observation containing variant information.'
    referenceAllele: Optional_['string'] = Field(default=None)
    'An allele is one of a set of coexisting sequence variants of a gene ([SO:0001023](http://www.sequenceontology.org/browser/current_svn/term/SO:0001023)). Nucleotide(s)/amino acids from start position of sequence to stop position of sequence on the positive (+) strand of the reference sequence. When the sequence  type is DNA, it should be the sequence on the positive (+) strand. This will lay in the range between variant.start and variant.end.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class MolecularSequence(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Raw data describing a biological sequence."""
    resourceType: Literal_['MolecularSequence'] = Field(default=...)
    'Information about a biological sequence'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['code'] = Field(default=None)
    'Amino Acid Sequence/ DNA Sequence / RNA Sequence.'
    device: Optional_['Reference'] = Field(default=None)
    'The method for sequencing, for example, chip information.'
    patient: Optional_['Reference'] = Field(default=None)
    'The patient whose sequencing results are described by this resource.'
    variant: List_['MolecularSequenceVariant'] = Field(default_factory=list)
    'The definition of variant here originates from Sequence ontology ([variant_of](http://www.sequenceontology.org/browser/current_svn/term/variant_of)). This element can represent amino acid or nucleic sequence change(including insertion,deletion,SNP,etc.)  It can represent some complex mutation or segment variation with the assist of CIGAR string.'
    quality: List_['MolecularSequenceQuality'] = Field(default_factory=list)
    'An experimental feature attribute that defines the quality of the feature in a quantitative way, such as a phred quality score ([SO:0001686](http://www.sequenceontology.org/browser/current_svn/term/SO:0001686)).'
    pointer: List_['Reference'] = Field(default_factory=list)
    'Pointer to next atomic sequence which at most contains one variant.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    specimen: Optional_['Reference'] = Field(default=None)
    'Specimen used for sequencing.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The number of copies of the sequence of interest. (RNASeq).'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    performer: Optional_['Reference'] = Field(default=None)
    'The organization or lab that should be responsible for this result.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier for this particular sequence instance. This is a FHIR-defined id.'
    repository: List_['MolecularSequenceRepository'] = Field(default_factory=list)
    "Configurations of the external repository. The repository shall store target's observedSeq or records related with target's observedSeq."
    observedSeq: Optional_['string'] = Field(default=None)
    'Sequence that was observed. It is the result marked by referenceSeq along with variant records on referenceSeq. This shall start from referenceSeq.windowStart and end by referenceSeq.windowEnd.'
    referenceSeq: Optional_['MolecularSequenceReferenceSeq'] = Field(default=None)
    'A sequence that is used as a reference to describe variants that are present in a sequence analyzed.'
    readCoverage: Optional_['integer'] = Field(default=None)
    'Coverage (read depth or depth) is the average number of reads representing a given nucleotide in the reconstructed sequence.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    coordinateSystem: 'integer' = Field(default=...)
    'Whether the sequence is numbered starting at 0 (0-based numbering or coordinates, inclusive start, exclusive end) or starting at 1 (1-based numbering, inclusive start and inclusive end).'
    structureVariant: List_['MolecularSequenceStructureVariant'] = Field(default_factory=list)
    'Information about chromosome structure variation.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NamingSystemUniqueId(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates how the system may be identified when referenced in electronic exchange."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'Identifies the unique identifier scheme used for this particular identifier.'
    value: 'string' = Field(default=...)
    'The string that should be sent over the wire to identify the code system or identifier system.'
    period: Optional_['Period'] = Field(default=None)
    'Identifies the period of time over which this identifier is considered appropriate to refer to the naming system.  Outside of this window, the identifier might be non-deterministic.'
    comment: Optional_['string'] = Field(default=None)
    'Notes about the past or intended usage of this identifier.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    preferred: Optional_['boolean'] = Field(default=None)
    'Indicates whether this identifier is the "preferred" identifier of this type.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NamingSystem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A curated namespace that issues unique symbols within that namespace for the identification of concepts, people, devices, etc.  Represents a "System" used within the Identifier and Coding data types."""
    resourceType: Literal_['NamingSystem'] = Field(default=...)
    'System of unique identification'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: 'string' = Field(default=...)
    'A natural language name identifying the naming system. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    kind: 'code' = Field(default=...)
    'Indicates the purpose for the naming system - what kinds of things does it make unique?'
    date: 'dateTime' = Field(default=...)
    'The date  (and optionally time) when the naming system was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the naming system changes.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Categorizes a naming system for easier search by grouping related naming systems.'
    usage: Optional_['string'] = Field(default=None)
    'Provides guidance on the use of the namespace, including the handling of formatting characters, use of upper vs. lower case, etc.'
    status: 'code' = Field(default=...)
    'The status of this naming system. Enables tracking the life-cycle of the content.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    uniqueId: List_['NamingSystemUniqueId'] = Field(default=...)
    'Indicates how the system may be identified when referenced in electronic exchange.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the naming system.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate naming system instances.'
    responsible: Optional_['string'] = Field(default=None)
    'The name of the organization that is responsible for issuing identifiers or codes for this namespace and ensuring their non-collision.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the naming system from a consumer's perspective. Details about what the namespace identifies including scope, granularity, version labeling, etc."
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the naming system is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NutritionOrderEnteralFormula(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Feeding provided through the gastrointestinal tract via a tube, catheter, or stoma that delivers nutrition distal to the oral cavity."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    additiveType: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the type of modular component such as protein, carbohydrate, fat or fiber to be provided in addition to or mixed with the base formula.'
    caloricDensity: Optional_['Quantity'] = Field(default=None)
    'The amount of energy (calories) that the formula should provide per specified volume, typically per mL or fluid oz.  For example, an infant may require a formula that provides 24 calories per fluid ounce or an adult may require an enteral formula that provides 1.5 calorie/mL.'
    administration: List_['NutritionOrderEnteralFormulaAdministration'] = Field(default_factory=list)
    'Formula administration instructions as structured data.  This repeating structure allows for changing the administration rate or volume over time for both bolus and continuous feeding.  An example of this would be an instruction to increase the rate of continuous feeding every 2 hours.'
    baseFormulaType: Optional_['CodeableConcept'] = Field(default=None)
    'The type of enteral or infant formula such as an adult standard formula with fiber or a soy-based infant formula.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    maxVolumeToDeliver: Optional_['Quantity'] = Field(default=None)
    'The maximum total quantity of formula that may be administered to a subject over the period of time, e.g. 1440 mL over 24 hours.'
    additiveProductName: Optional_['string'] = Field(default=None)
    'The product or brand name of the type of modular component to be added to the formula.'
    routeofAdministration: Optional_['CodeableConcept'] = Field(default=None)
    "The route or physiological path of administration into the patient's gastrointestinal  tract for purposes of providing the formula feeding, e.g. nasogastric tube."
    baseFormulaProductName: Optional_['string'] = Field(default=None)
    'The product or brand name of the enteral or infant formula product such as "ACME Adult Standard Formula".'
    administrationInstruction: Optional_['string'] = Field(default=None)
    'Free text formula administration, feeding instructions or additional instructions or information.'


class NutritionOrderEnteralFormulaAdministration(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Formula administration instructions as structured data.  This repeating structure allows for changing the administration rate or volume over time for both bolus and continuous feeding.  An example of this would be an instruction to increase the rate of continuous feeding every 2 hours."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    rateQuantity: Optional_['Quantity'] = Field(default=None)
    'The rate of administration of formula via a feeding pump, e.g. 60 mL per hour, according to the specified schedule.'
    rateRatio: Optional_['Ratio'] = Field(default=None)
    'The rate of administration of formula via a feeding pump, e.g. 60 mL per hour, according to the specified schedule.'
    schedule: Optional_['Timing'] = Field(default=None)
    'The time period and frequency at which the enteral formula should be delivered to the patient.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The volume of formula to provide to the patient per the specified administration schedule.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NutritionOrderSupplement(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Oral nutritional products given in order to add further nutritional value to the patient's diet."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of nutritional supplement product required such as a high protein or pediatric clear liquid supplement.'
    schedule: List_['Timing'] = Field(default_factory=list)
    'The time period and frequency at which the supplement(s) should be given.  The supplement should be given for the combination of all schedules if more than one schedule is present.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The amount of the nutritional supplement to be given.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    productName: Optional_['string'] = Field(default=None)
    'The product or brand name of the nutritional supplement such as "Acme Protein Shake".'
    instruction: Optional_['string'] = Field(default=None)
    'Free text or additional instructions or information pertaining to the oral supplement.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NutritionOrderOralDiet(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Diet given orally in contrast to enteral (tube) feeding."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'The kind of diet or dietary restriction such as fiber restricted diet or diabetic diet.'
    texture: List_['NutritionOrderOralDietTexture'] = Field(default_factory=list)
    'Class that describes any texture modifications required for the patient to safely consume various types of solid foods.'
    schedule: List_['Timing'] = Field(default_factory=list)
    'The time period and frequency at which the diet should be given.  The diet should be given for the combination of all schedules if more than one schedule is present.'
    nutrient: List_['NutritionOrderOralDietNutrient'] = Field(default_factory=list)
    'Class that defines the quantity and type of nutrient modifications (for example carbohydrate, fiber or sodium) required for the oral diet.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    instruction: Optional_['string'] = Field(default=None)
    'Free text or additional instructions or information pertaining to the oral diet.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    fluidConsistencyType: List_['CodeableConcept'] = Field(default_factory=list)
    'The required consistency (e.g. honey-thick, nectar-thick, thin, thickened.) of liquids or fluids served to the patient.'


class NutritionOrderOralDietNutrient(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Class that defines the quantity and type of nutrient modifications (for example carbohydrate, fiber or sodium) required for the oral diet."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    amount: Optional_['Quantity'] = Field(default=None)
    'The quantity of the specified nutrient to include in diet.'
    modifier: Optional_['CodeableConcept'] = Field(default=None)
    'The nutrient that is being modified such as carbohydrate or sodium.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NutritionOrderOralDietTexture(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Class that describes any texture modifications required for the patient to safely consume various types of solid foods."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    modifier: Optional_['CodeableConcept'] = Field(default=None)
    'Any texture modifications (for solid foods) that should be made, e.g. easy to chew, chopped, ground, and pureed.'
    foodType: Optional_['CodeableConcept'] = Field(default=None)
    'The food type(s) (e.g. meats, all foods)  that the texture modification applies to.  This could be all foods types.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NutritionOrder(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A request to supply a diet, formula feeding (enteral) or oral nutritional supplement to a patient/resident."""
    resourceType: Literal_['NutritionOrder'] = Field(default=...)
    'Diet, formula or nutritional supplement request'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments made about the {{title}} by the requester, performer, subject or other participants.'
    status: 'code' = Field(default=...)
    'The workflow status of the nutrition order/request.'
    intent: 'code' = Field(default=...)
    'Indicates the level of authority/intentionality associated with the NutrionOrder and where the request fits into the workflow chain.'
    patient: 'Reference' = Field(default=...)
    'The person (patient) who needs the nutrition order for an oral diet, nutritional supplement and/or enteral or formula feeding.'
    orderer: Optional_['Reference'] = Field(default=None)
    'The practitioner that holds legal responsibility for ordering the diet, nutritional supplement, or formula feedings.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    oralDiet: Optional_['NutritionOrderOralDiet'] = Field(default=None)
    'Diet given orally in contrast to enteral (tube) feeding.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'An encounter that provides additional information about the healthcare context in which this request is made.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers assigned to this order by the order sender or by the order receiver.'
    supplement: List_['NutritionOrderSupplement'] = Field(default_factory=list)
    "Oral nutritional products given in order to add further nutritional value to the patient's diet."
    instantiates: List_['uri'] = Field(default_factory=list)
    'The URL pointing to a protocol, guideline, orderset or other definition that is adhered to in whole or in part by this NutritionOrder.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    enteralFormula: Optional_['NutritionOrderEnteralFormula'] = Field(default=None)
    'Feeding provided through the gastrointestinal tract via a tube, catheter, or stoma that delivers nutrition distal to the oral cavity.'
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally maintained protocol, guideline, orderset or other definition that is adhered to in whole or in part by this NutritionOrder.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    allergyIntolerance: List_['Reference'] = Field(default_factory=list)
    'A link to a record of allergies or intolerances  which should be included in the nutrition order.'
    excludeFoodModifier: List_['CodeableConcept'] = Field(default_factory=list)
    'This modifier is used to convey Order-specific modifier about the type of oral food or oral fluids that should not be given. These can be derived from patient allergies, intolerances, or preferences such as No Red Meat, No Soy or No Wheat or  Gluten-Free.  While it should not be necessary to repeat allergy or intolerance information captured in the referenced AllergyIntolerance resource in the excludeFoodModifier, this element may be used to convey additional specificity related to foods that should be eliminated from the patient’s diet for any reason.  This modifier applies to the entire nutrition order inclusive of the oral diet, nutritional supplements and enteral formula feedings.'
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'The URL pointing to a FHIR-defined protocol, guideline, orderset or other definition that is adhered to in whole or in part by this NutritionOrder.'
    foodPreferenceModifier: List_['CodeableConcept'] = Field(default_factory=list)
    'This modifier is used to convey order-specific modifiers about the type of food that should be given. These can be derived from patient allergies, intolerances, or preferences such as Halal, Vegan or Kosher. This modifier applies to the entire nutrition order inclusive of the oral diet, nutritional supplements and enteral formula feedings.'
    dateTime: 'dateTime' = Field(default=...)
    'The date and time that this nutrition order was requested.'


class NutritionProductProductCharacteristic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies descriptive properties of the nutrition product."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'A code specifying which characteristic of the product is being described (for example, colour, shape).'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The actual characteristic value corresponding to the type.'
    valueString: Optional_['string'] = Field(default=None)
    'The actual characteristic value corresponding to the type.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The actual characteristic value corresponding to the type.'
    valueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'The actual characteristic value corresponding to the type.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'The actual characteristic value corresponding to the type.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The actual characteristic value corresponding to the type.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NutritionProductIngredient(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Ingredients contained in this product."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    item: 'CodeableReference' = Field(default=...)
    'The ingredient contained in the product.'
    amount: List_['Ratio'] = Field(default_factory=list)
    'The amount of ingredient that is in the product.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NutritionProductInstance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Conveys instance-level information about this product item. One or several physical, countable instances or occurrences of the product."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    useBy: Optional_['dateTime'] = Field(default=None)
    'The time after which the product is no longer expected to be in proper condition, or its use is not advised or not allowed.'
    expiry: Optional_['dateTime'] = Field(default=None)
    'The time after which the product is no longer expected to be in proper condition, or its use is not advised or not allowed.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The amount of items or instances that the resource considers, for instance when referring to 2 identical units together.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    lotNumber: Optional_['string'] = Field(default=None)
    'The identification of the batch or lot of the product.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'The identifier for the physical instance, typically a serial number.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NutritionProductNutrient(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The product's nutritional information expressed by the nutrients."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    item: Optional_['CodeableReference'] = Field(default=None)
    'The (relevant) nutrients in the product.'
    amount: List_['Ratio'] = Field(default_factory=list)
    'The amount of nutrient expressed in one or more units: X per pack / per serving / per dose.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class NutritionProduct(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A food or fluid product that is consumed by patients."""
    resourceType: Literal_['NutritionProduct'] = Field(default=...)
    'A product used for nutritional purposes'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments made about the product.'
    status: 'code' = Field(default=...)
    'The current state of the product.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'Nutrition products can have different classifications - according to its nutritional properties, preparation methods, etc.'
    nutrient: List_['NutritionProductNutrient'] = Field(default_factory=list)
    "The product's nutritional information expressed by the nutrients."
    instance: Optional_['NutritionProductInstance'] = Field(default=None)
    'Conveys instance-level information about this product item. One or several physical, countable instances or occurrences of the product.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    ingredient: List_['NutritionProductIngredient'] = Field(default_factory=list)
    'Ingredients contained in this product.'
    manufacturer: List_['Reference'] = Field(default_factory=list)
    'The organisation (manufacturer, representative or legal authorisation holder) that is responsible for the device.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    knownAllergen: List_['CodeableReference'] = Field(default_factory=list)
    'Allergens that are known or suspected to be a part of this nutrition product.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    productCharacteristic: List_['NutritionProductProductCharacteristic'] = Field(default_factory=list)
    'Specifies descriptive properties of the nutrition product.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The code assigned to the product, for example a manufacturer number or other terminology.'


class ObservationReferenceRange(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Guidance on how to interpret the value by comparison to a normal or recommended range.  Multiple reference ranges are interpreted as an "OR".   In other words, to represent two distinct target populations, two `referenceRange` elements would be used."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    low: Optional_['Quantity'] = Field(default=None)
    'The value of the low bound of the reference range.  The low bound of the reference range endpoint is inclusive of the value (e.g.  reference range is >=5 - <=9). If the low bound is omitted,  it is assumed to be meaningless (e.g. reference range is <=2.3).'
    age: Optional_['Range'] = Field(default=None)
    'The age at which this reference range is applicable. This is a neonatal age (e.g. number of weeks at term) if the meaning says so.'
    high: Optional_['Quantity'] = Field(default=None)
    'The value of the high bound of the reference range.  The high bound of the reference range endpoint is inclusive of the value (e.g.  reference range is >=5 - <=9). If the high bound is omitted,  it is assumed to be meaningless (e.g. reference range is >= 2.3).'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Codes to indicate the what part of the targeted reference population it applies to. For example, the normal or therapeutic range.'
    text: Optional_['string'] = Field(default=None)
    'Text based reference range in an observation which may be used when a quantitative range is not appropriate for an observation.  An example would be a reference value of "Negative" or a list or table of "normals".'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    appliesTo: List_['CodeableConcept'] = Field(default_factory=list)
    'Codes to indicate the target population this reference range applies to.  For example, a reference range may be based on the normal population or a particular sex or race.  Multiple `appliesTo`  are interpreted as an "AND" of the target populations.  For example, to represent a target population of African American females, both a code of female and a code for African American would be used.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ObservationComponent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Some observations have multiple component observations.  These component observations are expressed as separate code value pairs that share the same attributes.  Examples include systolic and diastolic component observations for blood pressure measurement and multiple component observations for genetics observations."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'Describes what was observed. Sometimes this is called the observation "code".'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueString: Optional_['string'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueRange: Optional_['Range'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueRatio: Optional_['Ratio'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueSampledData: Optional_['SampledData'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueTime: Optional_['time'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valuePeriod: Optional_['Period'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    interpretation: List_['CodeableConcept'] = Field(default_factory=list)
    'A categorical assessment of an observation value.  For example, high, low, normal.'
    referenceRange: List_['ObservationReferenceRange'] = Field(default_factory=list)
    'Guidance on how to interpret the value by comparison to a normal or recommended range.'
    dataAbsentReason: Optional_['CodeableConcept'] = Field(default=None)
    'Provides a reason why the expected value in the element Observation.component.value[x] is missing.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Observation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Measurements and simple assertions made about a patient, device or other subject."""
    resourceType: Literal_['Observation'] = Field(default=...)
    'Measurements and simple assertions'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments about the observation or the results.'
    focus: List_['Reference'] = Field(default_factory=list)
    "The actual focus of an observation when it is not the patient of record representing something or someone associated with the patient such as a spouse, parent, fetus, or donor. For example, fetus observations in a mother's record.  The focus of an observation could also be an existing condition,  an intervention, the subject's diet,  another observation of the subject,  or a body structure such as tumor or implanted device.   An example use case would be using the Observation resource to capture whether the mother is trained to change her child's tracheostomy tube. In this example, the child is the patient of record and the mother is the focus."
    partOf: List_['Reference'] = Field(default_factory=list)
    'A larger event of which this particular Observation is a component or step.  For example,  an observation as part of a procedure.'
    status: 'code' = Field(default=...)
    'The status of the result value.'
    issued: Optional_['instant'] = Field(default=None)
    'The date and time this version of the observation was made available to providers, typically after the results have been reviewed and verified.'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the mechanism used to perform the observation.'
    device: Optional_['Reference'] = Field(default=None)
    'The device used to generate the observation data.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A plan, proposal or order that is fulfilled in whole or in part by this event.  For example, a MedicationRequest may require a patient to have laboratory test performed before  it is dispensed.'
    subject: Optional_['Reference'] = Field(default=None)
    'The patient, or group of patients, location, or device this observation is about and into whose record the observation is placed. If the actual focus of the observation is different from the subject (or a sample of, part, or region of the subject), the `focus` element or the `code` itself specifies the actual focus of the observation.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'A code that classifies the general type of observation being made.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueString: Optional_['string'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueRange: Optional_['Range'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueRatio: Optional_['Ratio'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueSampledData: Optional_['SampledData'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueTime: Optional_['time'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    valuePeriod: Optional_['Period'] = Field(default=None)
    'The information determined as a result of making the observation, if the information has a simple value.'
    bodySite: Optional_['CodeableConcept'] = Field(default=None)
    "Indicates the site on the subject's body where the observation was made (i.e. the target site)."
    specimen: Optional_['Reference'] = Field(default=None)
    'The specimen that was used when this observation was made.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The healthcare event  (e.g. a patient and healthcare provider interaction) during which this observation is made.'
    performer: List_['Reference'] = Field(default_factory=list)
    'Who was responsible for asserting the observed value as "true".'
    hasMember: List_['Reference'] = Field(default_factory=list)
    'This observation is a group observation (e.g. a battery, a panel of tests, a set of vital sign measurements) that includes the target as a member of the group.'
    component: List_['ObservationComponent'] = Field(default_factory=list)
    'Some observations have multiple component observations.  These component observations are expressed as separate code value pairs that share the same attributes.  Examples include systolic and diastolic component observations for blood pressure measurement and multiple component observations for genetics observations.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this observation.'
    derivedFrom: List_['Reference'] = Field(default_factory=list)
    'The target resource that represents a measurement from which this observation value is derived. For example, a calculated anion gap or a fetal measurement based on an ultrasound image.'
    effectiveDateTime: Optional_['dateTime'] = Field(default=None)
    'The time or time-period the observed value is asserted as being true. For biological subjects - e.g. human patients - this is usually called the "physiologically relevant time". This is usually either the time of the procedure or of specimen collection, but very often the source of the date/time is not known, only the date/time itself.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The time or time-period the observed value is asserted as being true. For biological subjects - e.g. human patients - this is usually called the "physiologically relevant time". This is usually either the time of the procedure or of specimen collection, but very often the source of the date/time is not known, only the date/time itself.'
    effectiveTiming: Optional_['Timing'] = Field(default=None)
    'The time or time-period the observed value is asserted as being true. For biological subjects - e.g. human patients - this is usually called the "physiologically relevant time". This is usually either the time of the procedure or of specimen collection, but very often the source of the date/time is not known, only the date/time itself.'
    effectiveInstant: Optional_['instant'] = Field(default=None)
    'The time or time-period the observed value is asserted as being true. For biological subjects - e.g. human patients - this is usually called the "physiologically relevant time". This is usually either the time of the procedure or of specimen collection, but very often the source of the date/time is not known, only the date/time itself.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    interpretation: List_['CodeableConcept'] = Field(default_factory=list)
    'A categorical assessment of an observation value.  For example, high, low, normal.'
    referenceRange: List_['ObservationReferenceRange'] = Field(default_factory=list)
    'Guidance on how to interpret the value by comparison to a normal or recommended range.  Multiple reference ranges are interpreted as an "OR".   In other words, to represent two distinct target populations, two `referenceRange` elements would be used.'
    dataAbsentReason: Optional_['CodeableConcept'] = Field(default=None)
    'Provides a reason why the expected value in the element Observation.value[x] is missing.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'CodeableConcept' = Field(default=...)
    'Describes what was observed. Sometimes this is called the observation "name".'


class ObservationDefinitionQuantitativeDetails(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Characteristics for quantitative results of this observation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    unit: Optional_['CodeableConcept'] = Field(default=None)
    'SI unit used to report quantitative results of observations conforming to this ObservationDefinition.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    customaryUnit: Optional_['CodeableConcept'] = Field(default=None)
    'Customary unit used to report quantitative results of observations conforming to this ObservationDefinition.'
    conversionFactor: Optional_['decimal'] = Field(default=None)
    'Factor for converting value expressed with SI unit to value expressed with customary unit.'
    decimalPrecision: Optional_['integer'] = Field(default=None)
    'Number of digits after decimal separator when the results of such observations are of type Quantity.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ObservationDefinitionQualifiedInterval(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Multiple  ranges of results qualified by different contexts for ordinal or continuous observations conforming to this ObservationDefinition."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    age: Optional_['Range'] = Field(default=None)
    'The age at which this reference range is applicable. This is a neonatal age (e.g. number of weeks at term) if the meaning says so.'
    range: Optional_['Range'] = Field(default=None)
    'The low and high values determining the interval. There may be only one of the two.'
    gender: Optional_['code'] = Field(default=None)
    'Sex of the population the range applies to.'
    context: Optional_['CodeableConcept'] = Field(default=None)
    'Codes to indicate the health context the range applies to. For example, the normal or therapeutic range.'
    category: Optional_['code'] = Field(default=None)
    'The category of interval of values for continuous or ordinal observations conforming to this ObservationDefinition.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    appliesTo: List_['CodeableConcept'] = Field(default_factory=list)
    'Codes to indicate the target population this reference range applies to.'
    condition: Optional_['string'] = Field(default=None)
    'Text based condition for which the reference range is valid.'
    gestationalAge: Optional_['Range'] = Field(default=None)
    'The gestational age to which this reference range is applicable, in the context of pregnancy.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ObservationDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Set of definitional characteristics for a kind of observation or measurement produced or consumed by an orderable health care service."""
    resourceType: Literal_['ObservationDefinition'] = Field(default=...)
    'Definition of an observation'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'The method or technique used to perform the observation.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'A code that classifies the general type of observation.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this ObservationDefinition artifact.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    permittedDataType: List_['code'] = Field(default_factory=list)
    'The data types allowed for the value element of the instance observations conforming to this ObservationDefinition.'
    qualifiedInterval: List_['ObservationDefinitionQualifiedInterval'] = Field(default_factory=list)
    'Multiple  ranges of results qualified by different contexts for ordinal or continuous observations conforming to this ObservationDefinition.'
    validCodedValueSet: Optional_['Reference'] = Field(default=None)
    'The set of valid coded results for the observations  conforming to this ObservationDefinition.'
    preferredReportName: Optional_['string'] = Field(default=None)
    'The preferred name to be used when reporting the results of observations conforming to this ObservationDefinition.'
    quantitativeDetails: Optional_['ObservationDefinitionQuantitativeDetails'] = Field(default=None)
    'Characteristics for quantitative results of this observation.'
    normalCodedValueSet: Optional_['Reference'] = Field(default=None)
    'The set of normal coded results for the observations conforming to this ObservationDefinition.'
    abnormalCodedValueSet: Optional_['Reference'] = Field(default=None)
    'The set of abnormal coded results for the observation conforming to this ObservationDefinition.'
    criticalCodedValueSet: Optional_['Reference'] = Field(default=None)
    'The set of critical coded results for the observation conforming to this ObservationDefinition.'
    multipleResultsAllowed: Optional_['boolean'] = Field(default=None)
    'Multiple results allowed for observations conforming to this ObservationDefinition.'
    code: 'CodeableConcept' = Field(default=...)
    'Describes what will be observed. Sometimes this is called the observation "name".'


class OperationDefinitionParameter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The parameters for the operation/query."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: 'code' = Field(default=...)
    'Whether this is an input or an output parameter.'
    min: 'integer' = Field(default=...)
    'The minimum number of times this parameter SHALL appear in the request or response.'
    max: 'string' = Field(default=...)
    'The maximum number of times this element is permitted to appear in the request or response.'
    name: 'code' = Field(default=...)
    'The name of used to identify the parameter.'
    type: Optional_['code'] = Field(default=None)
    'The type for this parameter.'
    part: List_['OperationDefinitionParameter'] = Field(default_factory=list)
    'The parts of a nested Parameter.'
    binding: Optional_['OperationDefinitionParameterBinding'] = Field(default=None)
    'Binds to a value set if this parameter is coded (code, Coding, CodeableConcept).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    searchType: Optional_['code'] = Field(default=None)
    "How the parameter is understood as a search parameter. This is only used if the parameter type is 'string'."
    documentation: Optional_['string'] = Field(default=None)
    'Describes the meaning or use of this parameter.'
    targetProfile: List_['canonical'] = Field(default_factory=list)
    'Used when the type is "Reference" or "canonical", and identifies a profile structure or implementation Guide that applies to the target of the reference this parameter refers to. If any profiles are specified, then the content must conform to at least one of them. The URL can be a local reference - to a contained StructureDefinition, or a reference to another StructureDefinition or Implementation Guide by a canonical URL. When an implementation guide is specified, the target resource SHALL conform to at least one profile defined in the implementation guide.'
    referencedFrom: List_['OperationDefinitionParameterReferencedFrom'] = Field(default_factory=list)
    'Identifies other resource parameters within the operation invocation that are expected to resolve to this resource.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class OperationDefinitionParameterReferencedFrom(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies other resource parameters within the operation invocation that are expected to resolve to this resource."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    source: 'string' = Field(default=...)
    'The name of the parameter or dot-separated path of parameter names pointing to the resource parameter that is expected to contain a reference to this resource.'
    sourceId: Optional_['string'] = Field(default=None)
    'The id of the element in the referencing resource that is expected to resolve to this resource.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class OperationDefinitionParameterBinding(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Binds to a value set if this parameter is coded (code, Coding, CodeableConcept)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    strength: 'code' = Field(default=...)
    'Indicates the degree of conformance expectations associated with this binding - that is, the degree to which the provided value set must be adhered to in the instances.'
    valueSet: 'canonical' = Field(default=...)
    'Points to the value set or external definition (e.g. implicit value set) that identifies the set of codes to be used.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class OperationDefinitionOverload(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Defines an appropriate combination of parameters to use when invoking this operation, to help code generators when generating overloaded parameter sets for this operation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    comment: Optional_['string'] = Field(default=None)
    'Comments to go on overload.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    parameterName: List_['string'] = Field(default_factory=list)
    'Name of parameter to include in overload.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class OperationDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A formal computable definition of an operation (on the RESTful interface) or a named query (using the search interaction)."""
    resourceType: Literal_['OperationDefinition'] = Field(default=...)
    'Definition of an operation or a named query'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this operation definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this operation definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the operation definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: 'string' = Field(default=...)
    'A natural language name identifying the operation definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    kind: 'code' = Field(default=...)
    'Whether this is an operation or a named query.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the operation definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the operation definition changes.'
    base: Optional_['canonical'] = Field(default=None)
    'Indicates that this operation definition is a constraining profile on the base.'
    type: 'boolean' = Field(default=...)
    'Indicates whether this operation or named query can be invoked at the resource type level for any given resource type level (e.g. without needing to choose a specific resource id for the context).'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the operation definition.'
    status: 'code' = Field(default=...)
    'The status of this operation definition. Enables tracking the life-cycle of the content.'
    system: 'boolean' = Field(default=...)
    'Indicates whether this operation or named query can be invoked at the system level (e.g. without needing to choose a resource type for the context).'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the operation definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the operation definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this operation definition is needed and why it has been designed as it has.'
    comment: Optional_['markdown'] = Field(default=None)
    'Additional information about how to use this operation or named query.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    resource: List_['code'] = Field(default_factory=list)
    'The types on which this operation can be executed.'
    instance: 'boolean' = Field(default=...)
    'Indicates whether this operation can be invoked on a particular instance of one of the given types.'
    overload: List_['OperationDefinitionOverload'] = Field(default_factory=list)
    'Defines an appropriate combination of parameters to use when invoking this operation, to help code generators when generating overloaded parameter sets for this operation.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the operation definition.'
    parameter: List_['OperationDefinitionParameter'] = Field(default_factory=list)
    'The parameters for the operation/query.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate operation definition instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the operation definition from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this operation definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the operation definition is intended to be used.'
    affectsState: Optional_['boolean'] = Field(default=None)
    "Whether the operation affects state. Side effects such as producing audit trail entries do not count as 'affecting  state'."
    inputProfile: Optional_['canonical'] = Field(default=None)
    'Additional validation information for the in parameters - a single profile that covers all the parameters. The profile is a constraint on the parameters resource as a whole.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    outputProfile: Optional_['canonical'] = Field(default=None)
    'Additional validation information for the out parameters - a single profile that covers all the parameters. The profile is a constraint on the parameters resource.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'The name used to invoke the operation.'


class OperationOutcomeIssue(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An error, warning, or information message that results from a system action."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    details: Optional_['CodeableConcept'] = Field(default=None)
    'Additional details about the error. This may be a text description of the error or a system code that identifies the error.'
    severity: 'code' = Field(default=...)
    'Indicates whether the issue indicates a variation from successful processing.'
    location: List_['string'] = Field(default_factory=list)
    'This element is deprecated because it is XML specific. It is replaced by issue.expression, which is format independent, and simpler to parse. \n\nFor resource issues, this will be a simple XPath limited to element names, repetition indicators and the default child accessor that identifies one of the elements in the resource that caused this issue to be raised.  For HTTP errors, will be "http." + the parameter name.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: List_['string'] = Field(default_factory=list)
    'A [simple subset of FHIRPath](fhirpath.html#simple) limited to element names, repetition indicators and the default child accessor that identifies one of the elements in the resource that caused this issue to be raised.'
    diagnostics: Optional_['string'] = Field(default=None)
    'Additional diagnostic information about the issue.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'Describes the type of the issue. The system that creates an OperationOutcome SHALL choose the most applicable code from the IssueType value set, and may additional provide its own code for the error in the details element.'


class OperationOutcome(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A collection of error, warning, or information messages that result from a system action."""
    resourceType: Literal_['OperationOutcome'] = Field(default=...)
    'Information about the success/failure of an action'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    issue: List_['OperationOutcomeIssue'] = Field(default=...)
    'An error, warning, or information message that results from a system action.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class OrganizationContact(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Contact for the organization for a certain purpose."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['HumanName'] = Field(default=None)
    'A name associated with the contact.'
    purpose: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates a purpose for which the contact can be reached.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'A contact detail (e.g. a telephone number or an email address) by which the party may be contacted.'
    address: Optional_['Address'] = Field(default=None)
    'Visiting or postal addresses for the contact.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Organization(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A formally or informally recognized grouping of people or organizations formed for the purpose of achieving some form of collective action.  Includes companies, institutions, corporations, departments, community groups, healthcare practice groups, payer/insurer, etc."""
    resourceType: Literal_['Organization'] = Field(default=...)
    'A grouping of people or organizations with a common purpose'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'The kind(s) of organization that this is.'
    name: Optional_['string'] = Field(default=None)
    'A name associated with the organization.'
    alias: List_['string'] = Field(default_factory=list)
    'A list of alternate names that the organization is known as, or was known as in the past.'
    active: Optional_['boolean'] = Field(default=None)
    "Whether the organization's record is still in active use."
    partOf: Optional_['Reference'] = Field(default=None)
    'The organization of which this organization forms a part.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'A contact detail for the organization.'
    address: List_['Address'] = Field(default_factory=list)
    'An address for the organization.'
    contact: List_['OrganizationContact'] = Field(default_factory=list)
    'Contact for the organization for a certain purpose.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    endpoint: List_['Reference'] = Field(default_factory=list)
    'Technical endpoints providing access to services operated for the organization.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier for the organization that is used to identify the organization across multiple disparate systems.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class OrganizationAffiliation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Defines an affiliation/assotiation/relationship between 2 distinct oganizations, that is not a part-of relationship/sub-division relationship."""
    resourceType: Literal_['OrganizationAffiliation'] = Field(default=...)
    'Defines an affiliation/assotiation/relationship between 2 distinct oganizations, that is not a part-of relationship/sub-division relationship'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    active: Optional_['boolean'] = Field(default=None)
    'Whether this organization affiliation record is in active use.'
    period: Optional_['Period'] = Field(default=None)
    'The period during which the participatingOrganization is affiliated with the primary organization.'
    network: List_['Reference'] = Field(default_factory=list)
    "Health insurance provider network in which the participatingOrganization provides the role's services (if defined) at the indicated locations (if defined)."
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'Contact details at the participatingOrganization relevant to this Affiliation.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    location: List_['Reference'] = Field(default_factory=list)
    'The location(s) at which the role occurs.'
    endpoint: List_['Reference'] = Field(default_factory=list)
    'Technical endpoints providing access to services operated for this role.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    specialty: List_['CodeableConcept'] = Field(default_factory=list)
    'Specific specialty of the participatingOrganization in the context of the role.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers that are specific to this role.'
    organization: Optional_['Reference'] = Field(default=None)
    'Organization where the role is available (primary organization/has members).'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    healthcareService: List_['Reference'] = Field(default_factory=list)
    'Healthcare services provided through the role.'
    participatingOrganization: Optional_['Reference'] = Field(default=None)
    'The Participating Organization provides/performs the role(s) defined by the code to the Primary Organization (e.g. providing services or is a member of).'
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'Definition of the role the participatingOrganization plays in the association.'


class PackagedProductDefinitionLegalStatusOfSupply(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The legal status of supply of the packaged item as classified by the regulator."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The actual status of supply. Conveys in what situation this package type may be supplied for use.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    jurisdiction: Optional_['CodeableConcept'] = Field(default=None)
    'The place where the legal status of supply applies. When not specified, this indicates it is unknown in this context.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PackagedProductDefinitionPackage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A packaging item, as a container for medically related items, possibly with other packaging items within, or a packaging component, such as bottle cap (which is not a device or a medication manufactured item)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The physical type of the container of the items.'
    package: List_['PackagedProductDefinitionPackage'] = Field(default_factory=list)
    'Allows containers (and parts of containers) parwithin containers, still a single packaged product.  See also PackagedProductDefinition.package.containedItem.item(PackagedProductDefinition).'
    quantity: Optional_['integer'] = Field(default=None)
    'The quantity of this level of packaging in the package that contains it. If specified, the outermost level is always 1.'
    material: List_['CodeableConcept'] = Field(default_factory=list)
    'Material type of the package item.'
    property: List_['PackagedProductDefinitionPackageProperty'] = Field(default_factory=list)
    'General characteristics of this item.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'An identifier that is specific to this particular part of the packaging. Including possibly Data Carrier Identifier (a GS1 barcode).'
    manufacturer: List_['Reference'] = Field(default_factory=list)
    'Manufacturer of this package Item. When there are multiple it means these are all possible manufacturers.'
    containedItem: List_['PackagedProductDefinitionPackageContainedItem'] = Field(default_factory=list)
    'The item(s) within the packaging.'
    shelfLifeStorage: List_['PackagedProductDefinitionPackageShelfLifeStorage'] = Field(default_factory=list)
    'Shelf Life and storage information.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    alternateMaterial: List_['CodeableConcept'] = Field(default_factory=list)
    'A possible alternate material for this part of the packaging, that is allowed to be used instead of the usual material (e.g. different types of plastic for a blister sleeve).'


class PackagedProductDefinitionPackageShelfLifeStorage(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Shelf Life and storage information."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'This describes the shelf life, taking into account various scenarios such as shelf life of the packaged Medicinal Product itself, shelf life after transformation where necessary and shelf life after the first opening of a bottle, etc. The shelf life type shall be specified using an appropriate controlled vocabulary The controlled term and the controlled term identifier shall be specified.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    periodDuration: Optional_['Duration'] = Field(default=None)
    'The shelf life time period can be specified using a numerical value for the period of time and its unit of time measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.'
    periodString: Optional_['string'] = Field(default=None)
    'The shelf life time period can be specified using a numerical value for the period of time and its unit of time measurement The unit of measurement shall be specified in accordance with ISO 11240 and the resulting terminology The symbol and the symbol identifier shall be used.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    specialPrecautionsForStorage: List_['CodeableConcept'] = Field(default_factory=list)
    'Special precautions for storage, if any, can be specified using an appropriate controlled vocabulary. The controlled term and the controlled term identifier shall be specified.'


class PackagedProductDefinitionPackageContainedItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The item(s) within the packaging."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    item: 'CodeableReference' = Field(default=...)
    'The actual item(s) of medication, as manufactured, or a device (typically, but not necessarily, a co-packaged one), or other medically related item (such as food, biologicals, raw materials, medical fluids, gases etc.), as contained in the package. This also allows another whole packaged product to be included, which is solely for the case where a package of other entire packages is wanted - such as a wholesale or distribution pack (for layers within one package, use PackagedProductDefinition.package.package).'
    amount: Optional_['Quantity'] = Field(default=None)
    'The number of this type of item within this packaging.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PackagedProductDefinitionPackageProperty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """General characteristics of this item."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'A code expressing the type of characteristic.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A value for the characteristic.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'A value for the characteristic.'
    valueDate: Optional_['date'] = Field(default=None)
    'A value for the characteristic.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'A value for the characteristic.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'A value for the characteristic.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PackagedProductDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A medically related item or items, in a container or package."""
    resourceType: Literal_['PackagedProductDefinition'] = Field(default=...)
    'A medically related item or items, in a container or package'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A name for this package. Typically what it would be listed as in a drug formulary or catalogue, inventory etc.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'A high level category e.g. medicinal product, raw material, shipping/transport container, etc.'
    status: Optional_['CodeableConcept'] = Field(default=None)
    'The status within the lifecycle of this item. A high level status, this is not intended to duplicate details carried elsewhere such as legal status, or authorization or marketing status.'
    package: Optional_['PackagedProductDefinitionPackage'] = Field(default=None)
    'A packaging item, as a container for medically related items, possibly with other packaging items within, or a packaging component, such as bottle cap (which is not a device or a medication manufactured item).'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier for this package as whole. Unique instance identifiers assigned to a package by manufacturers, regulators, drug catalogue custodians or other organizations.'
    packageFor: List_['Reference'] = Field(default_factory=list)
    'The product that this is a pack for.'
    statusDate: Optional_['dateTime'] = Field(default=None)
    'The date at which the given status became applicable.'
    description: Optional_['markdown'] = Field(default=None)
    'Textual description. Note that this is not the name of the package or product.'
    manufacturer: List_['Reference'] = Field(default_factory=list)
    'Manufacturer of this package type. When there are multiple it means these are all possible manufacturers.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    characteristic: List_['CodeableConcept'] = Field(default_factory=list)
    'Allows the key features to be recorded, such as "hospital pack", "nurse prescribable", "calendar pack".'
    marketingStatus: List_['MarketingStatus'] = Field(default_factory=list)
    'Allows specifying that an item is on the market for sale, or that it is not available, and the dates and locations associated.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    legalStatusOfSupply: List_['PackagedProductDefinitionLegalStatusOfSupply'] = Field(default_factory=list)
    'The legal status of supply of the packaged item as classified by the regulator.'
    copackagedIndicator: Optional_['boolean'] = Field(default=None)
    'States whether a drug product is supplied with another item such as a diluent or adjuvant.'
    containedItemQuantity: List_['Quantity'] = Field(default_factory=list)
    "A total of the complete count of contained items of a particular type/form, independent of sub-packaging or organization. This can be considered as the pack size. This attribute differs from containedItem.amount in that it can give a single aggregated count of all tablet types in a pack, even when these are different manufactured items. For example a pill pack of 21 tablets plus 7 sugar tablets, can be denoted here as '28 tablets'. This attribute is repeatable so that the different item types in one pack type can be counted (e.g. a count of vials and count of syringes). Each repeat must have different units, so that it is clear what the different sets of counted items are, and it is not intended to allow different counts of similar items (e.g. not '2 tubes and 3 tubes'). Repeats are not to be used to represent different pack sizes (e.g. 20 pack vs. 50 pack) - which would be different instances of this resource."


class ParametersParameter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A parameter passed to or received from the operation."""
    name: 'string' = Field(default=...)
    'The name of the parameter (reference to the operation definition).'
    part: List_['ParametersParameter'] = Field(default_factory=list)
    'A named part of a multi-part parameter.'
    valueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueCanonical: Optional_['canonical'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueCode: Optional_['code'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueDate: Optional_['date'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueId: Optional_['id'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueInstant: Optional_['instant'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueMarkdown: Optional_['markdown'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueOid: Optional_['oid'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valuePositiveInt: Optional_['positiveInt'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueString: Optional_['string'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueTime: Optional_['time'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueUri: Optional_['uri'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueUrl: Optional_['url'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueUuid: Optional_['uuid'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueAddress: Optional_['Address'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueAge: Optional_['Age'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueAnnotation: Optional_['Annotation'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueCoding: Optional_['Coding'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueContactPoint: Optional_['ContactPoint'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueCount: Optional_['Count'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueDistance: Optional_['Distance'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueDuration: Optional_['Duration'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueHumanName: Optional_['HumanName'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueIdentifier: Optional_['Identifier'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueMoney: Optional_['Money'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valuePeriod: Optional_['Period'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueRange: Optional_['Range'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueRatio: Optional_['Ratio'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueSampledData: Optional_['SampledData'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueSignature: Optional_['Signature'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueTiming: Optional_['Timing'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueContactDetail: Optional_['ContactDetail'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueContributor: Optional_['Contributor'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueExpression: Optional_['Expression'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueParameterDefinition: Optional_['ParameterDefinition'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueRelatedArtifact: Optional_['RelatedArtifact'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueTriggerDefinition: Optional_['TriggerDefinition'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueUsageContext: Optional_['UsageContext'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueDosage: Optional_['Dosage'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    valueMeta: Optional_['Meta'] = Field(default=None)
    'Conveys the content if the parameter is a data type.'
    resource: Optional_['AnyResource'] = Field(default=None)
    'If the parameter is a whole resource.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class Parameters(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource is a non-persisted resource used to pass information into and back from an [operation](operations.html). It has no other use, and there is no RESTful endpoint associated with it."""
    resourceType: Literal_['Parameters'] = Field(default=...)
    'Operation Request or Response'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    parameter: List_['ParametersParameter'] = Field(default_factory=list)
    'A parameter passed to or received from the operation.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'


class PatientCommunication(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A language which may be used to communicate with the patient about his or her health."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    language: 'CodeableConcept' = Field(default=...)
    'The ISO-639-1 alpha 2 code in lower case for the language, optionally followed by a hyphen and the ISO-3166-1 alpha 2 code for the region in upper case; e.g. "en" for English, or "en-US" for American English versus "en-EN" for England English.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    preferred: Optional_['boolean'] = Field(default=None)
    'Indicates whether or not the patient prefers this language (over other languages he masters up a certain level).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PatientContact(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A contact party (e.g. guardian, partner, friend) for the patient."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['HumanName'] = Field(default=None)
    'A name associated with the contact person.'
    gender: Optional_['code'] = Field(default=None)
    'Administrative Gender - the gender that the contact person is considered to have for administration and record keeping purposes.'
    period: Optional_['Period'] = Field(default=None)
    'The period during which this contact person or organization is valid to be contacted relating to this patient.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'A contact detail for the person, e.g. a telephone number or an email address.'
    address: Optional_['Address'] = Field(default=None)
    'Address for the contact person.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    relationship: List_['CodeableConcept'] = Field(default_factory=list)
    'The nature of the relationship between the patient and the contact person.'
    organization: Optional_['Reference'] = Field(default=None)
    'Organization on behalf of which the contact is acting or for which the contact is working.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PatientLink(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Link to another patient resource that concerns the same actual patient."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of link between this patient resource and another patient resource.'
    other: 'Reference' = Field(default=...)
    'The other patient resource that the link refers to.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Patient(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Demographics and other administrative information about an individual or animal receiving care or other health-related services."""
    resourceType: Literal_['Patient'] = Field(default=...)
    'Information about an individual or animal receiving health care services'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: List_['HumanName'] = Field(default_factory=list)
    'A name associated with the individual.'
    link: List_['PatientLink'] = Field(default_factory=list)
    'Link to another patient resource that concerns the same actual patient.'
    photo: List_['Attachment'] = Field(default_factory=list)
    'Image of the patient.'
    active: Optional_['boolean'] = Field(default=None)
    "Whether this patient record is in active use. \nMany systems use this property to mark as non-current patients, such as those that have not been seen for a period of time based on an organization's business rules.\n\nIt is often used to filter patient lists to exclude inactive patients\n\nDeceased patients may also be marked as inactive for the same reasons, but may be active for some time after death."
    gender: Optional_['code'] = Field(default=None)
    'Administrative Gender - the gender that the patient is considered to have for administration and record keeping purposes.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'A contact detail (e.g. a telephone number or an email address) by which the individual may be contacted.'
    address: List_['Address'] = Field(default_factory=list)
    'An address for the individual.'
    contact: List_['PatientContact'] = Field(default_factory=list)
    'A contact party (e.g. guardian, partner, friend) for the patient.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    birthDate: Optional_['date'] = Field(default=None)
    'The date of birth for the individual.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'An identifier for this patient.'
    deceasedBoolean: Optional_['boolean'] = Field(default=None)
    'Indicates if the individual is deceased or not.'
    deceasedDateTime: Optional_['dateTime'] = Field(default=None)
    'Indicates if the individual is deceased or not.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    maritalStatus: Optional_['CodeableConcept'] = Field(default=None)
    "This field contains a patient's most recent marital (civil) status."
    communication: List_['PatientCommunication'] = Field(default_factory=list)
    'A language which may be used to communicate with the patient about his or her health.'
    multipleBirthBoolean: Optional_['boolean'] = Field(default=None)
    'Indicates whether the patient is part of a multiple (boolean) or indicates the actual birth order (integer).'
    multipleBirthInteger: Optional_['integer'] = Field(default=None)
    'Indicates whether the patient is part of a multiple (boolean) or indicates the actual birth order (integer).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    generalPractitioner: List_['Reference'] = Field(default_factory=list)
    "Patient's nominated care provider."
    managingOrganization: Optional_['Reference'] = Field(default=None)
    'Organization that is the custodian of the patient record.'


class PaymentNotice(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource provides the status of the payment for goods and services rendered, and the request and response resource references."""
    resourceType: Literal_['PaymentNotice'] = Field(default=...)
    'PaymentNotice request'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    payee: Optional_['Reference'] = Field(default=None)
    'The party who will receive or has received payment that is the subject of this notification.'
    status: 'code' = Field(default=...)
    'The status of the resource instance.'
    amount: 'Money' = Field(default=...)
    'The amount sent to the payee.'
    request: Optional_['Reference'] = Field(default=None)
    'Reference of resource for which payment is being made.'
    created: 'dateTime' = Field(default=...)
    'The date when this resource was created.'
    payment: 'Reference' = Field(default=...)
    'A reference to the payment which is the subject of this notice.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    response: Optional_['Reference'] = Field(default=None)
    'Reference of response to resource for which payment is being made.'
    provider: Optional_['Reference'] = Field(default=None)
    'The practitioner who is responsible for the services rendered to the patient.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    recipient: 'Reference' = Field(default=...)
    'The party who is notified of the payment status.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this payment notice.'
    paymentDate: Optional_['date'] = Field(default=None)
    'The date when the above payment action occurred.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    paymentStatus: Optional_['CodeableConcept'] = Field(default=None)
    'A code indicating whether payment has been sent or cleared.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PaymentReconciliationProcessNote(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A note that describes or explains the processing in a human readable form."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['code'] = Field(default=None)
    'The business purpose of the note text.'
    text: Optional_['string'] = Field(default=None)
    'The explanation or description associated with the processing.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PaymentReconciliationDetail(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Distribution of the payment amount for a previously acknowledged payable."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'Code to indicate the nature of the payment.'
    payee: Optional_['Reference'] = Field(default=None)
    'The party which is receiving the payment.'
    amount: Optional_['Money'] = Field(default=None)
    'The monetary amount allocated from the total payment to the payable.'
    request: Optional_['Reference'] = Field(default=None)
    'A resource, such as a Claim, the evaluation of which could lead to payment.'
    response: Optional_['Reference'] = Field(default=None)
    'A resource, such as a ClaimResponse, which contains a commitment to payment.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    submitter: Optional_['Reference'] = Field(default=None)
    'The party which submitted the claim or financial transaction.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Unique identifier for the current payment item for the referenced payable.'
    predecessor: Optional_['Identifier'] = Field(default=None)
    'Unique identifier for the prior payment item for the referenced payable.'
    responsible: Optional_['Reference'] = Field(default=None)
    'A reference to the individual who is responsible for inquiries regarding the response and its payment.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['date'] = Field(default=None)
    'The date from the response resource containing a commitment to pay.'


class PaymentReconciliation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource provides the details including amount of a payment and allocates the payment items being paid."""
    resourceType: Literal_['PaymentReconciliation'] = Field(default=...)
    'PaymentReconciliation resource'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: 'code' = Field(default=...)
    'The status of the resource instance.'
    period: Optional_['Period'] = Field(default=None)
    'The period of time for which payments have been gathered into this bulk payment for settlement.'
    detail: List_['PaymentReconciliationDetail'] = Field(default_factory=list)
    'Distribution of the payment amount for a previously acknowledged payable.'
    created: 'dateTime' = Field(default=...)
    'The date when the resource was created.'
    request: Optional_['Reference'] = Field(default=None)
    'Original request resource reference.'
    outcome: Optional_['code'] = Field(default=None)
    'The outcome of a request for a reconciliation.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    formCode: Optional_['CodeableConcept'] = Field(default=None)
    'A code for the form to be used for printing the content.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    requestor: Optional_['Reference'] = Field(default=None)
    'The practitioner who is responsible for the services rendered to the patient.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this payment reconciliation.'
    disposition: Optional_['string'] = Field(default=None)
    'A human readable description of the status of the request for the reconciliation.'
    paymentDate: 'date' = Field(default=...)
    'The date of payment as indicated on the financial instrument.'
    processNote: List_['PaymentReconciliationProcessNote'] = Field(default_factory=list)
    'A note that describes or explains the processing in a human readable form.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    paymentIssuer: Optional_['Reference'] = Field(default=None)
    'The party who generated the payment.'
    paymentAmount: 'Money' = Field(default=...)
    'Total payment amount as indicated on the financial instrument.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    paymentIdentifier: Optional_['Identifier'] = Field(default=None)
    "Issuer's unique identifier for the payment instrument."


class PersonLink(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Link to a resource that concerns the same actual person."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    target: 'Reference' = Field(default=...)
    'The resource to which this actual person is associated.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    assurance: Optional_['code'] = Field(default=None)
    'Level of assurance that this link is associated with the target resource.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Person(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Demographics and administrative information about a person independent of a specific health-related context."""
    resourceType: Literal_['Person'] = Field(default=...)
    'A generic person record'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: List_['HumanName'] = Field(default_factory=list)
    'A name associated with the person.'
    link: List_['PersonLink'] = Field(default_factory=list)
    'Link to a resource that concerns the same actual person.'
    photo: Optional_['Attachment'] = Field(default=None)
    'An image that can be displayed as a thumbnail of the person to enhance the identification of the individual.'
    gender: Optional_['code'] = Field(default=None)
    'Administrative Gender.'
    active: Optional_['boolean'] = Field(default=None)
    "Whether this person's record is in active use."
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'A contact detail for the person, e.g. a telephone number or an email address.'
    address: List_['Address'] = Field(default_factory=list)
    'One or more addresses for the person.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    birthDate: Optional_['date'] = Field(default=None)
    'The birth date for the person.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier for a person within a particular scope.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    managingOrganization: Optional_['Reference'] = Field(default=None)
    'The organization that is the custodian of the person record.'


class PlanDefinitionAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An action or group of actions to be taken as part of the plan. For example, in clinical care, an action would be to prescribe a particular indicated medication, or perform a particular test as appropriate. In pharmaceutical quality, an action would be the test that needs to be performed on a drug product as defined in the quality specification."""
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of action to perform (create, update, remove).'
    title: Optional_['string'] = Field(default=None)
    'The textual description of the action displayed to a user. For example, when the action is a test to be performed, the title would be the title of the test such as Assay by HPLC.'
    input: List_['DataRequirement'] = Field(default_factory=list)
    'Defines input data requirements for the action.'
    prefix: Optional_['string'] = Field(default=None)
    'A user-visible prefix for the action.'
    reason: List_['CodeableConcept'] = Field(default_factory=list)
    'A description of why this action is necessary or appropriate.'
    goalId: List_['id'] = Field(default_factory=list)
    'Identifies goals that this action supports. The reference must be to a goal element defined within this plan definition. In pharmaceutical quality, a goal represents acceptance criteria (Goal) for a given action (Test), so the goalId would be the unique id of a defined goal element establishing the acceptance criteria for the action.'
    output: List_['DataRequirement'] = Field(default_factory=list)
    'Defines the outputs of the action, if any.'
    action: List_['PlanDefinitionAction'] = Field(default_factory=list)
    'Sub actions that are contained within the action. The behavior of this action determines the functionality of the sub-actions. For example, a selection behavior of at-most-one indicates that of the sub-actions, at most one may be chosen as part of realizing the action definition.'
    trigger: List_['TriggerDefinition'] = Field(default_factory=list)
    'A description of when the action should be triggered.'
    priority: Optional_['code'] = Field(default=None)
    'Indicates how quickly the action should be addressed with respect to other actions.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    condition: List_['PlanDefinitionActionCondition'] = Field(default_factory=list)
    'An expression that describes applicability criteria or start/stop conditions for the action.'
    timingDateTime: Optional_['dateTime'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingAge: Optional_['Age'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingPeriod: Optional_['Period'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingDuration: Optional_['Duration'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingRange: Optional_['Range'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingTiming: Optional_['Timing'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    transform: Optional_['canonical'] = Field(default=None)
    'A reference to a StructureMap resource that defines a transform that can be executed to produce the intent resource using the ActivityDefinition instance as the input.'
    subjectCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A code, group definition, or canonical reference that describes the intended subject of the action and its children, if any. Canonical references are allowed to support the definition of protocols for drug and substance quality specifications, and is allowed to reference a MedicinalProductDefinition, SubstanceDefinition, AdministrableProductDefinition, ManufacturedItemDefinition, or PackagedProductDefinition resource.'
    subjectReference: Optional_['Reference'] = Field(default=None)
    'A code, group definition, or canonical reference that describes the intended subject of the action and its children, if any. Canonical references are allowed to support the definition of protocols for drug and substance quality specifications, and is allowed to reference a MedicinalProductDefinition, SubstanceDefinition, AdministrableProductDefinition, ManufacturedItemDefinition, or PackagedProductDefinition resource.'
    subjectCanonical: Optional_['canonical'] = Field(default=None)
    'A code, group definition, or canonical reference that describes the intended subject of the action and its children, if any. Canonical references are allowed to support the definition of protocols for drug and substance quality specifications, and is allowed to reference a MedicinalProductDefinition, SubstanceDefinition, AdministrableProductDefinition, ManufacturedItemDefinition, or PackagedProductDefinition resource.'
    description: Optional_['string'] = Field(default=None)
    'A brief description of the action used to provide a summary to display to the user.'
    participant: List_['PlanDefinitionActionParticipant'] = Field(default_factory=list)
    'Indicates who should participate in performing the action described.'
    dynamicValue: List_['PlanDefinitionActionDynamicValue'] = Field(default_factory=list)
    "Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result."
    documentation: List_['RelatedArtifact'] = Field(default_factory=list)
    'Didactic or other informational resources associated with the action that can be provided to the CDS recipient. Information resources can include inline text commentary and links to web resources.'
    relatedAction: List_['PlanDefinitionActionRelatedAction'] = Field(default_factory=list)
    'A relationship to another action such as "before" or "30-60 minutes after start of".'
    definitionCanonical: Optional_['canonical'] = Field(default=None)
    'A reference to an ActivityDefinition that describes the action to be taken in detail, or a PlanDefinition that describes a series of actions to be taken.'
    definitionUri: Optional_['uri'] = Field(default=None)
    'A reference to an ActivityDefinition that describes the action to be taken in detail, or a PlanDefinition that describes a series of actions to be taken.'
    textEquivalent: Optional_['string'] = Field(default=None)
    'A text equivalent of the action to be performed. This provides a human-interpretable description of the action when the definition is consumed by a system that might not be capable of interpreting it dynamically.'
    groupingBehavior: Optional_['code'] = Field(default=None)
    'Defines the grouping behavior for the action and its children.'
    requiredBehavior: Optional_['code'] = Field(default=None)
    'Defines the required behavior for the action.'
    precheckBehavior: Optional_['code'] = Field(default=None)
    'Defines whether the action should usually be preselected.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    selectionBehavior: Optional_['code'] = Field(default=None)
    'Defines the selection behavior for the action and its children.'
    cardinalityBehavior: Optional_['code'] = Field(default=None)
    'Defines whether the action can be selected multiple times.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'A code that provides a meaning, grouping, or classification for the action or action group. For example, a section may have a LOINC code for the section of a documentation template. In pharmaceutical quality, an action (Test) such as pH could be classified as a physical property.'


class PlanDefinitionActionRelatedAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A relationship to another action such as "before" or "30-60 minutes after start of"."""
    actionId: 'id' = Field(default=...)
    'The element id of the related action.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    offsetDuration: Optional_['Duration'] = Field(default=None)
    'A duration or range of durations to apply to the relationship. For example, 30-60 minutes before.'
    offsetRange: Optional_['Range'] = Field(default=None)
    'A duration or range of durations to apply to the relationship. For example, 30-60 minutes before.'
    relationship: 'code' = Field(default=...)
    'The relationship of this action to the related action.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class PlanDefinitionActionDynamicValue(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    path: Optional_['string'] = Field(default=None)
    'The path to the element to be customized. This is the path on the resource that will hold the result of the calculation defined by the expression. The specified path SHALL be a FHIRPath resolveable on the specified target type of the ActivityDefinition, and SHALL consist only of identifiers, constant indexers, and a restricted subset of functions. The path is allowed to contain qualifiers (.) to traverse sub-elements, as well as indexers ([x]) to traverse multiple-cardinality sub-elements (see the [Simple FHIRPath Profile](fhirpath.html#simple) for full details).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: Optional_['Expression'] = Field(default=None)
    'An expression specifying the value of the customized element.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PlanDefinitionActionParticipant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates who should participate in performing the action described."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of participant in the action.'
    role: Optional_['CodeableConcept'] = Field(default=None)
    'The role the participant should play in performing the described action.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PlanDefinitionActionCondition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An expression that describes applicability criteria or start/stop conditions for the action."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    kind: 'code' = Field(default=...)
    'The kind of condition.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: Optional_['Expression'] = Field(default=None)
    'An expression that returns true or false, indicating whether the condition is satisfied.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PlanDefinitionGoal(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A goal describes an expected outcome that activities within the plan are intended to achieve. For example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, meeting the acceptance criteria for a test as specified by a quality specification, etc."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    start: Optional_['CodeableConcept'] = Field(default=None)
    'The event after which the goal should begin being pursued.'
    target: List_['PlanDefinitionGoalTarget'] = Field(default_factory=list)
    'Indicates what should be done and within what timeframe.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates a category the goal falls within.'
    priority: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the expected level of importance associated with reaching/sustaining the defined goal.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    addresses: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies problems, conditions, issues, or concerns the goal is intended to address.'
    description: 'CodeableConcept' = Field(default=...)
    'Human-readable and/or coded description of a specific desired objective of care, such as "control blood pressure" or "negotiate an obstacle course" or "dance with child at wedding".'
    documentation: List_['RelatedArtifact'] = Field(default_factory=list)
    'Didactic or other informational resources associated with the goal that provide further supporting information about the goal. Information resources can include inline text commentary and links to web resources.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PlanDefinitionGoalTarget(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Indicates what should be done and within what timeframe."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    due: Optional_['Duration'] = Field(default=None)
    'Indicates the timeframe after the start of the goal in which the goal should be met.'
    measure: Optional_['CodeableConcept'] = Field(default=None)
    'The parameter whose value is to be tracked, e.g. body weight, blood pressure, or hemoglobin A1c level.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    detailQuantity: Optional_['Quantity'] = Field(default=None)
    'The target value of the measure to be achieved to signify fulfillment of the goal, e.g. 150 pounds or 7.0%, or in the case of pharmaceutical quality - NMT 0.6%, Clear solution, etc. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any value at or above the low value.'
    detailRange: Optional_['Range'] = Field(default=None)
    'The target value of the measure to be achieved to signify fulfillment of the goal, e.g. 150 pounds or 7.0%, or in the case of pharmaceutical quality - NMT 0.6%, Clear solution, etc. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any value at or above the low value.'
    detailCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The target value of the measure to be achieved to signify fulfillment of the goal, e.g. 150 pounds or 7.0%, or in the case of pharmaceutical quality - NMT 0.6%, Clear solution, etc. Either the high or low or both values of the range can be specified. When a low value is missing, it indicates that the goal is achieved at any value at or below the high value. Similarly, if the high value is missing, it indicates that the goal is achieved at any value at or above the low value.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PlanDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """This resource allows for the definition of various types of plans as a sharable, consumable, and executable artifact. The resource is general enough to support the description of a broad range of clinical and non-clinical artifacts such as clinical decision support rules, order sets, protocols, and drug quality specifications."""
    resourceType: Literal_['PlanDefinition'] = Field(default=...)
    'The definition of a plan for a series of actions, independent of any specific patient or context'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this plan definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this plan definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the plan definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the plan definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'A high-level category for the plan definition that distinguishes the kinds of systems that would be interested in the plan definition.'
    goal: List_['PlanDefinitionGoal'] = Field(default_factory=list)
    'A goal describes an expected outcome that activities within the plan are intended to achieve. For example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, meeting the acceptance criteria for a test as specified by a quality specification, etc.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the plan definition.'
    usage: Optional_['string'] = Field(default=None)
    'A detailed description of how the plan definition is used from a clinical perspective.'
    topic: List_['CodeableConcept'] = Field(default_factory=list)
    'Descriptive topics related to the content of the plan definition. Topics provide a high-level categorization of the definition that can be useful for filtering and searching.'
    status: 'code' = Field(default=...)
    'The status of this plan definition. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual or organization primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for internal coherence of the content.'
    action: List_['PlanDefinitionAction'] = Field(default_factory=list)
    'An action or group of actions to be taken as part of the plan. For example, in clinical care, an action would be to prescribe a particular indicated medication, or perform a particular test as appropriate. In pharmaceutical quality, an action would be the test that needs to be performed on a drug product as defined in the quality specification.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the plan definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the plan definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active artifacts.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this plan definition is needed and why it has been designed as it has.'
    library: List_['canonical'] = Field(default_factory=list)
    'A reference to a Library resource containing any formal logic used by the plan definition.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    subtitle: Optional_['string'] = Field(default=None)
    'An explanatory or alternate title for the plan definition giving additional information about its content.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization responsible for officially endorsing the content for use in some setting.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the plan definition.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the plan definition and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the plan definition.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this plan definition when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    subjectCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A code, group definition, or canonical reference that describes  or identifies the intended subject of the plan definition. Canonical references are allowed to support the definition of protocols for drug and substance quality specifications, and is allowed to reference a MedicinalProductDefinition, SubstanceDefinition, AdministrableProductDefinition, ManufacturedItemDefinition, or PackagedProductDefinition resource.'
    subjectReference: Optional_['Reference'] = Field(default=None)
    'A code, group definition, or canonical reference that describes  or identifies the intended subject of the plan definition. Canonical references are allowed to support the definition of protocols for drug and substance quality specifications, and is allowed to reference a MedicinalProductDefinition, SubstanceDefinition, AdministrableProductDefinition, ManufacturedItemDefinition, or PackagedProductDefinition resource.'
    subjectCanonical: Optional_['canonical'] = Field(default=None)
    'A code, group definition, or canonical reference that describes  or identifies the intended subject of the plan definition. Canonical references are allowed to support the definition of protocols for drug and substance quality specifications, and is allowed to reference a MedicinalProductDefinition, SubstanceDefinition, AdministrableProductDefinition, ManufacturedItemDefinition, or PackagedProductDefinition resource.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate plan definition instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the plan definition from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this plan definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the plan definition is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the plan definition content was or is planned to be in active use.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Related artifacts such as additional documentation, justification, or bibliographic references.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the plan definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the plan definition changes.'


class PractitionerQualification(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The official certifications, training, and licenses that authorize or otherwise pertain to the provision of care by the practitioner.  For example, a medical license issued by a medical board authorizing the practitioner to practice medicine within a certian locality."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: 'CodeableConcept' = Field(default=...)
    'Coded representation of the qualification.'
    period: Optional_['Period'] = Field(default=None)
    'Period during which the qualification is valid.'
    issuer: Optional_['Reference'] = Field(default=None)
    'Organization that regulates and issues the qualification.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    "An identifier that applies to this person's qualification in this role."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Practitioner(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A person who is directly or indirectly involved in the provisioning of healthcare."""
    resourceType: Literal_['Practitioner'] = Field(default=...)
    'A person with a  formal responsibility in the provisioning of healthcare or related services'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: List_['HumanName'] = Field(default_factory=list)
    'The name(s) associated with the practitioner.'
    photo: List_['Attachment'] = Field(default_factory=list)
    'Image of the person.'
    active: Optional_['boolean'] = Field(default=None)
    "Whether this practitioner's record is in active use."
    gender: Optional_['code'] = Field(default=None)
    'Administrative Gender - the gender that the person is considered to have for administration and record keeping purposes.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'A contact detail for the practitioner, e.g. a telephone number or an email address.'
    address: List_['Address'] = Field(default_factory=list)
    'Address(es) of the practitioner that are not role specific (typically home address). \rWork addresses are not typically entered in this property as they are usually role dependent.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    birthDate: Optional_['date'] = Field(default=None)
    'The date of birth for the practitioner.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'An identifier that applies to this person in this role.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    qualification: List_['PractitionerQualification'] = Field(default_factory=list)
    'The official certifications, training, and licenses that authorize or otherwise pertain to the provision of care by the practitioner.  For example, a medical license issued by a medical board authorizing the practitioner to practice medicine within a certian locality.'
    communication: List_['CodeableConcept'] = Field(default_factory=list)
    'A language the practitioner can use in patient communication.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PractitionerRoleAvailableTime(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A collection of times the practitioner is available or performing this role at the location and/or healthcareservice."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    allDay: Optional_['boolean'] = Field(default=None)
    'Is this always available? (hence times are irrelevant) e.g. 24 hour service.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    daysOfWeek: List_['code'] = Field(default_factory=list)
    'Indicates which days of the week are available between the start and end Times.'
    availableEndTime: Optional_['time'] = Field(default=None)
    'The closing time of day. Note: If the AllDay flag is set, then this time is ignored.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    availableStartTime: Optional_['time'] = Field(default=None)
    'The opening time of day. Note: If the AllDay flag is set, then this time is ignored.'


class PractitionerRoleNotAvailable(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The practitioner is not available or performing this role during this period of time due to the provided reason."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    during: Optional_['Period'] = Field(default=None)
    'Service is not available (seasonally or for a public holiday) from this date.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: 'string' = Field(default=...)
    'The reason that can be presented to the user as to why this time is not available.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class PractitionerRole(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A specific set of Roles/Locations/specialties/services that a practitioner may perform at an organization for a period of time."""
    resourceType: Literal_['PractitionerRole'] = Field(default=...)
    'Roles/organizations the practitioner is associated with'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    active: Optional_['boolean'] = Field(default=None)
    'Whether this practitioner role record is in active use.'
    period: Optional_['Period'] = Field(default=None)
    'The period during which the person is authorized to act as a practitioner in these role(s) for the organization.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'Contact details that are specific to the role/location/service.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    location: List_['Reference'] = Field(default_factory=list)
    'The location(s) at which this practitioner provides care.'
    endpoint: List_['Reference'] = Field(default_factory=list)
    'Technical endpoints providing access to services operated for the practitioner with this role.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    specialty: List_['CodeableConcept'] = Field(default_factory=list)
    'Specific specialty of the practitioner.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business Identifiers that are specific to a role/location.'
    practitioner: Optional_['Reference'] = Field(default=None)
    'Practitioner that is able to provide the defined services for the organization.'
    organization: Optional_['Reference'] = Field(default=None)
    'The organization where the Practitioner performs the roles associated.'
    notAvailable: List_['PractitionerRoleNotAvailable'] = Field(default_factory=list)
    'The practitioner is not available or performing this role during this period of time due to the provided reason.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    availableTime: List_['PractitionerRoleAvailableTime'] = Field(default_factory=list)
    'A collection of times the practitioner is available or performing this role at the location and/or healthcareservice.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    healthcareService: List_['Reference'] = Field(default_factory=list)
    "The list of healthcare services that this worker provides for this role's Organization/Location(s)."
    availabilityExceptions: Optional_['string'] = Field(default=None)
    'A description of site availability exceptions, e.g. public holiday availability. Succinctly describing all possible exceptions to normal site availability as details in the available Times and not available Times.'
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'Roles which this practitioner is authorized to perform for the organization.'


class ProcedureFocalDevice(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A device that is implanted, removed or otherwise manipulated (calibration, battery replacement, fitting a prosthesis, attaching a wound-vac, etc.) as a focal portion of the Procedure."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    action: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of change that happened to the device during the procedure.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    manipulated: 'Reference' = Field(default=...)
    'The device that was manipulated (changed) during the procedure.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ProcedurePerformer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Limited to "real" people rather than equipment."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    actor: 'Reference' = Field(default=...)
    'The practitioner who was involved in the procedure.'
    function: Optional_['CodeableConcept'] = Field(default=None)
    'Distinguishes the type of involvement of the performer in the procedure. For example, surgeon, anaesthetist, endoscopist.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    onBehalfOf: Optional_['Reference'] = Field(default=None)
    'The organization the device or practitioner was acting on behalf of.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Procedure(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An action that is or was performed on or for a patient. This can be a physical intervention like an operation, or less invasive like long term services, counseling, or hypnotherapy."""
    resourceType: Literal_['Procedure'] = Field(default=...)
    'An action that is being or was performed on a patient'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Any other notes and comments about the procedure.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'A larger event of which this particular procedure is a component or step.'
    status: 'code' = Field(default=...)
    'A code specifying the state of the procedure. Generally, this will be the in-progress or completed state.'
    report: List_['Reference'] = Field(default_factory=list)
    'This could be a histology result, pathology report, surgical report, etc.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A reference to a resource that contains details of the request for this procedure.'
    subject: 'Reference' = Field(default=...)
    'The person, animal or group on which the procedure was performed.'
    outcome: Optional_['CodeableConcept'] = Field(default=None)
    'The outcome of the procedure - did it resolve the reasons for the procedure being performed?'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'A code that classifies the procedure for searching, sorting and display purposes (e.g. "Surgical Procedure").'
    recorder: Optional_['Reference'] = Field(default=None)
    'Individual who recorded the record and takes responsibility for its content.'
    asserter: Optional_['Reference'] = Field(default=None)
    'Individual who is making the procedure statement.'
    location: Optional_['Reference'] = Field(default=None)
    'The location where the procedure actually happened.  E.g. a newborn at home, a tracheostomy at a restaurant.'
    bodySite: List_['CodeableConcept'] = Field(default_factory=list)
    'Detailed and structured anatomical location information. Multiple locations are allowed - e.g. multiple punch biopsies of a lesion.'
    followUp: List_['CodeableConcept'] = Field(default_factory=list)
    'If the procedure required specific follow up - e.g. removal of sutures. The follow up may be represented as a simple note or could potentially be more complex, in which case the CarePlan resource can be used.'
    usedCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Identifies coded items that were used as part of the procedure.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which this Procedure was created or performed or to which the creation of this record is tightly associated.'
    performer: List_['ProcedurePerformer'] = Field(default_factory=list)
    'Limited to "real" people rather than equipment.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this procedure by the performer or other systems which remain constant as the resource is updated and is propagated from server to server.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'The coded reason why the procedure was performed. This may be a coded entity of some type, or may simply be present as text.'
    focalDevice: List_['ProcedureFocalDevice'] = Field(default_factory=list)
    'A device that is implanted, removed or otherwise manipulated (calibration, battery replacement, fitting a prosthesis, attaching a wound-vac, etc.) as a focal portion of the Procedure.'
    statusReason: Optional_['CodeableConcept'] = Field(default=None)
    'Captures the reason for the current state of the procedure.'
    performedDateTime: Optional_['dateTime'] = Field(default=None)
    'Estimated or actual date, date-time, period, or age when the procedure was performed.  Allows a period to support complex procedures that span more than one date, and also allows for the length of the procedure to be captured.'
    performedPeriod: Optional_['Period'] = Field(default=None)
    'Estimated or actual date, date-time, period, or age when the procedure was performed.  Allows a period to support complex procedures that span more than one date, and also allows for the length of the procedure to be captured.'
    performedString: Optional_['string'] = Field(default=None)
    'Estimated or actual date, date-time, period, or age when the procedure was performed.  Allows a period to support complex procedures that span more than one date, and also allows for the length of the procedure to be captured.'
    performedAge: Optional_['Age'] = Field(default=None)
    'Estimated or actual date, date-time, period, or age when the procedure was performed.  Allows a period to support complex procedures that span more than one date, and also allows for the length of the procedure to be captured.'
    performedRange: Optional_['Range'] = Field(default=None)
    'Estimated or actual date, date-time, period, or age when the procedure was performed.  Allows a period to support complex procedures that span more than one date, and also allows for the length of the procedure to be captured.'
    complication: List_['CodeableConcept'] = Field(default_factory=list)
    "Any complications that occurred during the procedure, or in the immediate post-performance period. These are generally tracked separately from the notes, which will typically describe the procedure itself rather than any 'post procedure' issues."
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    usedReference: List_['Reference'] = Field(default_factory=list)
    'Identifies medications, devices and any other substance used as part of the procedure.'
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally maintained protocol, guideline, order set or other definition that is adhered to in whole or in part by this Procedure.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'The justification of why the procedure was performed.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    complicationDetail: List_['Reference'] = Field(default_factory=list)
    'Any complications that occurred during the procedure, or in the immediate post-performance period.'
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'The URL pointing to a FHIR-defined protocol, guideline, order set or other definition that is adhered to in whole or in part by this Procedure.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The specific procedure that is performed. Use text if the exact nature of the procedure cannot be coded (e.g. "Laparoscopic Appendectomy").'


class ProvenanceEntity(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An entity used in this activity."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: 'code' = Field(default=...)
    'How the entity was used during the activity.'
    what: 'Reference' = Field(default=...)
    'Identity of the  Entity used. May be a logical or physical uri and maybe absolute or relative.'
    agent: List_['ProvenanceAgent'] = Field(default_factory=list)
    "The entity is attributed to an agent to express the agent's responsibility for that entity, possibly along with other agents. This description can be understood as shorthand for saying that the agent was responsible for the activity which generated the entity."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ProvenanceAgent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An actor taking a role in an activity  for which it can be assigned some degree of responsibility for the activity taking place."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    who: 'Reference' = Field(default=...)
    'The individual, device or organization that participated in the event.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The participation the agent had with respect to the activity.'
    role: List_['CodeableConcept'] = Field(default_factory=list)
    'The function of the agent with respect to the activity. The security role enabling the agent with respect to the activity.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    onBehalfOf: Optional_['Reference'] = Field(default=None)
    'The individual, device, or organization for whom the change was made.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Provenance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Provenance of a resource is a record that describes entities and processes involved in producing and delivering or otherwise influencing that resource. Provenance provides a critical foundation for assessing authenticity, enabling trust, and allowing reproducibility. Provenance assertions are a form of contextual metadata and can themselves become important records with their own provenance. Provenance statement indicates clinical significance in terms of confidence in authenticity, reliability, and trustworthiness, integrity, and stage in lifecycle (e.g. Document Completion - has the artifact been legally authenticated), all of which may impact security, privacy, and trust policies."""
    resourceType: Literal_['Provenance'] = Field(default=...)
    'Who, What, When for a set of resources'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    agent: List_['ProvenanceAgent'] = Field(default=...)
    'An actor taking a role in an activity  for which it can be assigned some degree of responsibility for the activity taking place.'
    target: List_['Reference'] = Field(default=...)
    'The Reference(s) that were generated or updated by  the activity described in this resource. A provenance can point to more than one target if multiple resources were created/updated by the same activity.'
    policy: List_['uri'] = Field(default_factory=list)
    'Policy or plan the activity was defined by. Typically, a single activity may have multiple applicable policy documents, such as patient consent, guarantor funding, etc.'
    reason: List_['CodeableConcept'] = Field(default_factory=list)
    'The reason that the activity was taking place.'
    entity: List_['ProvenanceEntity'] = Field(default_factory=list)
    'An entity used in this activity.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    recorded: 'instant' = Field(default=...)
    'The instant of time at which the activity was recorded.'
    location: Optional_['Reference'] = Field(default=None)
    'Where the activity occurred, if relevant.'
    activity: Optional_['CodeableConcept'] = Field(default=None)
    'An activity is something that occurs over a period of time and acts upon or with entities; it may include consuming, processing, transforming, modifying, relocating, using, or generating entities.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    signature: List_['Signature'] = Field(default_factory=list)
    'A digital signature on the target Reference(s). The signer should match a Provenance.agent. The purpose of the signature is indicated.'
    occurredPeriod: Optional_['Period'] = Field(default=None)
    'The period during which the activity occurred.'
    occurredDateTime: Optional_['dateTime'] = Field(default=None)
    'The period during which the activity occurred.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class QuestionnaireItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A particular question, question grouping or display text that is part of the questionnaire."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    text: Optional_['string'] = Field(default=None)
    'The name of a section, the text of a question or text content for a display item.'
    type: 'code' = Field(default=...)
    'The type of questionnaire item this is - whether text for display, a grouping of other items or a particular type of data to be captured (string, integer, coded choice, etc.).'
    item: List_['QuestionnaireItem'] = Field(default_factory=list)
    'Text, questions and other groups to be nested beneath a question or group.'
    linkId: 'string' = Field(default=...)
    'An identifier that is unique within the Questionnaire allowing linkage to the equivalent item in a QuestionnaireResponse resource.'
    prefix: Optional_['string'] = Field(default=None)
    'A short label for a particular group, question or set of display text within the questionnaire used for reference by the individual completing the questionnaire.'
    repeats: Optional_['boolean'] = Field(default=None)
    'An indication, if true, that the item may occur multiple times in the response, collecting multiple answers for questions or multiple sets of answers for groups.'
    initial: List_['QuestionnaireItemInitial'] = Field(default_factory=list)
    'One or more values that should be pre-populated in the answer when initially rendering the questionnaire for user input.'
    required: Optional_['boolean'] = Field(default=None)
    'An indication, if true, that the item must be present in a "completed" QuestionnaireResponse.  If false, the item may be skipped when answering the questionnaire.'
    readOnly: Optional_['boolean'] = Field(default=None)
    'An indication, when true, that the value cannot be changed by a human respondent to the Questionnaire.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    maxLength: Optional_['integer'] = Field(default=None)
    'The maximum number of characters that are permitted in the answer to be considered a "valid" QuestionnaireResponse.'
    definition: Optional_['uri'] = Field(default=None)
    'This element is a URI that refers to an [ElementDefinition](elementdefinition.html) that provides information about this item, including information that might otherwise be included in the instance of the Questionnaire resource. A detailed description of the construction of the URI is shown in Comments, below. If this element is present then the following element values MAY be derived from the Element Definition if the corresponding elements of this Questionnaire resource instance have no value:\n\n* code (ElementDefinition.code) \n* type (ElementDefinition.type) \n* required (ElementDefinition.min) \n* repeats (ElementDefinition.max) \n* maxLength (ElementDefinition.maxLength) \n* answerValueSet (ElementDefinition.binding)\n* options (ElementDefinition.binding).'
    enableWhen: List_['QuestionnaireItemEnableWhen'] = Field(default_factory=list)
    'A constraint indicating that this item should only be enabled (displayed/allow answers to be captured) when the specified condition is true.'
    answerOption: List_['QuestionnaireItemAnswerOption'] = Field(default_factory=list)
    'One of the permitted answers for a "choice" or "open-choice" question.'
    enableBehavior: Optional_['code'] = Field(default=None)
    'Controls how multiple enableWhen values are interpreted -  whether all or any must be true.'
    answerValueSet: Optional_['canonical'] = Field(default=None)
    'A reference to a value set containing a list of codes representing permitted answers for a "choice" or "open-choice" question.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: List_['Coding'] = Field(default_factory=list)
    'A terminology code that corresponds to this group or question (e.g. a code from LOINC, which defines many questions and answers).'


class QuestionnaireItemAnswerOption(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """One of the permitted answers for a "choice" or "open-choice" question."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    valueInteger: Optional_['integer'] = Field(default=None)
    "A potential answer that's allowed as the answer to this question."
    valueDate: Optional_['date'] = Field(default=None)
    "A potential answer that's allowed as the answer to this question."
    valueTime: Optional_['time'] = Field(default=None)
    "A potential answer that's allowed as the answer to this question."
    valueString: Optional_['string'] = Field(default=None)
    "A potential answer that's allowed as the answer to this question."
    valueCoding: Optional_['Coding'] = Field(default=None)
    "A potential answer that's allowed as the answer to this question."
    valueReference: Optional_['Reference'] = Field(default=None)
    "A potential answer that's allowed as the answer to this question."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    initialSelected: Optional_['boolean'] = Field(default=None)
    'Indicates whether the answer value is selected when the list of possible answers is initially shown.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class QuestionnaireItemEnableWhen(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A constraint indicating that this item should only be enabled (displayed/allow answers to be captured) when the specified condition is true."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    question: 'string' = Field(default=...)
    'The linkId for the question whose answer (or lack of answer) governs whether this item is enabled.'
    operator: 'code' = Field(default=...)
    'Specifies the criteria by which the question is enabled.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    answerBoolean: Optional_['boolean'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    answerDecimal: Optional_['decimal'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    answerInteger: Optional_['integer'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    answerDate: Optional_['date'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    answerDateTime: Optional_['dateTime'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    answerTime: Optional_['time'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    answerString: Optional_['string'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    answerCoding: Optional_['Coding'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    answerQuantity: Optional_['Quantity'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    answerReference: Optional_['Reference'] = Field(default=None)
    'A value that the referenced question is tested using the specified operator in order for the item to be enabled.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class QuestionnaireItemInitial(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """One or more values that should be pre-populated in the answer when initially rendering the questionnaire for user input."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueDate: Optional_['date'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueTime: Optional_['time'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueString: Optional_['string'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueUri: Optional_['uri'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueCoding: Optional_['Coding'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The actual value to for an initial answer.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'The actual value to for an initial answer.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Questionnaire(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A structured set of questions intended to guide the collection of answers from end-users. Questionnaires provide detailed control over order, presentation, phraseology and grouping to allow coherent, consistent data collection."""
    resourceType: Literal_['Questionnaire'] = Field(default=...)
    'A structured set of questions'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this questionnaire when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this questionnaire is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the questionnaire is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the questionnaire. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    item: List_['QuestionnaireItem'] = Field(default_factory=list)
    'A particular question, question grouping or display text that is part of the questionnaire.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the questionnaire.'
    status: 'code' = Field(default=...)
    'The status of this questionnaire. Enables tracking the life-cycle of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the questionnaire when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the questionnaire author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this questionnaire is needed and why it has been designed as it has.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the questionnaire.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the questionnaire and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the questionnaire.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this questionnaire when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate questionnaire instances.'
    derivedFrom: List_['canonical'] = Field(default_factory=list)
    'The URL of a Questionnaire that this Questionnaire is based on.'
    subjectType: List_['code'] = Field(default_factory=list)
    'The types of subjects that can be the subject of responses created for the questionnaire.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the questionnaire from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this questionnaire is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the questionnaire is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the questionnaire content was or is planned to be in active use.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the questionnaire was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the questionnaire changes.'
    code: List_['Coding'] = Field(default_factory=list)
    'An identifier for this question or group of questions in a particular terminology such as LOINC.'


class QuestionnaireResponseItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A group or question item from the original questionnaire for which answers are provided."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    text: Optional_['string'] = Field(default=None)
    'Text that is displayed above the contents of the group or as the text of the question being answered.'
    item: List_['QuestionnaireResponseItem'] = Field(default_factory=list)
    'Questions or sub-groups nested beneath a question or group.'
    linkId: 'string' = Field(default=...)
    'The item from the Questionnaire that corresponds to this item in the QuestionnaireResponse resource.'
    answer: List_['QuestionnaireResponseItemAnswer'] = Field(default_factory=list)
    "The respondent's answer(s) to the question."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    definition: Optional_['uri'] = Field(default=None)
    'A reference to an [ElementDefinition](elementdefinition.html) that provides the details for the item.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class QuestionnaireResponseItemAnswer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The respondent's answer(s) to the question."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    item: List_['QuestionnaireResponseItem'] = Field(default_factory=list)
    'Nested groups and/or questions found within this particular answer.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueDate: Optional_['date'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueTime: Optional_['time'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueString: Optional_['string'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueUri: Optional_['uri'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueCoding: Optional_['Coding'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'The answer (or one of the answers) provided by the respondent to the question.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class QuestionnaireResponse(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A structured set of questions and their answers. The questions are ordered and grouped into coherent subsets, corresponding to the structure of the grouping of the questionnaire being responded to."""
    resourceType: Literal_['QuestionnaireResponse'] = Field(default=...)
    'A structured set of questions and their answers'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    item: List_['QuestionnaireResponseItem'] = Field(default_factory=list)
    'A group or question item from the original questionnaire for which answers are provided.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'A procedure or observation that this questionnaire was performed as part of the execution of.  For example, the surgery a checklist was executed as part of.'
    status: 'code' = Field(default=...)
    'The position of the questionnaire response within its overall lifecycle.'
    author: Optional_['Reference'] = Field(default=None)
    'Person who received the answers to the questions in the QuestionnaireResponse and recorded them in the system.'
    source: Optional_['Reference'] = Field(default=None)
    'The person who answered the questions about the subject.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'The order, proposal or plan that is fulfilled in whole or in part by this QuestionnaireResponse.  For example, a ServiceRequest seeking an intake assessment or a decision support recommendation to assess for post-partum depression.'
    subject: Optional_['Reference'] = Field(default=None)
    'The subject of the questionnaire response.  This could be a patient, organization, practitioner, device, etc.  This is who/what the answers apply to, but is not necessarily the source of information.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    authored: Optional_['dateTime'] = Field(default=None)
    'The date and/or time that this set of answers were last changed.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The Encounter during which this questionnaire response was created or to which the creation of this record is tightly associated.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'A business identifier assigned to a particular completed (or partially completed) questionnaire.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    questionnaire: Optional_['canonical'] = Field(default=None)
    'The Questionnaire that defines and organizes the questions for which answers are being provided.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class RegulatedAuthorizationCase(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The case or regulatory procedure for granting or amending a regulated authorization. An authorization is granted in response to submissions/applications by those seeking authorization. A case is the administrative process that deals with the application(s) that relate to this and assesses them. Note: This area is subject to ongoing review and the workgroup is seeking implementer feedback on its use (see link at bottom of page)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The defining type of case.'
    status: Optional_['CodeableConcept'] = Field(default=None)
    'The status associated with the case.'
    datePeriod: Optional_['Period'] = Field(default=None)
    'Relevant date for this case.'
    dateDateTime: Optional_['dateTime'] = Field(default=None)
    'Relevant date for this case.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Identifier by which this case can be referenced.'
    application: List_['RegulatedAuthorizationCase'] = Field(default_factory=list)
    'A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class RegulatedAuthorization(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Regulatory approval, clearance or licencing related to a regulated product, treatment, facility or activity that is cited in a guidance, regulation, rule or legislative act. An example is Market Authorization relating to a Medicinal Product."""
    resourceType: Literal_['RegulatedAuthorization'] = Field(default=...)
    'Regulatory approval, clearance or licencing related to a regulated product, treatment, facility or activity e.g. Market Authorization for a Medicinal Product'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Overall type of this authorization, for example drug marketing approval, orphan drug designation.'
    case: Optional_['RegulatedAuthorizationCase'] = Field(default=None)
    'The case or regulatory procedure for granting or amending a regulated authorization. An authorization is granted in response to submissions/applications by those seeking authorization. A case is the administrative process that deals with the application(s) that relate to this and assesses them. Note: This area is subject to ongoing review and the workgroup is seeking implementer feedback on its use (see link at bottom of page).'
    basis: List_['CodeableConcept'] = Field(default_factory=list)
    'The legal or regulatory framework against which this authorization is granted, or other reasons for it.'
    region: List_['CodeableConcept'] = Field(default_factory=list)
    'The territory (e.g., country, jurisdiction etc.) in which the authorization has been granted.'
    status: Optional_['CodeableConcept'] = Field(default=None)
    'The status that is authorised e.g. approved. Intermediate states and actions can be tracked with cases and applications.'
    holder: Optional_['Reference'] = Field(default=None)
    "The organization that has been granted this authorization, by some authoritative body (the 'regulator')."
    subject: List_['Reference'] = Field(default_factory=list)
    'The product type, treatment, facility or activity that is being authorized.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    regulator: Optional_['Reference'] = Field(default=None)
    'The regulatory authority or authorizing body granting the authorization. For example, European Medicines Agency (EMA), Food and Drug Administration (FDA), Health Canada (HC), etc.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifier for the authorization, typically assigned by the authorizing body.'
    statusDate: Optional_['dateTime'] = Field(default=None)
    'The date at which the current status was assigned.'
    indication: Optional_['CodeableReference'] = Field(default=None)
    'Condition for which the use of the regulated product applies.'
    description: Optional_['markdown'] = Field(default=None)
    'General textual supporting information.'
    intendedUse: Optional_['CodeableConcept'] = Field(default=None)
    'The intended use of the product, e.g. prevention, treatment, diagnosis.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    validityPeriod: Optional_['Period'] = Field(default=None)
    'The time period in which the regulatory approval, clearance or licencing is in effect. As an example, a Marketing Authorization includes the date of authorization and/or an expiration date.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class RelatedPersonCommunication(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A language which may be used to communicate with about the patient's health."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    language: 'CodeableConcept' = Field(default=...)
    'The ISO-639-1 alpha 2 code in lower case for the language, optionally followed by a hyphen and the ISO-3166-1 alpha 2 code for the region in upper case; e.g. "en" for English, or "en-US" for American English versus "en-EN" for England English.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    preferred: Optional_['boolean'] = Field(default=None)
    'Indicates whether or not the patient prefers this language (over other languages he masters up a certain level).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class RelatedPerson(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about a person that is involved in the care for a patient, but who is not the target of healthcare, nor has a formal responsibility in the care process."""
    resourceType: Literal_['RelatedPerson'] = Field(default=...)
    'A person that is related to a patient, but who is not a direct target of care'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: List_['HumanName'] = Field(default_factory=list)
    'A name associated with the person.'
    photo: List_['Attachment'] = Field(default_factory=list)
    'Image of the person.'
    active: Optional_['boolean'] = Field(default=None)
    'Whether this related person record is in active use.'
    gender: Optional_['code'] = Field(default=None)
    'Administrative Gender - the gender that the person is considered to have for administration and record keeping purposes.'
    period: Optional_['Period'] = Field(default=None)
    'The period of time during which this relationship is or was active. If there are no dates defined, then the interval is unknown.'
    patient: 'Reference' = Field(default=...)
    'The patient this person is related to.'
    telecom: List_['ContactPoint'] = Field(default_factory=list)
    'A contact detail for the person, e.g. a telephone number or an email address.'
    address: List_['Address'] = Field(default_factory=list)
    'Address where the related person can be contacted or visited.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    birthDate: Optional_['date'] = Field(default=None)
    'The date on which the related person was born.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier for a person within a particular scope.'
    relationship: List_['CodeableConcept'] = Field(default_factory=list)
    'The nature of the relationship between a patient and the related person.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    communication: List_['RelatedPersonCommunication'] = Field(default_factory=list)
    "A language which may be used to communicate with about the patient's health."
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class RequestGroupAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The actions, if any, produced by the evaluation of the artifact."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of action to perform (create, update, remove).'
    title: Optional_['string'] = Field(default=None)
    'The title of the action displayed to a user.'
    prefix: Optional_['string'] = Field(default=None)
    'A user-visible prefix for the action.'
    action: List_['RequestGroupAction'] = Field(default_factory=list)
    'Sub actions.'
    priority: Optional_['code'] = Field(default=None)
    'Indicates how quickly the action should be addressed with respect to other actions.'
    resource: Optional_['Reference'] = Field(default=None)
    'The resource that is the target of the action (e.g. CommunicationRequest).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    condition: List_['RequestGroupActionCondition'] = Field(default_factory=list)
    'An expression that describes applicability criteria, or start/stop conditions for the action.'
    timingDateTime: Optional_['dateTime'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingAge: Optional_['Age'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingPeriod: Optional_['Period'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingDuration: Optional_['Duration'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingRange: Optional_['Range'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    timingTiming: Optional_['Timing'] = Field(default=None)
    'An optional value describing when the action should be performed.'
    description: Optional_['string'] = Field(default=None)
    'A short description of the action used to provide a summary to display to the user.'
    participant: List_['Reference'] = Field(default_factory=list)
    'The participant that should perform or be responsible for this action.'
    documentation: List_['RelatedArtifact'] = Field(default_factory=list)
    'Didactic or other informational resources associated with the action that can be provided to the CDS recipient. Information resources can include inline text commentary and links to web resources.'
    relatedAction: List_['RequestGroupActionRelatedAction'] = Field(default_factory=list)
    'A relationship to another action such as "before" or "30-60 minutes after start of".'
    textEquivalent: Optional_['string'] = Field(default=None)
    'A text equivalent of the action to be performed. This provides a human-interpretable description of the action when the definition is consumed by a system that might not be capable of interpreting it dynamically.'
    groupingBehavior: Optional_['code'] = Field(default=None)
    'Defines the grouping behavior for the action and its children.'
    requiredBehavior: Optional_['code'] = Field(default=None)
    'Defines expectations around whether an action is required.'
    precheckBehavior: Optional_['code'] = Field(default=None)
    'Defines whether the action should usually be preselected.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    selectionBehavior: Optional_['code'] = Field(default=None)
    'Defines the selection behavior for the action and its children.'
    cardinalityBehavior: Optional_['code'] = Field(default=None)
    'Defines whether the action can be selected multiple times.'
    code: List_['CodeableConcept'] = Field(default_factory=list)
    'A code that provides meaning for the action or action group. For example, a section may have a LOINC code for a section of a documentation template.'


class RequestGroupActionRelatedAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A relationship to another action such as "before" or "30-60 minutes after start of"."""
    actionId: 'id' = Field(default=...)
    'The element id of the action this is related to.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    offsetDuration: Optional_['Duration'] = Field(default=None)
    'A duration or range of durations to apply to the relationship. For example, 30-60 minutes before.'
    offsetRange: Optional_['Range'] = Field(default=None)
    'A duration or range of durations to apply to the relationship. For example, 30-60 minutes before.'
    relationship: 'code' = Field(default=...)
    'The relationship of this action to the related action.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class RequestGroupActionCondition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An expression that describes applicability criteria, or start/stop conditions for the action."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    kind: 'code' = Field(default=...)
    'The kind of condition.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: Optional_['Expression'] = Field(default=None)
    'An expression that returns true or false, indicating whether or not the condition is satisfied.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class RequestGroup(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A group of related requests that can be used to capture intended activities that have inter-dependencies such as "give this medication after that one"."""
    resourceType: Literal_['RequestGroup'] = Field(default=...)
    'A group of related requests'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Provides a mechanism to communicate additional information about the response.'
    status: 'code' = Field(default=...)
    'The current state of the request. For request groups, the status reflects the status of all the requests in the group.'
    intent: 'code' = Field(default=...)
    'Indicates the level of authority/intentionality associated with the request and where the request fits into the workflow chain.'
    author: Optional_['Reference'] = Field(default=None)
    'Provides a reference to the author of the request group.'
    action: List_['RequestGroupAction'] = Field(default_factory=list)
    'The actions, if any, produced by the evaluation of the artifact.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A plan, proposal or order that is fulfilled in whole or in part by this request.'
    subject: Optional_['Reference'] = Field(default=None)
    'The subject for which the request group was created.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    replaces: List_['Reference'] = Field(default_factory=list)
    'Completed or terminated request(s) whose function is taken by this new request.'
    priority: Optional_['code'] = Field(default=None)
    'Indicates how quickly the request should be addressed with respect to other requests.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'Describes the context of the request group, if any.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Allows a service to provide a unique, business identifier for the request.'
    authoredOn: Optional_['dateTime'] = Field(default=None)
    'Indicates when the request group was created.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'Describes the reason for the request group in coded or textual form.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'A URL referencing an externally defined protocol, guideline, orderset or other definition that is adhered to in whole or in part by this request.'
    groupIdentifier: Optional_['Identifier'] = Field(default=None)
    'A shared identifier common to all requests that were authorized more or less simultaneously by a single author, representing the identifier of the requisition, prescription or similar form.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates another resource whose existence justifies this request group.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'A canonical URL referencing a FHIR-defined protocol, guideline, orderset or other definition that is adhered to in whole or in part by this request.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code that identifies what the overall request group is.'


class ResearchDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The ResearchDefinition resource describes the conditional state (population and any exposures being compared within the population) and outcome (if specified) that the knowledge (evidence, assertion, recommendation) is about."""
    resourceType: Literal_['ResearchDefinition'] = Field(default=...)
    'A research context or question'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this research definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this research definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the research definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the research definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the research definition.'
    usage: Optional_['string'] = Field(default=None)
    'A detailed description, from a clinical perspective, of how the ResearchDefinition is used.'
    topic: List_['CodeableConcept'] = Field(default_factory=list)
    'Descriptive topics related to the content of the ResearchDefinition. Topics provide a high-level categorization grouping types of ResearchDefinitions that can be useful for filtering and searching.'
    status: 'code' = Field(default=...)
    'The status of this research definition. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual or organization primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for internal coherence of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the research definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the research definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active artifacts.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    comment: List_['string'] = Field(default_factory=list)
    'A human-readable string to clarify or explain concepts about the resource.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this research definition is needed and why it has been designed as it has.'
    library: List_['canonical'] = Field(default_factory=list)
    'A reference to a Library resource containing the formal logic used by the ResearchDefinition.'
    outcome: Optional_['Reference'] = Field(default=None)
    'A reference to a ResearchElementDefinition resomece that defines the outcome for the research.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    subtitle: Optional_['string'] = Field(default=None)
    'An explanatory or alternate title for the ResearchDefinition giving additional information about its content.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization responsible for officially endorsing the content for use in some setting.'
    exposure: Optional_['Reference'] = Field(default=None)
    'A reference to a ResearchElementDefinition resource that defines the exposure for the research.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the research definition.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the research definition and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the research definition.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this research definition when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    shortTitle: Optional_['string'] = Field(default=None)
    'The short title provides an alternate title for use in informal descriptive contexts where the full, formal title is not necessary.'
    subjectCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The intended subjects for the ResearchDefinition. If this element is not provided, a Patient subject is assumed, but the subject of the ResearchDefinition can be anything.'
    subjectReference: Optional_['Reference'] = Field(default=None)
    'The intended subjects for the ResearchDefinition. If this element is not provided, a Patient subject is assumed, but the subject of the ResearchDefinition can be anything.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate research definition instances.'
    population: 'Reference' = Field(default=...)
    'A reference to a ResearchElementDefinition resource that defines the population for the research.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the research definition from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this research definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the research definition is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the research definition content was or is planned to be in active use.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Related artifacts such as additional documentation, justification, or bibliographic references.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    exposureAlternative: Optional_['Reference'] = Field(default=None)
    'A reference to a ResearchElementDefinition resource that defines the exposureAlternative for the research.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the research definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the research definition changes.'


class ResearchElementDefinitionCharacteristic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A characteristic that defines the members of the research element. Multiple characteristics are applied with "and" semantics."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    exclude: Optional_['boolean'] = Field(default=None)
    'When true, members with this characteristic are excluded from the element.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    usageContext: List_['UsageContext'] = Field(default_factory=list)
    'Use UsageContext to define the members of the population, such as Age Ranges, Genders, Settings.'
    definitionCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Define members of the research element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).'
    definitionCanonical: Optional_['canonical'] = Field(default=None)
    'Define members of the research element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).'
    definitionExpression: Optional_['Expression'] = Field(default=None)
    'Define members of the research element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).'
    definitionDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    'Define members of the research element using Codes (such as condition, medication, or observation), Expressions ( using an expression language such as FHIRPath or CQL) or DataRequirements (such as Diabetes diagnosis onset in the last year).'
    unitOfMeasure: Optional_['CodeableConcept'] = Field(default=None)
    'Specifies the UCUM unit for the outcome.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    studyEffectiveDateTime: Optional_['dateTime'] = Field(default=None)
    'Indicates what effective period the study covers.'
    studyEffectivePeriod: Optional_['Period'] = Field(default=None)
    'Indicates what effective period the study covers.'
    studyEffectiveDuration: Optional_['Duration'] = Field(default=None)
    'Indicates what effective period the study covers.'
    studyEffectiveTiming: Optional_['Timing'] = Field(default=None)
    'Indicates what effective period the study covers.'
    participantEffectiveDateTime: Optional_['dateTime'] = Field(default=None)
    'Indicates what effective period the study covers.'
    participantEffectivePeriod: Optional_['Period'] = Field(default=None)
    'Indicates what effective period the study covers.'
    participantEffectiveDuration: Optional_['Duration'] = Field(default=None)
    'Indicates what effective period the study covers.'
    participantEffectiveTiming: Optional_['Timing'] = Field(default=None)
    'Indicates what effective period the study covers.'
    studyEffectiveDescription: Optional_['string'] = Field(default=None)
    'A narrative description of the time period the study covers.'
    studyEffectiveGroupMeasure: Optional_['code'] = Field(default=None)
    'Indicates how elements are aggregated within the study effective period.'
    studyEffectiveTimeFromStart: Optional_['Duration'] = Field(default=None)
    'Indicates duration from the study initiation.'
    participantEffectiveDescription: Optional_['string'] = Field(default=None)
    'A narrative description of the time period the study covers.'
    participantEffectiveGroupMeasure: Optional_['code'] = Field(default=None)
    'Indicates how elements are aggregated within the study effective period.'
    participantEffectiveTimeFromStart: Optional_['Duration'] = Field(default=None)
    "Indicates duration from the participant's study entry."


class ResearchElementDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The ResearchElementDefinition resource describes a "PICO" element that knowledge (evidence, assertion, recommendation) is about."""
    resourceType: Literal_['ResearchElementDefinition'] = Field(default=...)
    'A population, intervention, or exposure definition'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this research element definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this research element definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the research element definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the research element definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    type: 'code' = Field(default=...)
    'The type of research element, a population, an exposure, or an outcome.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the research element definition.'
    usage: Optional_['string'] = Field(default=None)
    'A detailed description, from a clinical perspective, of how the ResearchElementDefinition is used.'
    topic: List_['CodeableConcept'] = Field(default_factory=list)
    'Descriptive topics related to the content of the ResearchElementDefinition. Topics provide a high-level categorization grouping types of ResearchElementDefinitions that can be useful for filtering and searching.'
    status: 'code' = Field(default=...)
    'The status of this research element definition. Enables tracking the life-cycle of the content.'
    author: List_['ContactDetail'] = Field(default_factory=list)
    'An individiual or organization primarily involved in the creation and maintenance of the content.'
    editor: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for internal coherence of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the research element definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the research element definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active artifacts.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    comment: List_['string'] = Field(default_factory=list)
    'A human-readable string to clarify or explain concepts about the resource.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this research element definition is needed and why it has been designed as it has.'
    library: List_['canonical'] = Field(default_factory=list)
    'A reference to a Library resource containing the formal logic used by the ResearchElementDefinition.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    subtitle: Optional_['string'] = Field(default=None)
    'An explanatory or alternate title for the ResearchElementDefinition giving additional information about its content.'
    reviewer: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization primarily responsible for review of some aspect of the content.'
    endorser: List_['ContactDetail'] = Field(default_factory=list)
    'An individual or organization responsible for officially endorsing the content for use in some setting.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the research element definition.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the research element definition and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the research element definition.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this research element definition when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    shortTitle: Optional_['string'] = Field(default=None)
    'The short title provides an alternate title for use in informal descriptive contexts where the full, formal title is not necessary.'
    subjectCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The intended subjects for the ResearchElementDefinition. If this element is not provided, a Patient subject is assumed, but the subject of the ResearchElementDefinition can be anything.'
    subjectReference: Optional_['Reference'] = Field(default=None)
    'The intended subjects for the ResearchElementDefinition. If this element is not provided, a Patient subject is assumed, but the subject of the ResearchElementDefinition can be anything.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate research element definition instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the research element definition from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this research element definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the research element definition is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    variableType: Optional_['code'] = Field(default=None)
    'The type of the outcome (e.g. Dichotomous, Continuous, or Descriptive).'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    'The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.'
    characteristic: List_['ResearchElementDefinitionCharacteristic'] = Field(default=...)
    'A characteristic that defines the members of the research element. Multiple characteristics are applied with "and" semantics.'
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the research element definition content was or is planned to be in active use.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Related artifacts such as additional documentation, justification, or bibliographic references.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the research element definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the research element definition changes.'


class ResearchStudyObjective(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A goal that the study is aiming to achieve in terms of a scientific question to be answered by the analysis of data collected during the study."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'Unique, human-readable label for this objective of the study.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of study objective.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ResearchStudyArm(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes an expected sequence of events for one of the participants of a study.  E.g. Exposure to drug A, wash-out, exposure to drug B, wash-out, follow-up."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'Unique, human-readable label for this arm of the study.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Categorization of study arm, e.g. experimental, active comparator, placebo comparater.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'A succinct description of the path through the study that would be followed by a subject adhering to this arm.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ResearchStudy(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A process where a researcher or organization plans and then executes a series of steps intended to increase the field of healthcare-related knowledge.  This includes studies of safety, efficacy, comparative effectiveness and other information about medications, devices, therapies and other interventional and investigative techniques.  A ResearchStudy involves the gathering of information about human or animal subjects."""
    resourceType: Literal_['ResearchStudy'] = Field(default=...)
    'Investigation to increase healthcare-related patient-independent knowledge'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    arm: List_['ResearchStudyArm'] = Field(default_factory=list)
    'Describes an expected sequence of events for one of the participants of a study.  E.g. Exposure to drug A, wash-out, exposure to drug B, wash-out, follow-up.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    site: List_['Reference'] = Field(default_factory=list)
    'A facility in which study activities are conducted.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Comments made about the study by the performer, subject or other participants.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive user-friendly label for the study.'
    phase: Optional_['CodeableConcept'] = Field(default=None)
    'The stage in the progression of a therapy from initial experimental use in humans in clinical trials to post-market evaluation.'
    focus: List_['CodeableConcept'] = Field(default_factory=list)
    'The medication(s), food(s), therapy(ies), device(s) or other concerns or interventions that the study is seeking to gain more information about.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'A larger research study of which this particular study is a component or step.'
    status: 'code' = Field(default=...)
    'The current state of the study.'
    period: Optional_['Period'] = Field(default=None)
    'Identifies the start date and the expected (or actual, depending on status) end date for the study.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in learning more about or engaging with the study.'
    keyword: List_['CodeableConcept'] = Field(default_factory=list)
    'Key terms to aid in searching for or filtering the study.'
    sponsor: Optional_['Reference'] = Field(default=None)
    'An organization that initiates the investigation and is legally responsible for the study.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    protocol: List_['Reference'] = Field(default_factory=list)
    'The set of steps expected to be performed as part of the execution of the study.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'Codes categorizing the type of study such as investigational vs. observational, type of blinding, type of randomization, safety vs. efficacy, etc.'
    location: List_['CodeableConcept'] = Field(default_factory=list)
    'Indicates a country, state or other region where the study is taking place.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    condition: List_['CodeableConcept'] = Field(default_factory=list)
    'The condition that is the focus of the study.  For example, In a study to examine risk factors for Lupus, might have as an inclusion criterion "healthy volunteer", but the target condition code would be a Lupus SNOMED code.'
    objective: List_['ResearchStudyObjective'] = Field(default_factory=list)
    'A goal that the study is aiming to achieve in terms of a scientific question to be answered by the analysis of data collected during the study.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers assigned to this research study by the sponsor or other systems.'
    enrollment: List_['Reference'] = Field(default_factory=list)
    'Reference to a Group that defines the criteria for and quantity of subjects participating in the study.  E.g. " 200 female Europeans between the ages of 20 and 45 with early onset diabetes".'
    description: Optional_['markdown'] = Field(default=None)
    'A full description of how the study is being conducted.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    reasonStopped: Optional_['CodeableConcept'] = Field(default=None)
    'A description and/or code explaining the premature termination of the study.'
    relatedArtifact: List_['RelatedArtifact'] = Field(default_factory=list)
    'Citations, references and other related documents.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    primaryPurposeType: Optional_['CodeableConcept'] = Field(default=None)
    "The type of study based upon the intent of the study's activities. A classification of the intent of the study."
    principalInvestigator: Optional_['Reference'] = Field(default=None)
    'A researcher in a study who oversees multiple aspects of the study, such as concept development, protocol writing, protocol submission for IRB approval, participant recruitment, informed consent, data collection, analysis, interpretation and presentation.'


class ResearchSubject(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A physical entity which is the primary unit of operational and/or administrative interest in a study."""
    resourceType: Literal_['ResearchSubject'] = Field(default=...)
    'Physical entity which is the primary unit of interest in the study'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    study: 'Reference' = Field(default=...)
    'Reference to the study the subject is participating in.'
    status: 'code' = Field(default=...)
    'The current state of the subject.'
    period: Optional_['Period'] = Field(default=None)
    'The dates the subject began and ended their participation in the study.'
    consent: Optional_['Reference'] = Field(default=None)
    "A record of the patient's informed agreement to participate in the study."
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    actualArm: Optional_['string'] = Field(default=None)
    'The name of the arm in the study the subject actually followed as part of this study.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers assigned to this research subject for a study.'
    individual: 'Reference' = Field(default=...)
    'The record of the person or animal who is involved in the study.'
    assignedArm: Optional_['string'] = Field(default=None)
    'The name of the arm in the study the subject is expected to follow as part of this study.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class RiskAssessmentPrediction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes the expected outcome for the subject."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    outcome: Optional_['CodeableConcept'] = Field(default=None)
    'One of the potential outcomes for the patient (e.g. remission, death,  a particular condition).'
    whenPeriod: Optional_['Period'] = Field(default=None)
    'Indicates the period of time or age range of the subject to which the specified probability applies.'
    whenRange: Optional_['Range'] = Field(default=None)
    'Indicates the period of time or age range of the subject to which the specified probability applies.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    rationale: Optional_['string'] = Field(default=None)
    'Additional information explaining the basis for the prediction.'
    relativeRisk: Optional_['decimal'] = Field(default=None)
    'Indicates the risk for this particular subject (with their specific characteristics) divided by the risk of the population in general.  (Numbers greater than 1 = higher risk than the population, numbers less than 1 = lower risk.).'
    probabilityDecimal: Optional_['decimal'] = Field(default=None)
    'Indicates how likely the outcome is (in the specified timeframe).'
    probabilityRange: Optional_['Range'] = Field(default=None)
    'Indicates how likely the outcome is (in the specified timeframe).'
    qualitativeRisk: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates how likely the outcome is (in the specified timeframe), expressed as a qualitative value (e.g. low, medium, or high).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class RiskAssessment(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An assessment of the likely outcome(s) for a patient or other subject as well as the likelihood of each outcome."""
    resourceType: Literal_['RiskAssessment'] = Field(default=...)
    'Potential outcomes for a subject with likelihood'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Additional comments about the risk assessment.'
    basis: List_['Reference'] = Field(default_factory=list)
    'Indicates the source data considered as part of the assessment (for example, FamilyHistory, Observations, Procedures, Conditions, etc.).'
    parent: Optional_['Reference'] = Field(default=None)
    'A reference to a resource that this risk assessment is part of, such as a Procedure.'
    status: 'code' = Field(default=...)
    'The status of the RiskAssessment, using the same statuses as an Observation.'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'The algorithm, process or mechanism used to evaluate the risk.'
    basedOn: Optional_['Reference'] = Field(default=None)
    'A reference to the request that is fulfilled by this risk assessment.'
    subject: 'Reference' = Field(default=...)
    'The patient or group the risk assessment applies to.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The encounter where the assessment was performed.'
    condition: Optional_['Reference'] = Field(default=None)
    'For assessments or prognosis specific to a particular condition, indicates the condition being assessed.'
    performer: Optional_['Reference'] = Field(default=None)
    'The provider or software application that performed the assessment.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifier assigned to the risk assessment.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'The reason the risk assessment was performed.'
    prediction: List_['RiskAssessmentPrediction'] = Field(default_factory=list)
    'Describes the expected outcome for the subject.'
    mitigation: Optional_['string'] = Field(default=None)
    'A description of the steps that might be taken to reduce the identified risk(s).'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'The date (and possibly time) the risk assessment was performed.'
    occurrencePeriod: Optional_['Period'] = Field(default=None)
    'The date (and possibly time) the risk assessment was performed.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Resources supporting the reason the risk assessment was performed.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The type of the risk assessment performed.'


class Schedule(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A container for slots of time that may be available for booking appointments."""
    resourceType: Literal_['Schedule'] = Field(default=...)
    'A container for slots of time that may be available for booking appointments'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    actor: List_['Reference'] = Field(default=...)
    'Slots that reference this schedule resource provide the availability details to these referenced resource(s).'
    active: Optional_['boolean'] = Field(default=None)
    'Whether this schedule record is in active use or should not be used (such as was entered in error).'
    comment: Optional_['string'] = Field(default=None)
    'Comments on the availability to describe any extended information. Such as custom constraints on the slots that may be associated.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    specialty: List_['CodeableConcept'] = Field(default_factory=list)
    'The specialty of a practitioner that would be required to perform the service requested in this appointment.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'External Ids for this item.'
    serviceType: List_['CodeableConcept'] = Field(default_factory=list)
    'The specific service that is to be performed during this appointment.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    serviceCategory: List_['CodeableConcept'] = Field(default_factory=list)
    'A broad categorization of the service that is to be performed during this appointment.'
    planningHorizon: Optional_['Period'] = Field(default=None)
    'The period of time that the slots that reference this Schedule resource cover (even if none exist). These  cover the amount of time that an organization\'s planning horizon; the interval for which they are currently accepting appointments. This does not define a "template" for planning outside these dates.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SearchParameterComponent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Used to define the parts of a composite search parameter."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    definition: 'canonical' = Field(default=...)
    'The definition of the search parameter that describes this part.'
    expression: 'string' = Field(default=...)
    'A sub-expression that defines how to extract values for this component from the output of the main SearchParameter.expression.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SearchParameter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A search parameter that defines a named search item that can be used to search/filter on a resource."""
    resourceType: Literal_['SearchParameter'] = Field(default=...)
    'Search parameter for a resource'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: 'uri' = Field(default=...)
    'An absolute URI that is used to identify this search parameter when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this search parameter is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the search parameter is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: 'string' = Field(default=...)
    'A natural language name identifying the search parameter. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the search parameter was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the search parameter changes.'
    base: List_['code'] = Field(default=...)
    'The base resource type(s) that this search parameter can be used against.'
    type: 'code' = Field(default=...)
    'The type of value that a search parameter may contain, and how the content is interpreted.'
    xpath: Optional_['string'] = Field(default=None)
    'An XPath expression that returns a set of elements for the search parameter.'
    chain: List_['string'] = Field(default_factory=list)
    'Contains the names of any search parameters which may be chained to the containing search parameter. Chained parameters may be added to search parameters of type reference and specify that resources will only be returned if they contain a reference to a resource which matches the chained parameter value. Values for this field should be drawn from SearchParameter.code for a parameter on the target resource type.'
    status: 'code' = Field(default=...)
    'The status of this search parameter. Enables tracking the life-cycle of the content.'
    target: List_['code'] = Field(default_factory=list)
    'Types of resource (if a resource is referenced).'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the search parameter when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the search parameter author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this search parameter is needed and why it has been designed as it has.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    modifier: List_['code'] = Field(default_factory=list)
    'A modifier supported for the search parameter.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the search parameter.'
    component: List_['SearchParameterComponent'] = Field(default_factory=list)
    'Used to define the parts of a composite search parameter.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate search parameter instances.'
    expression: Optional_['string'] = Field(default=None)
    'A FHIRPath expression that returns a set of elements for the search parameter.'
    xpathUsage: Optional_['code'] = Field(default=None)
    'How the search parameter relates to the set of elements returned by evaluating the xpath query.'
    multipleOr: Optional_['boolean'] = Field(default=None)
    'Whether multiple values are allowed for each time the parameter exists. Values are separated by commas, and the parameter matches if any of the values match.'
    comparator: List_['code'] = Field(default_factory=list)
    'Comparators supported for the search parameter.'
    derivedFrom: Optional_['canonical'] = Field(default=None)
    'Where this search parameter is originally defined. If a derivedFrom is provided, then the details in the search parameter must be consistent with the definition from which it is defined. i.e. the parameter should have the same meaning, and (usually) the functionality should be a proper subset of the underlying search parameter.'
    description: 'markdown' = Field(default=...)
    'And how it used.'
    multipleAnd: Optional_['boolean'] = Field(default=None)
    'Whether multiple parameters are allowed - e.g. more than one parameter with the same name. The search matches if all the parameters match.'
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this search parameter is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the search parameter is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'The code used in the URL or the parameter name in a parameters resource for this search parameter.'


class ServiceRequest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A record of a request for service such as diagnostic investigations, treatments, or operations to be performed."""
    resourceType: Literal_['ServiceRequest'] = Field(default=...)
    'A request for a service to be performed'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Any other notes and comments made about the service request. For example, internal billing notes.'
    status: 'code' = Field(default=...)
    'The status of the order.'
    intent: 'code' = Field(default=...)
    'Whether the request is a proposal, plan, an original order or a reflex order.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'Plan/proposal/order fulfilled by this request.'
    subject: 'Reference' = Field(default=...)
    'On whom or what the service is to be performed. This is usually a human patient, but can also be requested on animals, groups of humans or animals, devices such as dialysis machines, or even locations (typically for environmental scans).'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    replaces: List_['Reference'] = Field(default_factory=list)
    'The request takes the place of the referenced completed or terminated request(s).'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'A code that classifies the service for searching, sorting and display purposes (e.g. "Surgical Procedure").'
    priority: Optional_['code'] = Field(default=None)
    'Indicates how quickly the ServiceRequest should be addressed with respect to other requests.'
    specimen: List_['Reference'] = Field(default_factory=list)
    'One or more specimens that the laboratory procedure will use.'
    bodySite: List_['CodeableConcept'] = Field(default_factory=list)
    'Anatomic location where the procedure should be performed. This is the target site.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'An encounter that provides additional information about the healthcare context in which this request is made.'
    requester: Optional_['Reference'] = Field(default=None)
    'The individual who initiated the request and has responsibility for its activation.'
    performer: List_['Reference'] = Field(default_factory=list)
    'The desired performer for doing the requested service.  For example, the surgeon, dermatopathologist, endoscopist, etc.'
    insurance: List_['Reference'] = Field(default_factory=list)
    'Insurance plans, coverage extensions, pre-authorizations and/or pre-determinations that may be needed for delivering the requested service.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifiers assigned to this order instance by the orderer and/or the receiver and/or order fulfiller.'
    authoredOn: Optional_['dateTime'] = Field(default=None)
    'When the request transitioned to being actionable.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'An explanation or justification for why this service is being requested in coded or textual form.   This is often for billing purposes.  May relate to the resources referred to in `supportingInfo`.'
    requisition: Optional_['Identifier'] = Field(default=None)
    'A shared identifier common to all service requests that were authorized more or less simultaneously by a single author, representing the composite or group identifier.'
    orderDetail: List_['CodeableConcept'] = Field(default_factory=list)
    'Additional details and instructions about the how the services are to be delivered.   For example, and order for a urinary catheter may have an order detail for an external or indwelling catheter, or an order for a bandage may require additional instructions specifying how the bandage should be applied.'
    quantityQuantity: Optional_['Quantity'] = Field(default=None)
    'An amount of service being requested which can be a quantity ( for example $1,500 home modification), a ratio ( for example, 20 half day visits per month), or a range (2.0 to 1.8 Gy per fraction).'
    quantityRatio: Optional_['Ratio'] = Field(default=None)
    'An amount of service being requested which can be a quantity ( for example $1,500 home modification), a ratio ( for example, 20 half day visits per month), or a range (2.0 to 1.8 Gy per fraction).'
    quantityRange: Optional_['Range'] = Field(default=None)
    'An amount of service being requested which can be a quantity ( for example $1,500 home modification), a ratio ( for example, 20 half day visits per month), or a range (2.0 to 1.8 Gy per fraction).'
    asNeededBoolean: Optional_['boolean'] = Field(default=None)
    'If a CodeableConcept is present, it indicates the pre-condition for performing the service.  For example "pain", "on flare-up", etc.'
    asNeededCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'If a CodeableConcept is present, it indicates the pre-condition for performing the service.  For example "pain", "on flare-up", etc.'
    doNotPerform: Optional_['boolean'] = Field(default=None)
    'Set this to true if the record is saying that the service/procedure should NOT be performed.'
    locationCode: List_['CodeableConcept'] = Field(default_factory=list)
    'The preferred location(s) where the procedure should actually happen in coded or free text form. E.g. at home or nursing day care center.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'The date/time at which the requested service should occur.'
    occurrencePeriod: Optional_['Period'] = Field(default=None)
    'The date/time at which the requested service should occur.'
    occurrenceTiming: Optional_['Timing'] = Field(default=None)
    'The date/time at which the requested service should occur.'
    performerType: Optional_['CodeableConcept'] = Field(default=None)
    'Desired type of performer for doing the requested service.'
    supportingInfo: List_['Reference'] = Field(default_factory=list)
    'Additional clinical information about the patient or specimen that may influence the services or their interpretations.     This information includes diagnosis, clinical findings and other observations.  In laboratory ordering these are typically referred to as "ask at order entry questions (AOEs)".  This includes observations explicitly requested by the producer (filler) to provide context or supporting information needed to complete the order. For example,  reporting the amount of inspired oxygen for blood gas measurements.'
    instantiatesUri: List_['uri'] = Field(default_factory=list)
    'The URL pointing to an externally maintained protocol, guideline, orderset or other definition that is adhered to in whole or in part by this ServiceRequest.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'Indicates another resource that provides a justification for why this service is being requested.   May relate to the resources referred to in `supportingInfo`.'
    relevantHistory: List_['Reference'] = Field(default_factory=list)
    'Key events in the history of the request.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    locationReference: List_['Reference'] = Field(default_factory=list)
    'A reference to the the preferred location(s) where the procedure should actually happen. E.g. at home or nursing day care center.'
    patientInstruction: Optional_['string'] = Field(default=None)
    'Instructions in terms that are understood by the patient or consumer.'
    instantiatesCanonical: List_['canonical'] = Field(default_factory=list)
    'The URL pointing to a FHIR-defined protocol, guideline, orderset or other definition that is adhered to in whole or in part by this ServiceRequest.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code that identifies a particular service (i.e., procedure, diagnostic investigation, or panel of investigations) that have been requested.'


class Slot(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A slot of time on a schedule that may be available for booking appointments."""
    resourceType: Literal_['Slot'] = Field(default=...)
    'A slot of time on a schedule that may be available for booking appointments'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    end: 'instant' = Field(default=...)
    'Date/Time that the slot is to conclude.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    start: 'instant' = Field(default=...)
    'Date/Time that the slot is to begin.'
    status: 'code' = Field(default=...)
    'busy | free | busy-unavailable | busy-tentative | entered-in-error.'
    comment: Optional_['string'] = Field(default=None)
    'Comments on the slot to describe any extended information. Such as custom constraints on the slot.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    schedule: 'Reference' = Field(default=...)
    'The schedule resource that this slot defines an interval of status information.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    specialty: List_['CodeableConcept'] = Field(default_factory=list)
    'The specialty of a practitioner that would be required to perform the service requested in this appointment.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'External Ids for this item.'
    overbooked: Optional_['boolean'] = Field(default=None)
    'This slot has already been overbooked, appointments are unlikely to be accepted for this time.'
    serviceType: List_['CodeableConcept'] = Field(default_factory=list)
    'The type of appointments that can be booked into this slot (ideally this would be an identifiable service - which is at a location, rather than the location itself). If provided then this overrides the value provided on the availability resource.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    serviceCategory: List_['CodeableConcept'] = Field(default_factory=list)
    'A broad categorization of the service that is to be performed during this appointment.'
    appointmentType: Optional_['CodeableConcept'] = Field(default=None)
    'The style of appointment or patient that may be booked in the slot (not service type).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SpecimenProcessing(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details concerning processing and processing steps for the specimen."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    timeDateTime: Optional_['dateTime'] = Field(default=None)
    'A record of the time or period when the specimen processing occurred.  For example the time of sample fixation or the period of time the sample was in formalin.'
    timePeriod: Optional_['Period'] = Field(default=None)
    'A record of the time or period when the specimen processing occurred.  For example the time of sample fixation or the period of time the sample was in formalin.'
    additive: List_['Reference'] = Field(default_factory=list)
    'Material used in the processing step.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    procedure: Optional_['CodeableConcept'] = Field(default=None)
    'A coded value specifying the procedure used to process the specimen.'
    description: Optional_['string'] = Field(default=None)
    'Textual description of procedure.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SpecimenCollection(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details concerning the specimen collection."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'A coded value specifying the technique that is used to perform the procedure.'
    duration: Optional_['Duration'] = Field(default=None)
    'The span of time over which the collection of a specimen occurred.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The quantity of specimen collected; for instance the volume of a blood sample, or the physical measurement of an anatomic pathology sample.'
    bodySite: Optional_['CodeableConcept'] = Field(default=None)
    'Anatomical location from which the specimen was collected (if subject is a patient). This is the target site.  This element is not used for environmental specimens.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    collector: Optional_['Reference'] = Field(default=None)
    'Person who collected the specimen.'
    collectedDateTime: Optional_['dateTime'] = Field(default=None)
    'Time when specimen was collected from subject - the physiologically relevant time.'
    collectedPeriod: Optional_['Period'] = Field(default=None)
    'Time when specimen was collected from subject - the physiologically relevant time.'
    fastingStatusCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Abstinence or reduction from some or all food, drink, or both, for a period of time prior to sample collection.'
    fastingStatusDuration: Optional_['Duration'] = Field(default=None)
    'Abstinence or reduction from some or all food, drink, or both, for a period of time prior to sample collection.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SpecimenContainer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The container holding the specimen.  The recursive nature of containers; i.e. blood in tube in tray in rack is not addressed here."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of container associated with the specimen (e.g. slide, aliquot, etc.).'
    capacity: Optional_['Quantity'] = Field(default=None)
    'The capacity (volume or other measure) the container may contain.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    "Id for container. There may be multiple; a manufacturer's bar code, lab assigned identifier, etc. The container ID may differ from the specimen id in some circumstances."
    description: Optional_['string'] = Field(default=None)
    'Textual description of the container.'
    additiveCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Introduced substance to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.'
    additiveReference: Optional_['Reference'] = Field(default=None)
    'Introduced substance to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.'
    specimenQuantity: Optional_['Quantity'] = Field(default=None)
    'The quantity of specimen in the container; may be volume, dimensions, or other appropriate measurements, depending on the specimen type.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Specimen(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A sample to be used for analysis."""
    resourceType: Literal_['Specimen'] = Field(default=...)
    'Sample for analysis'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of material that forms the specimen.'
    note: List_['Annotation'] = Field(default_factory=list)
    'To communicate any details or issues about the specimen or during the specimen collection. (for example: broken vial, sent with patient, frozen).'
    status: Optional_['code'] = Field(default=None)
    'The availability of the specimen.'
    parent: List_['Reference'] = Field(default_factory=list)
    'Reference to the parent (source) specimen which is used when the specimen was either derived from or a component of another specimen.'
    subject: Optional_['Reference'] = Field(default=None)
    'Where the specimen came from. This may be from patient(s), from a location (e.g., the source of an environmental sample), or a sampling of a substance or a device.'
    request: List_['Reference'] = Field(default_factory=list)
    'Details concerning a service request that required a specimen to be collected.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    container: List_['SpecimenContainer'] = Field(default_factory=list)
    'The container holding the specimen.  The recursive nature of containers; i.e. blood in tube in tray in rack is not addressed here.'
    condition: List_['CodeableConcept'] = Field(default_factory=list)
    'A mode or state of being that describes the nature of the specimen.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Id for specimen.'
    collection: Optional_['SpecimenCollection'] = Field(default=None)
    'Details concerning the specimen collection.'
    processing: List_['SpecimenProcessing'] = Field(default_factory=list)
    'Details concerning processing and processing steps for the specimen.'
    receivedTime: Optional_['dateTime'] = Field(default=None)
    'Time when specimen was received for processing or testing.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    accessionIdentifier: Optional_['Identifier'] = Field(default=None)
    'The identifier assigned by the lab when accessioning specimen(s). This is not necessarily the same as the specimen identifier, depending on local lab procedures.'


class SpecimenDefinitionTypeTested(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specimen conditioned in a container as expected by the testing laboratory."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of specimen conditioned for testing expected by lab.'
    handling: List_['SpecimenDefinitionTypeTestedHandling'] = Field(default_factory=list)
    'Set of instructions for preservation/transport of the specimen at a defined temperature interval, prior the testing process.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    isDerived: Optional_['boolean'] = Field(default=None)
    'Primary of secondary specimen.'
    container: Optional_['SpecimenDefinitionTypeTestedContainer'] = Field(default=None)
    "The specimen's container."
    preference: 'code' = Field(default=...)
    'The preference for this type of conditioned specimen.'
    requirement: Optional_['string'] = Field(default=None)
    'Requirements for delivery and special handling of this kind of conditioned specimen.'
    retentionTime: Optional_['Duration'] = Field(default=None)
    'The usual time that a specimen of this kind is retained after the ordered tests are completed, for the purpose of additional testing.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    rejectionCriterion: List_['CodeableConcept'] = Field(default_factory=list)
    'Criterion for rejection of the specimen in its container by the laboratory.'


class SpecimenDefinitionTypeTestedContainer(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The specimen's container."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    cap: Optional_['CodeableConcept'] = Field(default=None)
    'Color of container cap.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The type of container used to contain this kind of specimen.'
    material: Optional_['CodeableConcept'] = Field(default=None)
    'The type of material of the container.'
    capacity: Optional_['Quantity'] = Field(default=None)
    'The capacity (volume or other measure) of this kind of container.'
    additive: List_['SpecimenDefinitionTypeTestedContainerAdditive'] = Field(default_factory=list)
    'Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'The textual description of the kind of container.'
    preparation: Optional_['string'] = Field(default=None)
    'Special processing that should be applied to the container for this kind of specimen.'
    minimumVolumeQuantity: Optional_['Quantity'] = Field(default=None)
    'The minimum volume to be conditioned in the container.'
    minimumVolumeString: Optional_['string'] = Field(default=None)
    'The minimum volume to be conditioned in the container.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SpecimenDefinitionTypeTestedContainerAdditive(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    additiveCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.'
    additiveReference: Optional_['Reference'] = Field(default=None)
    'Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SpecimenDefinitionTypeTestedHandling(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Set of instructions for preservation/transport of the specimen at a defined temperature interval, prior the testing process."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    maxDuration: Optional_['Duration'] = Field(default=None)
    'The maximum time interval of preservation of the specimen with these conditions.'
    instruction: Optional_['string'] = Field(default=None)
    "Additional textual instructions for the preservation or transport of the specimen. For instance, 'Protect from light exposure'."
    temperatureRange: Optional_['Range'] = Field(default=None)
    'The temperature interval for this set of handling instructions.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    temperatureQualifier: Optional_['CodeableConcept'] = Field(default=None)
    'It qualifies the interval of temperature, which characterizes an occurrence of handling. Conditions that are not related to temperature may be handled in the instruction element.'


class SpecimenDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A kind of specimen with associated set of requirements."""
    resourceType: Literal_['SpecimenDefinition'] = Field(default=...)
    'Kind of specimen'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'A business identifier associated with the kind of specimen.'
    timeAspect: Optional_['string'] = Field(default=None)
    'Time aspect of specimen collection (duration or offset).'
    collection: List_['CodeableConcept'] = Field(default_factory=list)
    'The action to be performed for collecting the specimen.'
    typeTested: List_['SpecimenDefinitionTypeTested'] = Field(default_factory=list)
    'Specimen conditioned in a container as expected by the testing laboratory.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    typeCollected: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of material to be collected.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    patientPreparation: List_['CodeableConcept'] = Field(default_factory=list)
    'Preparation of the patient for specimen collection.'


class StructureDefinitionDifferential(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A differential view is expressed relative to the base StructureDefinition - a statement of differences that it applies."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    element: List_['ElementDefinition'] = Field(default=...)
    'Captures constraints on each element within the resource.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class StructureDefinitionSnapshot(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A snapshot view is expressed in a standalone form that can be used and interpreted without considering the base StructureDefinition."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    element: List_['ElementDefinition'] = Field(default=...)
    'Captures constraints on each element within the resource.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class StructureDefinitionContext(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies the types of resource or data type elements to which the extension can be applied."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'Defines how to interpret the expression that defines what the context of the extension is.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: 'string' = Field(default=...)
    'An expression that defines where an extension can be used in resources.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class StructureDefinitionMapping(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An external specification that the content is mapped to."""
    name: Optional_['string'] = Field(default=None)
    'A name for the specification that is being mapped to.'
    comment: Optional_['string'] = Field(default=None)
    'Comments about this mapping, including version notes, issues, scope limitations, and other important notes for usage.'
    identity: 'id' = Field(default=...)
    'An Internal id that is used to identify this mapping set when specific mappings are made.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    uri: Optional_['uri'] = Field(default=None)
    'An absolute URI that identifies the specification that this mapping is expressed to.'


class StructureDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A definition of a FHIR structure. This resource is used to describe the underlying resources, data types defined in FHIR, and also for describing extensions and constraints on resources and data types."""
    resourceType: Literal_['StructureDefinition'] = Field(default=...)
    'Structural Definition'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: 'uri' = Field(default=...)
    'An absolute URI that is used to identify this structure definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this structure definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the structure definition is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: 'string' = Field(default=...)
    'A natural language name identifying the structure definition. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the structure definition was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the structure definition changes.'
    kind: 'code' = Field(default=...)
    'Defines the kind of structure that this definition is describing.'
    type: 'uri' = Field(default=...)
    'The type this structure describes. If the derivation kind is \'specialization\' then this is the master definition for a type, and there is always one of these (a data type, an extension, a resource, including abstract ones). Otherwise the structure definition is a constraint on the stated type (and in this case, the type cannot be an abstract type).  References are URLs that are relative to http://hl7.org/fhir/StructureDefinition e.g. "string" is a reference to http://hl7.org/fhir/StructureDefinition/string. Absolute URLs are only allowed in logical models.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the structure definition.'
    status: 'code' = Field(default=...)
    'The status of this structure definition. Enables tracking the life-cycle of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the structure definition when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the structure definition author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this structure definition is needed and why it has been designed as it has.'
    keyword: List_['Coding'] = Field(default_factory=list)
    'A set of key words or terms from external terminologies that may be used to assist with indexing and searching of templates nby describing the use of this structure definition, or the content it describes.'
    mapping: List_['StructureDefinitionMapping'] = Field(default_factory=list)
    'An external specification that the content is mapped to.'
    context: List_['StructureDefinitionContext'] = Field(default_factory=list)
    'Identifies the types of resource or data type elements to which the extension can be applied.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    abstract: 'boolean' = Field(default=...)
    'Whether structure this definition describes is abstract or not  - that is, whether the structure is not intended to be instantiated. For Resources and Data types, abstract types will never be exchanged  between systems.'
    snapshot: Optional_['StructureDefinitionSnapshot'] = Field(default=None)
    'A snapshot view is expressed in a standalone form that can be used and interpreted without considering the base StructureDefinition.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the structure definition.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the structure definition and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the structure definition.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this structure definition when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate structure definition instances.'
    derivation: Optional_['code'] = Field(default=None)
    'How the type relates to the baseDefinition.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the structure definition from a consumer's perspective."
    fhirVersion: Optional_['code'] = Field(default=None)
    'The version of the FHIR specification on which this StructureDefinition is based - this is the formal version of the specification, without the revision number, e.g. [publication].[major].[minor], which is 4.3.0 for this version.'
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this structure definition is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the structure definition is intended to be used.'
    differential: Optional_['StructureDefinitionDifferential'] = Field(default=None)
    'A differential view is expressed relative to the base StructureDefinition - a statement of differences that it applies.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    baseDefinition: Optional_['canonical'] = Field(default=None)
    'An absolute URI that is the base structure from which this type is derived, either by specialization or constraint.'
    contextInvariant: List_['string'] = Field(default_factory=list)
    'A set of rules as FHIRPath Invariants about when the extension can be used (e.g. co-occurrence variants for the extension). All the rules must be true.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class StructureMapStructure(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A structure definition used by this map. The structure definition may describe instances that are converted, or the instances that are produced."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    url: 'canonical' = Field(default=...)
    'The canonical reference to the structure.'
    mode: 'code' = Field(default=...)
    'How the referenced structure is used in this mapping.'
    alias: Optional_['string'] = Field(default=None)
    'The name used for this type in the map.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    documentation: Optional_['string'] = Field(default=None)
    'Documentation that describes how the structure is used in the mapping.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class StructureMapGroup(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Organizes the mapping into manageable chunks for human review/ease of maintenance."""
    name: 'id' = Field(default=...)
    'A unique name for the group for the convenience of human readers.'
    rule: List_['StructureMapGroupRule'] = Field(default=...)
    'Transform Rule from source to target.'
    input: List_['StructureMapGroupInput'] = Field(default=...)
    'A name assigned to an instance of data. The instance must be provided when the mapping is invoked.'
    extends: Optional_['id'] = Field(default=None)
    'Another group that this group adds rules to.'
    typeMode: 'code' = Field(default=...)
    'If this is the default rule set to apply for the source type or this combination of types.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    documentation: Optional_['string'] = Field(default=None)
    'Additional supporting documentation that explains the purpose of the group and the types of mappings within it.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class StructureMapGroupInput(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A name assigned to an instance of data. The instance must be provided when the mapping is invoked."""
    name: 'id' = Field(default=...)
    'Name for this instance of data.'
    type: Optional_['string'] = Field(default=None)
    'Type for this instance of data.'
    mode: 'code' = Field(default=...)
    'Mode for this instance of data.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    documentation: Optional_['string'] = Field(default=None)
    'Documentation for this instance of data.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class StructureMapGroupRule(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Transform Rule from source to target."""
    name: 'id' = Field(default=...)
    'Name of the rule for internal references.'
    rule: List_['StructureMapGroupRule'] = Field(default_factory=list)
    'Rules contained in this rule.'
    source: List_['StructureMapGroupRuleSource'] = Field(default=...)
    'Source inputs to the mapping.'
    target: List_['StructureMapGroupRuleTarget'] = Field(default_factory=list)
    'Content to create because of this mapping rule.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    dependent: List_['StructureMapGroupRuleDependent'] = Field(default_factory=list)
    'Which other rules to apply in the context of this rule.'
    documentation: Optional_['string'] = Field(default=None)
    'Documentation for this instance of data.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class StructureMapGroupRuleDependent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Which other rules to apply in the context of this rule."""
    name: 'id' = Field(default=...)
    'Name of a rule or group to apply.'
    variable: List_['string'] = Field(default=...)
    'Variable to pass to the rule or group.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class StructureMapGroupRuleTarget(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Content to create because of this mapping rule."""
    context: Optional_['id'] = Field(default=None)
    'Type or variable this rule applies to.'
    element: Optional_['string'] = Field(default=None)
    'Field to create in the context.'
    variable: Optional_['id'] = Field(default=None)
    'Named context for field, if desired, and a field is specified.'
    listMode: List_['code'] = Field(default_factory=list)
    'If field is a list, how to manage the list.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    transform: Optional_['code'] = Field(default=None)
    'How the data is copied / created.'
    parameter: List_['StructureMapGroupRuleTargetParameter'] = Field(default_factory=list)
    'Parameters to the transform.'
    listRuleId: Optional_['id'] = Field(default=None)
    'Internal rule reference for shared list items.'
    contextType: Optional_['code'] = Field(default=None)
    'How to interpret the context.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class StructureMapGroupRuleTargetParameter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Parameters to the transform."""
    valueId: Optional_['id'] = Field(default=None)
    'Parameter value - variable or literal.'
    valueString: Optional_['string'] = Field(default=None)
    'Parameter value - variable or literal.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'Parameter value - variable or literal.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'Parameter value - variable or literal.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'Parameter value - variable or literal.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class StructureMapGroupRuleSource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Source inputs to the mapping."""
    min: Optional_['integer'] = Field(default=None)
    'Specified minimum cardinality for the element. This is optional; if present, it acts an implicit check on the input content.'
    max: Optional_['string'] = Field(default=None)
    'Specified maximum cardinality for the element - a number or a "*". This is optional; if present, it acts an implicit check on the input content (* just serves as documentation; it\'s the default value).'
    type: Optional_['string'] = Field(default=None)
    'Specified type for the element. This works as a condition on the mapping - use for polymorphic elements.'
    check: Optional_['string'] = Field(default=None)
    'FHIRPath expression  - must be true or the mapping engine throws an error instead of completing.'
    context: 'id' = Field(default=...)
    'Type or variable this rule applies to.'
    element: Optional_['string'] = Field(default=None)
    'Optional field for this source.'
    listMode: Optional_['code'] = Field(default=None)
    'How to handle the list mode for this element.'
    variable: Optional_['id'] = Field(default=None)
    'Named context for field, if a field is specified.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    condition: Optional_['string'] = Field(default=None)
    'FHIRPath expression  - must be true or the rule does not apply.'
    logMessage: Optional_['string'] = Field(default=None)
    'A FHIRPath expression which specifies a message to put in the transform log when content matching the source rule is found.'
    defaultValueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueBoolean: Optional_['boolean'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueCanonical: Optional_['canonical'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueCode: Optional_['code'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueDate: Optional_['date'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueDateTime: Optional_['dateTime'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueDecimal: Optional_['decimal'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueId: Optional_['id'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueInstant: Optional_['instant'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueInteger: Optional_['integer'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueMarkdown: Optional_['markdown'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueOid: Optional_['oid'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValuePositiveInt: Optional_['positiveInt'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueString: Optional_['string'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueTime: Optional_['time'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueUri: Optional_['uri'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueUrl: Optional_['url'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueUuid: Optional_['uuid'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueAddress: Optional_['Address'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueAge: Optional_['Age'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueAnnotation: Optional_['Annotation'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueAttachment: Optional_['Attachment'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueCoding: Optional_['Coding'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueContactPoint: Optional_['ContactPoint'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueCount: Optional_['Count'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueDistance: Optional_['Distance'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueDuration: Optional_['Duration'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueHumanName: Optional_['HumanName'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueIdentifier: Optional_['Identifier'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueMoney: Optional_['Money'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValuePeriod: Optional_['Period'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueQuantity: Optional_['Quantity'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueRange: Optional_['Range'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueRatio: Optional_['Ratio'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueReference: Optional_['Reference'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueSampledData: Optional_['SampledData'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueSignature: Optional_['Signature'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueTiming: Optional_['Timing'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueContactDetail: Optional_['ContactDetail'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueContributor: Optional_['Contributor'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueExpression: Optional_['Expression'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueParameterDefinition: Optional_['ParameterDefinition'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueRelatedArtifact: Optional_['RelatedArtifact'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueTriggerDefinition: Optional_['TriggerDefinition'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueUsageContext: Optional_['UsageContext'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueDosage: Optional_['Dosage'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    defaultValueMeta: Optional_['Meta'] = Field(default=None)
    'A value to use if there is no existing value in the source object.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class StructureMap(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A Map of relationships between 2 structures that can be used to transform data."""
    resourceType: Literal_['StructureMap'] = Field(default=...)
    'A Map of relationships between 2 structures that can be used to transform data'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: 'uri' = Field(default=...)
    'An absolute URI that is used to identify this structure map when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this structure map is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the structure map is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: 'string' = Field(default=...)
    'A natural language name identifying the structure map. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the structure map was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the structure map changes.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the structure map.'
    group: List_['StructureMapGroup'] = Field(default=...)
    'Organizes the mapping into manageable chunks for human review/ease of maintenance.'
    status: 'code' = Field(default=...)
    'The status of this structure map. Enables tracking the life-cycle of the content.'
    import_: List_['canonical'] = Field(default_factory=list, alias='import')
    'Other maps used by this map (canonical URLs).'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the structure map when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the structure map author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this structure map is needed and why it has been designed as it has.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the structure map.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the structure map and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the structure map.'
    structure: List_['StructureMapStructure'] = Field(default_factory=list)
    'A structure definition used by this map. The structure definition may describe instances that are converted, or the instances that are produced.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this structure map when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate structure map instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the structure map from a consumer's perspective."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this structure map is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the structure map is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubscriptionChannel(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details where to send notifications when resources are received that meet the criteria."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of channel to send notifications on.'
    header: List_['string'] = Field(default_factory=list)
    'Additional headers / information to send as part of the notification.'
    payload: Optional_['code'] = Field(default=None)
    'The mime type to send the payload in - either application/fhir+xml, or application/fhir+json. If the payload is not present, then there is no payload in the notification, just a notification. The mime type "text/plain" may also be used for Email and SMS subscriptions.'
    endpoint: Optional_['url'] = Field(default=None)
    'The url that describes the actual end-point to send messages to.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Subscription(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The subscription resource is used to define a push-based subscription from a server to another system. Once a subscription is registered with the server, the server checks every resource that is created or updated, and if the resource matches the given criteria, it sends a message on the defined "channel" so that another system can take an appropriate action."""
    resourceType: Literal_['Subscription'] = Field(default=...)
    'Server push subscription criteria'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    end: Optional_['instant'] = Field(default=None)
    'The time for the server to turn the subscription off.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    error: Optional_['string'] = Field(default=None)
    'A record of the last error that occurred when the server processed a notification.'
    status: 'code' = Field(default=...)
    'The status of the subscription, which marks the server state for managing the subscription.'
    reason: 'string' = Field(default=...)
    'A description of why this subscription is defined.'
    contact: List_['ContactPoint'] = Field(default_factory=list)
    'Contact details for a human to contact about the subscription. The primary use of this for system administrator troubleshooting.'
    channel: 'SubscriptionChannel' = Field(default=...)
    'Details where to send notifications when resources are received that meet the criteria.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    criteria: 'string' = Field(default=...)
    'The rules that the server should use to determine when to generate notifications for this subscription.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubscriptionStatusNotificationEvent(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Detailed information about events relevant to this subscription notification."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    focus: Optional_['Reference'] = Field(default=None)
    'The focus of this event. While this will usually be a reference to the focus resource of the event, it MAY contain a reference to a non-FHIR object.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    timestamp: Optional_['instant'] = Field(default=None)
    'The actual time this event occured on the server.'
    eventNumber: 'string' = Field(default=...)
    'The sequential number of this event in this subscription context. Note that this value is a 64-bit integer value, encoded as a string.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    additionalContext: List_['Reference'] = Field(default_factory=list)
    'Additional context information for this event. Generally, this will contain references to additional resources included with the event (e.g., the Patient relevant to an Encounter), however it MAY refer to non-FHIR objects.'


class SubscriptionStatus(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The SubscriptionStatus resource describes the state of a Subscription during notifications."""
    resourceType: Literal_['SubscriptionStatus'] = Field(default=...)
    'Status information about a Subscription provided during event notification'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: 'code' = Field(default=...)
    'The type of event being conveyed with this notificaiton.'
    topic: Optional_['canonical'] = Field(default=None)
    'The reference to the SubscriptionTopic for the Subscription which generated this notification.'
    error: List_['CodeableConcept'] = Field(default_factory=list)
    'A record of errors that occurred when the server processed a notification.'
    status: Optional_['code'] = Field(default=None)
    'The status of the subscription, which marks the server state for managing the subscription.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    subscription: 'Reference' = Field(default=...)
    'The reference to the Subscription which generated this notification.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    notificationEvent: List_['SubscriptionStatusNotificationEvent'] = Field(default_factory=list)
    'Detailed information about events relevant to this subscription notification.'
    eventsSinceSubscriptionStart: Optional_['string'] = Field(default=None)
    'The total number of actual events which have been generated since the Subscription was created (inclusive of this notification) - regardless of how many have been successfully communicated.  This number is NOT incremented for handshake and heartbeat notifications.'


class SubscriptionTopicNotificationShape(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """List of properties to describe the shape (e.g., resources) included in notifications from this Subscription Topic."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    include: List_['string'] = Field(default_factory=list)
    'Search-style _include directives, rooted in the resource for this shape. Servers SHOULD include resources listed here, if they exist and the user is authorized to receive them.  Clients SHOULD be prepared to receive these additional resources, but SHALL function properly without them.'
    resource: 'uri' = Field(default=...)
    'URL of the Resource that is the type used in this shape. This is the "focus" of the topic (or one of them if there are more than one) and the root resource for this shape definition. It will be the same, a generality, or a specificity of SubscriptionTopic.resourceTrigger.resource or SubscriptionTopic.eventTrigger.resource when they are present.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    revInclude: List_['string'] = Field(default_factory=list)
    'Search-style _revinclude directives, rooted in the resource for this shape. Servers SHOULD include resources listed here, if they exist and the user is authorized to receive them.  Clients SHOULD be prepared to receive these additional resources, but SHALL function properly without them.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubscriptionTopicResourceTrigger(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A definition of a resource-based event that triggers a notification based on the SubscriptionTopic. The criteria may be just a human readable description and/or a full FHIR search string or FHIRPath expression. Multiple triggers are considered OR joined (e.g., a resource update matching ANY of the definitions will trigger a notification)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    resource: 'uri' = Field(default=...)
    'URL of the Resource that is the type used in this resource trigger.  Relative URLs are relative to the StructureDefinition root of the implemented FHIR version (e.g., http://hl7.org/fhir/StructureDefinition). For example, "Patient" maps to http://hl7.org/fhir/StructureDefinition/Patient.  For more information, see <a href="elementdefinition-definitions.html#ElementDefinition.type.code">ElementDefinition.type.code</a>.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['markdown'] = Field(default=None)
    'The human readable description of this resource trigger for the SubscriptionTopic -  for example, "An Encounter enters the \'in-progress\' state".'
    queryCriteria: Optional_['SubscriptionTopicResourceTriggerQueryCriteria'] = Field(default=None)
    'The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic.'
    fhirPathCriteria: Optional_['string'] = Field(default=None)
    'The FHIRPath based rules that the server should use to determine when to trigger a notification for this topic.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    supportedInteraction: List_['code'] = Field(default_factory=list)
    'The FHIR RESTful interaction which can be used to trigger a notification for the SubscriptionTopic. Multiple values are considered OR joined (e.g., CREATE or UPDATE).'


class SubscriptionTopicResourceTriggerQueryCriteria(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    current: Optional_['string'] = Field(default=None)
    'The FHIR query based rules are applied to the current resource state (e.g., state after an update).'
    previous: Optional_['string'] = Field(default=None)
    'The FHIR query based rules are applied to the previous resource state (e.g., state before an update).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    requireBoth: Optional_['boolean'] = Field(default=None)
    'If set to true, both current and previous criteria must evaluate true to  trigger a notification for this topic.  Otherwise a notification for this topic will be triggered if either one evaluates to true.'
    resultForCreate: Optional_['code'] = Field(default=None)
    'For "create" interactions, should the "previous" criteria count as an automatic pass or an automatic fail.'
    resultForDelete: Optional_['code'] = Field(default=None)
    'For "delete" interactions, should the "current" criteria count as an automatic pass or an automatic fail.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubscriptionTopicEventTrigger(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Event definition which can be used to trigger the SubscriptionTopic."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    event: 'CodeableConcept' = Field(default=...)
    'A well-defined event which can be used to trigger notifications from the SubscriptionTopic.'
    resource: 'uri' = Field(default=...)
    'URL of the Resource that is the focus type used in this event trigger.  Relative URLs are relative to the StructureDefinition root of the implemented FHIR version (e.g., http://hl7.org/fhir/StructureDefinition). For example, "Patient" maps to http://hl7.org/fhir/StructureDefinition/Patient.  For more information, see <a href="elementdefinition-definitions.html#ElementDefinition.type.code">ElementDefinition.type.code</a>.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['markdown'] = Field(default=None)
    'The human readable description of an event to trigger a notification for the SubscriptionTopic - for example, "Patient Admission, as defined in HL7v2 via message ADT^A01". Multiple values are considered OR joined (e.g., matching any single event listed).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubscriptionTopicCanFilterBy(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """List of properties by which Subscriptions on the SubscriptionTopic can be filtered. May be defined Search Parameters (e.g., Encounter.patient) or parameters defined within this SubscriptionTopic context (e.g., hub.event)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    resource: Optional_['uri'] = Field(default=None)
    'URL of the Resource that is the type used in this filter. This is the "focus" of the topic (or one of them if there are more than one). It will be the same, a generality, or a specificity of SubscriptionTopic.resourceTrigger.resource or SubscriptionTopic.eventTrigger.resource when they are present.'
    modifier: List_['code'] = Field(default_factory=list)
    'Allowable operators to apply when determining matches (Search Modifiers).  If the filterParameter is a SearchParameter, this list of modifiers SHALL be a strict subset of the modifiers defined on that SearchParameter.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['markdown'] = Field(default=None)
    'Description of how this filtering parameter is intended to be used.'
    filterParameter: 'string' = Field(default=...)
    'Either the canonical URL to a search parameter (like "http://hl7.org/fhir/SearchParameter/encounter-patient") or topic-defined parameter (like "hub.event") which is a label for the filter.'
    filterDefinition: Optional_['uri'] = Field(default=None)
    'Either the canonical URL to a search parameter (like "http://hl7.org/fhir/SearchParameter/encounter-patient") or the officially-defined URI for a shared filter concept (like "http://example.org/concepts/shared-common-event").'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubscriptionTopic(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes a stream of resource state changes or events and annotated with labels useful to filter projections from this topic."""
    resourceType: Literal_['SubscriptionTopic'] = Field(default=...)
    'The definition of a specific topic for triggering events within the Subscriptions framework'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: 'uri' = Field(default=...)
    'An absolute URI that is used to identify this subscription topic when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this subscription topic is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the subscription topic is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the SubscriptionTopic, for example, "admission".'
    status: 'code' = Field(default=...)
    'The current state of the SubscriptionTopic.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the subscription topic when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the Topic author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions are orderable.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explains why this Topic is needed and why it has been designed as it has.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'Helps establish the "authority/credibility" of the SubscriptionTopic.  May also allow for contact.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the SubscriptionTopic and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the SubscriptionTopic.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this subscription topic by the performer and/or other systems.  These identifiers remain constant as the resource is updated and propagates from server to server.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These terms may be used to assist with indexing and searching of code system definitions.'
    derivedFrom: List_['canonical'] = Field(default_factory=list)
    'The canonical URL pointing to another FHIR-defined SubscriptionTopic that is adhered to in whole or in part by this SubscriptionTopic.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the Topic from the consumer's perspective."
    canFilterBy: List_['SubscriptionTopicCanFilterBy'] = Field(default_factory=list)
    'List of properties by which Subscriptions on the SubscriptionTopic can be filtered. May be defined Search Parameters (e.g., Encounter.patient) or parameters defined within this SubscriptionTopic context (e.g., hub.event).'
    experimental: Optional_['boolean'] = Field(default=None)
    'A flag to indicate that this TopSubscriptionTopicic is authored for testing purposes (or education/evaluation/marketing), and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A jurisdiction in which the Topic is intended to be used.'
    approvalDate: Optional_['date'] = Field(default=None)
    'The date on which the asset content was approved by the publisher. Approval happens once when the content is officially approved for usage.'
    eventTrigger: List_['SubscriptionTopicEventTrigger'] = Field(default_factory=list)
    'Event definition which can be used to trigger the SubscriptionTopic.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastReviewDate: Optional_['date'] = Field(default=None)
    "The date on which the asset content was last reviewed. Review happens periodically after that, but doesn't change the original approval date."
    effectivePeriod: Optional_['Period'] = Field(default=None)
    'The period during which the SubscriptionTopic content was or is planned to be effective.'
    resourceTrigger: List_['SubscriptionTopicResourceTrigger'] = Field(default_factory=list)
    'A definition of a resource-based event that triggers a notification based on the SubscriptionTopic. The criteria may be just a human readable description and/or a full FHIR search string or FHIRPath expression. Multiple triggers are considered OR joined (e.g., a resource update matching ANY of the definitions will trigger a notification).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    notificationShape: List_['SubscriptionTopicNotificationShape'] = Field(default_factory=list)
    'List of properties to describe the shape (e.g., resources) included in notifications from this Subscription Topic.'
    date: Optional_['dateTime'] = Field(default=None)
    'For draft definitions, indicates the date of initial creation.  For active definitions, represents the date of activation.  For withdrawn definitions, indicates the date of withdrawal.'


class SubstanceIngredient(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A substance can be composed of other substances."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    quantity: Optional_['Ratio'] = Field(default=None)
    'The amount of the ingredient in the substance - a concentration ratio.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    substanceCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Another substance that is a component of this substance.'
    substanceReference: Optional_['Reference'] = Field(default=None)
    'Another substance that is a component of this substance.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubstanceInstance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Substance may be used to describe a kind of substance, or a specific package/container of the substance: an instance."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    expiry: Optional_['dateTime'] = Field(default=None)
    'When the substance is no longer valid to use. For some substances, a single arbitrary date is used for expiry.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The amount of the substance.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Identifier associated with the package/container (usually a label affixed directly).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class Substance(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A homogeneous material with a definite composition."""
    resourceType: Literal_['Substance'] = Field(default=...)
    'A homogeneous material with a definite composition'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: Optional_['code'] = Field(default=None)
    'A code to indicate if the substance is actively used.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: List_['CodeableConcept'] = Field(default_factory=list)
    'A code that classifies the general type of substance.  This is used  for searching, sorting and display purposes.'
    instance: List_['SubstanceInstance'] = Field(default_factory=list)
    'Substance may be used to describe a kind of substance, or a specific package/container of the substance: an instance.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Unique identifier for the substance.'
    ingredient: List_['SubstanceIngredient'] = Field(default_factory=list)
    'A substance can be composed of other substances.'
    description: Optional_['string'] = Field(default=None)
    'A description of the substance - its appearance, handling requirements, and other usage notes.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'CodeableConcept' = Field(default=...)
    'A code (or set of codes) that identify this substance.'


class SubstanceDefinitionMolecularWeight(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The molecular weight or weight range (for proteins, polymers or nucleic acids)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Type of molecular weight such as exact, average (also known as. number average), weight average.'
    method: Optional_['CodeableConcept'] = Field(default=None)
    'The method by which the molecular weight was determined.'
    amount: 'Quantity' = Field(default=...)
    'Used to capture quantitative values for a variety of elements. If only limits are given, the arithmetic mean would be the average. If only a single definite value for a given element is given, it would be captured in this field.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubstanceDefinitionSourceMaterial(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Material or taxonomic/anatomical source for the substance."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'A classification that provides the origin of the raw material. Example: cat hair would be an Animal source type.'
    part: Optional_['CodeableConcept'] = Field(default=None)
    'An anatomical origin of the source material within an organism.'
    genus: Optional_['CodeableConcept'] = Field(default=None)
    'The genus of an organism, typically referring to the Latin epithet of the genus element of the plant/animal scientific name.'
    species: Optional_['CodeableConcept'] = Field(default=None)
    'The species of an organism, typically referring to the Latin epithet of the species of the plant/animal.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    countryOfOrigin: List_['CodeableConcept'] = Field(default_factory=list)
    'The country or countries where the material is harvested.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubstanceDefinitionRelationship(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A link between this substance and another, with details of the relationship."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'For example "salt to parent", "active moiety", "starting material", "polymorph", "impurity of".'
    source: List_['Reference'] = Field(default_factory=list)
    'Supporting literature.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    amountQuantity: Optional_['Quantity'] = Field(default=None)
    'A numeric factor for the relationship, for instance to express that the salt of a substance has some percentage of the active substance in relation to some other.'
    amountRatio: Optional_['Ratio'] = Field(default=None)
    'A numeric factor for the relationship, for instance to express that the salt of a substance has some percentage of the active substance in relation to some other.'
    amountString: Optional_['string'] = Field(default=None)
    'A numeric factor for the relationship, for instance to express that the salt of a substance has some percentage of the active substance in relation to some other.'
    isDefining: Optional_['boolean'] = Field(default=None)
    'For example where an enzyme strongly bonds with a particular substance, this is a defining relationship for that enzyme, out of several possible substance relationships.'
    comparator: Optional_['CodeableConcept'] = Field(default=None)
    'An operator for the amount, for example "average", "approximately", "less than".'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    ratioHighLimitAmount: Optional_['Ratio'] = Field(default=None)
    'For use when the numeric has an uncertain range.'
    substanceDefinitionReference: Optional_['Reference'] = Field(default=None)
    'A pointer to another substance, as a resource or just a representational code.'
    substanceDefinitionCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A pointer to another substance, as a resource or just a representational code.'


class SubstanceDefinitionStructure(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Structural information."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    technique: List_['CodeableConcept'] = Field(default_factory=list)
    'The method used to elucidate the structure or characterization of the drug substance. Examples: X-ray, HPLC, NMR, Peptide mapping, Ligand binding assay.'
    sourceDocument: List_['Reference'] = Field(default_factory=list)
    'The source of information about the structure.'
    representation: List_['SubstanceDefinitionStructureRepresentation'] = Field(default_factory=list)
    'A depiction of the structure or characterization of the substance.'
    stereochemistry: Optional_['CodeableConcept'] = Field(default=None)
    'Stereochemistry type.'
    opticalActivity: Optional_['CodeableConcept'] = Field(default=None)
    'Optical activity type.'
    molecularWeight: Optional_['SubstanceDefinitionMolecularWeight'] = Field(default=None)
    'The molecular weight or weight range (for proteins, polymers or nucleic acids).'
    molecularFormula: Optional_['string'] = Field(default=None)
    'Molecular formula of this substance, typically using the Hill system.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    molecularFormulaByMoiety: Optional_['string'] = Field(default=None)
    'Specified per moiety according to the Hill system, i.e. first C, then H, then alphabetical, each moiety separated by a dot.'


class SubstanceDefinitionStructureRepresentation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A depiction of the structure or characterization of the substance."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'The kind of structural representation (e.g. full, partial).'
    format: Optional_['CodeableConcept'] = Field(default=None)
    'The format of the representation e.g. InChI, SMILES, MOLFILE, CDX, SDF, PDB, mmCIF. The logical content type rather than the physical file format of a document.'
    document: Optional_['Reference'] = Field(default=None)
    'An attached file with the structural representation or characterization e.g. a molecular structure graphic of the substance, a JCAMP or AnIML file.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    representation: Optional_['string'] = Field(default=None)
    'The structural representation or characterization as a text string in a standard format.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubstanceDefinitionProperty(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """General specifications for this substance."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'CodeableConcept' = Field(default=...)
    'A code expressing the type of property.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'A value for the property.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'A value for the property.'
    valueDate: Optional_['date'] = Field(default=None)
    'A value for the property.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'A value for the property.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'A value for the property.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubstanceDefinitionMoiety(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Moiety, for structural modifications."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    role: Optional_['CodeableConcept'] = Field(default=None)
    'Role that the moiety is playing.'
    name: Optional_['string'] = Field(default=None)
    'Textual name for this moiety substance.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    amountQuantity: Optional_['Quantity'] = Field(default=None)
    'Quantitative value for this moiety.'
    amountString: Optional_['string'] = Field(default=None)
    'Quantitative value for this moiety.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Identifier by which this moiety substance is known.'
    stereochemistry: Optional_['CodeableConcept'] = Field(default=None)
    'Stereochemistry type.'
    opticalActivity: Optional_['CodeableConcept'] = Field(default=None)
    'Optical activity type.'
    measurementType: Optional_['CodeableConcept'] = Field(default=None)
    'The measurement type of the quantitative value. In capturing the actual relative amounts of substances or molecular fragments it may be necessary to indicate whether the amount refers to, for example, a mole ratio or weight ratio.'
    molecularFormula: Optional_['string'] = Field(default=None)
    'Molecular formula for this moiety of this substance, typically using the Hill system.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubstanceDefinitionName(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Names applicable to this substance."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'The actual name.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    "Name type, for example 'systematic',  'scientific, 'brand'."
    status: Optional_['CodeableConcept'] = Field(default=None)
    "The status of the name, for example 'current', 'proposed'."
    domain: List_['CodeableConcept'] = Field(default_factory=list)
    'The use context of this name for example if there is a different name a drug active ingredient as opposed to a food colour additive.'
    source: List_['Reference'] = Field(default_factory=list)
    'Supporting literature.'
    synonym: List_['SubstanceDefinitionName'] = Field(default_factory=list)
    'A synonym of this particular name, by which the substance is also known.'
    language: List_['CodeableConcept'] = Field(default_factory=list)
    'Human language that the name is written in.'
    official: List_['SubstanceDefinitionNameOfficial'] = Field(default_factory=list)
    'Details of the official nature of this name.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    preferred: Optional_['boolean'] = Field(default=None)
    'If this is the preferred name for this substance.'
    translation: List_['SubstanceDefinitionName'] = Field(default_factory=list)
    'A translation for this name into another human language.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'The jurisdiction where this name applies.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubstanceDefinitionNameOfficial(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Details of the official nature of this name."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    date: Optional_['dateTime'] = Field(default=None)
    'Date of the official name change.'
    status: Optional_['CodeableConcept'] = Field(default=None)
    "The status of the official name, for example 'draft', 'active', 'retired'."
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    authority: Optional_['CodeableConcept'] = Field(default=None)
    'Which authority uses this official name.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubstanceDefinitionCode(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Codes associated with the substance."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'The specific code.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Any comment can be provided in this field, if necessary.'
    status: Optional_['CodeableConcept'] = Field(default=None)
    "Status of the code assignment, for example 'provisional', 'approved'."
    source: List_['Reference'] = Field(default_factory=list)
    'Supporting literature.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    statusDate: Optional_['dateTime'] = Field(default=None)
    'The date at which the code status was changed as part of the terminology maintenance.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SubstanceDefinition(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The detailed description of a substance, typically at a level beyond what is used for prescribing."""
    resourceType: Literal_['SubstanceDefinition'] = Field(default=...)
    'The detailed description of a substance, typically at a level beyond what is used for prescribing'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    "Textual comment about the substance's catalogue or registry record."
    name: List_['SubstanceDefinitionName'] = Field(default_factory=list)
    'Names applicable to this substance.'
    grade: List_['CodeableConcept'] = Field(default_factory=list)
    'The quality standard, established benchmark, to which substance complies (e.g. USP/NF, Ph. Eur, JP, BP, Company Standard).'
    status: Optional_['CodeableConcept'] = Field(default=None)
    'Status of substance within the catalogue e.g. active, retired.'
    domain: Optional_['CodeableConcept'] = Field(default=None)
    'If the substance applies to human or veterinary use.'
    moiety: List_['SubstanceDefinitionMoiety'] = Field(default_factory=list)
    'Moiety, for structural modifications.'
    version: Optional_['string'] = Field(default=None)
    'A business level version identifier of the substance.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    supplier: List_['Reference'] = Field(default_factory=list)
    'An entity that is the source for the substance. It may be different from the manufacturer. Supplier is synonymous to a distributor.'
    property: List_['SubstanceDefinitionProperty'] = Field(default_factory=list)
    'General specifications for this substance.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    structure: Optional_['SubstanceDefinitionStructure'] = Field(default=None)
    'Structural information.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier by which this substance is known.'
    description: Optional_['markdown'] = Field(default=None)
    'Textual description of the substance.'
    manufacturer: List_['Reference'] = Field(default_factory=list)
    'The entity that creates, makes, produces or fabricates the substance. This is a set of potential manufacturers but is not necessarily comprehensive.'
    relationship: List_['SubstanceDefinitionRelationship'] = Field(default_factory=list)
    'A link between this substance and another, with details of the relationship.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    classification: List_['CodeableConcept'] = Field(default_factory=list)
    'A high level categorization, e.g. polymer or nucleic acid, or food, chemical, biological, or a lower level such as the general types of polymer (linear or branch chain) or type of impurity (process related or contaminant).'
    sourceMaterial: Optional_['SubstanceDefinitionSourceMaterial'] = Field(default=None)
    'Material or taxonomic/anatomical source for the substance.'
    molecularWeight: List_['SubstanceDefinitionMolecularWeight'] = Field(default_factory=list)
    'The molecular weight or weight range (for proteins, polymers or nucleic acids).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    informationSource: List_['Reference'] = Field(default_factory=list)
    'Supporting literature.'
    code: List_['SubstanceDefinitionCode'] = Field(default_factory=list)
    'Codes associated with the substance.'


class SupplyDeliverySuppliedItem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The item that is being delivered or has been supplied."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    itemCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'Identifies the medication, substance or device being dispensed. This is either a link to a resource representing the details of the item or a code that identifies the item from a known list.'
    itemReference: Optional_['Reference'] = Field(default=None)
    'Identifies the medication, substance or device being dispensed. This is either a link to a resource representing the details of the item or a code that identifies the item from a known list.'
    quantity: Optional_['Quantity'] = Field(default=None)
    'The amount of supply that has been dispensed. Includes unit of measure.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SupplyDelivery(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Record of delivery of what is supplied."""
    resourceType: Literal_['SupplyDelivery'] = Field(default=...)
    'Delivery of bulk Supplies'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    type: Optional_['CodeableConcept'] = Field(default=None)
    'Indicates the type of dispensing event that is performed. Examples include: Trial Fill, Completion of Trial, Partial Fill, Emergency Fill, Samples, etc.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'A larger event of which this particular event is a component or step.'
    status: Optional_['code'] = Field(default=None)
    'A code specifying the state of the dispense event.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'A plan, proposal or order that is fulfilled in whole or in part by this event.'
    patient: Optional_['Reference'] = Field(default=None)
    'A link to a resource representing the person whom the delivered item is for.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    supplier: Optional_['Reference'] = Field(default=None)
    'The individual responsible for dispensing the medication, supplier or device.'
    receiver: List_['Reference'] = Field(default_factory=list)
    'Identifies the person who picked up the Supply.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Identifier for the supply delivery event that is used to identify it across multiple disparate systems.'
    destination: Optional_['Reference'] = Field(default=None)
    'Identification of the facility/location where the Supply was shipped to, as part of the dispense event.'
    suppliedItem: Optional_['SupplyDeliverySuppliedItem'] = Field(default=None)
    'The item that is being delivered or has been supplied.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'The date or time(s) the activity occurred.'
    occurrencePeriod: Optional_['Period'] = Field(default=None)
    'The date or time(s) the activity occurred.'
    occurrenceTiming: Optional_['Timing'] = Field(default=None)
    'The date or time(s) the activity occurred.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SupplyRequestParameter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specific parameters for the ordered item.  For example, the size of the indicated item."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A code or string that identifies the device detail being asserted.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The value of the device detail.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The value of the device detail.'
    valueRange: Optional_['Range'] = Field(default=None)
    'The value of the device detail.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The value of the device detail.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class SupplyRequest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A record of a request for a medication, substance or device used in the healthcare setting."""
    resourceType: Literal_['SupplyRequest'] = Field(default=...)
    'Request for a medication, substance or device'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: Optional_['code'] = Field(default=None)
    'Status of the supply request.'
    itemCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The item that is requested to be supplied. This is either a link to a resource representing the details of the item or a code that identifies the item from a known list.'
    itemReference: Optional_['Reference'] = Field(default=None)
    'The item that is requested to be supplied. This is either a link to a resource representing the details of the item or a code that identifies the item from a known list.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    category: Optional_['CodeableConcept'] = Field(default=None)
    'Category of supply, e.g.  central, non-stock, etc. This is used to support work flows associated with the supply process.'
    priority: Optional_['code'] = Field(default=None)
    'Indicates how quickly this SupplyRequest should be addressed with respect to other requests.'
    quantity: 'Quantity' = Field(default=...)
    'The amount that is being ordered of the indicated item.'
    supplier: List_['Reference'] = Field(default_factory=list)
    'Who is intended to fulfill the request.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    parameter: List_['SupplyRequestParameter'] = Field(default_factory=list)
    'Specific parameters for the ordered item.  For example, the size of the indicated item.'
    requester: Optional_['Reference'] = Field(default=None)
    'The device, practitioner, etc. who initiated the request.'
    deliverTo: Optional_['Reference'] = Field(default=None)
    'Where the supply is destined to go.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'Business identifiers assigned to this SupplyRequest by the author and/or other systems. These identifiers remain constant as the resource is updated and propagates from server to server.'
    authoredOn: Optional_['dateTime'] = Field(default=None)
    'When the request was made.'
    reasonCode: List_['CodeableConcept'] = Field(default_factory=list)
    'The reason why the supply item was requested.'
    deliverFrom: Optional_['Reference'] = Field(default=None)
    'Where the supply is expected to come from.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    occurrenceDateTime: Optional_['dateTime'] = Field(default=None)
    'When the request should be fulfilled.'
    occurrencePeriod: Optional_['Period'] = Field(default=None)
    'When the request should be fulfilled.'
    occurrenceTiming: Optional_['Timing'] = Field(default=None)
    'When the request should be fulfilled.'
    reasonReference: List_['Reference'] = Field(default_factory=list)
    'The reason why the supply item was requested.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TaskRestriction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """If the Task.focus is a request resource and the task is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    period: Optional_['Period'] = Field(default=None)
    'Over what time-period is fulfillment sought.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    recipient: List_['Reference'] = Field(default_factory=list)
    'For requests that are targeted to more than on potential recipient/target, for whom is fulfillment sought?'
    repetitions: Optional_['positiveInt'] = Field(default=None)
    'Indicates the number of times the requested action should occur.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TaskOutput(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Outputs produced by the Task."""
    type: 'CodeableConcept' = Field(default=...)
    'The name of the Output parameter.'
    valueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueCanonical: Optional_['canonical'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueCode: Optional_['code'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueDate: Optional_['date'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueId: Optional_['id'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueInstant: Optional_['instant'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueMarkdown: Optional_['markdown'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueOid: Optional_['oid'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valuePositiveInt: Optional_['positiveInt'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueString: Optional_['string'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueTime: Optional_['time'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueUri: Optional_['uri'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueUrl: Optional_['url'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueUuid: Optional_['uuid'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueAddress: Optional_['Address'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueAge: Optional_['Age'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueAnnotation: Optional_['Annotation'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueCoding: Optional_['Coding'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueContactPoint: Optional_['ContactPoint'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueCount: Optional_['Count'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueDistance: Optional_['Distance'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueDuration: Optional_['Duration'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueHumanName: Optional_['HumanName'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueIdentifier: Optional_['Identifier'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueMoney: Optional_['Money'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valuePeriod: Optional_['Period'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueRange: Optional_['Range'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueRatio: Optional_['Ratio'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueSampledData: Optional_['SampledData'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueSignature: Optional_['Signature'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueTiming: Optional_['Timing'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueContactDetail: Optional_['ContactDetail'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueContributor: Optional_['Contributor'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueExpression: Optional_['Expression'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueParameterDefinition: Optional_['ParameterDefinition'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueRelatedArtifact: Optional_['RelatedArtifact'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueTriggerDefinition: Optional_['TriggerDefinition'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueUsageContext: Optional_['UsageContext'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueDosage: Optional_['Dosage'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    valueMeta: Optional_['Meta'] = Field(default=None)
    'The value of the Output parameter as a basic type.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class TaskInput(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Additional information that may be needed in the execution of the task."""
    type: 'CodeableConcept' = Field(default=...)
    'A code or description indicating how the input is intended to be used as part of the task execution.'
    valueBase64Binary: Optional_['base64Binary'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueCanonical: Optional_['canonical'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueCode: Optional_['code'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueDate: Optional_['date'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueId: Optional_['id'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueInstant: Optional_['instant'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueMarkdown: Optional_['markdown'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueOid: Optional_['oid'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valuePositiveInt: Optional_['positiveInt'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueString: Optional_['string'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueTime: Optional_['time'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueUnsignedInt: Optional_['unsignedInt'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueUri: Optional_['uri'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueUrl: Optional_['url'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueUuid: Optional_['uuid'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueAddress: Optional_['Address'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueAge: Optional_['Age'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueAnnotation: Optional_['Annotation'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueAttachment: Optional_['Attachment'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueCodeableConcept: Optional_['CodeableConcept'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueCoding: Optional_['Coding'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueContactPoint: Optional_['ContactPoint'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueCount: Optional_['Count'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueDistance: Optional_['Distance'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueDuration: Optional_['Duration'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueHumanName: Optional_['HumanName'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueIdentifier: Optional_['Identifier'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueMoney: Optional_['Money'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valuePeriod: Optional_['Period'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueQuantity: Optional_['Quantity'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueRange: Optional_['Range'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueRatio: Optional_['Ratio'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueReference: Optional_['Reference'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueSampledData: Optional_['SampledData'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueSignature: Optional_['Signature'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueTiming: Optional_['Timing'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueContactDetail: Optional_['ContactDetail'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueContributor: Optional_['Contributor'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueDataRequirement: Optional_['DataRequirement'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueExpression: Optional_['Expression'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueParameterDefinition: Optional_['ParameterDefinition'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueRelatedArtifact: Optional_['RelatedArtifact'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueTriggerDefinition: Optional_['TriggerDefinition'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueUsageContext: Optional_['UsageContext'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueDosage: Optional_['Dosage'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    valueMeta: Optional_['Meta'] = Field(default=None)
    'The value of the input parameter as a basic type.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class Task(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A task to be performed."""
    resourceType: Literal_['Task'] = Field(default=...)
    'A task to be performed'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    for_: Optional_['Reference'] = Field(default=None, alias='for')
    'The entity who benefits from the performance of the service specified in the task (e.g., the patient).'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Free-text information captured about the task as it progresses.'
    focus: Optional_['Reference'] = Field(default=None)
    'The request being actioned or the resource being manipulated by this task.'
    owner: Optional_['Reference'] = Field(default=None)
    'Individual organization or Device currently responsible for task execution.'
    input: List_['TaskInput'] = Field(default_factory=list)
    'Additional information that may be needed in the execution of the task.'
    partOf: List_['Reference'] = Field(default_factory=list)
    'Task that this particular task is part of.'
    status: 'code' = Field(default=...)
    'The current status of the task.'
    intent: 'code' = Field(default=...)
    'Indicates the "level" of actionability associated with the Task, i.e. i+R[9]Cs this a proposed task, a planned task, an actionable task, etc.'
    output: List_['TaskOutput'] = Field(default_factory=list)
    'Outputs produced by the Task.'
    basedOn: List_['Reference'] = Field(default_factory=list)
    'BasedOn refers to a higher-level authorization that triggered the creation of the task.  It references a "request" resource such as a ServiceRequest, MedicationRequest, ServiceRequest, CarePlan, etc. which is distinct from the "request" resource the task is seeking to fulfill.  This latter resource is referenced by FocusOn.  For example, based on a ServiceRequest (= BasedOn), a task is created to fulfill a procedureRequest ( = FocusOn ) to collect a specimen from a patient.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    priority: Optional_['code'] = Field(default=None)
    'Indicates how quickly the Task should be addressed with respect to other requests.'
    location: Optional_['Reference'] = Field(default=None)
    'Principal physical location where the this task is performed.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'The healthcare event  (e.g. a patient and healthcare provider interaction) during which this task was created.'
    requester: Optional_['Reference'] = Field(default=None)
    'The creator of the task.'
    insurance: List_['Reference'] = Field(default_factory=list)
    'Insurance plans, coverage extensions, pre-authorizations and/or pre-determinations that may be relevant to the Task.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'The business identifier for this task.'
    authoredOn: Optional_['dateTime'] = Field(default=None)
    'The date and time this task was created.'
    reasonCode: Optional_['CodeableConcept'] = Field(default=None)
    'A description or code indicating why this task needs to be performed.'
    description: Optional_['string'] = Field(default=None)
    'A free-text description of what is to be performed.'
    restriction: Optional_['TaskRestriction'] = Field(default=None)
    'If the Task.focus is a request resource and the task is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.'
    statusReason: Optional_['CodeableConcept'] = Field(default=None)
    'An explanation as to why this task is held, failed, was refused, etc.'
    lastModified: Optional_['dateTime'] = Field(default=None)
    'The date and time of last modification to this task.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    performerType: List_['CodeableConcept'] = Field(default_factory=list)
    'The kind of participant that should perform the task.'
    businessStatus: Optional_['CodeableConcept'] = Field(default=None)
    'Contains business-specific nuances of the business state.'
    instantiatesUri: Optional_['uri'] = Field(default=None)
    'The URL pointing to an *externally* maintained  protocol, guideline, orderset or other definition that is adhered to in whole or in part by this Task.'
    groupIdentifier: Optional_['Identifier'] = Field(default=None)
    'An identifier that links together multiple tasks and other requests that were created in the same context.'
    executionPeriod: Optional_['Period'] = Field(default=None)
    'Identifies the time action was first taken against the task (start) and/or the time final action was taken against the task prior to marking it as completed (end).'
    reasonReference: Optional_['Reference'] = Field(default=None)
    'A resource reference indicating why this task needs to be performed.'
    relevantHistory: List_['Reference'] = Field(default_factory=list)
    'Links to Provenance records for past versions of this Task that identify key state transitions or updates that are likely to be relevant to a user looking at the current version of the task.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    instantiatesCanonical: Optional_['canonical'] = Field(default=None)
    'The URL pointing to a *FHIR*-defined protocol, guideline, orderset or other definition that is adhered to in whole or in part by this Task.'
    code: Optional_['CodeableConcept'] = Field(default=None)
    'A name or code (or both) briefly describing what the task involves.'


class TerminologyCapabilitiesImplementation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies a specific implementation instance that is described by the terminology capability statement - i.e. a particular installation, rather than the capabilities of a software program."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: 'string' = Field(default=...)
    'Information about the specific installation that this terminology capability statement relates to.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    url: Optional_['url'] = Field(default=None)
    'An absolute base URL for the implementation.'


class TerminologyCapabilitiesValidateCode(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the [ValueSet/$validate-code](valueset-operation-validate-code.html) operation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    translations: 'boolean' = Field(default=...)
    'Whether translations are validated.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TerminologyCapabilitiesTranslation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the [ConceptMap/$translate](conceptmap-operation-translate.html) operation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    needsMap: 'boolean' = Field(default=...)
    'Whether the client must identify the map.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TerminologyCapabilitiesCodeSystem(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Identifies a code system that is supported by the server. If there is a no code system URL, then this declares the general assumptions a client can make about support for any CodeSystem resource."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    uri: Optional_['canonical'] = Field(default=None)
    'URI for the Code System.'
    version: List_['TerminologyCapabilitiesCodeSystemVersion'] = Field(default_factory=list)
    'For the code system, a list of versions that are supported by the server.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    subsumption: Optional_['boolean'] = Field(default=None)
    'True if subsumption is supported for this version of the code system.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TerminologyCapabilitiesCodeSystemVersion(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """For the code system, a list of versions that are supported by the server."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    filter: List_['TerminologyCapabilitiesCodeSystemVersionFilter'] = Field(default_factory=list)
    'Filter Properties supported.'
    language: List_['code'] = Field(default_factory=list)
    'Language Displays supported.'
    property: List_['code'] = Field(default_factory=list)
    'Properties supported for $lookup.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    isDefault: Optional_['boolean'] = Field(default=None)
    'If this is the default version for this code system.'
    compositional: Optional_['boolean'] = Field(default=None)
    'If the compositional grammar defined by the code system is supported.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['string'] = Field(default=None)
    'For version-less code systems, there should be a single version with no identifier.'


class TerminologyCapabilitiesCodeSystemVersionFilter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Filter Properties supported."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    op: List_['code'] = Field(default=...)
    'Operations supported for the property.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'Code of the property supported.'


class TerminologyCapabilitiesExpansion(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the [ValueSet/$expand](valueset-operation-expand.html) operation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    paging: Optional_['boolean'] = Field(default=None)
    'Whether the server supports paging on expansion.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    parameter: List_['TerminologyCapabilitiesExpansionParameter'] = Field(default_factory=list)
    'Supported expansion parameter.'
    incomplete: Optional_['boolean'] = Field(default=None)
    'Allow request for incomplete expansions?'
    textFilter: Optional_['markdown'] = Field(default=None)
    'Documentation about text searching works.'
    hierarchical: Optional_['boolean'] = Field(default=None)
    'Whether the server can return nested value sets.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TerminologyCapabilitiesExpansionParameter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Supported expansion parameter."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'code' = Field(default=...)
    'Expansion Parameter name.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    documentation: Optional_['string'] = Field(default=None)
    'Description of support for parameter.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TerminologyCapabilitiesSoftware(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Software that is covered by this terminology capability statement.  It is used when the statement describes the capabilities of a particular software version, independent of an installation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'Name the software is known by.'
    version: Optional_['string'] = Field(default=None)
    'The version identifier for the software covered by this statement.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TerminologyCapabilitiesClosure(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Whether the $closure operation is supported."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    translation: Optional_['boolean'] = Field(default=None)
    'If cross-system closure is supported.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TerminologyCapabilities(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A TerminologyCapabilities resource documents a set of capabilities (behaviors) of a FHIR Terminology Server that may be used as a statement of actual server functionality or a statement of required or desired server implementation."""
    resourceType: Literal_['TerminologyCapabilities'] = Field(default=...)
    'A statement of system capabilities'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this terminology capabilities when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this terminology capabilities is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the terminology capabilities is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the terminology capabilities. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: 'dateTime' = Field(default=...)
    'The date  (and optionally time) when the terminology capabilities was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the terminology capabilities changes.'
    kind: 'code' = Field(default=...)
    'The way that this statement is intended to be used, to describe an actual running instance of software, a particular product (kind, not instance of software) or a class of implementation (e.g. a desired purchase).'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the terminology capabilities.'
    status: 'code' = Field(default=...)
    'The status of this terminology capabilities. Enables tracking the life-cycle of the content.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the terminology capabilities when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the terminology capabilities author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this terminology capabilities is needed and why it has been designed as it has.'
    closure: Optional_['TerminologyCapabilitiesClosure'] = Field(default=None)
    'Whether the $closure operation is supported.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    software: Optional_['TerminologyCapabilitiesSoftware'] = Field(default=None)
    'Software that is covered by this terminology capability statement.  It is used when the statement describes the capabilities of a particular software version, independent of an installation.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the terminology capabilities.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the terminology capabilities and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the terminology capabilities.'
    expansion: Optional_['TerminologyCapabilitiesExpansion'] = Field(default=None)
    'Information about the [ValueSet/$expand](valueset-operation-expand.html) operation.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate terminology capabilities instances.'
    lockedDate: Optional_['boolean'] = Field(default=None)
    'Whether the server supports lockedDate.'
    codeSystem: List_['TerminologyCapabilitiesCodeSystem'] = Field(default_factory=list)
    'Identifies a code system that is supported by the server. If there is a no code system URL, then this declares the general assumptions a client can make about support for any CodeSystem resource.'
    codeSearch: Optional_['code'] = Field(default=None)
    'The degree to which the server supports the code search parameter on ValueSet, if it is supported.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the terminology capabilities from a consumer's perspective. Typically, this is used when the capability statement describes a desired rather than an actual solution, for example as a formal expression of requirements as part of an RFP."
    translation: Optional_['TerminologyCapabilitiesTranslation'] = Field(default=None)
    'Information about the [ConceptMap/$translate](conceptmap-operation-translate.html) operation.'
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this terminology capabilities is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the terminology capabilities is intended to be used.'
    validateCode: Optional_['TerminologyCapabilitiesValidateCode'] = Field(default=None)
    'Information about the [ValueSet/$validate-code](valueset-operation-validate-code.html) operation.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    implementation: Optional_['TerminologyCapabilitiesImplementation'] = Field(default=None)
    'Identifies a specific implementation instance that is described by the terminology capability statement - i.e. a particular installation, rather than the capabilities of a software program.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestReportParticipant(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A participant in the test execution, either the execution engine, a client, or a server."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    type: 'code' = Field(default=...)
    'The type of participant.'
    display: Optional_['string'] = Field(default=None)
    'The display name of the participant.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    uri: 'uri' = Field(default=...)
    'The uri of the participant. An absolute URL is preferred.'


class TestReportTeardown(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The results of the series of operations required to clean up after all the tests were executed (successfully or otherwise)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    action: List_['TestReportTeardownAction'] = Field(default=...)
    'The teardown action will only contain an operation.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestReportTeardownAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The teardown action will only contain an operation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: 'TestReportSetupActionOperation' = Field(default=...)
    'An operation would involve a REST request to a server.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestReportSetup(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The results of the series of required setup operations before the tests were executed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    action: List_['TestReportSetupAction'] = Field(default=...)
    'Action would contain either an operation or an assertion.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestReportSetupAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Action would contain either an operation or an assertion."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    assert_: Optional_['TestReportSetupActionAssert'] = Field(default=None, alias='assert')
    'The results of the assertion performed on the previous operations.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: Optional_['TestReportSetupActionOperation'] = Field(default=None)
    'The operation performed.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestReportSetupActionOperation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The operation performed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    result: 'code' = Field(default=...)
    'The result of this operation.'
    detail: Optional_['uri'] = Field(default=None)
    'A link to further details on the result.'
    message: Optional_['markdown'] = Field(default=None)
    'An explanatory message associated with the result.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestReportSetupActionAssert(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The results of the assertion performed on the previous operations."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    result: 'code' = Field(default=...)
    'The result of this assertion.'
    detail: Optional_['string'] = Field(default=None)
    'A link to further details on the result.'
    message: Optional_['markdown'] = Field(default=None)
    'An explanatory message associated with the result.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestReportTest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A test executed from the test script."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'The name of this test used for tracking/logging purposes by test engines.'
    action: List_['TestReportTestAction'] = Field(default=...)
    'Action would contain either an operation or an assertion.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'A short description of the test used by test engines for tracking and reporting purposes.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestReportTestAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Action would contain either an operation or an assertion."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    assert_: Optional_['TestReportSetupActionAssert'] = Field(default=None, alias='assert')
    'The results of the assertion performed on the previous operations.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: Optional_['TestReportSetupActionOperation'] = Field(default=None)
    'An operation would involve a REST request to a server.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestReport(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A summary of information based on the results of executing a TestScript."""
    resourceType: Literal_['TestReport'] = Field(default=...)
    'Describes the results of a TestScript execution'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A free text natural language name identifying the executed TestScript.'
    test: List_['TestReportTest'] = Field(default_factory=list)
    'A test executed from the test script.'
    score: Optional_['decimal'] = Field(default=None)
    'The final score (percentage of tests passed) resulting from the execution of the TestScript.'
    setup: Optional_['TestReportSetup'] = Field(default=None)
    'The results of the series of required setup operations before the tests were executed.'
    status: 'code' = Field(default=...)
    'The current state of this test report.'
    result: 'code' = Field(default=...)
    'The overall result from the execution of the TestScript.'
    tester: Optional_['string'] = Field(default=None)
    'Name of the tester producing this report (Organization or individual).'
    issued: Optional_['dateTime'] = Field(default=None)
    'When the TestScript was executed and this TestReport was generated.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    teardown: Optional_['TestReportTeardown'] = Field(default=None)
    'The results of the series of operations required to clean up after all the tests were executed (successfully or otherwise).'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'Identifier for the TestScript assigned for external purposes outside the context of FHIR.'
    testScript: 'Reference' = Field(default=...)
    'Ideally this is an absolute URL that is used to identify the version-specific TestScript that was executed, matching the `TestScript.url`.'
    participant: List_['TestReportParticipant'] = Field(default_factory=list)
    'A participant in the test execution, either the execution engine, a client, or a server.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptDestination(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An abstract server used in operations within this test script in the destination element."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    index: 'integer' = Field(default=...)
    'Abstract name given to a destination server in this test script.  The name is provided as a number starting at 1.'
    profile: 'Coding' = Field(default=...)
    'The type of destination profile the test system supports.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptTeardown(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A series of operations required to clean up after all the tests are executed (successfully or otherwise)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    action: List_['TestScriptTeardownAction'] = Field(default=...)
    'The teardown action will only contain an operation.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptTeardownAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The teardown action will only contain an operation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: 'TestScriptSetupActionOperation' = Field(default=...)
    'An operation would involve a REST request to a server.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptVariable(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Variable is set based either on element value in response body or on header field value in the response headers."""
    name: 'string' = Field(default=...)
    'Descriptive name for this variable.'
    hint: Optional_['string'] = Field(default=None)
    'Displayable text string with hint help information to the user when entering a default value.'
    path: Optional_['string'] = Field(default=None)
    'XPath or JSONPath to evaluate against the fixture body.  When variables are defined, only one of either expression, headerField or path must be specified.'
    sourceId: Optional_['id'] = Field(default=None)
    'Fixture to evaluate the XPath/JSONPath expression or the headerField  against within this variable.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    expression: Optional_['string'] = Field(default=None)
    'The FHIRPath expression to evaluate against the fixture body. When variables are defined, only one of either expression, headerField or path must be specified.'
    description: Optional_['string'] = Field(default=None)
    'A free text natural language description of the variable and its purpose.'
    headerField: Optional_['string'] = Field(default=None)
    'Will be used to grab the HTTP header field value from the headers that sourceId is pointing to.'
    defaultValue: Optional_['string'] = Field(default=None)
    'A default, hard-coded, or user-defined value for this variable.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class TestScriptMetadata(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The required capability must exist and are assumed to function correctly on the FHIR server being tested."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    link: List_['TestScriptMetadataLink'] = Field(default_factory=list)
    'A link to the FHIR specification that this test is covering.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    capability: List_['TestScriptMetadataCapability'] = Field(default=...)
    'Capabilities that must exist and are assumed to function correctly on the FHIR server being tested.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptMetadataCapability(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Capabilities that must exist and are assumed to function correctly on the FHIR server being tested."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    link: List_['uri'] = Field(default_factory=list)
    'Links to the FHIR specification that describes this interaction and the resources involved in more detail.'
    origin: List_['integer'] = Field(default_factory=list)
    'Which origin server these requirements apply to.'
    required: 'boolean' = Field(default=...)
    'Whether or not the test execution will require the given capabilities of the server in order for this test script to execute.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    validated: 'boolean' = Field(default=...)
    'Whether or not the test execution will validate the given capabilities of the server in order for this test script to execute.'
    description: Optional_['string'] = Field(default=None)
    'Description of the capabilities that this test script is requiring the server to support.'
    destination: Optional_['integer'] = Field(default=None)
    'Which server these requirements apply to.'
    capabilities: 'canonical' = Field(default=...)
    'Minimum capabilities required of server for test script to execute successfully.   If server does not meet at a minimum the referenced capability statement, then all tests in this script are skipped.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptMetadataLink(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A link to the FHIR specification that this test is covering."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    url: 'uri' = Field(default=...)
    'URL to a particular requirement or feature within the FHIR specification.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'Short description of the link.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptFixture(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Fixture in the test script - by reference (uri). All fixtures are required for the test script to execute."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    resource: Optional_['Reference'] = Field(default=None)
    'Reference to the resource (containing the contents of the resource needed for operations).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    autocreate: 'boolean' = Field(default=...)
    'Whether or not to implicitly create the fixture during setup. If true, the fixture is automatically created on each server being tested during setup, therefore no create operation is required for this fixture in the TestScript.setup section.'
    autodelete: 'boolean' = Field(default=...)
    'Whether or not to implicitly delete the fixture during teardown. If true, the fixture is automatically deleted on each server being tested during teardown, therefore no delete operation is required for this fixture in the TestScript.teardown section.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptOrigin(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An abstract server used in operations within this test script in the origin element."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    index: 'integer' = Field(default=...)
    'Abstract name given to an origin server in this test script.  The name is provided as a number starting at 1.'
    profile: 'Coding' = Field(default=...)
    'The type of origin profile the test system supports.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptSetup(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A series of required setup operations before tests are executed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    action: List_['TestScriptSetupAction'] = Field(default=...)
    'Action would contain either an operation or an assertion.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptSetupAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Action would contain either an operation or an assertion."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    assert_: Optional_['TestScriptSetupActionAssert'] = Field(default=None, alias='assert')
    'Evaluates the results of previous operations to determine if the server under test behaves appropriately.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: Optional_['TestScriptSetupActionOperation'] = Field(default=None)
    'The operation to perform.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptSetupActionOperation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The operation to perform."""
    url: Optional_['string'] = Field(default=None)
    'Complete request URL.'
    type: Optional_['Coding'] = Field(default=None)
    'Server interaction or operation type.'
    label: Optional_['string'] = Field(default=None)
    'The label would be used for tracking/logging purposes by test engines.'
    accept: Optional_['code'] = Field(default=None)
    "The mime-type to use for RESTful operation in the 'Accept' header."
    method: Optional_['code'] = Field(default=None)
    'The HTTP method the test engine MUST use for this operation regardless of any other operation details.'
    origin: Optional_['integer'] = Field(default=None)
    'The server where the request message originates from.  Must be one of the server numbers listed in TestScript.origin section.'
    params: Optional_['string'] = Field(default=None)
    'Path plus parameters after [type].  Used to set parts of the request URL explicitly.'
    resource: Optional_['code'] = Field(default=None)
    'The type of the resource.  See http://build.fhir.org/resourcelist.html.'
    sourceId: Optional_['id'] = Field(default=None)
    'The id of the fixture used as the body of a PUT or POST request.'
    targetId: Optional_['id'] = Field(default=None)
    'Id of fixture used for extracting the [id],  [type], and [vid] for GET requests.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    requestId: Optional_['id'] = Field(default=None)
    'The fixture id (maybe new) to map to the request.'
    responseId: Optional_['id'] = Field(default=None)
    'The fixture id (maybe new) to map to the response.'
    description: Optional_['string'] = Field(default=None)
    'The description would be used by test engines for tracking and reporting purposes.'
    contentType: Optional_['code'] = Field(default=None)
    "The mime-type to use for RESTful operation in the 'Content-Type' header."
    destination: Optional_['integer'] = Field(default=None)
    'The server where the request message is destined for.  Must be one of the server numbers listed in TestScript.destination section.'
    requestHeader: List_['TestScriptSetupActionOperationRequestHeader'] = Field(default_factory=list)
    'Header elements would be used to set HTTP headers.'
    encodeRequestUrl: 'boolean' = Field(default=...)
    'Whether or not to implicitly send the request url in encoded format. The default is true to match the standard RESTful client behavior. Set to false when communicating with a server that does not support encoded url paths.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class TestScriptSetupActionOperationRequestHeader(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Header elements would be used to set HTTP headers."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    field: 'string' = Field(default=...)
    'The HTTP header field e.g. "Accept".'
    value: 'string' = Field(default=...)
    'The value of the header e.g. "application/fhir+xml".'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptSetupActionAssert(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Evaluates the results of previous operations to determine if the server under test behaves appropriately."""
    path: Optional_['string'] = Field(default=None)
    'The XPath or JSONPath expression to be evaluated against the fixture representing the response received from server.'
    label: Optional_['string'] = Field(default=None)
    'The label would be used for tracking/logging purposes by test engines.'
    value: Optional_['string'] = Field(default=None)
    'The value to compare to.'
    operator: Optional_['code'] = Field(default=None)
    'The operator type defines the conditional behavior of the assert. If not defined, the default is equals.'
    resource: Optional_['code'] = Field(default=None)
    'The type of the resource.  See http://build.fhir.org/resourcelist.html.'
    response: Optional_['code'] = Field(default=None)
    'okay | created | noContent | notModified | bad | forbidden | notFound | methodNotAllowed | conflict | gone | preconditionFailed | unprocessable.'
    sourceId: Optional_['id'] = Field(default=None)
    'Fixture to evaluate the XPath/JSONPath expression or the headerField  against.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    direction: Optional_['code'] = Field(default=None)
    'The direction to use for the assertion.'
    minimumId: Optional_['string'] = Field(default=None)
    'The ID of a fixture.  Asserts that the response contains at a minimum the fixture specified by minimumId.'
    expression: Optional_['string'] = Field(default=None)
    'The FHIRPath expression to be evaluated against the request or response message contents - HTTP headers and payload.'
    requestURL: Optional_['string'] = Field(default=None)
    'The value to use in a comparison against the request URL path string.'
    description: Optional_['string'] = Field(default=None)
    'The description would be used by test engines for tracking and reporting purposes.'
    contentType: Optional_['code'] = Field(default=None)
    "The mime-type contents to compare against the request or response message 'Content-Type' header."
    headerField: Optional_['string'] = Field(default=None)
    "The HTTP header field name e.g. 'Location'."
    warningOnly: 'boolean' = Field(default=...)
    'Whether or not the test execution will produce a warning only on error for this assert.'
    responseCode: Optional_['string'] = Field(default=None)
    'The value of the HTTP response code to be tested.'
    requestMethod: Optional_['code'] = Field(default=None)
    'The request method or HTTP operation code to compare against that used by the client system under test.'
    navigationLinks: Optional_['boolean'] = Field(default=None)
    'Whether or not the test execution performs validation on the bundle navigation links.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    compareToSourceId: Optional_['string'] = Field(default=None)
    'Id of the source fixture used as the contents to be evaluated by either the "source/expression" or "sourceId/path" definition.'
    validateProfileId: Optional_['id'] = Field(default=None)
    'The ID of the Profile to validate against.'
    compareToSourcePath: Optional_['string'] = Field(default=None)
    'XPath or JSONPath expression to evaluate against the source fixture. When compareToSourceId is defined, either compareToSourceExpression or compareToSourcePath must be defined, but not both.'
    compareToSourceExpression: Optional_['string'] = Field(default=None)
    'The FHIRPath expression to evaluate against the source fixture. When compareToSourceId is defined, either compareToSourceExpression or compareToSourcePath must be defined, but not both.'
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'


class TestScriptTest(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A test in this script."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: Optional_['string'] = Field(default=None)
    'The name of this test used for tracking/logging purposes by test engines.'
    action: List_['TestScriptTestAction'] = Field(default=...)
    'Action would contain either an operation or an assertion.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    description: Optional_['string'] = Field(default=None)
    'A short description of the test used by test engines for tracking and reporting purposes.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScriptTestAction(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Action would contain either an operation or an assertion."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    assert_: Optional_['TestScriptSetupActionAssert'] = Field(default=None, alias='assert')
    'Evaluates the results of previous operations to determine if the server under test behaves appropriately.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    operation: Optional_['TestScriptSetupActionOperation'] = Field(default=None)
    'An operation would involve a REST request to a server.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class TestScript(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A structured set of tests against a FHIR server or client implementation to determine compliance against the FHIR specification."""
    resourceType: Literal_['TestScript'] = Field(default=...)
    'Describes a set of tests'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: 'uri' = Field(default=...)
    'An absolute URI that is used to identify this test script when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this test script is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the test script is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: 'string' = Field(default=...)
    'A natural language name identifying the test script. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    'The date  (and optionally time) when the test script was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the test script changes.'
    test: List_['TestScriptTest'] = Field(default_factory=list)
    'A test in this script.'
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the test script.'
    setup: Optional_['TestScriptSetup'] = Field(default=None)
    'A series of required setup operations before tests are executed.'
    status: 'code' = Field(default=...)
    'The status of this test script. Enables tracking the life-cycle of the content.'
    origin: List_['TestScriptOrigin'] = Field(default_factory=list)
    'An abstract server used in operations within this test script in the origin element.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the test script when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the test script author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this test script is needed and why it has been designed as it has.'
    fixture: List_['TestScriptFixture'] = Field(default_factory=list)
    'Fixture in the test script - by reference (uri). All fixtures are required for the test script to execute.'
    profile: List_['Reference'] = Field(default_factory=list)
    'Reference to the profile to be used for validation.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    metadata: Optional_['TestScriptMetadata'] = Field(default=None)
    'The required capability must exist and are assumed to function correctly on the FHIR server being tested.'
    variable: List_['TestScriptVariable'] = Field(default_factory=list)
    'Variable is set based either on element value in response body or on header field value in the response headers.'
    teardown: Optional_['TestScriptTeardown'] = Field(default=None)
    'A series of operations required to clean up after all the tests are executed (successfully or otherwise).'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the test script.'
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the test script and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the test script.'
    identifier: Optional_['Identifier'] = Field(default=None)
    'A formal identifier that is used to identify this test script when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate test script instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the test script from a consumer's perspective."
    destination: List_['TestScriptDestination'] = Field(default_factory=list)
    'An abstract server used in operations within this test script in the destination element.'
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this test script is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the test script is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ValueSetExpansion(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A value set can also be "expanded", where the value set is turned into a simple collection of enumerated codes. This element holds the expansion, if it has been performed."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    total: Optional_['integer'] = Field(default=None)
    'The total number of concepts in the expansion. If the number of concept nodes in this resource is less than the stated number, then the server can return more using the offset parameter.'
    offset: Optional_['integer'] = Field(default=None)
    'If paging is being used, the offset at which this resource starts.  I.e. this resource is a partial view into the expansion. If paging is not being used, this element SHALL NOT be present.'
    contains: List_['ValueSetExpansionContains'] = Field(default_factory=list)
    'The codes that are contained in the value set expansion.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    timestamp: 'dateTime' = Field(default=...)
    'The time at which the expansion was produced by the expanding system.'
    parameter: List_['ValueSetExpansionParameter'] = Field(default_factory=list)
    'A parameter that controlled the expansion process. These parameters may be used by users of expanded value sets to check whether the expansion is suitable for a particular purpose, or to pick the correct expansion.'
    identifier: Optional_['uri'] = Field(default=None)
    'An identifier that uniquely identifies this expansion of the valueset, based on a unique combination of the provided parameters, the system default parameters, and the underlying system code system versions etc. Systems may re-use the same identifier as long as those factors remain the same, and the expansion is the same, but are not required to do so. This is a business identifier.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ValueSetExpansionParameter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A parameter that controlled the expansion process. These parameters may be used by users of expanded value sets to check whether the expansion is suitable for a particular purpose, or to pick the correct expansion."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    name: 'string' = Field(default=...)
    'Name of the input parameter to the $expand operation; may be a server-assigned name for additional default or other server-supplied parameters used to control the expansion process.'
    valueString: Optional_['string'] = Field(default=None)
    'The value of the parameter.'
    valueBoolean: Optional_['boolean'] = Field(default=None)
    'The value of the parameter.'
    valueInteger: Optional_['integer'] = Field(default=None)
    'The value of the parameter.'
    valueDecimal: Optional_['decimal'] = Field(default=None)
    'The value of the parameter.'
    valueUri: Optional_['uri'] = Field(default=None)
    'The value of the parameter.'
    valueCode: Optional_['code'] = Field(default=None)
    'The value of the parameter.'
    valueDateTime: Optional_['dateTime'] = Field(default=None)
    'The value of the parameter.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ValueSetExpansionContains(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """The codes that are contained in the value set expansion."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    system: Optional_['uri'] = Field(default=None)
    'An absolute URI which is the code system in which the code for this item in the expansion is defined.'
    version: Optional_['string'] = Field(default=None)
    'The version of the code system from this code was taken. Note that a well-maintained code system does not need the version reported, because the meaning of codes is consistent across versions. However this cannot consistently be assured, and when the meaning is not guaranteed to be consistent, the version SHOULD be exchanged.'
    display: Optional_['string'] = Field(default=None)
    'The recommended display for this item in the expansion.'
    abstract: Optional_['boolean'] = Field(default=None)
    'If true, this entry is included in the expansion for navigational purposes, and the user cannot select the code directly as a proper value.'
    inactive: Optional_['boolean'] = Field(default=None)
    'If the concept is inactive in the code system that defines it. Inactive codes are those that are no longer to be used, but are maintained by the code system for understanding legacy data. It might not be known or specified whether an concept is inactive (and it may depend on the context of use).'
    contains: List_['ValueSetExpansionContains'] = Field(default_factory=list)
    'Other codes and entries contained under this entry in the hierarchy.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    designation: List_['ValueSetComposeIncludeConceptDesignation'] = Field(default_factory=list)
    'Additional representations for this item - other languages, aliases, specialized purposes, used for particular purposes, etc. These are relevant when the conditions of the expansion do not fix to a single correct representation.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: Optional_['code'] = Field(default=None)
    'The code for this item in the expansion hierarchy. If this code is missing the entry in the hierarchy is a place holder (abstract) and does not represent a valid code in the value set.'


class ValueSetCompose(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A set of criteria that define the contents of the value set by including or excluding codes selected from the specified code system(s) that the value set draws from. This is also known as the Content Logical Definition (CLD)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    include: List_['ValueSetComposeInclude'] = Field(default=...)
    'Include one or more codes from a code system or other value set(s).'
    exclude: List_['ValueSetComposeInclude'] = Field(default_factory=list)
    'Exclude one or more codes from the value set based on code system filters and/or other value sets.'
    inactive: Optional_['boolean'] = Field(default=None)
    'Whether inactive codes - codes that are not approved for current use - are in the value set. If inactive = true, inactive codes are to be included in the expansion, if inactive = false, the inactive codes will not be included in the expansion. If absent, the behavior is determined by the implementation, or by the applicable $expand parameters (but generally, inactive codes would be expected to be included).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    lockedDate: Optional_['date'] = Field(default=None)
    'The Locked Date is  the effective date that is used to determine the version of all referenced Code Systems and Value Set Definitions included in the compose that are not already tied to a specific version.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ValueSetComposeInclude(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Include one or more codes from a code system or other value set(s)."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    system: Optional_['uri'] = Field(default=None)
    'An absolute URI which is the code system from which the selected codes come from.'
    filter: List_['ValueSetComposeIncludeFilter'] = Field(default_factory=list)
    'Select concepts by specify a matching criterion based on the properties (including relationships) defined by the system, or on filters defined by the system. If multiple filters are specified, they SHALL all be true.'
    version: Optional_['string'] = Field(default=None)
    "The version of the code system that the codes are selected from, or the special version '*' for all versions."
    concept: List_['ValueSetComposeIncludeConcept'] = Field(default_factory=list)
    'Specifies a concept to be included or excluded.'
    valueSet: List_['canonical'] = Field(default_factory=list)
    'Selects the concepts found in this value set (based on its value set definition). This is an absolute URI that is a reference to ValueSet.url.  If multiple value sets are specified this includes the union of the contents of all of the referenced value sets.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ValueSetComposeIncludeConcept(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Specifies a concept to be included or excluded."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    display: Optional_['string'] = Field(default=None)
    'The text to display to the user for this concept in the context of this valueset. If no display is provided, then applications using the value set use the display specified for the code by the system.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    designation: List_['ValueSetComposeIncludeConceptDesignation'] = Field(default_factory=list)
    'Additional representations for this concept when used in this value set - other languages, aliases, specialized purposes, used for particular purposes, etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    code: 'code' = Field(default=...)
    'Specifies a code for the concept to be included or excluded.'


class ValueSetComposeIncludeConceptDesignation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Additional representations for this concept when used in this value set - other languages, aliases, specialized purposes, used for particular purposes, etc."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    use: Optional_['Coding'] = Field(default=None)
    'A code that represents types of uses of designations.'
    value: 'string' = Field(default=...)
    'The text value for this designation.'
    language: Optional_['code'] = Field(default=None)
    'The language this designation is defined for.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ValueSetComposeIncludeFilter(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Select concepts by specify a matching criterion based on the properties (including relationships) defined by the system, or on filters defined by the system. If multiple filters are specified, they SHALL all be true."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    op: 'code' = Field(default=...)
    'The kind of operation to perform as a part of the filter criteria.'
    value: 'string' = Field(default=...)
    "The match value may be either a code defined by the system, or a string value, which is a regex match on the literal string of the property value  (if the filter represents a property defined in CodeSystem) or of the system filter value (if the filter represents a filter defined in CodeSystem) when the operation is 'regex', or one of the values (true and false), when the operation is 'exists'."
    property: 'code' = Field(default=...)
    'A code that identifies a property or a filter defined in the code system.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class ValueSet(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """A ValueSet resource instance specifies a set of codes drawn from one or more code systems, intended for use in a particular context. Value sets link between [CodeSystem](codesystem.html) definitions and their use in [coded elements](terminologies.html)."""
    resourceType: Literal_['ValueSet'] = Field(default=...)
    'A set of codes drawn from one or more code systems'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    url: Optional_['uri'] = Field(default=None)
    'An absolute URI that is used to identify this value set when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this value set is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the value set is stored on different servers.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    name: Optional_['string'] = Field(default=None)
    'A natural language name identifying the value set. This name should be usable as an identifier for the module by machine processing applications such as code generation.'
    date: Optional_['dateTime'] = Field(default=None)
    "The date (and optionally time) when the value set was created or revised (e.g. the 'content logical definition')."
    title: Optional_['string'] = Field(default=None)
    'A short, descriptive, user-friendly title for the value set.'
    status: 'code' = Field(default=...)
    'The status of this value set. Enables tracking the life-cycle of the content. The status of the value set applies to the value set definition (ValueSet.compose) and the associated ValueSet metadata. Expansions do not have a state.'
    version: Optional_['string'] = Field(default=None)
    'The identifier that is used to identify this version of the value set when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the value set author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence.'
    contact: List_['ContactDetail'] = Field(default_factory=list)
    'Contact details to assist a user in finding and communicating with the publisher.'
    purpose: Optional_['markdown'] = Field(default=None)
    'Explanation of why this value set is needed and why it has been designed as it has.'
    compose: Optional_['ValueSetCompose'] = Field(default=None)
    'A set of criteria that define the contents of the value set by including or excluding codes selected from the specified code system(s) that the value set draws from. This is also known as the Content Logical Definition (CLD).'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    publisher: Optional_['string'] = Field(default=None)
    'The name of the organization or individual that published the value set.'
    immutable: Optional_['boolean'] = Field(default=None)
    "If this is set to 'true', then no new versions of the content logical definition can be created.  Note: Other metadata might still change."
    copyright: Optional_['markdown'] = Field(default=None)
    'A copyright statement relating to the value set and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the value set.'
    expansion: Optional_['ValueSetExpansion'] = Field(default=None)
    'A value set can also be "expanded", where the value set is turned into a simple collection of enumerated codes. This element holds the expansion, if it has been performed.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A formal identifier that is used to identify this value set when it is represented in other formats, or referenced in a specification, model, design or an instance.'
    useContext: List_['UsageContext'] = Field(default_factory=list)
    'The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate value set instances.'
    description: Optional_['markdown'] = Field(default=None)
    "A free text natural language description of the value set from a consumer's perspective. The textual description specifies the span of meanings for concepts to be included within the Value Set Expansion, and also may specify the intended use and limitations of the Value Set."
    experimental: Optional_['boolean'] = Field(default=None)
    'A Boolean value to indicate that this value set is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.'
    jurisdiction: List_['CodeableConcept'] = Field(default_factory=list)
    'A legal or geographic region in which the value set is intended to be used.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class VerificationResultPrimarySource(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the primary source(s) involved in validation."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    who: Optional_['Reference'] = Field(default=None)
    'Reference to the primary source.'
    type: List_['CodeableConcept'] = Field(default_factory=list)
    'Type of primary source (License Board; Primary Education; Continuing Education; Postal Service; Relationship owner; Registration Authority; legal source; issuing source; authoritative source).'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    validationDate: Optional_['dateTime'] = Field(default=None)
    'When the target was validated against the primary source.'
    canPushUpdates: Optional_['CodeableConcept'] = Field(default=None)
    'Ability of the primary source to push updates/alerts (yes; no; undetermined).'
    validationStatus: Optional_['CodeableConcept'] = Field(default=None)
    'Status of the validation of the target against the primary source (successful; failed; unknown).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    pushTypeAvailable: List_['CodeableConcept'] = Field(default_factory=list)
    'Type of alerts/updates the primary source can send (specific requested changes; any changes; as defined by source).'
    communicationMethod: List_['CodeableConcept'] = Field(default_factory=list)
    'Method for communicating with the primary source (manual; API; Push).'


class VerificationResultAttestation(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the entity attesting to information."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    who: Optional_['Reference'] = Field(default=None)
    'The individual or organization attesting to information.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    onBehalfOf: Optional_['Reference'] = Field(default=None)
    'When the who is asserting on behalf of another (organization or individual).'
    proxySignature: Optional_['Signature'] = Field(default=None)
    'Signed assertion by the proxy entity indicating that they have the right to submit attested information on behalf of the attestation source.'
    sourceSignature: Optional_['Signature'] = Field(default=None)
    'Signed assertion by the attestation source that they have attested to the information.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    communicationMethod: Optional_['CodeableConcept'] = Field(default=None)
    'The method by which attested information was submitted/retrieved (manual; API; Push).'
    proxyIdentityCertificate: Optional_['string'] = Field(default=None)
    'A digital identity certificate associated with the proxy entity submitting attested information on behalf of the attestation source.'
    sourceIdentityCertificate: Optional_['string'] = Field(default=None)
    'A digital identity certificate associated with the attestation source.'
    date: Optional_['date'] = Field(default=None)
    'The date the information was attested to.'


class VerificationResultValidator(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Information about the entity validating information."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    organization: 'Reference' = Field(default=...)
    'Reference to the organization validating information.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    identityCertificate: Optional_['string'] = Field(default=None)
    'A digital identity certificate associated with the validator.'
    attestationSignature: Optional_['Signature'] = Field(default=None)
    'Signed assertion by the validator that they have validated the information.'


class VerificationResult(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Describes validation requirements, source(s), status and dates for one or more elements."""
    resourceType: Literal_['VerificationResult'] = Field(default=...)
    'Describes validation requirements, source(s), status and dates for one or more elements'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    need: Optional_['CodeableConcept'] = Field(default=None)
    'The frequency with which the target must be validated (none; initial; periodic).'
    target: List_['Reference'] = Field(default_factory=list)
    'A resource that was validated.'
    status: 'code' = Field(default=...)
    'The validation status of the target (attested; validated; in process; requires revalidation; validation failed; revalidation failed).'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    frequency: Optional_['Timing'] = Field(default=None)
    'Frequency of revalidation.'
    validator: List_['VerificationResultValidator'] = Field(default_factory=list)
    'Information about the entity validating information.'
    statusDate: Optional_['dateTime'] = Field(default=None)
    'When the validation status was updated.'
    attestation: Optional_['VerificationResultAttestation'] = Field(default=None)
    'Information about the entity attesting to information.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    lastPerformed: Optional_['dateTime'] = Field(default=None)
    'The date/time validation was last completed (including failed validations).'
    nextScheduled: Optional_['date'] = Field(default=None)
    'The date when target is next validated, if appropriate.'
    failureAction: Optional_['CodeableConcept'] = Field(default=None)
    'The result if validation fails (fatal; warning; record only; none).'
    primarySource: List_['VerificationResultPrimarySource'] = Field(default_factory=list)
    'Information about the primary source(s) involved in validation.'
    targetLocation: List_['string'] = Field(default_factory=list)
    'The fhirpath location(s) within the resource that was validated.'
    validationType: Optional_['CodeableConcept'] = Field(default=None)
    'What the target is validated against (nothing; primary source; multiple sources).'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    validationProcess: List_['CodeableConcept'] = Field(default_factory=list)
    'The primary process by which the target is validated (edit check; value set; primary source; multiple sources; standalone; in context).'


class VisionPrescriptionLensSpecification(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Contain the details of  the individual lens specifications and serves as the authorization for the fullfillment by certified professionals."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    eye: 'code' = Field(default=...)
    'The eye for which the lens specification applies.'
    add: Optional_['decimal'] = Field(default=None)
    'Power adjustment for multifocal lenses measured in dioptres (0.25 units).'
    axis: Optional_['integer'] = Field(default=None)
    'Adjustment for astigmatism measured in integer degrees.'
    note: List_['Annotation'] = Field(default_factory=list)
    'Notes for special requirements such as coatings and lens materials.'
    prism: List_['VisionPrescriptionLensSpecificationPrism'] = Field(default_factory=list)
    'Allows for adjustment on two axis.'
    power: Optional_['decimal'] = Field(default=None)
    'Contact lens power measured in dioptres (0.25 units).'
    color: Optional_['string'] = Field(default=None)
    'Special color or pattern.'
    brand: Optional_['string'] = Field(default=None)
    'Brand recommendations or restrictions.'
    sphere: Optional_['decimal'] = Field(default=None)
    'Lens power measured in dioptres (0.25 units).'
    product: 'CodeableConcept' = Field(default=...)
    'Identifies the type of vision correction product which is required for the patient.'
    cylinder: Optional_['decimal'] = Field(default=None)
    'Power adjustment for astigmatism measured in dioptres (0.25 units).'
    diameter: Optional_['decimal'] = Field(default=None)
    'Contact lens diameter measured in millimetres.'
    duration: Optional_['Quantity'] = Field(default=None)
    'The recommended maximum wear period for the lens.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    backCurve: Optional_['decimal'] = Field(default=None)
    'Back curvature measured in millimetres.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class VisionPrescriptionLensSpecificationPrism(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """Allows for adjustment on two axis."""
    id: Optional_['str'] = Field(default=None)
    'Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.'
    base: 'code' = Field(default=...)
    'The relative base, or reference lens edge, for the prism.'
    amount: 'decimal' = Field(default=...)
    'Amount of prism to compensate for eye alignment in fractional units.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."


class VisionPrescription(BaseModel, extra=Extra.ignore, validate_assignment=True):
    """An authorization for the provision of glasses and/or contact lenses to a patient."""
    resourceType: Literal_['VisionPrescription'] = Field(default=...)
    'Prescription for vision correction products for a patient'
    id: Optional_['str'] = Field(default=None)
    'The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.'
    meta: Optional_['Meta'] = Field(default=None)
    'The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.'
    text: Optional_['Narrative'] = Field(default=None)
    'A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it "clinically safe" for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.'
    status: 'code' = Field(default=...)
    'The status of the resource instance.'
    created: 'dateTime' = Field(default=...)
    'The date this resource was created.'
    patient: 'Reference' = Field(default=...)
    'A resource reference to the person to whom the vision prescription applies.'
    language: Optional_['code'] = Field(default=None)
    'The base language in which the resource is written.'
    contained: List_['AnyResource'] = Field(default_factory=list)
    'These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.'
    extension: List_['Extension'] = Field(default_factory=list)
    'May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.'
    encounter: Optional_['Reference'] = Field(default=None)
    'A reference to a resource that identifies the particular occurrence of contact between patient and health care provider during which the prescription was issued.'
    identifier: List_['Identifier'] = Field(default_factory=list)
    'A unique identifier assigned to this vision prescription.'
    prescriber: 'Reference' = Field(default=...)
    'The healthcare professional responsible for authorizing the prescription.'
    dateWritten: 'dateTime' = Field(default=...)
    'The date (and perhaps time) when the prescription was written.'
    implicitRules: Optional_['uri'] = Field(default=None)
    'A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.'
    modifierExtension: List_['Extension'] = Field(default_factory=list)
    "May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself)."
    lensSpecification: List_['VisionPrescriptionLensSpecification'] = Field(default=...)
    'Contain the details of  the individual lens specifications and serves as the authorization for the fullfillment by certified professionals.'


AnyResource = Annotated_[Account | ActivityDefinition | AdministrableProductDefinition | AdverseEvent | AllergyIntolerance | Appointment | AppointmentResponse | AuditEvent | Basic | Binary | BiologicallyDerivedProduct | BodyStructure | Bundle | CapabilityStatement | CarePlan | CareTeam | CatalogEntry | ChargeItem | ChargeItemDefinition | Citation | Claim | ClaimResponse | ClinicalImpression | ClinicalUseDefinition | CodeSystem | Communication | CommunicationRequest | CompartmentDefinition | Composition | ConceptMap | Condition | Consent | Contract | Coverage | CoverageEligibilityRequest | CoverageEligibilityResponse | DetectedIssue | Device | DeviceDefinition | DeviceMetric | DeviceRequest | DeviceUseStatement | DiagnosticReport | DocumentManifest | DocumentReference | Encounter | Endpoint | EnrollmentRequest | EnrollmentResponse | EpisodeOfCare | EventDefinition | Evidence | EvidenceReport | EvidenceVariable | ExampleScenario | ExplanationOfBenefit | FamilyMemberHistory | Flag | Goal | GraphDefinition | Group | GuidanceResponse | HealthcareService | ImagingStudy | Immunization | ImmunizationEvaluation | ImmunizationRecommendation | ImplementationGuide | Ingredient | InsurancePlan | Invoice | Library | Linkage | List | Location | ManufacturedItemDefinition | Measure | MeasureReport | Media | Medication | MedicationAdministration | MedicationDispense | MedicationKnowledge | MedicationRequest | MedicationStatement | MedicinalProductDefinition | MessageDefinition | MessageHeader | MolecularSequence | NamingSystem | NutritionOrder | NutritionProduct | Observation | ObservationDefinition | OperationDefinition | OperationOutcome | Organization | OrganizationAffiliation | PackagedProductDefinition | Parameters | Patient | PaymentNotice | PaymentReconciliation | Person | PlanDefinition | Practitioner | PractitionerRole | Procedure | Provenance | Questionnaire | QuestionnaireResponse | RegulatedAuthorization | RelatedPerson | RequestGroup | ResearchDefinition | ResearchElementDefinition | ResearchStudy | ResearchSubject | RiskAssessment | Schedule | SearchParameter | ServiceRequest | Slot | Specimen | SpecimenDefinition | StructureDefinition | StructureMap | Subscription | SubscriptionStatus | SubscriptionTopic | Substance | SubstanceDefinition | SupplyDelivery | SupplyRequest | Task | TerminologyCapabilities | TestReport | TestScript | ValueSet | VerificationResult | VisionPrescription, Field(..., discriminator='resourceType')]


Element.update_forward_refs()


BackboneElement.update_forward_refs()


Address.update_forward_refs()


Age.update_forward_refs()


Annotation.update_forward_refs()


Attachment.update_forward_refs()


CodeableConcept.update_forward_refs()


CodeableReference.update_forward_refs()


Coding.update_forward_refs()


ContactDetail.update_forward_refs()


ContactPoint.update_forward_refs()


Contributor.update_forward_refs()


Count.update_forward_refs()


DataRequirementDateFilter.update_forward_refs()


DataRequirementCodeFilter.update_forward_refs()


DataRequirementSort.update_forward_refs()


DataRequirement.update_forward_refs()


Distance.update_forward_refs()


DosageDoseAndRate.update_forward_refs()


Dosage.update_forward_refs()


Duration.update_forward_refs()


ElementDefinitionConstraint.update_forward_refs()


ElementDefinitionMapping.update_forward_refs()


ElementDefinitionBinding.update_forward_refs()


ElementDefinitionExample.update_forward_refs()


ElementDefinitionSlicing.update_forward_refs()


ElementDefinitionSlicingDiscriminator.update_forward_refs()


ElementDefinitionType.update_forward_refs()


ElementDefinitionBase.update_forward_refs()


ElementDefinition.update_forward_refs()


Expression.update_forward_refs()


Extension.update_forward_refs()


HumanName.update_forward_refs()


Identifier.update_forward_refs()


MarketingStatus.update_forward_refs()


Meta.update_forward_refs()


Money.update_forward_refs()


Narrative.update_forward_refs()


ParameterDefinition.update_forward_refs()


Period.update_forward_refs()


Population.update_forward_refs()


ProdCharacteristic.update_forward_refs()


ProductShelfLife.update_forward_refs()


Quantity.update_forward_refs()


Range.update_forward_refs()


Ratio.update_forward_refs()


RatioRange.update_forward_refs()


Reference.update_forward_refs()


RelatedArtifact.update_forward_refs()


SampledData.update_forward_refs()


Signature.update_forward_refs()


TimingRepeat.update_forward_refs()


Timing.update_forward_refs()


TriggerDefinition.update_forward_refs()


UsageContext.update_forward_refs()


MoneyQuantity.update_forward_refs()


SimpleQuantity.update_forward_refs()


Resource.update_forward_refs()


AccountGuarantor.update_forward_refs()


AccountCoverage.update_forward_refs()


Account.update_forward_refs()


ActivityDefinitionDynamicValue.update_forward_refs()


ActivityDefinitionParticipant.update_forward_refs()


ActivityDefinition.update_forward_refs()


AdministrableProductDefinitionRouteOfAdministration.update_forward_refs()


AdministrableProductDefinitionRouteOfAdministrationTargetSpecies.update_forward_refs()


AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriod.update_forward_refs()


AdministrableProductDefinitionProperty.update_forward_refs()


AdministrableProductDefinition.update_forward_refs()


AdverseEventSuspectEntity.update_forward_refs()


AdverseEventSuspectEntityCausality.update_forward_refs()


AdverseEvent.update_forward_refs()


AllergyIntoleranceReaction.update_forward_refs()


AllergyIntolerance.update_forward_refs()


AppointmentParticipant.update_forward_refs()


Appointment.update_forward_refs()


AppointmentResponse.update_forward_refs()


AuditEventEntity.update_forward_refs()


AuditEventEntityDetail.update_forward_refs()


AuditEventSource.update_forward_refs()


AuditEventAgent.update_forward_refs()


AuditEventAgentNetwork.update_forward_refs()


AuditEvent.update_forward_refs()


Basic.update_forward_refs()


Binary.update_forward_refs()


BiologicallyDerivedProductManipulation.update_forward_refs()


BiologicallyDerivedProductProcessing.update_forward_refs()


BiologicallyDerivedProductCollection.update_forward_refs()


BiologicallyDerivedProductStorage.update_forward_refs()


BiologicallyDerivedProduct.update_forward_refs()


BodyStructure.update_forward_refs()


BundleEntry.update_forward_refs()


BundleEntryResponse.update_forward_refs()


BundleEntryRequest.update_forward_refs()


BundleEntrySearch.update_forward_refs()


BundleLink.update_forward_refs()


Bundle.update_forward_refs()


CapabilityStatementImplementation.update_forward_refs()


CapabilityStatementMessaging.update_forward_refs()


CapabilityStatementMessagingSupportedMessage.update_forward_refs()


CapabilityStatementMessagingEndpoint.update_forward_refs()


CapabilityStatementDocument.update_forward_refs()


CapabilityStatementSoftware.update_forward_refs()


CapabilityStatementRest.update_forward_refs()


CapabilityStatementRestInteraction.update_forward_refs()


CapabilityStatementRestResource.update_forward_refs()


CapabilityStatementRestResourceSearchParam.update_forward_refs()


CapabilityStatementRestResourceInteraction.update_forward_refs()


CapabilityStatementRestResourceOperation.update_forward_refs()


CapabilityStatementRestSecurity.update_forward_refs()


CapabilityStatement.update_forward_refs()


CarePlanActivity.update_forward_refs()


CarePlanActivityDetail.update_forward_refs()


CarePlan.update_forward_refs()


CareTeamParticipant.update_forward_refs()


CareTeam.update_forward_refs()


CatalogEntryRelatedEntry.update_forward_refs()


CatalogEntry.update_forward_refs()


ChargeItemPerformer.update_forward_refs()


ChargeItem.update_forward_refs()


ChargeItemDefinitionPropertyGroup.update_forward_refs()


ChargeItemDefinitionPropertyGroupPriceComponent.update_forward_refs()


ChargeItemDefinitionApplicability.update_forward_refs()


ChargeItemDefinition.update_forward_refs()


CitationClassification.update_forward_refs()


CitationCitedArtifact.update_forward_refs()


CitationCitedArtifactContributorship.update_forward_refs()


CitationCitedArtifactContributorshipSummary.update_forward_refs()


CitationCitedArtifactContributorshipEntry.update_forward_refs()


CitationCitedArtifactContributorshipEntryContributionInstance.update_forward_refs()


CitationCitedArtifactContributorshipEntryAffiliationInfo.update_forward_refs()


CitationCitedArtifactPublicationForm.update_forward_refs()


CitationCitedArtifactPublicationFormPeriodicRelease.update_forward_refs()


CitationCitedArtifactPublicationFormPeriodicReleaseDateOfPublication.update_forward_refs()


CitationCitedArtifactPublicationFormPublishedIn.update_forward_refs()


CitationCitedArtifactClassification.update_forward_refs()


CitationCitedArtifactClassificationWhoClassified.update_forward_refs()


CitationCitedArtifactWebLocation.update_forward_refs()


CitationCitedArtifactStatusDate.update_forward_refs()


CitationCitedArtifactRelatesTo.update_forward_refs()


CitationCitedArtifactAbstract.update_forward_refs()


CitationCitedArtifactVersion.update_forward_refs()


CitationCitedArtifactTitle.update_forward_refs()


CitationCitedArtifactPart.update_forward_refs()


CitationStatusDate.update_forward_refs()


CitationRelatesTo.update_forward_refs()


CitationSummary.update_forward_refs()


Citation.update_forward_refs()


ClaimSupportingInfo.update_forward_refs()


ClaimInsurance.update_forward_refs()


ClaimProcedure.update_forward_refs()


ClaimDiagnosis.update_forward_refs()


ClaimAccident.update_forward_refs()


ClaimCareTeam.update_forward_refs()


ClaimRelated.update_forward_refs()


ClaimPayee.update_forward_refs()


ClaimItem.update_forward_refs()


ClaimItemDetail.update_forward_refs()


ClaimItemDetailSubDetail.update_forward_refs()


Claim.update_forward_refs()


ClaimResponseProcessNote.update_forward_refs()


ClaimResponseInsurance.update_forward_refs()


ClaimResponsePayment.update_forward_refs()


ClaimResponseAddItem.update_forward_refs()


ClaimResponseAddItemDetail.update_forward_refs()


ClaimResponseAddItemDetailSubDetail.update_forward_refs()


ClaimResponseError.update_forward_refs()


ClaimResponseTotal.update_forward_refs()


ClaimResponseItem.update_forward_refs()


ClaimResponseItemAdjudication.update_forward_refs()


ClaimResponseItemDetail.update_forward_refs()


ClaimResponseItemDetailSubDetail.update_forward_refs()


ClaimResponse.update_forward_refs()


ClinicalImpressionInvestigation.update_forward_refs()


ClinicalImpressionFinding.update_forward_refs()


ClinicalImpression.update_forward_refs()


ClinicalUseDefinitionUndesirableEffect.update_forward_refs()


ClinicalUseDefinitionContraindication.update_forward_refs()


ClinicalUseDefinitionContraindicationOtherTherapy.update_forward_refs()


ClinicalUseDefinitionInteraction.update_forward_refs()


ClinicalUseDefinitionInteractionInteractant.update_forward_refs()


ClinicalUseDefinitionIndication.update_forward_refs()


ClinicalUseDefinitionWarning.update_forward_refs()


ClinicalUseDefinition.update_forward_refs()


CodeSystemProperty.update_forward_refs()


CodeSystemConcept.update_forward_refs()


CodeSystemConceptDesignation.update_forward_refs()


CodeSystemConceptProperty.update_forward_refs()


CodeSystemFilter.update_forward_refs()


CodeSystem.update_forward_refs()


CommunicationPayload.update_forward_refs()


Communication.update_forward_refs()


CommunicationRequestPayload.update_forward_refs()


CommunicationRequest.update_forward_refs()


CompartmentDefinitionResource.update_forward_refs()


CompartmentDefinition.update_forward_refs()


CompositionRelatesTo.update_forward_refs()


CompositionAttester.update_forward_refs()


CompositionSection.update_forward_refs()


CompositionEvent.update_forward_refs()


Composition.update_forward_refs()


ConceptMapGroup.update_forward_refs()


ConceptMapGroupUnmapped.update_forward_refs()


ConceptMapGroupElement.update_forward_refs()


ConceptMapGroupElementTarget.update_forward_refs()


ConceptMapGroupElementTargetDependsOn.update_forward_refs()


ConceptMap.update_forward_refs()


ConditionEvidence.update_forward_refs()


ConditionStage.update_forward_refs()


Condition.update_forward_refs()


ConsentVerification.update_forward_refs()


ConsentProvision.update_forward_refs()


ConsentProvisionActor.update_forward_refs()


ConsentProvisionData.update_forward_refs()


ConsentPolicy.update_forward_refs()


Consent.update_forward_refs()


ContractContentDefinition.update_forward_refs()


ContractFriendly.update_forward_refs()


ContractSigner.update_forward_refs()


ContractLegal.update_forward_refs()


ContractRule.update_forward_refs()


ContractTerm.update_forward_refs()


ContractTermSecurityLabel.update_forward_refs()


ContractTermAction.update_forward_refs()


ContractTermActionSubject.update_forward_refs()


ContractTermAsset.update_forward_refs()


ContractTermAssetValuedItem.update_forward_refs()


ContractTermAssetContext.update_forward_refs()


ContractTermOffer.update_forward_refs()


ContractTermOfferAnswer.update_forward_refs()


ContractTermOfferParty.update_forward_refs()


Contract.update_forward_refs()


CoverageCostToBeneficiary.update_forward_refs()


CoverageCostToBeneficiaryException.update_forward_refs()


CoverageClass.update_forward_refs()


Coverage.update_forward_refs()


CoverageEligibilityRequestSupportingInfo.update_forward_refs()


CoverageEligibilityRequestInsurance.update_forward_refs()


CoverageEligibilityRequestItem.update_forward_refs()


CoverageEligibilityRequestItemDiagnosis.update_forward_refs()


CoverageEligibilityRequest.update_forward_refs()


CoverageEligibilityResponseInsurance.update_forward_refs()


CoverageEligibilityResponseInsuranceItem.update_forward_refs()


CoverageEligibilityResponseInsuranceItemBenefit.update_forward_refs()


CoverageEligibilityResponseError.update_forward_refs()


CoverageEligibilityResponse.update_forward_refs()


DetectedIssueMitigation.update_forward_refs()


DetectedIssueEvidence.update_forward_refs()


DetectedIssue.update_forward_refs()


DeviceSpecialization.update_forward_refs()


DeviceDeviceName.update_forward_refs()


DeviceUdiCarrier.update_forward_refs()


DeviceProperty.update_forward_refs()


DeviceVersion.update_forward_refs()


Device.update_forward_refs()


DeviceDefinitionUdiDeviceIdentifier.update_forward_refs()


DeviceDefinitionSpecialization.update_forward_refs()


DeviceDefinitionCapability.update_forward_refs()


DeviceDefinitionDeviceName.update_forward_refs()


DeviceDefinitionMaterial.update_forward_refs()


DeviceDefinitionProperty.update_forward_refs()


DeviceDefinition.update_forward_refs()


DeviceMetricCalibration.update_forward_refs()


DeviceMetric.update_forward_refs()


DeviceRequestParameter.update_forward_refs()


DeviceRequest.update_forward_refs()


DeviceUseStatement.update_forward_refs()


DiagnosticReportMedia.update_forward_refs()


DiagnosticReport.update_forward_refs()


DocumentManifestRelated.update_forward_refs()


DocumentManifest.update_forward_refs()


DocumentReferenceRelatesTo.update_forward_refs()


DocumentReferenceContext.update_forward_refs()


DocumentReferenceContent.update_forward_refs()


DocumentReference.update_forward_refs()


DomainResource.update_forward_refs()


EncounterHospitalization.update_forward_refs()


EncounterStatusHistory.update_forward_refs()


EncounterClassHistory.update_forward_refs()


EncounterParticipant.update_forward_refs()


EncounterDiagnosis.update_forward_refs()


EncounterLocation.update_forward_refs()


Encounter.update_forward_refs()


Endpoint.update_forward_refs()


EnrollmentRequest.update_forward_refs()


EnrollmentResponse.update_forward_refs()


EpisodeOfCareStatusHistory.update_forward_refs()


EpisodeOfCareDiagnosis.update_forward_refs()


EpisodeOfCare.update_forward_refs()


EventDefinition.update_forward_refs()


EvidenceVariableDefinition.update_forward_refs()


EvidenceCertainty.update_forward_refs()


EvidenceStatistic.update_forward_refs()


EvidenceStatisticModelCharacteristic.update_forward_refs()


EvidenceStatisticModelCharacteristicVariable.update_forward_refs()


EvidenceStatisticAttributeEstimate.update_forward_refs()


EvidenceStatisticSampleSize.update_forward_refs()


Evidence.update_forward_refs()


EvidenceReportRelatesTo.update_forward_refs()


EvidenceReportSection.update_forward_refs()


EvidenceReportSubject.update_forward_refs()


EvidenceReportSubjectCharacteristic.update_forward_refs()


EvidenceReport.update_forward_refs()


EvidenceVariableCharacteristic.update_forward_refs()


EvidenceVariableCharacteristicTimeFromStart.update_forward_refs()


EvidenceVariableCategory.update_forward_refs()


EvidenceVariable.update_forward_refs()


ExampleScenarioInstance.update_forward_refs()


ExampleScenarioInstanceContainedInstance.update_forward_refs()


ExampleScenarioInstanceVersion.update_forward_refs()


ExampleScenarioProcess.update_forward_refs()


ExampleScenarioProcessStep.update_forward_refs()


ExampleScenarioProcessStepAlternative.update_forward_refs()


ExampleScenarioProcessStepOperation.update_forward_refs()


ExampleScenarioActor.update_forward_refs()


ExampleScenario.update_forward_refs()


ExplanationOfBenefitBenefitBalance.update_forward_refs()


ExplanationOfBenefitBenefitBalanceFinancial.update_forward_refs()


ExplanationOfBenefitSupportingInfo.update_forward_refs()


ExplanationOfBenefitProcessNote.update_forward_refs()


ExplanationOfBenefitInsurance.update_forward_refs()


ExplanationOfBenefitProcedure.update_forward_refs()


ExplanationOfBenefitDiagnosis.update_forward_refs()


ExplanationOfBenefitAccident.update_forward_refs()


ExplanationOfBenefitCareTeam.update_forward_refs()


ExplanationOfBenefitPayment.update_forward_refs()


ExplanationOfBenefitAddItem.update_forward_refs()


ExplanationOfBenefitAddItemDetail.update_forward_refs()


ExplanationOfBenefitAddItemDetailSubDetail.update_forward_refs()


ExplanationOfBenefitRelated.update_forward_refs()


ExplanationOfBenefitTotal.update_forward_refs()


ExplanationOfBenefitPayee.update_forward_refs()


ExplanationOfBenefitItem.update_forward_refs()


ExplanationOfBenefitItemAdjudication.update_forward_refs()


ExplanationOfBenefitItemDetail.update_forward_refs()


ExplanationOfBenefitItemDetailSubDetail.update_forward_refs()


ExplanationOfBenefit.update_forward_refs()


FamilyMemberHistoryCondition.update_forward_refs()


FamilyMemberHistory.update_forward_refs()


Flag.update_forward_refs()


GoalTarget.update_forward_refs()


Goal.update_forward_refs()


GraphDefinitionLink.update_forward_refs()


GraphDefinitionLinkTarget.update_forward_refs()


GraphDefinitionLinkTargetCompartment.update_forward_refs()


GraphDefinition.update_forward_refs()


GroupCharacteristic.update_forward_refs()


GroupMember.update_forward_refs()


Group.update_forward_refs()


GuidanceResponse.update_forward_refs()


HealthcareServiceAvailableTime.update_forward_refs()


HealthcareServiceNotAvailable.update_forward_refs()


HealthcareServiceEligibility.update_forward_refs()


HealthcareService.update_forward_refs()


ImagingStudySeries.update_forward_refs()


ImagingStudySeriesPerformer.update_forward_refs()


ImagingStudySeriesInstance.update_forward_refs()


ImagingStudy.update_forward_refs()


ImmunizationProtocolApplied.update_forward_refs()


ImmunizationEducation.update_forward_refs()


ImmunizationPerformer.update_forward_refs()


ImmunizationReaction.update_forward_refs()


Immunization.update_forward_refs()


ImmunizationEvaluation.update_forward_refs()


ImmunizationRecommendationRecommendation.update_forward_refs()


ImmunizationRecommendationRecommendationDateCriterion.update_forward_refs()


ImmunizationRecommendation.update_forward_refs()


ImplementationGuideDefinition.update_forward_refs()


ImplementationGuideDefinitionParameter.update_forward_refs()


ImplementationGuideDefinitionTemplate.update_forward_refs()


ImplementationGuideDefinitionResource.update_forward_refs()


ImplementationGuideDefinitionGrouping.update_forward_refs()


ImplementationGuideDefinitionPage.update_forward_refs()


ImplementationGuideDependsOn.update_forward_refs()


ImplementationGuideManifest.update_forward_refs()


ImplementationGuideManifestResource.update_forward_refs()


ImplementationGuideManifestPage.update_forward_refs()


ImplementationGuideGlobal.update_forward_refs()


ImplementationGuide.update_forward_refs()


IngredientManufacturer.update_forward_refs()


IngredientSubstance.update_forward_refs()


IngredientSubstanceStrength.update_forward_refs()


IngredientSubstanceStrengthReferenceStrength.update_forward_refs()


Ingredient.update_forward_refs()


InsurancePlanCoverage.update_forward_refs()


InsurancePlanCoverageBenefit.update_forward_refs()


InsurancePlanCoverageBenefitLimit.update_forward_refs()


InsurancePlanContact.update_forward_refs()


InsurancePlanPlan.update_forward_refs()


InsurancePlanPlanSpecificCost.update_forward_refs()


InsurancePlanPlanSpecificCostBenefit.update_forward_refs()


InsurancePlanPlanSpecificCostBenefitCost.update_forward_refs()


InsurancePlanPlanGeneralCost.update_forward_refs()


InsurancePlan.update_forward_refs()


InvoiceParticipant.update_forward_refs()


InvoiceLineItem.update_forward_refs()


InvoiceLineItemPriceComponent.update_forward_refs()


Invoice.update_forward_refs()


Library.update_forward_refs()


LinkageItem.update_forward_refs()


Linkage.update_forward_refs()


ListEntry.update_forward_refs()


List.update_forward_refs()


LocationHoursOfOperation.update_forward_refs()


LocationPosition.update_forward_refs()


Location.update_forward_refs()


ManufacturedItemDefinitionProperty.update_forward_refs()


ManufacturedItemDefinition.update_forward_refs()


MeasureSupplementalData.update_forward_refs()


MeasureGroup.update_forward_refs()


MeasureGroupStratifier.update_forward_refs()


MeasureGroupStratifierComponent.update_forward_refs()


MeasureGroupPopulation.update_forward_refs()


Measure.update_forward_refs()


MeasureReportGroup.update_forward_refs()


MeasureReportGroupStratifier.update_forward_refs()


MeasureReportGroupStratifierStratum.update_forward_refs()


MeasureReportGroupStratifierStratumPopulation.update_forward_refs()


MeasureReportGroupStratifierStratumComponent.update_forward_refs()


MeasureReportGroupPopulation.update_forward_refs()


MeasureReport.update_forward_refs()


Media.update_forward_refs()


MedicationIngredient.update_forward_refs()


MedicationBatch.update_forward_refs()


Medication.update_forward_refs()


MedicationAdministrationPerformer.update_forward_refs()


MedicationAdministrationDosage.update_forward_refs()


MedicationAdministration.update_forward_refs()


MedicationDispenseSubstitution.update_forward_refs()


MedicationDispensePerformer.update_forward_refs()


MedicationDispense.update_forward_refs()


MedicationKnowledgeRelatedMedicationKnowledge.update_forward_refs()


MedicationKnowledgeAdministrationGuidelines.update_forward_refs()


MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics.update_forward_refs()


MedicationKnowledgeAdministrationGuidelinesDosage.update_forward_refs()


MedicationKnowledgeMedicineClassification.update_forward_refs()


MedicationKnowledgeDrugCharacteristic.update_forward_refs()


MedicationKnowledgeMonitoringProgram.update_forward_refs()


MedicationKnowledgeRegulatory.update_forward_refs()


MedicationKnowledgeRegulatorySubstitution.update_forward_refs()


MedicationKnowledgeRegulatoryMaxDispense.update_forward_refs()


MedicationKnowledgeRegulatorySchedule.update_forward_refs()


MedicationKnowledgeIngredient.update_forward_refs()


MedicationKnowledgePackaging.update_forward_refs()


MedicationKnowledgeMonograph.update_forward_refs()


MedicationKnowledgeKinetics.update_forward_refs()


MedicationKnowledgeCost.update_forward_refs()


MedicationKnowledge.update_forward_refs()


MedicationRequestDispenseRequest.update_forward_refs()


MedicationRequestDispenseRequestInitialFill.update_forward_refs()


MedicationRequestSubstitution.update_forward_refs()


MedicationRequest.update_forward_refs()


MedicationStatement.update_forward_refs()


MedicinalProductDefinitionCharacteristic.update_forward_refs()


MedicinalProductDefinitionCrossReference.update_forward_refs()


MedicinalProductDefinitionOperation.update_forward_refs()


MedicinalProductDefinitionContact.update_forward_refs()


MedicinalProductDefinitionName.update_forward_refs()


MedicinalProductDefinitionNameCountryLanguage.update_forward_refs()


MedicinalProductDefinitionNameNamePart.update_forward_refs()


MedicinalProductDefinition.update_forward_refs()


MessageDefinitionAllowedResponse.update_forward_refs()


MessageDefinitionFocus.update_forward_refs()


MessageDefinition.update_forward_refs()


MessageHeaderDestination.update_forward_refs()


MessageHeaderResponse.update_forward_refs()


MessageHeaderSource.update_forward_refs()


MessageHeader.update_forward_refs()


MolecularSequenceStructureVariant.update_forward_refs()


MolecularSequenceStructureVariantInner.update_forward_refs()


MolecularSequenceStructureVariantOuter.update_forward_refs()


MolecularSequenceReferenceSeq.update_forward_refs()


MolecularSequenceRepository.update_forward_refs()


MolecularSequenceQuality.update_forward_refs()


MolecularSequenceQualityRoc.update_forward_refs()


MolecularSequenceVariant.update_forward_refs()


MolecularSequence.update_forward_refs()


NamingSystemUniqueId.update_forward_refs()


NamingSystem.update_forward_refs()


NutritionOrderEnteralFormula.update_forward_refs()


NutritionOrderEnteralFormulaAdministration.update_forward_refs()


NutritionOrderSupplement.update_forward_refs()


NutritionOrderOralDiet.update_forward_refs()


NutritionOrderOralDietNutrient.update_forward_refs()


NutritionOrderOralDietTexture.update_forward_refs()


NutritionOrder.update_forward_refs()


NutritionProductProductCharacteristic.update_forward_refs()


NutritionProductIngredient.update_forward_refs()


NutritionProductInstance.update_forward_refs()


NutritionProductNutrient.update_forward_refs()


NutritionProduct.update_forward_refs()


ObservationReferenceRange.update_forward_refs()


ObservationComponent.update_forward_refs()


Observation.update_forward_refs()


ObservationDefinitionQuantitativeDetails.update_forward_refs()


ObservationDefinitionQualifiedInterval.update_forward_refs()


ObservationDefinition.update_forward_refs()


OperationDefinitionParameter.update_forward_refs()


OperationDefinitionParameterReferencedFrom.update_forward_refs()


OperationDefinitionParameterBinding.update_forward_refs()


OperationDefinitionOverload.update_forward_refs()


OperationDefinition.update_forward_refs()


OperationOutcomeIssue.update_forward_refs()


OperationOutcome.update_forward_refs()


OrganizationContact.update_forward_refs()


Organization.update_forward_refs()


OrganizationAffiliation.update_forward_refs()


PackagedProductDefinitionLegalStatusOfSupply.update_forward_refs()


PackagedProductDefinitionPackage.update_forward_refs()


PackagedProductDefinitionPackageShelfLifeStorage.update_forward_refs()


PackagedProductDefinitionPackageContainedItem.update_forward_refs()


PackagedProductDefinitionPackageProperty.update_forward_refs()


PackagedProductDefinition.update_forward_refs()


ParametersParameter.update_forward_refs()


Parameters.update_forward_refs()


PatientCommunication.update_forward_refs()


PatientContact.update_forward_refs()


PatientLink.update_forward_refs()


Patient.update_forward_refs()


PaymentNotice.update_forward_refs()


PaymentReconciliationProcessNote.update_forward_refs()


PaymentReconciliationDetail.update_forward_refs()


PaymentReconciliation.update_forward_refs()


PersonLink.update_forward_refs()


Person.update_forward_refs()


PlanDefinitionAction.update_forward_refs()


PlanDefinitionActionRelatedAction.update_forward_refs()


PlanDefinitionActionDynamicValue.update_forward_refs()


PlanDefinitionActionParticipant.update_forward_refs()


PlanDefinitionActionCondition.update_forward_refs()


PlanDefinitionGoal.update_forward_refs()


PlanDefinitionGoalTarget.update_forward_refs()


PlanDefinition.update_forward_refs()


PractitionerQualification.update_forward_refs()


Practitioner.update_forward_refs()


PractitionerRoleAvailableTime.update_forward_refs()


PractitionerRoleNotAvailable.update_forward_refs()


PractitionerRole.update_forward_refs()


ProcedureFocalDevice.update_forward_refs()


ProcedurePerformer.update_forward_refs()


Procedure.update_forward_refs()


ProvenanceEntity.update_forward_refs()


ProvenanceAgent.update_forward_refs()


Provenance.update_forward_refs()


QuestionnaireItem.update_forward_refs()


QuestionnaireItemAnswerOption.update_forward_refs()


QuestionnaireItemEnableWhen.update_forward_refs()


QuestionnaireItemInitial.update_forward_refs()


Questionnaire.update_forward_refs()


QuestionnaireResponseItem.update_forward_refs()


QuestionnaireResponseItemAnswer.update_forward_refs()


QuestionnaireResponse.update_forward_refs()


RegulatedAuthorizationCase.update_forward_refs()


RegulatedAuthorization.update_forward_refs()


RelatedPersonCommunication.update_forward_refs()


RelatedPerson.update_forward_refs()


RequestGroupAction.update_forward_refs()


RequestGroupActionRelatedAction.update_forward_refs()


RequestGroupActionCondition.update_forward_refs()


RequestGroup.update_forward_refs()


ResearchDefinition.update_forward_refs()


ResearchElementDefinitionCharacteristic.update_forward_refs()


ResearchElementDefinition.update_forward_refs()


ResearchStudyObjective.update_forward_refs()


ResearchStudyArm.update_forward_refs()


ResearchStudy.update_forward_refs()


ResearchSubject.update_forward_refs()


RiskAssessmentPrediction.update_forward_refs()


RiskAssessment.update_forward_refs()


Schedule.update_forward_refs()


SearchParameterComponent.update_forward_refs()


SearchParameter.update_forward_refs()


ServiceRequest.update_forward_refs()


Slot.update_forward_refs()


SpecimenProcessing.update_forward_refs()


SpecimenCollection.update_forward_refs()


SpecimenContainer.update_forward_refs()


Specimen.update_forward_refs()


SpecimenDefinitionTypeTested.update_forward_refs()


SpecimenDefinitionTypeTestedContainer.update_forward_refs()


SpecimenDefinitionTypeTestedContainerAdditive.update_forward_refs()


SpecimenDefinitionTypeTestedHandling.update_forward_refs()


SpecimenDefinition.update_forward_refs()


StructureDefinitionDifferential.update_forward_refs()


StructureDefinitionSnapshot.update_forward_refs()


StructureDefinitionContext.update_forward_refs()


StructureDefinitionMapping.update_forward_refs()


StructureDefinition.update_forward_refs()


StructureMapStructure.update_forward_refs()


StructureMapGroup.update_forward_refs()


StructureMapGroupInput.update_forward_refs()


StructureMapGroupRule.update_forward_refs()


StructureMapGroupRuleDependent.update_forward_refs()


StructureMapGroupRuleTarget.update_forward_refs()


StructureMapGroupRuleTargetParameter.update_forward_refs()


StructureMapGroupRuleSource.update_forward_refs()


StructureMap.update_forward_refs()


SubscriptionChannel.update_forward_refs()


Subscription.update_forward_refs()


SubscriptionStatusNotificationEvent.update_forward_refs()


SubscriptionStatus.update_forward_refs()


SubscriptionTopicNotificationShape.update_forward_refs()


SubscriptionTopicResourceTrigger.update_forward_refs()


SubscriptionTopicResourceTriggerQueryCriteria.update_forward_refs()


SubscriptionTopicEventTrigger.update_forward_refs()


SubscriptionTopicCanFilterBy.update_forward_refs()


SubscriptionTopic.update_forward_refs()


SubstanceIngredient.update_forward_refs()


SubstanceInstance.update_forward_refs()


Substance.update_forward_refs()


SubstanceDefinitionMolecularWeight.update_forward_refs()


SubstanceDefinitionSourceMaterial.update_forward_refs()


SubstanceDefinitionRelationship.update_forward_refs()


SubstanceDefinitionStructure.update_forward_refs()


SubstanceDefinitionStructureRepresentation.update_forward_refs()


SubstanceDefinitionProperty.update_forward_refs()


SubstanceDefinitionMoiety.update_forward_refs()


SubstanceDefinitionName.update_forward_refs()


SubstanceDefinitionNameOfficial.update_forward_refs()


SubstanceDefinitionCode.update_forward_refs()


SubstanceDefinition.update_forward_refs()


SupplyDeliverySuppliedItem.update_forward_refs()


SupplyDelivery.update_forward_refs()


SupplyRequestParameter.update_forward_refs()


SupplyRequest.update_forward_refs()


TaskRestriction.update_forward_refs()


TaskOutput.update_forward_refs()


TaskInput.update_forward_refs()


Task.update_forward_refs()


TerminologyCapabilitiesImplementation.update_forward_refs()


TerminologyCapabilitiesValidateCode.update_forward_refs()


TerminologyCapabilitiesTranslation.update_forward_refs()


TerminologyCapabilitiesCodeSystem.update_forward_refs()


TerminologyCapabilitiesCodeSystemVersion.update_forward_refs()


TerminologyCapabilitiesCodeSystemVersionFilter.update_forward_refs()


TerminologyCapabilitiesExpansion.update_forward_refs()


TerminologyCapabilitiesExpansionParameter.update_forward_refs()


TerminologyCapabilitiesSoftware.update_forward_refs()


TerminologyCapabilitiesClosure.update_forward_refs()


TerminologyCapabilities.update_forward_refs()


TestReportParticipant.update_forward_refs()


TestReportTeardown.update_forward_refs()


TestReportTeardownAction.update_forward_refs()


TestReportSetup.update_forward_refs()


TestReportSetupAction.update_forward_refs()


TestReportSetupActionOperation.update_forward_refs()


TestReportSetupActionAssert.update_forward_refs()


TestReportTest.update_forward_refs()


TestReportTestAction.update_forward_refs()


TestReport.update_forward_refs()


TestScriptDestination.update_forward_refs()


TestScriptTeardown.update_forward_refs()


TestScriptTeardownAction.update_forward_refs()


TestScriptVariable.update_forward_refs()


TestScriptMetadata.update_forward_refs()


TestScriptMetadataCapability.update_forward_refs()


TestScriptMetadataLink.update_forward_refs()


TestScriptFixture.update_forward_refs()


TestScriptOrigin.update_forward_refs()


TestScriptSetup.update_forward_refs()


TestScriptSetupAction.update_forward_refs()


TestScriptSetupActionOperation.update_forward_refs()


TestScriptSetupActionOperationRequestHeader.update_forward_refs()


TestScriptSetupActionAssert.update_forward_refs()


TestScriptTest.update_forward_refs()


TestScriptTestAction.update_forward_refs()


TestScript.update_forward_refs()


ValueSetExpansion.update_forward_refs()


ValueSetExpansionParameter.update_forward_refs()


ValueSetExpansionContains.update_forward_refs()


ValueSetCompose.update_forward_refs()


ValueSetComposeInclude.update_forward_refs()


ValueSetComposeIncludeConcept.update_forward_refs()


ValueSetComposeIncludeConceptDesignation.update_forward_refs()


ValueSetComposeIncludeFilter.update_forward_refs()


ValueSet.update_forward_refs()


VerificationResultPrimarySource.update_forward_refs()


VerificationResultAttestation.update_forward_refs()


VerificationResultValidator.update_forward_refs()


VerificationResult.update_forward_refs()


VisionPrescriptionLensSpecification.update_forward_refs()


VisionPrescriptionLensSpecificationPrism.update_forward_refs()


VisionPrescription.update_forward_refs()